zabbix_export:
  version: '7.4'
  template_groups:
    - uuid: a571c0d144b14fd4a87a9d9b2aa9fcd6
      name: Templates/Applications
  host_groups:
    - uuid: a571c0d144b14fd4a87a9d9b2aa9fcd6
      name: Applications
  templates:
    - uuid: 86702e8bc514434e8c914d50c206cb94
      template: 'Apache by HTTP'
      name: 'Apache by HTTP'
      description: |
        This template is designed for the effortless deployment of Apache monitoring by Zabbix via HTTP and doesn't require any external scripts.
        
        The template collects metrics by polling 'mod_status' with HTTP agent remotely.
        
        Setup:
        
        1. See the setup instructions for mod_status:
        https://httpd.apache.org/docs/current/mod/mod_status.html
        
        Check the availability of the module with this command line:
        httpd -M 2>/dev/null | grep status_module
        
        This is an example configuration of the Apache web server:
        
        <Location "/server-status">
          SetHandler server-status
          Require host example.com
        </Location>
        
        2. Set the hostname or IP address of the Apache status page host in the '{$APACHE.STATUS.HOST}' macro. You can also change the status page port in the '{$APACHE.STATUS.PORT}' macro and status page path in the '{$APACHE.STATUS.PATH}' macro if necessary.
        
        You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/384764-discussion-thread-for-official-zabbix-template-apache
        
        Generated by official Zabbix template tool "Templator"
      wizard_ready: 'YES'
      readme: |
        ## Overview
        
        This template is designed for the effortless deployment of Apache monitoring by Zabbix via HTTP and doesn't require any external scripts.
        
        The template collects metrics by polling [`mod_status`](https://httpd.apache.org/docs/current/mod/mod_status.html) with HTTP agent remotely:
        
        ```text
        127.0.0.1
        ServerVersion: Apache/2.4.41 (Unix)
        ServerMPM: event
        Server Built: Aug 14 2019 00:35:10
        CurrentTime: Friday, 16-Aug-2019 12:38:40 UTC
        RestartTime: Wednesday, 14-Aug-2019 07:58:26 UTC
        ParentServerConfigGeneration: 1
        ParentServerMPMGeneration: 0
        ServerUptimeSeconds: 189613
        ServerUptime: 2 days 4 hours 40 minutes 13 seconds
        Load1: 4.60
        Load5: 1.20
        Load15: 0.47
        Total Accesses: 27860
        Total kBytes: 33011
        Total Duration: 54118
        CPUUser: 18.02
        CPUSystem: 31.76
        CPUChildrenUser: 0
        CPUChildrenSystem: 0
        CPULoad: .0262535
        Uptime: 189613
        ReqPerSec: .146931
        BytesPerSec: 178.275
        BytesPerReq: 1213.33
        DurationPerReq: 1.9425
        BusyWorkers: 7
        IdleWorkers: 93
        Processes: 4
        Stopping: 0
        BusyWorkers: 7
        IdleWorkers: 93
        ConnsTotal: 13
        ConnsAsyncWriting: 0
        ConnsAsyncKeepAlive: 5
        ConnsAsyncClosing: 0
        Scoreboard: ...
        ```
        
        ## Setup
        
        1. See the setup instructions for [`mod_status`](https://httpd.apache.org/docs/current/mod/mod_status.html).
        
        Check the availability of the module with this command line:
        `httpd -M 2>/dev/null | grep status_module`
        
        This is an example configuration of the Apache web server:
        
        ```text
        <Location "/server-status">
          SetHandler server-status
          Require host example.com
        </Location>
        ```
        
        2. Set the hostname or IP address of the Apache status page host in the `Apache status host` host wizard configuration field. You can also change the status page port in the `Apache status page port` field and status page path in the `Apache status page path` field if necessary.
      vendor:
        name: Zabbix
        version: 7.4-1
      groups:
        - name: Templates/Applications
      items:
        - uuid: b9fe6f0bbe174e9f81af84a3bc0b0e7c
          name: 'Total bytes'
          type: DEPENDENT
          key: apache.bytes
          value_type: FLOAT
          units: B
          description: 'The total bytes served.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$["Total kBytes"]'
            - type: MULTIPLIER
              parameters:
                - '1024'
          master_item:
            key: apache.get_status
          tags:
            - tag: component
              value: network
        - uuid: b36010be10874cf188eeacc81f2c366f
          name: 'Bytes per second'
          type: DEPENDENT
          key: apache.bytes.rate
          value_type: FLOAT
          units: Bps
          description: |
            It is calculated as a rate of change for total bytes statistics.
            `BytesPerSec` is not used, as it counts the average since the last Apache server start.
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$["Total kBytes"]'
            - type: MULTIPLIER
              parameters:
                - '1024'
            - type: CHANGE_PER_SECOND
          master_item:
            key: apache.get_status
          tags:
            - tag: component
              value: network
        - uuid: e61be8ad92004100aca55fcedd2a3807
          name: 'Get status'
          type: HTTP_AGENT
          key: apache.get_status
          history: 1h
          value_type: TEXT
          description: |
            Getting data from a machine-readable version of the Apache status page.
            For more information see Apache Module [mod_status](https://httpd.apache.org/docs/current/mod/mod_status.html).
          preprocessing:
            - type: JAVASCRIPT
              parameters:
                - |
                  var lines = value.split('\n');
                  var output = {},
                  	workers = {
                  		'_': 0, 'S': 0, 'R': 0, 'W': 0,
                  		'K': 0, 'D': 0, 'C': 0, 'L': 0,
                  		'G': 0, 'I': 0, '.': 0
                  	};
                  
                  for (var i = 0; i < lines.length; i++) {
                  	var line = lines[i].match(/([A-z0-9 ]+): (.*)/);
                  
                  	if (line !== null) {
                  		output[line[1]] = isNaN(line[2]) ? line[2] : Number(line[2]);
                  	}
                  }
                  
                  output.ServerUptimeSeconds = output.ServerUptimeSeconds || output.Uptime;
                  output.ServerVersion = output.ServerVersion || output.Server;
                  
                  if (typeof output.Scoreboard === 'string') {
                  	for (var i = 0; i < output.Scoreboard.length; i++) {
                  		var char = output.Scoreboard[i];
                  
                  		workers[char]++;
                  	}
                  }
                  
                  output.Workers = {
                  	waiting: workers['_'], starting: workers['S'], reading: workers['R'],
                  	sending: workers['W'], keepalive: workers['K'], dnslookup: workers['D'],
                  	closing: workers['C'], logging: workers['L'], finishing: workers['G'],
                  	cleanup: workers['I'], slot: workers['.']
                  };
                  
                  return JSON.stringify(output);
          url: '{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}'
          retrieve_mode: BOTH
          tags:
            - tag: component
              value: raw
          triggers:
            - uuid: db396445cc5042f89f31dc12cb99c32e
              expression: 'nodata(/Apache by HTTP/apache.get_status,30m)=1'
              name: 'Apache: Failed to fetch status page'
              event_name: 'Apache: Failed to fetch status page (or no data for 30m)'
              priority: WARNING
              description: 'Zabbix has not received any data for items for the last 30 minutes.'
              manual_close: 'YES'
              dependencies:
                - name: 'Apache: Service is down'
                  expression: 'last(/Apache by HTTP/net.tcp.service[http,"{$APACHE.STATUS.HOST}","{$APACHE.STATUS.PORT}"])=0'
              tags:
                - tag: scope
                  value: availability
        - uuid: 5fb5101de70a43fab50d55f418462255
          name: 'Total requests'
          type: DEPENDENT
          key: apache.requests
          description: 'The total number of the Apache server accesses.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$["Total Accesses"]'
          master_item:
            key: apache.get_status
          tags:
            - tag: component
              value: network
        - uuid: ee15f4958040459da53251cc3561ed39
          name: 'Requests per second'
          type: DEPENDENT
          key: apache.requests.rate
          value_type: FLOAT
          description: |
            It is calculated as a rate of change for the "Total requests" statistics.
            `ReqPerSec` is not used, as it counts the average since the last Apache server start.
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$["Total Accesses"]'
            - type: CHANGE_PER_SECOND
          master_item:
            key: apache.get_status
          tags:
            - tag: component
              value: network
        - uuid: 3dd8ba505d584b028c7ac08d8b959eb3
          name: Uptime
          type: DEPENDENT
          key: apache.uptime
          units: uptime
          description: 'The service uptime expressed in seconds.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.ServerUptimeSeconds
          master_item:
            key: apache.get_status
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 76cfa6ebf39f4c8fbd8fde9e0f36d3ed
              expression: 'last(/Apache by HTTP/apache.uptime)<10m'
              name: 'Apache: Service has been restarted'
              event_name: 'Apache: Service has been restarted (uptime < 10m)'
              priority: INFO
              description: 'Uptime is less than 10 minutes.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: fe0de2eb1478482f99b38c13bd20564c
          name: Version
          type: DEPENDENT
          key: apache.version
          value_type: CHAR
          description: 'The Apache service version.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.ServerVersion
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: apache.get_status
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 5296d69af0704d0e8a07398f0b4c9685
              expression: 'last(/Apache by HTTP/apache.version,#1)<>last(/Apache by HTTP/apache.version,#2) and length(last(/Apache by HTTP/apache.version))>0'
              name: 'Apache: Version has changed'
              event_name: 'Apache: Version has changed (new version: {ITEM.VALUE})'
              priority: INFO
              description: 'Apache version has changed. Acknowledge to close the problem manually.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: f74ffb92e30e48958b5b82f7dfbe5147
          name: 'Workers idle cleanup'
          type: DEPENDENT
          key: apache.workers.cleanup
          description: 'The number of workers in cleanup state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.cleanup
          master_item:
            key: apache.get_status
          tags:
            - tag: component
              value: system
        - uuid: d664bee9a330480bbaee7273b871a8d3
          name: 'Workers closing connection'
          type: DEPENDENT
          key: apache.workers.closing
          description: 'The number of workers in closing state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.closing
          master_item:
            key: apache.get_status
          tags:
            - tag: component
              value: system
        - uuid: a6fb3444585749be998ec840cd8e4511
          name: 'Workers DNS lookup'
          type: DEPENDENT
          key: apache.workers.dnslookup
          description: 'The number of workers in `dnslookup` state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.dnslookup
          master_item:
            key: apache.get_status
          tags:
            - tag: component
              value: system
        - uuid: fcf771f2a9b64a81a37db679f0494ed3
          name: 'Workers finishing'
          type: DEPENDENT
          key: apache.workers.finishing
          description: 'The number of workers in finishing state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.finishing
          master_item:
            key: apache.get_status
          tags:
            - tag: component
              value: system
        - uuid: cb81a6a77395444283bc5e065fcbfc2e
          name: 'Workers keepalive (read)'
          type: DEPENDENT
          key: apache.workers.keepalive
          description: 'The number of workers in `keepalive` state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.keepalive
          master_item:
            key: apache.get_status
          tags:
            - tag: component
              value: system
        - uuid: 7fc0002a279b4541af569a03c1aca2ac
          name: 'Workers logging'
          type: DEPENDENT
          key: apache.workers.logging
          description: 'The number of workers in logging state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.logging
          master_item:
            key: apache.get_status
          tags:
            - tag: component
              value: system
        - uuid: 78b0bd7d8bec49549fc003d460af9177
          name: 'Workers reading request'
          type: DEPENDENT
          key: apache.workers.reading
          description: 'The number of workers in reading state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.reading
          master_item:
            key: apache.get_status
          tags:
            - tag: component
              value: system
        - uuid: 379ac66397b94463ad17b24fbd20c615
          name: 'Workers sending reply'
          type: DEPENDENT
          key: apache.workers.sending
          description: 'The number of workers in sending state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.sending
          master_item:
            key: apache.get_status
          tags:
            - tag: component
              value: system
        - uuid: 1c90055e02a244fc8d18e73b23daa0f1
          name: 'Workers slot with no current process'
          type: DEPENDENT
          key: apache.workers.slot
          description: 'The number of slots with no current process.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.slot
          master_item:
            key: apache.get_status
          tags:
            - tag: component
              value: system
        - uuid: ae21ea113e8840349aff81ab582d92b4
          name: 'Workers starting up'
          type: DEPENDENT
          key: apache.workers.starting
          description: 'The number of workers in starting state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.starting
          master_item:
            key: apache.get_status
          tags:
            - tag: component
              value: system
        - uuid: be1a05a6eab84b64ac4d51c966ea91e8
          name: 'Workers waiting for connection'
          type: DEPENDENT
          key: apache.workers.waiting
          description: 'The number of workers in waiting state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.waiting
          master_item:
            key: apache.get_status
          tags:
            - tag: component
              value: system
        - uuid: 1752b9bcf7b34abbaf105f5261638271
          name: 'Total workers busy'
          type: DEPENDENT
          key: apache.workers_total.busy
          description: 'The total number of busy worker threads/processes.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.BusyWorkers
          master_item:
            key: apache.get_status
          tags:
            - tag: component
              value: system
        - uuid: b1b1c86a12964ae2813c63481e464ec7
          name: 'Total workers idle'
          type: DEPENDENT
          key: apache.workers_total.idle
          description: 'The total number of idle worker threads/processes.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.IdleWorkers
          master_item:
            key: apache.get_status
          tags:
            - tag: component
              value: system
        - uuid: 5039d11bc3964d6e9928a0a46dd0b402
          name: 'Service response time'
          type: SIMPLE
          key: 'net.tcp.service.perf[http,"{$APACHE.STATUS.HOST}","{$APACHE.STATUS.PORT}"]'
          value_type: FLOAT
          units: s
          tags:
            - tag: component
              value: application
            - tag: component
              value: health
          triggers:
            - uuid: ffbb564032c7462eb0bb9b4c2f700559
              expression: 'min(/Apache by HTTP/net.tcp.service.perf[http,"{$APACHE.STATUS.HOST}","{$APACHE.STATUS.PORT}"],5m)>{$APACHE.RESPONSE_TIME.MAX.WARN}'
              name: 'Apache: Service response time is too high'
              event_name: 'Apache: Service response time is too high (over {$APACHE.RESPONSE_TIME.MAX.WARN}s for 5m)'
              priority: WARNING
              manual_close: 'YES'
              dependencies:
                - name: 'Apache: Service is down'
                  expression: 'last(/Apache by HTTP/net.tcp.service[http,"{$APACHE.STATUS.HOST}","{$APACHE.STATUS.PORT}"])=0'
              tags:
                - tag: scope
                  value: performance
        - uuid: fb65918695094026838e2b9e4ca00402
          name: 'Service ping'
          type: SIMPLE
          key: 'net.tcp.service[http,"{$APACHE.STATUS.HOST}","{$APACHE.STATUS.PORT}"]'
          valuemap:
            name: 'Service state'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 10m
          tags:
            - tag: component
              value: application
            - tag: component
              value: health
          triggers:
            - uuid: afe2fde35d054333adc8369a0f9af778
              expression: 'last(/Apache by HTTP/net.tcp.service[http,"{$APACHE.STATUS.HOST}","{$APACHE.STATUS.PORT}"])=0'
              name: 'Apache: Service is down'
              priority: AVERAGE
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: availability
      discovery_rules:
        - uuid: eee8abd3174d426092e8bca9b3ba982e
          name: 'Event MPM discovery'
          type: DEPENDENT
          key: apache.mpm.event.discovery
          description: |
            The discovery of additional metrics if the event Multi-Processing Module (MPM) is used.
            For more details see [Apache MPM event](https://httpd.apache.org/docs/current/mod/event.html).
          item_prototypes:
            - uuid: f52700379f9a4ee8b378a2eb9caea070
              name: 'Bytes per request'
              type: DEPENDENT
              key: 'apache.bytes[per_request{#SINGLETON}]'
              value_type: FLOAT
              units: B
              description: 'The average number of client requests per second.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.BytesPerReq
              master_item:
                key: apache.get_status
              tags:
                - tag: component
                  value: connection
            - uuid: 062d7c941f0c468d8b63fa76ae0610f6
              name: 'Connections async closing'
              type: DEPENDENT
              key: 'apache.connections[async_closing{#SINGLETON}]'
              description: 'The number of asynchronous connections in closing state (applicable only to the event MPM).'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.ConnsAsyncClosing
              master_item:
                key: apache.get_status
              tags:
                - tag: component
                  value: connection
            - uuid: 6cb8b255ad8343a48e622912bc298366
              name: 'Connections async keepalive'
              type: DEPENDENT
              key: 'apache.connections[async_keep_alive{#SINGLETON}]'
              description: 'The number of asynchronous connections in keepalive state (applicable only to the event MPM).'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.ConnsAsyncKeepAlive
              master_item:
                key: apache.get_status
              tags:
                - tag: component
                  value: connection
            - uuid: 997b3452aac24ad6afbad775d649c727
              name: 'Connections async writing'
              type: DEPENDENT
              key: 'apache.connections[async_writing{#SINGLETON}]'
              description: 'The number of asynchronous connections in writing state (applicable only to the event MPM).'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.ConnsAsyncWriting
              master_item:
                key: apache.get_status
              tags:
                - tag: component
                  value: connection
            - uuid: 31cb044eed904ca19150921fe36f3285
              name: 'Connections total'
              type: DEPENDENT
              key: 'apache.connections[total{#SINGLETON}]'
              description: 'The number of total connections.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.ConnsTotal
              master_item:
                key: apache.get_status
              tags:
                - tag: component
                  value: connection
            - uuid: 34555340f3ad4b878504df188f54a9c9
              name: 'Number of async processes'
              type: DEPENDENT
              key: 'apache.process[num{#SINGLETON}]'
              description: 'The number of asynchronous processes.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.Processes
              master_item:
                key: apache.get_status
              tags:
                - tag: component
                  value: system
          graph_prototypes:
            - uuid: 066b53ed2244414ca3090498eb035c27
              name: 'Apache: Current async connections{#SINGLETON}'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'Apache by HTTP'
                    key: 'apache.connections[async_closing{#SINGLETON}]'
                - sortorder: '1'
                  color: F63100
                  item:
                    host: 'Apache by HTTP'
                    key: 'apache.connections[async_keep_alive{#SINGLETON}]'
                - sortorder: '2'
                  color: 00611C
                  item:
                    host: 'Apache by HTTP'
                    key: 'apache.connections[async_writing{#SINGLETON}]'
                - sortorder: '3'
                  drawtype: BOLD_LINE
                  color: F7941D
                  item:
                    host: 'Apache by HTTP'
                    key: 'apache.connections[total{#SINGLETON}]'
            - uuid: dbaa0c2468cc40fca977fb382d19cb78
              name: 'Apache: Current async processes{#SINGLETON}'
              graph_items:
                - drawtype: GRADIENT_LINE
                  color: 199C0D
                  item:
                    host: 'Apache by HTTP'
                    key: 'apache.process[num{#SINGLETON}]'
          master_item:
            key: apache.get_status
          preprocessing:
            - type: JAVASCRIPT
              parameters:
                - |
                  return JSON.stringify(JSON.parse(value).ServerMPM === 'event'
                  	? [{'{#SINGLETON}': ''}] : []);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
      tags:
        - tag: class
          value: software
        - tag: subclass
          value: webserver
        - tag: target
          value: apache
      macros:
        - macro: '{$APACHE.RESPONSE_TIME.MAX.WARN}'
          value: '10'
          description: 'The maximum Apache response time expressed in seconds for a trigger expression.'
          config:
            type: TEXT
            priority: '5'
            section_name: Other
            label: 'Maximum Apache response time'
            description: 'Maximum Apache response time expressed in seconds for a trigger expression. No less than 0.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$APACHE.STATUS.HOST}'
          description: 'The hostname or IP address of the Apache status page host.'
          config:
            type: TEXT
            priority: '1'
            label: 'Apache status host'
            description: 'Hostname or IP address of the Apache status page host.'
            required: 'YES'
        - macro: '{$APACHE.STATUS.PATH}'
          value: 'server-status?auto'
          description: 'The URL path of the Apache status page.'
          config:
            type: TEXT
            priority: '3'
            label: 'Apache status page path'
            description: 'URL path of the Apache status page.'
            required: 'YES'
        - macro: '{$APACHE.STATUS.PORT}'
          value: '80'
          description: 'The port of the Apache status page.'
          config:
            type: TEXT
            priority: '2'
            label: 'Apache status page port'
            description: 'In the range from 1 to 65535 inclusive.'
            required: 'YES'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$APACHE.STATUS.SCHEME}'
          value: http
          description: 'The request scheme, which may be either HTTP or HTTPS.'
          config:
            type: LIST
            priority: '4'
            label: 'Request scheme'
            description: 'Request scheme, which may be either HTTP or HTTPS.'
            options:
              - value: http
                text: HTTP
              - value: https
                text: HTTPS
      dashboards:
        - uuid: a328c9e713424465a8e1adec7322b0dc
          name: 'Apache performance'
          pages:
            - name: General
              widgets:
                - type: graph
                  width: '72'
                  height: '7'
                  fields:
                    - type: GRAPH
                      name: graphid.0
                      value:
                        host: 'Apache by HTTP'
                        name: 'Apache: Worker states'
                    - type: STRING
                      name: reference
                      value: AAAAA
                - type: graph
                  'y': '7'
                  width: '36'
                  height: '5'
                  fields:
                    - type: GRAPH
                      name: graphid.0
                      value:
                        host: 'Apache by HTTP'
                        name: 'Apache: Requests per second'
                    - type: STRING
                      name: reference
                      value: AAAAB
                - type: graphprototype
                  'y': '12'
                  width: '36'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'Apache by HTTP'
                        name: 'Apache: Current async connections{#SINGLETON}'
                    - type: STRING
                      name: reference
                      value: AAAAD
                - type: graph
                  x: '36'
                  'y': '7'
                  width: '36'
                  height: '5'
                  fields:
                    - type: GRAPH
                      name: graphid.0
                      value:
                        host: 'Apache by HTTP'
                        name: 'Apache: Workers total'
                    - type: STRING
                      name: reference
                      value: AAAAC
                - type: graphprototype
                  x: '36'
                  'y': '12'
                  width: '36'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'Apache by HTTP'
                        name: 'Apache: Current async processes{#SINGLETON}'
                    - type: STRING
                      name: reference
                      value: AAAAE
      valuemaps:
        - uuid: a5d1f911fb264bd4bc087ea582626d7f
          name: 'Service state'
          mappings:
            - value: '0'
              newvalue: Down
            - value: '1'
              newvalue: Up
    - uuid: a8d91e4f36794e32b73090d5edf3d7ae
      template: 'Apache by Zabbix agent'
      name: 'Apache by Zabbix agent'
      description: |
        Get metrics from mod_status module using HTTP agent.
        https://httpd.apache.org/docs/current/mod/mod_status.html
        
        You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/384764-discussion-thread-for-official-zabbix-template-apache
        
        Generated by official Zabbix template tool "Templator"
      wizard_ready: 'YES'
      readme: |
        ## Overview
        
        This template is designed for the effortless deployment of Apache monitoring by Zabbix via Zabbix agent and doesn't require any external scripts.
        The template `Apache by Zabbix agent` - collects metrics by polling [mod_status](https://httpd.apache.org/docs/current/mod/mod_status.html) locally with Zabbix agent:
          
        ```text
        127.0.0.1
        ServerVersion: Apache/2.4.41 (Unix)
        ServerMPM: event
        Server Built: Aug 14 2019 00:35:10
        CurrentTime: Friday, 16-Aug-2019 12:38:40 UTC
        RestartTime: Wednesday, 14-Aug-2019 07:58:26 UTC
        ParentServerConfigGeneration: 1
        ParentServerMPMGeneration: 0
        ServerUptimeSeconds: 189613
        ServerUptime: 2 days 4 hours 40 minutes 13 seconds
        Load1: 4.60
        Load5: 1.20
        Load15: 0.47
        Total Accesses: 27860
        Total kBytes: 33011
        Total Duration: 54118
        CPUUser: 18.02
        CPUSystem: 31.76
        CPUChildrenUser: 0
        CPUChildrenSystem: 0
        CPULoad: .0262535
        Uptime: 189613
        ReqPerSec: .146931
        BytesPerSec: 178.275
        BytesPerReq: 1213.33
        DurationPerReq: 1.9425
        BusyWorkers: 7
        IdleWorkers: 93
        Processes: 4
        Stopping: 0
        BusyWorkers: 7
        IdleWorkers: 93
        ConnsTotal: 13
        ConnsAsyncWriting: 0
        ConnsAsyncKeepAlive: 5
        ConnsAsyncClosing: 0
        Scoreboard: ...
        
        ```
          
        It also uses Zabbix agent to collect `Apache` Linux process statistics such as CPU usage, memory usage, and whether the process is running or not.
        
        ## Setup
        
        See the setup instructions for [mod_status](https://httpd.apache.org/docs/current/mod/mod_status.html).
        
        Check the availability of the module with this command line: `httpd -M 2>/dev/null | grep status_module`
        
        This is an example configuration of the Apache web server:
        
        ```text
        <Location "/server-status">
          SetHandler server-status
          Require host example.com
        </Location>
        ```
        
        If you use another path, then do not forget to change the `Apache status page path` host wizard configuration field.
      vendor:
        name: Zabbix
        version: 7.4-1
      groups:
        - name: Templates/Applications
      items:
        - uuid: 2d3ebb059bd944ee8a7b95e2c60b08f0
          name: 'Total bytes'
          type: DEPENDENT
          key: apache.bytes
          value_type: FLOAT
          units: B
          description: 'The total bytes served.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$["Total kBytes"]'
            - type: MULTIPLIER
              parameters:
                - '1024'
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: network
        - uuid: be97c53d82f846cdbc2d0ec640435b6f
          name: 'Bytes per second'
          type: DEPENDENT
          key: apache.bytes.rate
          value_type: FLOAT
          units: Bps
          description: |
            It is calculated as a rate of change for total bytes statistics.
            `BytesPerSec` is not used, as it counts the average since the last Apache server start.
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$["Total kBytes"]'
            - type: MULTIPLIER
              parameters:
                - '1024'
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: network
        - uuid: 5919f29c692b468fb5642e83f408c2e5
          name: 'Total requests'
          type: DEPENDENT
          key: apache.requests
          description: 'The total number of the Apache server accesses.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$["Total Accesses"]'
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: network
        - uuid: 7e1e674a23d24fafa31b76a048fe9fd0
          name: 'Requests per second'
          type: DEPENDENT
          key: apache.requests.rate
          value_type: FLOAT
          description: |
            It is calculated as a rate of change for the "Total requests" statistics.
            `ReqPerSec` is not used, as it counts the average since the last Apache server start.
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$["Total Accesses"]'
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: network
        - uuid: 5a4bd2d6c2874d888ec4c82409e1c711
          name: Uptime
          type: DEPENDENT
          key: apache.uptime
          units: uptime
          description: 'The service uptime expressed in seconds.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.ServerUptimeSeconds
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 7872d9665c234f45941ca26206e0255c
              expression: 'last(/Apache by Zabbix agent/apache.uptime)<10m'
              name: 'Apache: Service has been restarted'
              event_name: 'Apache: Service has been restarted (uptime < 10m)'
              priority: INFO
              description: 'Uptime is less than 10 minutes.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: 78a611c2b15c4ae8949257b6fdf922f1
          name: Version
          type: DEPENDENT
          key: apache.version
          value_type: CHAR
          description: 'The Apache service version.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.ServerVersion
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 5124b17918f545758ca5c936332f51cd
              expression: 'last(/Apache by Zabbix agent/apache.version,#1)<>last(/Apache by Zabbix agent/apache.version,#2) and length(last(/Apache by Zabbix agent/apache.version))>0'
              name: 'Apache: Version has changed'
              event_name: 'Apache: Version has changed (new version: {ITEM.VALUE})'
              priority: INFO
              description: 'Apache version has changed. Acknowledge to close the problem manually.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: 35f48761ec6d451bbb8b0d80cd0ccd91
          name: 'Workers idle cleanup'
          type: DEPENDENT
          key: apache.workers.cleanup
          description: 'The number of workers in cleanup state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.cleanup
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: ebd391702cbd432ab458578a3cb45361
          name: 'Workers closing connection'
          type: DEPENDENT
          key: apache.workers.closing
          description: 'The number of workers in closing state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.closing
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: 6a961707e7084d8ebc09f572b15ef1fd
          name: 'Workers DNS lookup'
          type: DEPENDENT
          key: apache.workers.dnslookup
          description: 'The number of workers in `dnslookup` state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.dnslookup
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: fd383c9ace4647deb9d3e3882554b8d0
          name: 'Workers finishing'
          type: DEPENDENT
          key: apache.workers.finishing
          description: 'The number of workers in finishing state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.finishing
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: 2a02413c0e9144b4a70b8a5a71d680e0
          name: 'Workers keepalive (read)'
          type: DEPENDENT
          key: apache.workers.keepalive
          description: 'The number of workers in `keepalive` state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.keepalive
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: ed71fb2ec75f4537a2937293add75274
          name: 'Workers logging'
          type: DEPENDENT
          key: apache.workers.logging
          description: 'The number of workers in logging state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.logging
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: 6c38147f9f3449a194f36a6e6d828865
          name: 'Workers reading request'
          type: DEPENDENT
          key: apache.workers.reading
          description: 'The number of workers in reading state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.reading
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: 47856ac3b68644e0861b593d3083d35b
          name: 'Workers sending reply'
          type: DEPENDENT
          key: apache.workers.sending
          description: 'The number of workers in sending state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.sending
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: 60cf954a40594cf69afdd1bf0319c031
          name: 'Workers slot with no current process'
          type: DEPENDENT
          key: apache.workers.slot
          description: 'The number of slots with no current process.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.slot
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: 441c797164bf4c8da8112d78240abc43
          name: 'Workers starting up'
          type: DEPENDENT
          key: apache.workers.starting
          description: 'The number of workers in starting state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.starting
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: ec87e89ee9304acd8c7a76e863cb4443
          name: 'Workers waiting for connection'
          type: DEPENDENT
          key: apache.workers.waiting
          description: 'The number of workers in waiting state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.waiting
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: b52addb50ccb415fb63eaf67076991c1
          name: 'Total workers busy'
          type: DEPENDENT
          key: apache.workers_total.busy
          description: 'The total number of busy worker threads/processes.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.BusyWorkers
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: 6955f78c203b435987b5ab75a1114867
          name: 'Total workers idle'
          type: DEPENDENT
          key: apache.workers_total.idle
          description: 'The total number of idle worker threads/processes.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.IdleWorkers
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: 267ca6fe038346e5be1113f3bf9b4023
          name: 'Service response time'
          key: 'net.tcp.service.perf[http,"{$APACHE.STATUS.HOST}","{$APACHE.STATUS.PORT}"]'
          value_type: FLOAT
          units: s
          tags:
            - tag: component
              value: application
            - tag: component
              value: health
        - uuid: 369f00e2970048c786ce3bd609e65566
          name: 'Service ping'
          key: 'net.tcp.service[http,"{$APACHE.STATUS.HOST}","{$APACHE.STATUS.PORT}"]'
          valuemap:
            name: 'Service state'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 10m
          tags:
            - tag: component
              value: application
            - tag: component
              value: health
        - uuid: 99b1a38ed45b4212974b0bea72b076d2
          name: 'Get processes summary'
          key: 'proc.get[{$APACHE.PROCESS.NAME.PARAMETER},,,summary]'
          history: '0'
          value_type: TEXT
          description: 'The aggregated data of summary metrics for all processes.'
          tags:
            - tag: component
              value: raw
        - uuid: 115413a0f5ab4caba418ab841ad81eba
          name: 'Get status'
          key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          history: 1h
          value_type: TEXT
          description: |
            Getting data from a machine-readable version of the Apache status page.
            For more information see Apache Module [mod_status](https://httpd.apache.org/docs/current/mod/mod_status.html).
          preprocessing:
            - type: JAVASCRIPT
              parameters:
                - |
                  var lines = value.split('\n');
                  var output = {},
                  	workers = {
                  		'_': 0, 'S': 0, 'R': 0, 'W': 0,
                  		'K': 0, 'D': 0, 'C': 0, 'L': 0,
                  		'G': 0, 'I': 0, '.': 0
                  	};
                  
                  for (var i = 0; i < lines.length; i++) {
                  	var line = lines[i].match(/([A-z0-9 ]+): (.*)/);
                  
                  	if (line !== null) {
                  		output[line[1]] = isNaN(line[2]) ? line[2] : Number(line[2]);
                  	}
                  }
                  
                  output.ServerUptimeSeconds = output.ServerUptimeSeconds || output.Uptime;
                  output.ServerVersion = output.ServerVersion || output.Server;
                  
                  if (typeof output.Scoreboard === 'string') {
                  	for (var i = 0; i < output.Scoreboard.length; i++) {
                  		var char = output.Scoreboard[i];
                  
                  		workers[char]++;
                  	}
                  }
                  
                  output.Workers = {
                  	waiting: workers['_'], starting: workers['S'], reading: workers['R'],
                  	sending: workers['W'], keepalive: workers['K'], dnslookup: workers['D'],
                  	closing: workers['C'], logging: workers['L'], finishing: workers['G'],
                  	cleanup: workers['I'], slot: workers['.']
                  };
                  
                  return JSON.stringify(output);
          tags:
            - tag: component
              value: raw
      discovery_rules:
        - uuid: 36a82bdda7754c51a05da3bb0b65b83e
          name: 'Event MPM discovery'
          type: DEPENDENT
          key: apache.mpm.event.discovery
          description: |
            The discovery of additional metrics if the event Multi-Processing Module (MPM) is used.
            For more details see [Apache MPM event](https://httpd.apache.org/docs/current/mod/event.html).
          item_prototypes:
            - uuid: 99df2ff5970b4497887371bcd16d5ada
              name: 'Bytes per request'
              type: DEPENDENT
              key: 'apache.bytes[per_request{#SINGLETON}]'
              value_type: FLOAT
              units: B
              description: 'The average number of client requests per second.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.BytesPerReq
              master_item:
                key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
              tags:
                - tag: component
                  value: connection
            - uuid: 2e0692f36b924b52ab7b2ff7788b641d
              name: 'Connections async closing'
              type: DEPENDENT
              key: 'apache.connections[async_closing{#SINGLETON}]'
              description: 'The number of asynchronous connections in closing state (applicable only to the event MPM).'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.ConnsAsyncClosing
              master_item:
                key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
              tags:
                - tag: component
                  value: connection
            - uuid: 33d3fec8f45c493097bab986d5ea1e55
              name: 'Connections async keepalive'
              type: DEPENDENT
              key: 'apache.connections[async_keep_alive{#SINGLETON}]'
              description: 'The number of asynchronous connections in keepalive state (applicable only to the event MPM).'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.ConnsAsyncKeepAlive
              master_item:
                key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
              tags:
                - tag: component
                  value: connection
            - uuid: 9ad0e5c49e7c4b939eb7977a5158953f
              name: 'Connections async writing'
              type: DEPENDENT
              key: 'apache.connections[async_writing{#SINGLETON}]'
              description: 'The number of asynchronous connections in writing state (applicable only to the event MPM).'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.ConnsAsyncWriting
              master_item:
                key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
              tags:
                - tag: component
                  value: connection
            - uuid: 0fbfbfae187040c790bb4d68f9e2fae5
              name: 'Connections total'
              type: DEPENDENT
              key: 'apache.connections[total{#SINGLETON}]'
              description: 'The number of total connections.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.ConnsTotal
              master_item:
                key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
              tags:
                - tag: component
                  value: connection
            - uuid: 778a1bfeaa1b474ba529e6c0a55a9949
              name: 'Number of async processes'
              type: DEPENDENT
              key: 'apache.process[num{#SINGLETON}]'
              description: 'The number of asynchronous processes.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.Processes
              master_item:
                key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
              tags:
                - tag: component
                  value: system
          graph_prototypes:
            - uuid: 4845e6716bd74e7698406e6d8389eba5
              name: 'Apache: Current async connections{#SINGLETON}'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'Apache by Zabbix agent'
                    key: 'apache.connections[async_closing{#SINGLETON}]'
                - sortorder: '1'
                  color: F63100
                  item:
                    host: 'Apache by Zabbix agent'
                    key: 'apache.connections[async_keep_alive{#SINGLETON}]'
                - sortorder: '2'
                  color: 00611C
                  item:
                    host: 'Apache by Zabbix agent'
                    key: 'apache.connections[async_writing{#SINGLETON}]'
                - sortorder: '3'
                  drawtype: BOLD_LINE
                  color: F7941D
                  item:
                    host: 'Apache by Zabbix agent'
                    key: 'apache.connections[total{#SINGLETON}]'
            - uuid: 19ecb4e04c3742daac1a0e06d5f98c0c
              name: 'Apache: Current async processes{#SINGLETON}'
              graph_items:
                - drawtype: GRADIENT_LINE
                  color: 199C0D
                  item:
                    host: 'Apache by Zabbix agent'
                    key: 'apache.process[num{#SINGLETON}]'
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          preprocessing:
            - type: JAVASCRIPT
              parameters:
                - |
                  return JSON.stringify(JSON.parse(value).ServerMPM === 'event'
                  	? [{'{#SINGLETON}': ''}] : []);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
        - uuid: 357a2a1f056a4f59985e858d72e0bdae
          name: 'Apache process discovery'
          type: DEPENDENT
          key: apache.proc.discovery
          filter:
            evaltype: AND
            conditions:
              - macro: '{#APACHE.NAME}'
                value: '{$APACHE.PROCESS_NAME}'
          description: 'The discovery of the Apache process summary.'
          item_prototypes:
            - uuid: 458bfecc83f64540838e3ffc3a7f3cb1
              name: 'Get process data'
              type: DEPENDENT
              key: 'apache.proc.get[{#APACHE.NAME}]'
              history: '0'
              value_type: TEXT
              description: 'The summary metrics aggregated by a process {#APACHE.NAME}.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[?(@["name"]=="{#APACHE.NAME}")].first()'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: 'Failed to retrieve process {#APACHE.NAME} data'
              master_item:
                key: 'proc.get[{$APACHE.PROCESS.NAME.PARAMETER},,,summary]'
              tags:
                - tag: component
                  value: raw
            - uuid: 233b5466014640e4b990ffd81fa19fa1
              name: 'Number of running processes'
              type: DEPENDENT
              key: 'apache.proc.num[{#APACHE.NAME}]'
              description: 'The number of running processes {#APACHE.NAME}.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.processes
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '0'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'apache.proc.get[{#APACHE.NAME}]'
              tags:
                - tag: component
                  value: system
              trigger_prototypes:
                - uuid: b62f49b09d6b4c6ca01ff60cd9dd2209
                  expression: 'last(/Apache by Zabbix agent/apache.proc.num[{#APACHE.NAME}])=0'
                  name: 'Apache: Process is not running'
                  priority: HIGH
                  tags:
                    - tag: scope
                      value: availability
            - uuid: 683d4489dbb549f3bb5b45d3c2696c4f
              name: 'Memory usage, %'
              type: DEPENDENT
              key: 'apache.proc.pmem[{#APACHE.NAME}]'
              value_type: FLOAT
              units: '%'
              description: 'The percentage of real memory used by a process {#APACHE.NAME}.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.pmem
                  error_handler: DISCARD_VALUE
              master_item:
                key: 'apache.proc.get[{#APACHE.NAME}]'
              tags:
                - tag: component
                  value: memory
            - uuid: 384bf197e6a241b3b63bb89d009bba6b
              name: 'Memory usage (rss)'
              type: DEPENDENT
              key: 'apache.proc.rss[{#APACHE.NAME}]'
              units: B
              description: 'The summary of resident set size memory used by a process {#APACHE.NAME} expressed in bytes.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.rss
                  error_handler: DISCARD_VALUE
              master_item:
                key: 'apache.proc.get[{#APACHE.NAME}]'
              tags:
                - tag: component
                  value: memory
            - uuid: f20b7a01ff134a128c54ea83af8557e2
              name: 'Memory usage (vsize)'
              type: DEPENDENT
              key: 'apache.proc.vmem[{#APACHE.NAME}]'
              units: B
              description: 'The summary of virtual memory used by a process {#APACHE.NAME} expressed in bytes.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.vsize
                  error_handler: DISCARD_VALUE
              master_item:
                key: 'apache.proc.get[{#APACHE.NAME}]'
              tags:
                - tag: component
                  value: memory
            - uuid: b73280fb0af64c7899abfc74cc074b13
              name: 'CPU utilization'
              key: 'proc.cpu.util[{#APACHE.NAME}]'
              value_type: FLOAT
              units: '%'
              description: 'The percentage of the CPU utilization by a process {#APACHE.NAME}.'
              tags:
                - tag: component
                  value: cpu
          trigger_prototypes:
            - uuid: 0166ec63913e4bbea25c54b458b3213a
              expression: 'nodata(/Apache by Zabbix agent/web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"],30m)=1 and last(/Apache by Zabbix agent/apache.proc.num[{#APACHE.NAME}])>0'
              name: 'Apache: Failed to fetch status page'
              event_name: 'Apache: Failed to fetch status page (or no data for 30m)'
              priority: WARNING
              description: 'Zabbix has not received any data for items for the last 30 minutes.'
              manual_close: 'YES'
              dependencies:
                - name: 'Apache: Service is down'
                  expression: 'last(/Apache by Zabbix agent/net.tcp.service[http,"{$APACHE.STATUS.HOST}","{$APACHE.STATUS.PORT}"])=0 and last(/Apache by Zabbix agent/apache.proc.num[{#APACHE.NAME}])>0'
              tags:
                - tag: scope
                  value: availability
            - uuid: e24dbf9b89c34d839cb12a22b1103df3
              expression: 'last(/Apache by Zabbix agent/net.tcp.service[http,"{$APACHE.STATUS.HOST}","{$APACHE.STATUS.PORT}"])=0 and last(/Apache by Zabbix agent/apache.proc.num[{#APACHE.NAME}])>0'
              name: 'Apache: Service is down'
              priority: AVERAGE
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: availability
            - uuid: 128905793a4b4a1db5a49f87e87d3383
              expression: 'min(/Apache by Zabbix agent/net.tcp.service.perf[http,"{$APACHE.STATUS.HOST}","{$APACHE.STATUS.PORT}"],5m)>{$APACHE.RESPONSE_TIME.MAX.WARN} and last(/Apache by Zabbix agent/apache.proc.num[{#APACHE.NAME}])>0'
              name: 'Apache: Service response time is too high'
              event_name: 'Apache: Service response time is too high (over {$APACHE.RESPONSE_TIME.MAX.WARN}s for 5m)'
              priority: WARNING
              manual_close: 'YES'
              dependencies:
                - name: 'Apache: Service is down'
                  expression: 'last(/Apache by Zabbix agent/net.tcp.service[http,"{$APACHE.STATUS.HOST}","{$APACHE.STATUS.PORT}"])=0 and last(/Apache by Zabbix agent/apache.proc.num[{#APACHE.NAME}])>0'
              tags:
                - tag: scope
                  value: performance
          graph_prototypes:
            - uuid: d317a2ccde4f4a2ab20e983b27ae64e2
              name: 'Apache: Memory usage[{#APACHE.NAME}]'
              graph_items:
                - drawtype: BOLD_LINE
                  color: 199C0D
                  item:
                    host: 'Apache by Zabbix agent'
                    key: 'apache.proc.vmem[{#APACHE.NAME}]'
                - sortorder: '1'
                  drawtype: BOLD_LINE
                  color: F63100
                  item:
                    host: 'Apache by Zabbix agent'
                    key: 'apache.proc.rss[{#APACHE.NAME}]'
          master_item:
            key: 'proc.get[{$APACHE.PROCESS.NAME.PARAMETER},,,summary]'
          lld_macro_paths:
            - lld_macro: '{#APACHE.NAME}'
              path: $.name
      tags:
        - tag: class
          value: software
        - tag: subclass
          value: webserver
        - tag: target
          value: apache
      macros:
        - macro: '{$APACHE.PROCESS.NAME.PARAMETER}'
          description: 'The process name of the Apache web server used in the item key `proc.get`. It could be specified if the correct process name is known.'
          config:
            type: TEXT
            priority: '7'
            section_name: Other
            label: 'Apache process name'
            description: 'Process name of the Apache web server Used in the item key `proc.get`.'
        - macro: '{$APACHE.PROCESS_NAME}'
          value: (httpd|apache2)
          description: 'The process name filter for the Apache process discovery.'
          config:
            type: TEXT
            priority: '6'
            section_name: Other
            label: 'Apache process name LLD filter'
            description: 'Process name filter for the Apache process discovery.'
        - macro: '{$APACHE.RESPONSE_TIME.MAX.WARN}'
          value: '10'
          description: 'The maximum Apache response time expressed in seconds for a trigger expression.'
          config:
            type: TEXT
            priority: '5'
            section_name: Other
            label: 'Maximum Apache response time'
            description: 'Maximum Apache response time expressed in seconds for a trigger expression. No less than 0.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$APACHE.STATUS.HOST}'
          value: 127.0.0.1
          description: 'The hostname or IP address of the Apache status page.'
          config:
            type: TEXT
            priority: '1'
            label: 'Apache status host'
            description: 'Hostname or IP address of the Apache status page host.'
            required: 'YES'
        - macro: '{$APACHE.STATUS.PATH}'
          value: 'server-status?auto'
          description: 'The URL path of the Apache status page.'
          config:
            type: TEXT
            priority: '3'
            label: 'Apache status page path'
            description: 'URL path of the Apache status page.'
            required: 'YES'
        - macro: '{$APACHE.STATUS.PORT}'
          value: '80'
          description: 'The port of the Apache status page.'
          config:
            type: TEXT
            priority: '2'
            label: 'Apache status page port'
            description: 'In the range from 1 to 65535 inclusive.'
            required: 'YES'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$APACHE.STATUS.SCHEME}'
          value: http
          description: 'The request scheme, which may be either HTTP or HTTPS.'
          config:
            type: LIST
            priority: '4'
            label: 'Request scheme'
            description: 'Request scheme, which may be either HTTP or HTTPS.'
            options:
              - value: http
                text: HTTP
              - value: https
                text: HTTPS
      dashboards:
        - uuid: c27c68fb9c234a09b4023076b45affc1
          name: 'Apache performance'
          pages:
            - name: General
              widgets:
                - type: graph
                  width: '72'
                  height: '7'
                  fields:
                    - type: GRAPH
                      name: graphid.0
                      value:
                        host: 'Apache by Zabbix agent'
                        name: 'Apache: Worker states'
                    - type: STRING
                      name: reference
                      value: AAAAA
                - type: graph
                  'y': '7'
                  width: '36'
                  height: '5'
                  fields:
                    - type: GRAPH
                      name: graphid.0
                      value:
                        host: 'Apache by Zabbix agent'
                        name: 'Apache: Requests per second'
                    - type: STRING
                      name: reference
                      value: AAAAB
                - type: graphprototype
                  'y': '12'
                  width: '36'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'Apache by Zabbix agent'
                        name: 'Apache: Current async connections{#SINGLETON}'
                    - type: STRING
                      name: reference
                      value: AAAAD
                - type: graph
                  x: '36'
                  'y': '7'
                  width: '36'
                  height: '5'
                  fields:
                    - type: GRAPH
                      name: graphid.0
                      value:
                        host: 'Apache by Zabbix agent'
                        name: 'Apache: Workers total'
                    - type: STRING
                      name: reference
                      value: AAAAC
                - type: graphprototype
                  x: '36'
                  'y': '12'
                  width: '36'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'Apache by Zabbix agent'
                        name: 'Apache: Current async processes{#SINGLETON}'
                    - type: STRING
                      name: reference
                      value: AAAAE
      valuemaps:
        - uuid: 452297e814a84b08a72730a7b777e378
          name: 'Service state'
          mappings:
            - value: '0'
              newvalue: Down
            - value: '1'
              newvalue: Up
    - uuid: aa3286a824464020863ead141e8f0afc
      template: 'Apache by Zabbix agent active'
      name: 'Apache by Zabbix agent active'
      description: |
        Get metrics from mod_status module using HTTP agent.
        https://httpd.apache.org/docs/current/mod/mod_status.html
        
        You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/384764-discussion-thread-for-official-zabbix-template-apache
        
        Generated by official Zabbix template tool "Templator"
      wizard_ready: 'YES'
      readme: |
        ## Overview
        
        This template is designed for the effortless deployment of Apache monitoring by Zabbix via Zabbix agent and doesn't require any external scripts.
        The template `Apache by Zabbix agent` - collects metrics by polling [mod_status](https://httpd.apache.org/docs/current/mod/mod_status.html) locally with Zabbix agent:
          
        ```text
        127.0.0.1
        ServerVersion: Apache/2.4.41 (Unix)
        ServerMPM: event
        Server Built: Aug 14 2019 00:35:10
        CurrentTime: Friday, 16-Aug-2019 12:38:40 UTC
        RestartTime: Wednesday, 14-Aug-2019 07:58:26 UTC
        ParentServerConfigGeneration: 1
        ParentServerMPMGeneration: 0
        ServerUptimeSeconds: 189613
        ServerUptime: 2 days 4 hours 40 minutes 13 seconds
        Load1: 4.60
        Load5: 1.20
        Load15: 0.47
        Total Accesses: 27860
        Total kBytes: 33011
        Total Duration: 54118
        CPUUser: 18.02
        CPUSystem: 31.76
        CPUChildrenUser: 0
        CPUChildrenSystem: 0
        CPULoad: .0262535
        Uptime: 189613
        ReqPerSec: .146931
        BytesPerSec: 178.275
        BytesPerReq: 1213.33
        DurationPerReq: 1.9425
        BusyWorkers: 7
        IdleWorkers: 93
        Processes: 4
        Stopping: 0
        BusyWorkers: 7
        IdleWorkers: 93
        ConnsTotal: 13
        ConnsAsyncWriting: 0
        ConnsAsyncKeepAlive: 5
        ConnsAsyncClosing: 0
        Scoreboard: ...
        
        ```
          
        It also uses Zabbix agent to collect `Apache` Linux process statistics such as CPU usage, memory usage, and whether the process is running or not.
        
        ## Setup
        
        See the setup instructions for [mod_status](https://httpd.apache.org/docs/current/mod/mod_status.html).
        
        Check the availability of the module with this command line: `httpd -M 2>/dev/null | grep status_module`
        
        This is an example configuration of the Apache web server:
        
        ```text
        <Location "/server-status">
          SetHandler server-status
          Require host example.com
        </Location>
        ```
        
        If you use another path, then do not forget to change the `Apache status page path` host wizard configuration field.
      vendor:
        name: Zabbix
        version: 7.4-1
      groups:
        - name: Templates/Applications
      items:
        - uuid: 4f77b3a553d446619715e681799ea92c
          name: 'Total bytes'
          type: DEPENDENT
          key: apache.bytes
          value_type: FLOAT
          units: B
          description: 'The total bytes served.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$["Total kBytes"]'
            - type: MULTIPLIER
              parameters:
                - '1024'
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: network
        - uuid: a15b5f65e81440a49fc5918afd31d73b
          name: 'Bytes per second'
          type: DEPENDENT
          key: apache.bytes.rate
          value_type: FLOAT
          units: Bps
          description: |
            It is calculated as a rate of change for total bytes statistics.
            `BytesPerSec` is not used, as it counts the average since the last Apache server start.
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$["Total kBytes"]'
            - type: MULTIPLIER
              parameters:
                - '1024'
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: network
        - uuid: b0726bf9933a4349854bce2005e66f77
          name: 'Total requests'
          type: DEPENDENT
          key: apache.requests
          description: 'The total number of the Apache server accesses.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$["Total Accesses"]'
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: network
        - uuid: 864887722e62444a8d8f0756f161fc23
          name: 'Requests per second'
          type: DEPENDENT
          key: apache.requests.rate
          value_type: FLOAT
          description: |
            It is calculated as a rate of change for the "Total requests" statistics.
            `ReqPerSec` is not used, as it counts the average since the last Apache server start.
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$["Total Accesses"]'
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: network
        - uuid: af675fca551a45659f823cdf2e06175c
          name: Uptime
          type: DEPENDENT
          key: apache.uptime
          units: uptime
          description: 'The service uptime expressed in seconds.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.ServerUptimeSeconds
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 2f9e1d5e188f4f6190088986f6fc3f70
              expression: 'last(/Apache by Zabbix agent active/apache.uptime)<10m'
              name: 'Apache: Service has been restarted'
              event_name: 'Apache: Service has been restarted (uptime < 10m)'
              priority: INFO
              description: 'Uptime is less than 10 minutes.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: 67523f1351814d388f95178363a106ff
          name: Version
          type: DEPENDENT
          key: apache.version
          value_type: CHAR
          description: 'The Apache service version.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.ServerVersion
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 80d8c27a060347a4a852c3f6481244c3
              expression: 'last(/Apache by Zabbix agent active/apache.version,#1)<>last(/Apache by Zabbix agent active/apache.version,#2) and length(last(/Apache by Zabbix agent active/apache.version))>0'
              name: 'Apache: Version has changed'
              event_name: 'Apache: Version has changed (new version: {ITEM.VALUE})'
              priority: INFO
              description: 'Apache version has changed. Acknowledge to close the problem manually.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: 93beadab3d194772ac1a6f1950b20cad
          name: 'Workers idle cleanup'
          type: DEPENDENT
          key: apache.workers.cleanup
          description: 'The number of workers in cleanup state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.cleanup
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: 657a21b70a104778b32805226a05b27a
          name: 'Workers closing connection'
          type: DEPENDENT
          key: apache.workers.closing
          description: 'The number of workers in closing state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.closing
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: 86afd9d804f146b1adeed8844223d38b
          name: 'Workers DNS lookup'
          type: DEPENDENT
          key: apache.workers.dnslookup
          description: 'The number of workers in `dnslookup` state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.dnslookup
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: 70565d82384a439587ff6a32fa09ee1e
          name: 'Workers finishing'
          type: DEPENDENT
          key: apache.workers.finishing
          description: 'The number of workers in finishing state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.finishing
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: 7a2c9e6039b942c09ff30d8ff77b9658
          name: 'Workers keepalive (read)'
          type: DEPENDENT
          key: apache.workers.keepalive
          description: 'The number of workers in `keepalive` state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.keepalive
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: 0c3f9385fcc047d6ae8ee523f7bebb79
          name: 'Workers logging'
          type: DEPENDENT
          key: apache.workers.logging
          description: 'The number of workers in logging state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.logging
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: 7a4580dcfd974c7f9d59b8703054e77f
          name: 'Workers reading request'
          type: DEPENDENT
          key: apache.workers.reading
          description: 'The number of workers in reading state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.reading
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: 63d775979b934e72a2ed474419cf5c03
          name: 'Workers sending reply'
          type: DEPENDENT
          key: apache.workers.sending
          description: 'The number of workers in sending state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.sending
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: 8acd6c143a074c6faa46aa64869afc9b
          name: 'Workers slot with no current process'
          type: DEPENDENT
          key: apache.workers.slot
          description: 'The number of slots with no current process.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.slot
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: 86200cce3b7d47798cc35bab713f87aa
          name: 'Workers starting up'
          type: DEPENDENT
          key: apache.workers.starting
          description: 'The number of workers in starting state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.starting
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: 64b26283b39946fe92d729ac00afeca0
          name: 'Workers waiting for connection'
          type: DEPENDENT
          key: apache.workers.waiting
          description: 'The number of workers in waiting state.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Workers.waiting
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: 90757d625da543b18e136da7a0099be6
          name: 'Total workers busy'
          type: DEPENDENT
          key: apache.workers_total.busy
          description: 'The total number of busy worker threads/processes.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.BusyWorkers
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: 87be88163d4940658400ddf762faaeb6
          name: 'Total workers idle'
          type: DEPENDENT
          key: apache.workers_total.idle
          description: 'The total number of idle worker threads/processes.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.IdleWorkers
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          tags:
            - tag: component
              value: system
        - uuid: 3ac09d338f0847288eda20732bf5aa10
          name: 'Service response time'
          type: ZABBIX_ACTIVE
          key: 'net.tcp.service.perf[http,"{$APACHE.STATUS.HOST}","{$APACHE.STATUS.PORT}"]'
          value_type: FLOAT
          units: s
          tags:
            - tag: component
              value: application
            - tag: component
              value: health
        - uuid: e4252071d0864fd5bf7c60c4d6e4915d
          name: 'Service ping'
          type: ZABBIX_ACTIVE
          key: 'net.tcp.service[http,"{$APACHE.STATUS.HOST}","{$APACHE.STATUS.PORT}"]'
          valuemap:
            name: 'Service state'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 10m
          tags:
            - tag: component
              value: application
            - tag: component
              value: health
        - uuid: 37f15f5a28364399aa66aad31d0acc08
          name: 'Get processes summary'
          type: ZABBIX_ACTIVE
          key: 'proc.get[{$APACHE.PROCESS.NAME.PARAMETER},,,summary]'
          history: '0'
          value_type: TEXT
          description: 'The aggregated data of summary metrics for all processes.'
          tags:
            - tag: component
              value: raw
        - uuid: d103e519e5044dfd982d535a0981bc84
          name: 'Get status'
          type: ZABBIX_ACTIVE
          key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          history: 1h
          value_type: TEXT
          description: |
            Getting data from a machine-readable version of the Apache status page.
            For more information see Apache Module [mod_status](https://httpd.apache.org/docs/current/mod/mod_status.html).
          preprocessing:
            - type: JAVASCRIPT
              parameters:
                - |
                  var lines = value.split('\n');
                  var output = {},
                  	workers = {
                  		'_': 0, 'S': 0, 'R': 0, 'W': 0,
                  		'K': 0, 'D': 0, 'C': 0, 'L': 0,
                  		'G': 0, 'I': 0, '.': 0
                  	};
                  
                  for (var i = 0; i < lines.length; i++) {
                  	var line = lines[i].match(/([A-z0-9 ]+): (.*)/);
                  
                  	if (line !== null) {
                  		output[line[1]] = isNaN(line[2]) ? line[2] : Number(line[2]);
                  	}
                  }
                  
                  output.ServerUptimeSeconds = output.ServerUptimeSeconds || output.Uptime;
                  output.ServerVersion = output.ServerVersion || output.Server;
                  
                  if (typeof output.Scoreboard === 'string') {
                  	for (var i = 0; i < output.Scoreboard.length; i++) {
                  		var char = output.Scoreboard[i];
                  
                  		workers[char]++;
                  	}
                  }
                  
                  output.Workers = {
                  	waiting: workers['_'], starting: workers['S'], reading: workers['R'],
                  	sending: workers['W'], keepalive: workers['K'], dnslookup: workers['D'],
                  	closing: workers['C'], logging: workers['L'], finishing: workers['G'],
                  	cleanup: workers['I'], slot: workers['.']
                  };
                  
                  return JSON.stringify(output);
          tags:
            - tag: component
              value: raw
      discovery_rules:
        - uuid: 973011cd85cb4ef58d25bc5e0a1118b6
          name: 'Event MPM discovery'
          type: DEPENDENT
          key: apache.mpm.event.discovery
          description: |
            The discovery of additional metrics if the event Multi-Processing Module (MPM) is used.
            For more details see [Apache MPM event](https://httpd.apache.org/docs/current/mod/event.html).
          item_prototypes:
            - uuid: a640f7cba9314dd595d609ef79286548
              name: 'Bytes per request'
              type: DEPENDENT
              key: 'apache.bytes[per_request{#SINGLETON}]'
              value_type: FLOAT
              units: B
              description: 'The average number of client requests per second.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.BytesPerReq
              master_item:
                key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
              tags:
                - tag: component
                  value: connection
            - uuid: 3f1daaa5642545f1bdd5ab9b50ec49c9
              name: 'Connections async closing'
              type: DEPENDENT
              key: 'apache.connections[async_closing{#SINGLETON}]'
              description: 'The number of asynchronous connections in closing state (applicable only to the event MPM).'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.ConnsAsyncClosing
              master_item:
                key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
              tags:
                - tag: component
                  value: connection
            - uuid: 0beb4c6e7915408691264f8aa8073d67
              name: 'Connections async keepalive'
              type: DEPENDENT
              key: 'apache.connections[async_keep_alive{#SINGLETON}]'
              description: 'The number of asynchronous connections in keepalive state (applicable only to the event MPM).'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.ConnsAsyncKeepAlive
              master_item:
                key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
              tags:
                - tag: component
                  value: connection
            - uuid: da590c6635484f178d4d26de5863f00e
              name: 'Connections async writing'
              type: DEPENDENT
              key: 'apache.connections[async_writing{#SINGLETON}]'
              description: 'The number of asynchronous connections in writing state (applicable only to the event MPM).'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.ConnsAsyncWriting
              master_item:
                key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
              tags:
                - tag: component
                  value: connection
            - uuid: c11f36a9483444e38cecb5e7ae667735
              name: 'Connections total'
              type: DEPENDENT
              key: 'apache.connections[total{#SINGLETON}]'
              description: 'The number of total connections.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.ConnsTotal
              master_item:
                key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
              tags:
                - tag: component
                  value: connection
            - uuid: ca00fe11b10140f6ad791c8fcc012082
              name: 'Number of async processes'
              type: DEPENDENT
              key: 'apache.process[num{#SINGLETON}]'
              description: 'The number of asynchronous processes.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.Processes
              master_item:
                key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
              tags:
                - tag: component
                  value: system
          graph_prototypes:
            - uuid: 43fb144dfa5b47afbdd146231e185c13
              name: 'Apache: Current async connections{#SINGLETON}'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'Apache by Zabbix agent active'
                    key: 'apache.connections[async_closing{#SINGLETON}]'
                - sortorder: '1'
                  color: F63100
                  item:
                    host: 'Apache by Zabbix agent active'
                    key: 'apache.connections[async_keep_alive{#SINGLETON}]'
                - sortorder: '2'
                  color: 00611C
                  item:
                    host: 'Apache by Zabbix agent active'
                    key: 'apache.connections[async_writing{#SINGLETON}]'
                - sortorder: '3'
                  drawtype: BOLD_LINE
                  color: F7941D
                  item:
                    host: 'Apache by Zabbix agent active'
                    key: 'apache.connections[total{#SINGLETON}]'
            - uuid: 1ab50e84f1d94ea98bb7e5c9d0cf159c
              name: 'Apache: Current async processes{#SINGLETON}'
              graph_items:
                - drawtype: GRADIENT_LINE
                  color: 199C0D
                  item:
                    host: 'Apache by Zabbix agent active'
                    key: 'apache.process[num{#SINGLETON}]'
          master_item:
            key: 'web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]'
          preprocessing:
            - type: JAVASCRIPT
              parameters:
                - |
                  return JSON.stringify(JSON.parse(value).ServerMPM === 'event'
                  	? [{'{#SINGLETON}': ''}] : []);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
        - uuid: 7c4b0d02427b4cf199817b5d5ae66378
          name: 'Apache process discovery'
          type: DEPENDENT
          key: apache.proc.discovery
          filter:
            evaltype: AND
            conditions:
              - macro: '{#APACHE.NAME}'
                value: '{$APACHE.PROCESS_NAME}'
          description: 'The discovery of the Apache process summary.'
          item_prototypes:
            - uuid: 68c53fcf8d8545ac98e923c04945aec4
              name: 'Get process data'
              type: DEPENDENT
              key: 'apache.proc.get[{#APACHE.NAME}]'
              history: '0'
              value_type: TEXT
              description: 'The summary metrics aggregated by a process {#APACHE.NAME}.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[?(@["name"]=="{#APACHE.NAME}")].first()'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: 'Failed to retrieve process {#APACHE.NAME} data'
              master_item:
                key: 'proc.get[{$APACHE.PROCESS.NAME.PARAMETER},,,summary]'
              tags:
                - tag: component
                  value: raw
            - uuid: 5f29e764f0024047bd955388b6585442
              name: 'Number of running processes'
              type: DEPENDENT
              key: 'apache.proc.num[{#APACHE.NAME}]'
              description: 'The number of running processes {#APACHE.NAME}.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.processes
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '0'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'apache.proc.get[{#APACHE.NAME}]'
              tags:
                - tag: component
                  value: system
              trigger_prototypes:
                - uuid: 653a0f021ece4993aaaef441172366b3
                  expression: 'last(/Apache by Zabbix agent active/apache.proc.num[{#APACHE.NAME}])=0'
                  name: 'Apache: Process is not running'
                  priority: HIGH
                  tags:
                    - tag: scope
                      value: availability
            - uuid: 77f232c075384a11a3aefd31a55c0113
              name: 'Memory usage, %'
              type: DEPENDENT
              key: 'apache.proc.pmem[{#APACHE.NAME}]'
              value_type: FLOAT
              units: '%'
              description: 'The percentage of real memory used by a process {#APACHE.NAME}.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.pmem
                  error_handler: DISCARD_VALUE
              master_item:
                key: 'apache.proc.get[{#APACHE.NAME}]'
              tags:
                - tag: component
                  value: memory
            - uuid: 0ded808ba0b34d03865a288dd9bb0672
              name: 'Memory usage (rss)'
              type: DEPENDENT
              key: 'apache.proc.rss[{#APACHE.NAME}]'
              units: B
              description: 'The summary of resident set size memory used by a process {#APACHE.NAME} expressed in bytes.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.rss
                  error_handler: DISCARD_VALUE
              master_item:
                key: 'apache.proc.get[{#APACHE.NAME}]'
              tags:
                - tag: component
                  value: memory
            - uuid: ba4d0197f2cb484597175ffd8f693dce
              name: 'Memory usage (vsize)'
              type: DEPENDENT
              key: 'apache.proc.vmem[{#APACHE.NAME}]'
              units: B
              description: 'The summary of virtual memory used by a process {#APACHE.NAME} expressed in bytes.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.vsize
                  error_handler: DISCARD_VALUE
              master_item:
                key: 'apache.proc.get[{#APACHE.NAME}]'
              tags:
                - tag: component
                  value: memory
            - uuid: b1e48077179f4e439e2d3c3b918c9a03
              name: 'CPU utilization'
              type: ZABBIX_ACTIVE
              key: 'proc.cpu.util[{#APACHE.NAME}]'
              value_type: FLOAT
              units: '%'
              description: 'The percentage of the CPU utilization by a process {#APACHE.NAME}.'
              tags:
                - tag: component
                  value: cpu
          trigger_prototypes:
            - uuid: c848c1449cef42bd90af13e6767bd2c9
              expression: 'nodata(/Apache by Zabbix agent active/web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"],30m)=1 and last(/Apache by Zabbix agent active/apache.proc.num[{#APACHE.NAME}])>0'
              name: 'Apache: Failed to fetch status page'
              event_name: 'Apache: Failed to fetch status page (or no data for 30m)'
              priority: WARNING
              description: 'Zabbix has not received any data for items for the last 30 minutes.'
              manual_close: 'YES'
              dependencies:
                - name: 'Apache: Service is down'
                  expression: 'last(/Apache by Zabbix agent active/net.tcp.service[http,"{$APACHE.STATUS.HOST}","{$APACHE.STATUS.PORT}"])=0 and last(/Apache by Zabbix agent active/apache.proc.num[{#APACHE.NAME}])>0'
              tags:
                - tag: scope
                  value: availability
            - uuid: 4b460b835cb14513b5aace3275827c79
              expression: 'last(/Apache by Zabbix agent active/net.tcp.service[http,"{$APACHE.STATUS.HOST}","{$APACHE.STATUS.PORT}"])=0 and last(/Apache by Zabbix agent active/apache.proc.num[{#APACHE.NAME}])>0'
              name: 'Apache: Service is down'
              priority: AVERAGE
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: availability
            - uuid: 93157365ee90446fa8191dfc5d623874
              expression: 'min(/Apache by Zabbix agent active/net.tcp.service.perf[http,"{$APACHE.STATUS.HOST}","{$APACHE.STATUS.PORT}"],5m)>{$APACHE.RESPONSE_TIME.MAX.WARN} and last(/Apache by Zabbix agent active/apache.proc.num[{#APACHE.NAME}])>0'
              name: 'Apache: Service response time is too high'
              event_name: 'Apache: Service response time is too high (over {$APACHE.RESPONSE_TIME.MAX.WARN}s for 5m)'
              priority: WARNING
              manual_close: 'YES'
              dependencies:
                - name: 'Apache: Service is down'
                  expression: 'last(/Apache by Zabbix agent active/net.tcp.service[http,"{$APACHE.STATUS.HOST}","{$APACHE.STATUS.PORT}"])=0 and last(/Apache by Zabbix agent active/apache.proc.num[{#APACHE.NAME}])>0'
              tags:
                - tag: scope
                  value: performance
          graph_prototypes:
            - uuid: 5427aef4eaad4519b193b38cdc71fde1
              name: 'Apache: Memory usage[{#APACHE.NAME}]'
              graph_items:
                - drawtype: BOLD_LINE
                  color: 199C0D
                  item:
                    host: 'Apache by Zabbix agent active'
                    key: 'apache.proc.vmem[{#APACHE.NAME}]'
                - sortorder: '1'
                  drawtype: BOLD_LINE
                  color: F63100
                  item:
                    host: 'Apache by Zabbix agent active'
                    key: 'apache.proc.rss[{#APACHE.NAME}]'
          master_item:
            key: 'proc.get[{$APACHE.PROCESS.NAME.PARAMETER},,,summary]'
          lld_macro_paths:
            - lld_macro: '{#APACHE.NAME}'
              path: $.name
      tags:
        - tag: class
          value: software
        - tag: subclass
          value: webserver
        - tag: target
          value: apache
      macros:
        - macro: '{$APACHE.PROCESS.NAME.PARAMETER}'
          description: 'The process name of the Apache web server used in the item key `proc.get`. It could be specified if the correct process name is known.'
          config:
            type: TEXT
            priority: '7'
            section_name: Other
            label: 'Apache process name'
            description: 'Process name of the Apache web server Used in the item key `proc.get`.'
        - macro: '{$APACHE.PROCESS_NAME}'
          value: (httpd|apache2)
          description: 'The process name filter for the Apache process discovery.'
          config:
            type: TEXT
            priority: '6'
            section_name: Other
            label: 'Apache process name LLD filter'
            description: 'Process name filter for the Apache process discovery.'
        - macro: '{$APACHE.RESPONSE_TIME.MAX.WARN}'
          value: '10'
          description: 'The maximum Apache response time expressed in seconds for a trigger expression.'
          config:
            type: TEXT
            priority: '5'
            section_name: Other
            label: 'Maximum Apache response time'
            description: 'Maximum Apache response time expressed in seconds for a trigger expression. No less than 0.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$APACHE.STATUS.HOST}'
          value: 127.0.0.1
          description: 'The hostname or IP address of the Apache status page.'
          config:
            type: TEXT
            priority: '1'
            label: 'Apache status host'
            description: 'Hostname or IP address of the Apache status page host.'
            required: 'YES'
        - macro: '{$APACHE.STATUS.PATH}'
          value: 'server-status?auto'
          description: 'The URL path of the Apache status page.'
          config:
            type: TEXT
            priority: '3'
            label: 'Apache status page path'
            description: 'URL path of the Apache status page.'
            required: 'YES'
        - macro: '{$APACHE.STATUS.PORT}'
          value: '80'
          description: 'The port of the Apache status page.'
          config:
            type: TEXT
            priority: '2'
            label: 'Apache status page port'
            description: 'In the range from 1 to 65535 inclusive.'
            required: 'YES'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$APACHE.STATUS.SCHEME}'
          value: http
          description: 'The request scheme, which may be either HTTP or HTTPS.'
          config:
            type: LIST
            priority: '4'
            label: 'Request scheme'
            description: 'Request scheme, which may be either HTTP or HTTPS.'
            options:
              - value: http
                text: HTTP
              - value: https
                text: HTTPS
      dashboards:
        - uuid: dd69695bb88241e6b457d06da37967fc
          name: 'Apache performance'
          pages:
            - name: General
              widgets:
                - type: graph
                  width: '72'
                  height: '7'
                  fields:
                    - type: GRAPH
                      name: graphid.0
                      value:
                        host: 'Apache by Zabbix agent active'
                        name: 'Apache: Worker states'
                    - type: STRING
                      name: reference
                      value: AAAAA
                - type: graph
                  'y': '7'
                  width: '36'
                  height: '5'
                  fields:
                    - type: GRAPH
                      name: graphid.0
                      value:
                        host: 'Apache by Zabbix agent active'
                        name: 'Apache: Requests per second'
                    - type: STRING
                      name: reference
                      value: AAAAB
                - type: graphprototype
                  'y': '12'
                  width: '36'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'Apache by Zabbix agent active'
                        name: 'Apache: Current async connections{#SINGLETON}'
                    - type: STRING
                      name: reference
                      value: AAAAD
                - type: graph
                  x: '36'
                  'y': '7'
                  width: '36'
                  height: '5'
                  fields:
                    - type: GRAPH
                      name: graphid.0
                      value:
                        host: 'Apache by Zabbix agent active'
                        name: 'Apache: Workers total'
                    - type: STRING
                      name: reference
                      value: AAAAC
                - type: graphprototype
                  x: '36'
                  'y': '12'
                  width: '36'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'Apache by Zabbix agent active'
                        name: 'Apache: Current async processes{#SINGLETON}'
                    - type: STRING
                      name: reference
                      value: AAAAE
      valuemaps:
        - uuid: 872ac3dadab34de9a69acd71d68cd7ea
          name: 'Service state'
          mappings:
            - value: '0'
              newvalue: Down
            - value: '1'
              newvalue: Up
    - uuid: 85ce114c802e4e28a5f3597e07d07032
      template: 'Kubernetes API server by HTTP'
      name: 'Kubernetes API server by HTTP'
      description: |
        Get Kubernetes API server metrics by HTTP agent from Prometheus metrics endpoint.
        
        Don't forget change macros {$KUBE.API.SERVER.URL}, {$KUBE.API.TOKEN}.
        Some metrics may not be collected depending on your Kubernetes API server instance version and configuration.
        
        You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback
        
        Generated by official Zabbix template tool "Templator"
      wizard_ready: 'YES'
      readme: |
        ## Overview
        
        The template to monitor Kubernetes API server that works without any external scripts.
        Most of the metrics are collected in one go, thanks to Zabbix bulk data collection.
        
        Template `Kubernetes API server by HTTP` - collects metrics by HTTP agent from API server /metrics endpoint.
        
        ## Setup
        
        Internal service metrics are collected from /metrics endpoint.
        Template needs to use Authorization via API token.
        
        Set the following fields: `Kubernetes API server URL`, `API Authorization Token`.
        
        *NOTE.* Some metrics may not be collected depending on your Kubernetes API server instance version and configuration.
      vendor:
        name: Zabbix
        version: 7.4-1
      groups:
        - name: Templates/Applications
      items:
        - uuid: 28944ee2c0a3478e84612cd5650f3cd5
          name: 'Request terminations, rate'
          type: DEPENDENT
          key: kubernetes.api.apiserver_request_terminations
          value_type: FLOAT
          description: 'Number of requests which apiserver terminated in self-defense per second.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - apiserver_request_terminations_total
                - function
                - sum
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: kubernetes.api.get_metrics
          tags:
            - tag: component
              value: requests
        - uuid: 1ac74141a4b241b196bc47d0dee37a2c
          name: 'API server requests: 0'
          type: DEPENDENT
          key: kubernetes.api.apiserver_request_total_0.rate
          value_type: FLOAT
          description: 'Counter of apiserver requests broken out for each HTTP response code.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - 'apiserver_request_total{code = "0"}'
                - function
                - sum
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: kubernetes.api.get_metrics
          tags:
            - tag: component
              value: requests
            - tag: http-code
              value: '0'
        - uuid: d7f8363e1bc5424f89c7386fcbe6fb06
          name: 'API server requests: 2xx, rate'
          type: DEPENDENT
          key: kubernetes.api.apiserver_request_total_200.rate
          value_type: FLOAT
          description: 'Counter of apiserver requests broken out for each HTTP response code.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - 'apiserver_request_total{code =~ "2.."}'
                - function
                - sum
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: kubernetes.api.get_metrics
          tags:
            - tag: component
              value: requests
            - tag: http-code
              value: 2xx
        - uuid: 453852b621ca4a7cbc4d80e5327c80da
          name: 'API server requests: 3xx, rate'
          type: DEPENDENT
          key: kubernetes.api.apiserver_request_total_300.rate
          value_type: FLOAT
          description: 'Counter of apiserver requests broken out for each HTTP response code.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - 'apiserver_request_total{code =~ "3.."}'
                - function
                - sum
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: kubernetes.api.get_metrics
          tags:
            - tag: component
              value: requests
            - tag: http-code
              value: 3xx
        - uuid: 1f72779899f94620bc55870f5e2c2ca0
          name: 'API server requests: 4xx, rate'
          type: DEPENDENT
          key: kubernetes.api.apiserver_request_total_400.rate
          value_type: FLOAT
          description: 'Counter of apiserver requests broken out for each HTTP response code.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - 'apiserver_request_total{code =~ "4.."}'
                - function
                - sum
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: kubernetes.api.get_metrics
          tags:
            - tag: component
              value: requests
            - tag: http-code
              value: 4xx
        - uuid: 1c24d58b28bc423e868a965d689cf146
          name: 'API server requests: 5xx, rate'
          type: DEPENDENT
          key: kubernetes.api.apiserver_request_total_500.rate
          value_type: FLOAT
          description: 'Counter of apiserver requests broken out for each HTTP response code.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - 'apiserver_request_total{code =~ "5.."}'
                - function
                - sum
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: kubernetes.api.get_metrics
          tags:
            - tag: component
              value: requests
            - tag: http-code
              value: 5xx
          triggers:
            - uuid: 0e1ef1630b5d4cb98270564f324f5382
              expression: 'min(/Kubernetes API server by HTTP/kubernetes.api.apiserver_request_total_500.rate,5m)>{$KUBE.API.HTTP.SERVER.ERROR}'
              name: 'Kubernetes API server: Too many server errors'
              event_name: 'Kubernetes API server: Too many server errors (over {$KUBE.API.HTTP.SERVER.ERROR} for 5m)'
              priority: WARNING
              description: '"Kubernetes API server is experiencing high error rate (with 5xx HTTP code).'
              tags:
                - tag: scope
                  value: availability
        - uuid: 5bd8b2deaf1142369ba67afc7a41ab11
          name: 'TLS handshake errors, rate'
          type: DEPENDENT
          key: kubernetes.api.apiserver_tls_handshake_errors_total.rate
          value_type: FLOAT
          description: 'Number of requests dropped with ''TLS handshake error from'' error per second.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - apiserver_tls_handshake_errors_total
                - function
                - sum
              error_handler: DISCARD_VALUE
          master_item:
            key: kubernetes.api.get_metrics
          tags:
            - tag: component
              value: tls
        - uuid: 54723f57a20a47a698fbf47cbec0f7a1
          name: 'Audit events, total'
          type: DEPENDENT
          key: kubernetes.api.audit_event_total
          value_type: FLOAT
          description: 'Accumulated number audit events generated and sent to the audit backend.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - apiserver_audit_event_total
                - function
                - sum
              error_handler: DISCARD_VALUE
          master_item:
            key: kubernetes.api.get_metrics
          tags:
            - tag: component
              value: audit
        - uuid: de87284b8bd644398e4a88a064e206bb
          name: CPU
          type: DEPENDENT
          key: kubernetes.api.cpu.util
          value_type: FLOAT
          units: '%'
          description: 'Total user and system CPU usage ratio.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - process_cpu_seconds_total
                - value
                - ''
            - type: CHANGE_PER_SECOND
            - type: MULTIPLIER
              parameters:
                - '100'
          master_item:
            key: kubernetes.api.get_metrics
          tags:
            - tag: component
              value: cpu
        - uuid: e4e3c570a55a48689c145c4a2310c597
          name: 'Get API instance metrics'
          type: HTTP_AGENT
          key: kubernetes.api.get_metrics
          history: '0'
          value_type: TEXT
          description: 'Get raw metrics from API instance /metrics endpoint.'
          preprocessing:
            - type: CHECK_NOT_SUPPORTED
              parameters:
                - '-1'
          timeout: 15s
          url: '{$KUBE.API.SERVER.URL}'
          headers:
            - name: Authorization
              value: 'Bearer {$KUBE.API.TOKEN}'
          tags:
            - tag: component
              value: raw
        - uuid: 79db985ac8f645999fe8aa73b4073bfb
          name: Goroutines
          type: DEPENDENT
          key: kubernetes.api.go_goroutines
          value_type: FLOAT
          description: 'Number of goroutines that currently exist.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - go_goroutines
                - function
                - sum
              error_handler: DISCARD_VALUE
          master_item:
            key: kubernetes.api.get_metrics
          tags:
            - tag: component
              value: goroutines
        - uuid: 2022d65c2f7a4f07bc1cba435a2be1e9
          name: 'Go threads'
          type: DEPENDENT
          key: kubernetes.api.go_threads
          value_type: FLOAT
          description: 'Number of OS threads created.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - go_threads
                - value
                - ''
              error_handler: DISCARD_VALUE
          master_item:
            key: kubernetes.api.get_metrics
          tags:
            - tag: component
              value: go-threads
        - uuid: 837c546cb3bc400ab7a62a672792f88b
          name: 'gRPCs messages received, rate'
          type: DEPENDENT
          key: kubernetes.api.grpc_client_msg_received.rate
          value_type: FLOAT
          description: 'Total number of gRPC stream messages received per second.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - grpc_client_msg_received_total
                - function
                - sum
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: kubernetes.api.get_metrics
          tags:
            - tag: component
              value: grpc
        - uuid: 353559f3b9684647a74bd429d80731b9
          name: 'gRPCs messages sent, rate'
          type: DEPENDENT
          key: kubernetes.api.grpc_client_msg_sent.rate
          value_type: FLOAT
          description: 'Total number of gRPC stream messages sent per second.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - grpc_client_msg_sent_total
                - function
                - sum
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: kubernetes.api.get_metrics
          tags:
            - tag: component
              value: grpc
        - uuid: 0850afe759684950be79135ed4f32c79
          name: 'gRPCs client started, rate'
          type: DEPENDENT
          key: kubernetes.api.grpc_client_started.rate
          value_type: FLOAT
          description: 'Total number of RPCs started per second.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - grpc_client_started_total
                - function
                - sum
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: kubernetes.api.get_metrics
          tags:
            - tag: component
              value: grpc
        - uuid: 187702b1c3a24d07aaf9cc07fa359095
          name: 'Fds max'
          type: DEPENDENT
          key: kubernetes.api.max_fds
          value_type: FLOAT
          description: 'Maximum allowed open file descriptors.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - process_max_fds
                - value
                - ''
              error_handler: DISCARD_VALUE
          master_item:
            key: kubernetes.api.get_metrics
          tags:
            - tag: component
              value: fds
        - uuid: 41f802305a234b1ab9fb0e89d1e40290
          name: 'Fds open'
          type: DEPENDENT
          key: kubernetes.api.open_fds
          value_type: FLOAT
          description: 'Number of open file descriptors.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - process_open_fds
                - value
                - ''
              error_handler: DISCARD_VALUE
          master_item:
            key: kubernetes.api.get_metrics
          tags:
            - tag: component
              value: fds
        - uuid: 53fd5211b6da47d3b3fc87ab8a2d0c33
          name: 'Resident memory, bytes'
          type: DEPENDENT
          key: kubernetes.api.process_resident_memory_bytes
          value_type: FLOAT
          units: B
          description: 'Resident memory size in bytes.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - process_resident_memory_bytes
                - value
                - ''
              error_handler: DISCARD_VALUE
          master_item:
            key: kubernetes.api.get_metrics
          tags:
            - tag: component
              value: memory
        - uuid: 010a983426c9407eb4b6bf7822b411ce
          name: 'Virtual memory, bytes'
          type: DEPENDENT
          key: kubernetes.api.process_virtual_memory_bytes
          value_type: FLOAT
          units: B
          description: 'Virtual memory size in bytes.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - process_virtual_memory_bytes
                - value
                - ''
              error_handler: DISCARD_VALUE
          master_item:
            key: kubernetes.api.get_metrics
          tags:
            - tag: component
              value: memory
        - uuid: 3f15d60ef7cb4a068424d5835d04a817
          name: 'HTTP requests: 2xx, rate'
          type: DEPENDENT
          key: kubernetes.api.rest_client_requests_total_200.rate
          value_type: FLOAT
          description: 'Number of HTTP requests with 2xx status code per second.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - 'rest_client_requests_total{code =~ "2.."}'
                - function
                - sum
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: kubernetes.api.get_metrics
          tags:
            - tag: component
              value: requests
            - tag: http-code
              value: 2xx
        - uuid: 450607dda045428fb6d4a96ca8888c19
          name: 'HTTP requests: 3xx, rate'
          type: DEPENDENT
          key: kubernetes.api.rest_client_requests_total_300.rate
          value_type: FLOAT
          description: 'Number of HTTP requests with 3xx status code per second.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - 'rest_client_requests_total{code =~ "3.."}'
                - function
                - sum
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: kubernetes.api.get_metrics
          tags:
            - tag: component
              value: requests
            - tag: http-code
              value: 3xx
        - uuid: f11b87e0bc5a41ff956391b6cb7115c5
          name: 'HTTP requests: 4xx, rate'
          type: DEPENDENT
          key: kubernetes.api.rest_client_requests_total_400.rate
          value_type: FLOAT
          description: 'Number of HTTP requests with 4xx status code per second.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - 'rest_client_requests_total{code =~ "4.."}'
                - function
                - sum
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: kubernetes.api.get_metrics
          tags:
            - tag: component
              value: requests
            - tag: http-code
              value: 4xx
        - uuid: 2588c2332fea48f8bae414e8b7c42184
          name: 'HTTP requests: 5xx, rate'
          type: DEPENDENT
          key: kubernetes.api.rest_client_requests_total_500.rate
          value_type: FLOAT
          description: 'Number of HTTP requests with 5xx status code per second.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - 'rest_client_requests_total{code =~ "5.."}'
                - function
                - sum
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: kubernetes.api.get_metrics
          tags:
            - tag: component
              value: requests
            - tag: http-code
              value: 5xx
          triggers:
            - uuid: 4c79888da91448738092c86e5f427a6a
              expression: 'min(/Kubernetes API server by HTTP/kubernetes.api.rest_client_requests_total_500.rate,5m)>{$KUBE.API.HTTP.CLIENT.ERROR}'
              name: 'Kubernetes API server: Too many client errors'
              event_name: 'Kubernetes API server: Too many client errors (over {$KUBE.API.HTTP.CLIENT.ERROR} for 5m)'
              priority: WARNING
              description: '"Kubernetes API client is experiencing high error rate (with 5xx HTTP code).'
              tags:
                - tag: scope
                  value: availability
      discovery_rules:
        - uuid: 22c5e2a84d9542c1905d0c20f4ca6700
          name: 'Watchers metrics discovery'
          type: DEPENDENT
          key: kubernetes.api.apiserver_registered_watchers.discovery
          description: 'Discovery watchers by kind.'
          item_prototypes:
            - uuid: 09d0815f893c42c1b95721f7f908940a
              name: 'Watchers: {#KIND}'
              type: DEPENDENT
              key: 'kubernetes.api.apiserver_registered_watchers["{#KIND}"]'
              value_type: FLOAT
              description: 'Number of currently registered watchers for a given resource.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'apiserver_registered_watchers{kind = "{#KIND}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kubernetes.api.get_metrics
              tags:
                - tag: component
                  value: watchers
                - tag: kind
                  value: '{#KIND}'
          master_item:
            key: kubernetes.api.get_metrics
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - 'apiserver_registered_watchers{kind =~ ".*"}'
            - type: JAVASCRIPT
              parameters:
                - |
                  var lookup = {},
                  	result = [];
                  
                  JSON.parse(value).forEach(function (item) {
                  	var kind = item.labels.kind;
                  	if (!(lookup[kind])) {
                  		lookup[kind] = 1;
                  		result.push({ '{#KIND}': kind });
                  	}
                  });
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
        - uuid: 45ad0dd7331d4b9391d26b78838b0433
          name: 'Authentication requests discovery'
          type: DEPENDENT
          key: kubernetes.api.authenticated_user_requests.discovery
          description: 'Discovery authentication attempts by name.'
          item_prototypes:
            - uuid: 6950d30d0b1d4162acee45f184453fbd
              name: 'Authenticated requests: {#NAME}, rate'
              type: DEPENDENT
              key: 'kubernetes.api.authenticated_user_requests.rate["{#NAME}"]'
              value_type: FLOAT
              description: 'Counter of authenticated requests broken out by username per second.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'authenticated_user_requests{result = "{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
                - type: CHANGE_PER_SECOND
              master_item:
                key: kubernetes.api.get_metrics
              tags:
                - tag: component
                  value: authentication
                - tag: name
                  value: '{#NAME}'
          master_item:
            key: kubernetes.api.get_metrics
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - 'authenticated_user_requests{username =~ ".*"}'
            - type: JAVASCRIPT
              parameters:
                - |
                  var lookup = {},
                  	result = [];
                  
                  JSON.parse(value).forEach(function (item) {
                  	var name = item.labels.username;
                  	if (!(lookup[result])) {
                  		lookup[name] = 1;
                  		result.push({ '{#NAME}': name });
                  	}
                  });
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
        - uuid: ca23c310c71f4e88891ceae883527389
          name: 'Authentication attempts discovery'
          type: DEPENDENT
          key: kubernetes.api.authentication_attempts.discovery
          description: 'Discovery authentication attempts by result.'
          item_prototypes:
            - uuid: d9ddaa016a7c4ca381fbe857959dd0fd
              name: 'Authentication attempts: {#RESULT}, rate'
              type: DEPENDENT
              key: 'kubernetes.api.authentication_attempts.rate["{#RESULT}"]'
              value_type: FLOAT
              description: 'Authentication attempts by result per second.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'authentication_attempts{result = "{#RESULT}"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
                - type: CHANGE_PER_SECOND
              master_item:
                key: kubernetes.api.get_metrics
              tags:
                - tag: component
                  value: authentication
                - tag: result
                  value: '{#RESULT}'
          master_item:
            key: kubernetes.api.get_metrics
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - 'authentication_attempts{result =~ ".*"}'
            - type: JAVASCRIPT
              parameters:
                - |
                  var lookup = {},
                  	result = [];
                  
                  JSON.parse(value).forEach(function (item) {
                  	var result_api = item.labels.result;
                  	if (!(lookup[result])) {
                  		lookup[result_api] = 1;
                  		result.push({ '{#RESULT}': result_api });
                  	}
                  });
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
        - uuid: 0821009ea3be43e089247e843723577f
          name: 'Client certificate expiration histogram'
          type: DEPENDENT
          key: kubernetes.api.certificate_expiration.discovery
          description: 'Discovery raw data of client certificate expiration'
          item_prototypes:
            - uuid: b69600f22c7b42b48f8601ada06a5a9f
              name: 'Client certificate expiration, p1'
              type: CALCULATED
              key: 'kubernetes.api.client_certificate_expiration_p1[{#SINGLETON}]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kubernetes.api.client_certificate_expiration_seconds_bucket[*],5m,1)'
              description: '1 percentile of the remaining lifetime on the certificate used to authenticate a request.'
              tags:
                - tag: component
                  value: client-certificate
              trigger_prototypes:
                - uuid: 1371958c0339430b8a333851766c01c0
                  expression: 'last(/Kubernetes API server by HTTP/kubernetes.api.client_certificate_expiration_p1[{#SINGLETON}]) > 0 and last(/Kubernetes API server by HTTP/kubernetes.api.client_certificate_expiration_p1[{#SINGLETON}]) < 24*60*60'
                  name: 'Kubernetes API server: Kubernetes client certificate expires soon'
                  priority: WARNING
                  description: 'A client certificate used to authenticate to the apiserver is expiring in less than 24.0 hours.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 132d58724bd141afa3f28101326fe922
                  expression: 'last(/Kubernetes API server by HTTP/kubernetes.api.client_certificate_expiration_p1[{#SINGLETON}]) > 0 and last(/Kubernetes API server by HTTP/kubernetes.api.client_certificate_expiration_p1[{#SINGLETON}]) < {$KUBE.API.CERT.EXPIRATION}*24*60*60'
                  name: 'Kubernetes API server: Kubernetes client certificate is expiring'
                  event_name: 'Kubernetes API server: Kubernetes client certificate expires in {$KUBE.API.CERT.EXPIRATION} days'
                  priority: WARNING
                  description: 'A client certificate used to authenticate to the apiserver is expiring in {$KUBE.API.CERT.EXPIRATION} days.'
                  dependencies:
                    - name: 'Kubernetes API server: Kubernetes client certificate expires soon'
                      expression: 'last(/Kubernetes API server by HTTP/kubernetes.api.client_certificate_expiration_p1[{#SINGLETON}]) > 0 and last(/Kubernetes API server by HTTP/kubernetes.api.client_certificate_expiration_p1[{#SINGLETON}]) < 24*60*60'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: 860cc40806254564bddb3617b8b75e74
              name: 'Certificate expiration seconds bucket, {#LE}'
              type: DEPENDENT
              key: 'kubernetes.api.client_certificate_expiration_seconds_bucket[{#LE}]'
              history: 1h
              value_type: FLOAT
              trends: '0'
              discover: NO_DISCOVER
              description: 'Distribution of the remaining lifetime on the certificate used to authenticate a request.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'apiserver_client_certificate_expiration_seconds_bucket{le = "{#LE}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kubernetes.api.get_metrics
              tags:
                - tag: component
                  value: client-certificate
          master_item:
            key: kubernetes.api.get_metrics
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - '{__name__=~ "apiserver_client_certificate_expiration_seconds_*"}'
            - type: JAVASCRIPT
              parameters:
                - |
                  var lookup = {},
                  	result = [];
                  
                  JSON.parse(value).forEach(function (item) {
                  	if (item.name === "apiserver_client_certificate_expiration_seconds_count") {
                  		result.push({
                  			'{#TYPE}': 'totals',
                  			'{#SINGLETON}': ''
                  		});
                  
                  	}
                  	else if (item.name === "apiserver_client_certificate_expiration_seconds_bucket") {
                  		result.push({
                  			'{#TYPE}': 'buckets',
                  			'{#LE}': item.labels.le
                  		});
                  	}
                  });
                  
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
          overrides:
            - name: 'bucket item'
              step: '1'
              filter:
                conditions:
                  - macro: '{#TYPE}'
                    value: buckets
              operations:
                - operator: LIKE
                  value: bucket
                  discover: DISCOVER
            - name: 'total item'
              step: '2'
              filter:
                conditions:
                  - macro: '{#TYPE}'
                    value: totals
              operations:
                - operator: NOT_LIKE
                  value: bucket
                  discover: DISCOVER
        - uuid: 8dcd7c95a9364efdb2fe64c651360ad4
          name: 'Etcd objects metrics discovery'
          type: DEPENDENT
          key: kubernetes.api.etcd_object_counts.discovery
          description: 'Discovery etcd objects by resource.'
          item_prototypes:
            - uuid: 75c15b57189d4cbeb6ed6397fc377e2a
              name: 'etcd objects: {#RESOURCE}'
              type: DEPENDENT
              key: 'kubernetes.api.etcd_object_counts["{#RESOURCE}"]'
              value_type: FLOAT
              description: 'Number of stored objects at the time of last check split by kind.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'etcd_object_counts{ resource = "{#RESOURCE}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kubernetes.api.get_metrics
              tags:
                - tag: component
                  value: etcd
                - tag: resource
                  value: '{#RESOURCE}'
          master_item:
            key: kubernetes.api.get_metrics
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - 'etcd_object_counts{resource =~ ".*"}'
            - type: JAVASCRIPT
              parameters:
                - |
                  var lookup = {},
                  	result = [];
                  
                  JSON.parse(value).forEach(function (item) {
                  	var resource = item.labels.resource;
                  	if (!(lookup[resource])) {
                  		lookup[resource] = 1;
                  		result.push({ '{#RESOURCE}': resource });
                  	}
                  });
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
        - uuid: 099e6ff46075457cba6b669a5880ceef
          name: 'gRPC completed requests discovery'
          type: DEPENDENT
          key: kubernetes.api.grpc_client_handled.discovery
          description: 'Discovery grpc completed requests by grpc code.'
          item_prototypes:
            - uuid: 690dc00ad92d44d0b9bc7db58c07bd8f
              name: 'gRPCs completed: {#GRPC_CODE}, rate'
              type: DEPENDENT
              key: 'kubernetes.api.grpc_client_handled_total.rate["{#GRPC_CODE}"]'
              value_type: FLOAT
              description: 'Total number of RPCs completed by the client regardless of success or failure per second.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'grpc_client_handled_total{grpc_code = "{#GRPC_CODE}"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
                - type: CHANGE_PER_SECOND
              master_item:
                key: kubernetes.api.get_metrics
              tags:
                - tag: component
                  value: grpc
                - tag: grpc-code
                  value: '{#GRPC_CODE}'
          master_item:
            key: kubernetes.api.get_metrics
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - 'grpc_client_handled_total{grpc_code =~ ".*"}'
            - type: JAVASCRIPT
              parameters:
                - |
                  var lookup = {},
                  	result = [];
                  
                  JSON.parse(value).forEach(function (item) {
                  	var grpc_code = item.labels.grpc_code;
                  	if (!(lookup[grpc_code])) {
                  		lookup[grpc_code] = 1;
                  		result.push({ '{#GRPC_CODE}': grpc_code });
                  	}
                  });
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
        - uuid: 948e1d84d44642a78f59c92271a21a68
          name: 'Requests inflight discovery'
          type: DEPENDENT
          key: kubernetes.api.inflight_requests.discovery
          description: 'Discovery requests inflight by kind.'
          item_prototypes:
            - uuid: 5076679154cc464ebab0b678f65c8853
              name: 'Requests current: {#KIND}'
              type: DEPENDENT
              key: 'kubernetes.api.current_inflight_requests["{#KIND}"]'
              value_type: FLOAT
              description: 'Maximal number of currently used inflight request limit of this apiserver per request kind in last second.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'apiserver_current_inflight_requests{request_kind = "{#KIND}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kubernetes.api.get_metrics
              tags:
                - tag: component
                  value: requests
                - tag: kind
                  value: '{#KIND}'
          master_item:
            key: kubernetes.api.get_metrics
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - 'apiserver_current_inflight_requests{request_kind =~ ".*"}'
            - type: JAVASCRIPT
              parameters:
                - |
                  var lookup = {},
                  	result = [];
                  
                  JSON.parse(value).forEach(function (item) {
                  	var request_kind = item.labels.request_kind;
                  	if (!(lookup[request_kind])) {
                  		lookup[request_kind] = 1;
                  		result.push({ '{#KIND}': request_kind });
                  	}
                  });
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
        - uuid: 7cd3ef5e2c874db18088b3531c944b25
          name: 'Long-running requests'
          type: DEPENDENT
          key: kubernetes.api.longrunning_gauge.discovery
          description: 'Discovery of long-running requests by verb, resource and scope.'
          item_prototypes:
            - uuid: feee53d3fc69401ba359ecd97788e552
              name: 'Long-running ["{#VERB}"] requests ["{#RESOURCE}"]: {#SCOPE}'
              type: DEPENDENT
              key: 'kubernetes.api.longrunning_gauge["{#RESOURCE}","{#SCOPE}","{#VERB}"]'
              value_type: FLOAT
              description: 'Gauge of all active long-running apiserver requests broken out by verb, resource and scope. Not all requests are tracked this way.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'apiserver_longrunning_gauge{resource = "{#RESOURCE}", scope = "{#SCOPE}", verb = "{#VERB}"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
              master_item:
                key: kubernetes.api.get_metrics
              tags:
                - tag: component
                  value: requests
                - tag: resource
                  value: '{#RESOURCE}'
                - tag: scope
                  value: '{#SCOPE}'
                - tag: verb
                  value: '{#VERB}'
          master_item:
            key: kubernetes.api.get_metrics
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - 'apiserver_longrunning_gauge{resource =~ ".*", scope =~ ".*", verb =~ ".*"}'
              error_handler: DISCARD_VALUE
            - type: JAVASCRIPT
              parameters:
                - |
                  var lookup = {},
                  	result = [];
                  
                  JSON.parse(value).forEach(function (item) {
                  	var request_kind = item.labels.resource + item.labels.scope + item.labels.verb;
                  	if (!(lookup[request_kind])) {
                  		lookup[request_kind] = 1;
                  		result.push({
                  			'{#RESOURCE}': item.labels.resource,
                  			'{#SCOPE}': item.labels.scope,
                  			'{#VERB}': item.labels.verb
                  		});
                  	}
                  });
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
        - uuid: 7c5ffdbafc5e4e349cc62ed0d0c0f20f
          name: 'Request duration histogram'
          type: DEPENDENT
          key: kubernetes.api.requests_bucket.discovery
          description: 'Discovery raw data and percentile items of request duration.'
          item_prototypes:
            - uuid: 5135a1bc92514c79965edea9d7d2a47e
              name: '["{#VERB}"] Requests bucket: {#LE}'
              type: DEPENDENT
              key: 'kubernetes.api.request_duration_seconds_bucket[{#LE},"{#VERB}"]'
              history: 1h
              value_type: FLOAT
              trends: '0'
              discover: NO_DISCOVER
              description: 'Response latency distribution in seconds for each verb.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'apiserver_request_duration_seconds_bucket{le="{#LE}",verb="{#VERB}"}'
                    - function
                    - sum
              master_item:
                key: kubernetes.api.get_metrics
              tags:
                - tag: component
                  value: requests
                - tag: verb
                  value: '{#VERB}'
            - uuid: a4f39bb87ef248edbb578c0c89baba46
              name: '["{#VERB}"] Requests, p50'
              type: CALCULATED
              key: 'kubernetes.api.request_duration_seconds_p50["{#VERB}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kubernetes.api.request_duration_seconds_bucket[*,"{#VERB}"],5m,50)'
              description: '50 percentile of response latency distribution in seconds for each verb.'
              tags:
                - tag: component
                  value: requests
                - tag: verb
                  value: '{#VERB}'
            - uuid: 12d65aff584e459586284967e570fc0a
              name: '["{#VERB}"] Requests, p90'
              type: CALCULATED
              key: 'kubernetes.api.request_duration_seconds_p90["{#VERB}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kubernetes.api.request_duration_seconds_bucket[*,"{#VERB}"],5m,90)'
              description: '90 percentile of response latency distribution in seconds for each verb.'
              tags:
                - tag: component
                  value: requests
                - tag: verb
                  value: '{#VERB}'
            - uuid: 3e900f1e4cab4edba4d068f1b6759428
              name: '["{#VERB}"] Requests, p95'
              type: CALCULATED
              key: 'kubernetes.api.request_duration_seconds_p95["{#VERB}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kubernetes.api.request_duration_seconds_bucket[*,"{#VERB}"],5m,95)'
              description: '95 percentile of response latency distribution in seconds for each verb.'
              tags:
                - tag: component
                  value: requests
                - tag: verb
                  value: '{#VERB}'
            - uuid: a34c3c5f5f844c46a4d3f148cacd3fd3
              name: '["{#VERB}"] Requests, p99'
              type: CALCULATED
              key: 'kubernetes.api.request_duration_seconds_p99["{#VERB}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kubernetes.api.request_duration_seconds_bucket[*,"{#VERB}"],5m,99)'
              description: '99 percentile of response latency distribution in seconds for each verb.'
              tags:
                - tag: component
                  value: requests
                - tag: verb
                  value: '{#VERB}'
          graph_prototypes:
            - uuid: a974cb068f184b7385bf5eb2e4ba084a
              name: 'Kubernetes API: ["{#VERB}"] Requests latency'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'Kubernetes API server by HTTP'
                    key: 'kubernetes.api.request_duration_seconds_p90["{#VERB}"]'
                - sortorder: '1'
                  color: F63100
                  item:
                    host: 'Kubernetes API server by HTTP'
                    key: 'kubernetes.api.request_duration_seconds_p95["{#VERB}"]'
                - sortorder: '2'
                  color: 00611C
                  item:
                    host: 'Kubernetes API server by HTTP'
                    key: 'kubernetes.api.request_duration_seconds_p99["{#VERB}"]'
                - sortorder: '3'
                  color: F7941D
                  item:
                    host: 'Kubernetes API server by HTTP'
                    key: 'kubernetes.api.request_duration_seconds_p50["{#VERB}"]'
          master_item:
            key: kubernetes.api.get_metrics
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - '{__name__=~ "apiserver_request_duration_*", verb =~ ".*"}'
            - type: JAVASCRIPT
              parameters:
                - |
                  var lookup = {},
                  	lookup_histogram = {},
                  	result = [];
                  
                  JSON.parse(value).forEach(function (item) {
                  	if (item.name === 'apiserver_request_duration_seconds_count') {
                  		var label_verb = item.labels.verb;
                  		if (lookup[label_verb]) {
                  			return;
                  		}
                  		lookup[label_verb] = 1;
                  		result.push({
                  			'{#TYPE}': 'totals',
                  			'{#VERB}': label_verb
                  		});
                  
                  	}
                  	else if (item.name === 'apiserver_request_duration_seconds_bucket') {
                  		var labels = item.labels.verb + item.labels.le;
                  
                  		if (lookup_histogram[labels]) {
                  			return;
                  		}
                  
                  		lookup_histogram[labels] = 1;
                  		result.push({
                  			'{#TYPE}': 'buckets',
                  			'{#VERB}': item.labels.verb,
                  			'{#LE}': item.labels.le
                  		});
                  	}
                  });
                  
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
          overrides:
            - name: 'bucket item'
              step: '1'
              filter:
                conditions:
                  - macro: '{#TYPE}'
                    value: buckets
              operations:
                - operator: LIKE
                  value: bucket
                  discover: DISCOVER
            - name: 'total item'
              step: '2'
              filter:
                conditions:
                  - macro: '{#TYPE}'
                    value: totals
              operations:
                - operator: NOT_LIKE
                  value: bucket
                  discover: DISCOVER
        - uuid: d015cafd6e9f4707bb78125ff17cc679
          name: 'Workqueue metrics discovery'
          type: DEPENDENT
          key: kubernetes.api.workqueue.discovery
          description: 'Discovery workqueue metrics by name.'
          item_prototypes:
            - uuid: cf58e773a5684eafa74b56ed43490148
              name: '["{#NAME}"] Workqueue adds total, rate'
              type: DEPENDENT
              key: 'kubernetes.api.workqueue_adds_total.rate["{#NAME}"]'
              value_type: FLOAT
              description: 'Total number of adds handled by workqueue per second.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'workqueue_adds_total{name = "{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
                - type: CHANGE_PER_SECOND
              master_item:
                key: kubernetes.api.get_metrics
              tags:
                - tag: component
                  value: workqueue
                - tag: workqueue
                  value: '{#NAME}'
            - uuid: 4fe45ff01cdf4bdf85e74a52d2d3b917
              name: '["{#NAME}"] Workqueue depth'
              type: DEPENDENT
              key: 'kubernetes.api.workqueue_depth["{#NAME}"]'
              value_type: FLOAT
              description: 'Current depth of workqueue.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'workqueue_depth{name = "{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kubernetes.api.get_metrics
              tags:
                - tag: component
                  value: workqueue
                - tag: workqueue
                  value: '{#NAME}'
          master_item:
            key: kubernetes.api.get_metrics
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - 'workqueue_adds_total{name =~ ".*"}'
            - type: JAVASCRIPT
              parameters:
                - |
                  var lookup = {},
                  	result = [];
                  
                  JSON.parse(value).forEach(function (item) {
                  	var name = item.labels.name;
                  	if (!(lookup[name])) {
                  		lookup[name] = 1;
                  		result.push({ '{#NAME}': name });
                  	}
                  });
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
      tags:
        - tag: class
          value: software
        - tag: subclass
          value: automation
        - tag: subclass
          value: containers
        - tag: subclass
          value: deploy
        - tag: subclass
          value: development
        - tag: subclass
          value: virtualization
        - tag: target
          value: api-server
        - tag: target
          value: kubernetes
      macros:
        - macro: '{$KUBE.API.CERT.EXPIRATION}'
          value: '7'
          description: 'Number of days for alert of client certificate used for trigger.'
          config:
            type: TEXT
            priority: '3'
            label: 'Certificate Expiration Alert (days)'
            description: 'Number of days before the client certificate expiration to trigger an alert. No less than 0.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$KUBE.API.HTTP.CLIENT.ERROR}'
          value: '2'
          description: 'Maximum number of HTTP client requests failures used for trigger.'
          config:
            type: TEXT
            priority: '4'
            section_name: Thresholds
            label: 'HTTP Client Error Threshold'
            description: 'Maximum number of HTTP client request failures allowed before triggering an alert. No less than 0.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$KUBE.API.HTTP.SERVER.ERROR}'
          value: '2'
          description: 'Maximum number of HTTP server requests failures used for trigger.'
          config:
            type: TEXT
            priority: '5'
            section_name: Thresholds
            label: 'HTTP Server Error Threshold'
            description: 'Maximum number of HTTP server request failures allowed before triggering an alert. No less than 0.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$KUBE.API.SERVER.URL}'
          value: 'https://localhost:6443/metrics'
          description: 'Kubernetes API server metrics endpoint URL.'
          config:
            type: TEXT
            priority: '2'
            label: 'Kubernetes API server URL'
            description: 'URL to access the Kubernetes API server metrics endpoint.'
            required: 'YES'
        - macro: '{$KUBE.API.TOKEN}'
          type: SECRET_TEXT
          description: 'API Authorization Token.'
          config:
            type: TEXT
            priority: '1'
            label: 'API Authorization Token'
            description: 'Token used for API authorization to access the Kubernetes API server.'
            required: 'YES'
      dashboards:
        - uuid: 5dd45bdfb5ed45bd9e3b26f01806820f
          name: 'API server overview'
          pages:
            - name: 'HTTP requests rate'
              widgets:
                - type: graph
                  width: '72'
                  height: '10'
                  fields:
                    - type: GRAPH
                      name: graphid.0
                      value:
                        host: 'Kubernetes API server by HTTP'
                        name: 'Kubernetes API: HTTP requests rate'
                    - type: STRING
                      name: reference
                      value: AAAAA
            - name: 'Requests duration histogram'
              widgets:
                - type: graphprototype
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'Kubernetes API server by HTTP'
                        name: 'Kubernetes API: ["{#VERB}"] Requests latency'
                    - type: STRING
                      name: reference
                      value: AAAAB
    - uuid: 07695028a2ba4b66a5414797bec791df
      template: 'Kubernetes cluster state by HTTP'
      name: 'Kubernetes cluster state by HTTP'
      description: |
        Get Kubernetes state metrics by HTTP.
        Metrics are collected by requests to Kubernetes API.
        
        Don't forget to read the README.md for the correct setup of the template.
        
        You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback
        
        Generated by official Zabbix template tool "Templator"
      wizard_ready: 'YES'
      readme: |
        ## Overview
        
        The template to monitor Kubernetes state.
        It works without external scripts and uses the script item to make HTTP requests to the Kubernetes API.
        
        Template `Kubernetes cluster state by HTTP` - collects metrics by HTTP agent from kube-state-metrics endpoint and Kubernetes API.
        
        *NOTE.* Some metrics may not be collected depending on your Kubernetes version and configuration.
        
        ## Setup
        
        Install the [Zabbix Helm Chart](https://git.zabbix.com/projects/ZT/repos/kubernetes-helm/browse?at=refs%2Fheads%2Fmaster) in your Kubernetes cluster.
        Internal service metrics are collected from kube-state-metrics endpoint.
        
        Template needs to use authorization via API token.
        
        Set the `Kubernetes API URL` such as `<scheme>://<host>:<port>`.
        
        Get the generated service account token using the command:
        
        `kubectl get secret zabbix-service-account -n monitoring -o jsonpath={.data.token} | base64 -d`
        
        Then set it to the field: `API Authorization Token`.
        Set `State Endpoint Name` with Kube state metrics endpoint name. See `kubectl -n monitoring get ep`. Default: `zabbix-kube-state-metrics`.
        
        *NOTE.* If you wish to monitor Controller Manager and Scheduler components, you might need to set the `--binding-address` option for them to the address where Zabbix proxy can reach them.
        For example, for clusters created with `kubeadm` it can be set in the following manifest files (changes will be applied immediately):
        
        - /etc/kubernetes/manifests/kube-controller-manager.yaml
        - /etc/kubernetes/manifests/kube-scheduler.yaml
        
        Depending on your Kubernetes distribution, you might need to adjust `Control Plane Taint` field (for example, set it to `node-role.kubernetes.io/master` for OpenShift).
        
        *NOTE.* Some metrics may not be collected depending on your Kubernetes version and configuration.
        
        Set up the fields to filter the metrics of discovered Kubelets by node names:
        
        - `Kubelet Node Matches Filter`
        - `Kubelet Node Exclude Filter`
        
        Set up fields to filter metrics by namespace:
        
        - `Namespace Matches Filter`
        - `Namespace Exclude Filter`
        
        Set up fields to filter node metrics by nodename:
        
        - `Node Matches Filter`
        - `Node Exclude Filter`
        
        **Note**: If you have a large cluster, it is highly recommended to set a filter for discoverable namespaces.
        
        You can use the `Kubelet Labels Filter` and `Kubelet Annotations Filter` fields for advanced filtering of kubelets by node labels and annotations.
        
        Notes about labels and annotations filters:
        
        - Values should be specified separated by commas and must have the key/value form with support for regular expressions in the value (`key1: value, key2: regexp`).
        - ECMAScript syntax is used for regular expressions.
        - Filters are applied if such label key exists for the entity that is being filtered (it means that if you specify a key in the filter, entities that do not have this key will not be affected by the filter and will still be discovered, and only entities containing that key will be filtered by the value).
        - You can also use the exclamation point symbol (`!`) to invert the filter (`!key: value`).
        
        For example: `kubernetes.io/hostname: kubernetes-node[5-25], !node-role.kubernetes.io/ingress: .*`. As a result, the kubelets on nodes 5-25 without the "ingress" role will be discovered.
        
        
        See the Kubernetes documentation for details about labels and annotations:
        
        - <https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/>
        - <https://kubernetes.io/docs/concepts/overview/working-with-objects/annotations/>
        
        You can also set up evaluation periods for replica mismatch triggers (Deployments, ReplicaSets, StatefulSets) with the field `Replica Mismatch Evaluation Period`, which supports context and regular expressions.
      vendor:
        name: Zabbix
        version: 7.4-1
      groups:
        - name: Templates/Applications
      items:
        - uuid: 41c79d9286734cc3b0e3aa5ef729e5fe
          name: 'Get component statuses'
          type: HTTP_AGENT
          key: kube.componentstatuses
          history: '0'
          value_type: TEXT
          preprocessing:
            - type: CHECK_NOT_SUPPORTED
              parameters:
                - '-1'
          timeout: 10s
          url: '{$KUBE.API.URL}{$KUBE.API.COMPONENTSTATUSES.ENDPOINT}'
          status_codes: '200, 403'
          headers:
            - name: Authorization
              value: 'Bearer {$KUBE.API.TOKEN}'
          tags:
            - tag: component
              value: raw
        - uuid: e40b126a0cf64ce6bfed3b3de1d4dfa8
          name: 'Control plane LLD'
          type: SCRIPT
          key: kube.control_plane.lld
          history: '0'
          value_type: TEXT
          params: |
            var Kube = {
            	params: {},
            
            	setParams: function (params) {
            		['api_token', 'api_url', 'api_server_scheme', 'api_server_port', 'controller_scheme', 'controller_port',
            			'scheduler_scheme', 'scheduler_port', 'control_plane_taint'].forEach(function (field) {
            				if (typeof params !== 'object' || typeof params[field] === 'undefined'
            					|| params[field] === '') {
            					throw 'Required param is not set: "' + field + '".';
            				}
            			});
            
            		Kube.params = params;
            		if (typeof Kube.params.api_url === 'string' && !Kube.params.api_url.endsWith('/')) {
            			Kube.params.api_url += '/';
            		}
            	},
            
            	apiRequest: function (query) {
            		var request = new HttpRequest(),
            			response,
            			url = encodeURI(Kube.params.api_url + query);
            		if (typeof Kube.params.http_proxy !== 'undefined' && Kube.params.http_proxy !== '') {
            			request.setProxy(Kube.params.http_proxy);
            		}
            		request.addHeader('Content-Type: application/json');
            		request.addHeader('Authorization: Bearer ' + Kube.params.api_token);
            
            		Zabbix.log(4, '[ Kubernetes ] Sending request: ' + url);
            
            		if (Kube.params.http_proxy) {
            			Zabbix.log(4, '[ Kubernetes ] Using http proxy: ' + Kube.params.http_proxy);
            		}
            
            		response = request.get(url);
            
            		Zabbix.log(4, '[ Kubernetes ] Received response with status code ' + request.getStatus() + ': ' + response);
            
            		if (request.getStatus() < 200 || request.getStatus() >= 300) {
            			throw 'Request failed with status code ' + request.getStatus() + ': ' + response;
            		}
            
            		try {
            			response = JSON.parse(response);
            		}
            		catch (error) {
            			throw 'Failed to parse response received from Kubernetes API. Check debug log for more information.';
            		}
            		return response;
            	},
            
            	getField: function (data, path) {
            		var steps = path.split('.');
            		for (var i = 0; i < steps.length; i++) {
            			var step = steps[i];
            			if (typeof data !== 'object' || typeof data[step] === 'undefined') {
            				throw 'Required field was not found: ' + path;
            			}
            
            			data = data[step];
            		}
            
            		return data;
            	},
            
            	getNodes: function () {
            		var result = Kube.apiRequest('api/v1/nodes?labelSelector=' + Kube.params.control_plane_taint);
            
            		if (typeof result !== 'object'
            			|| typeof result.items === 'undefined') {
            			throw 'Cannot get control plane nodes from Kubernetes API. Check debug log for more information.';
            		};
            
            		var nodes = result.items,
            			IPv4 = /(?:\d{1,3}\.){3}\d{1,3}/,
            			controlPlaneNodes = [],
            			hostname = Kube.params.api_url.match(/https?:\/\/([\w.-]+|\[[a-f0-9:]+\]|[^a-zA-Z:]+)(?::\d+)?/);
            
            		if (typeof hostname[1] === 'undefined') {
            			Zabbix.log(4, '[ Kubernetes ] Received incorrect Kubernetes API url: ' + api_url + '. Expected format: <scheme>://<host>:<port>');
            			throw 'Cannot get hostname from Kubernetes API url. Check debug log for more information.';
            		};
            
            		controlPlaneNodes = nodes.map(function (node) {
            			var internalIPs = Kube.getField(node, 'status.addresses').filter(function (addr) {
            				return addr.type === 'InternalIP';
            			});
            			var internalIP = internalIPs.length && internalIPs[0].address;
            
            			return {
            				'{#NAME}': Kube.getField(node, 'metadata.name'),
            				'{#IP}': internalIP,
            				'{#KUBE.API.SERVER.URL}': Kube.params.api_server_scheme + '://' + (IPv4.test(internalIP) ? internalIP : '[' + internalIP + ']') + ':' + Kube.params.api_server_port + '/metrics',
            				'{#KUBE.CONTROLLER.SERVER.URL}': Kube.params.controller_scheme + '://' + (IPv4.test(internalIP) ? internalIP : '[' + internalIP + ']') + ':' + Kube.params.controller_port + '/metrics',
            				'{#KUBE.SCHEDULER.SERVER.URL}': Kube.params.scheduler_scheme + '://' + (IPv4.test(internalIP) ? internalIP : '[' + internalIP + ']') + ':' + Kube.params.scheduler_port + '/metrics',
            				'{#COMPONENT.API}': 'API',
            				'{#COMPONENT.CONTROLLER}': 'Controller manager',
            				'{#COMPONENT.SCHEDULER}': 'Scheduler',
            				'{#CLUSTER_HOSTNAME}': hostname[1]
            			};
            		});
            
            		return JSON.stringify(controlPlaneNodes);
            	}
            };
            
            try {
            	Kube.setParams(JSON.parse(value));
            	return Kube.getNodes();
            }
            catch (error) {
            	error += (String(error).endsWith('.')) ? '' : '.';
            	Zabbix.log(3, '[ Kubernetes ] ERROR: ' + error);
            	return JSON.stringify({ error: error });
            }
          description: 'Generation of data for Control plane discovery rules.'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
          timeout: 10s
          parameters:
            - name: api_server_port
              value: '{$KUBE.API_SERVER.PORT}'
            - name: api_server_scheme
              value: '{$KUBE.API_SERVER.SCHEME}'
            - name: api_token
              value: '{$KUBE.API.TOKEN}'
            - name: api_url
              value: '{$KUBE.API.URL}'
            - name: controller_port
              value: '{$KUBE.CONTROLLER_MANAGER.PORT}'
            - name: controller_scheme
              value: '{$KUBE.CONTROLLER_MANAGER.SCHEME}'
            - name: control_plane_taint
              value: '{$KUBE.CONTROL_PLANE.TAINT}'
            - name: http_proxy
              value: '{$KUBE.HTTP.PROXY}'
            - name: scheduler_port
              value: '{$KUBE.SCHEDULER.PORT}'
            - name: scheduler_scheme
              value: '{$KUBE.SCHEDULER.SCHEME}'
          tags:
            - tag: component
              value: raw
        - uuid: 6f22e81d69d04eeca88a7992463556a7
          name: 'CronJob count'
          type: DEPENDENT
          key: kube.cronjob.count
          description: 'Number of cronjobs.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - kube_cronjob_created
                - function
                - count
              error_handler: DISCARD_VALUE
          master_item:
            key: kube.state.metrics
          tags:
            - tag: component
              value: cronjob
        - uuid: 483fc2c315264ae5963d34a45f80156e
          name: 'Deployment count'
          type: DEPENDENT
          key: kube.deployment.count
          description: 'The number of deployments.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - kube_deployment_created
                - function
                - count
              error_handler: DISCARD_VALUE
          master_item:
            key: kube.state.metrics
          tags:
            - tag: component
              value: deployment
        - uuid: 93126582e30e45b8a70f6e45402e2f54
          name: 'Endpoint count'
          type: DEPENDENT
          key: kube.endpoint.count
          description: 'Number of endpoints.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - kube_endpoint_created
                - function
                - count
              error_handler: DISCARD_VALUE
          master_item:
            key: kube.state.metrics
          tags:
            - tag: component
              value: endpoint
        - uuid: c08df3a8ae044ae9a331db33bcca7db3
          name: 'Job count'
          type: DEPENDENT
          key: kube.job.count
          description: 'Number of jobs (generated by cronjob + job).'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - kube_job_created
                - function
                - count
              error_handler: DISCARD_VALUE
          master_item:
            key: kube.state.metrics
          tags:
            - tag: component
              value: job
        - uuid: d731fb05f0284921ab3548ba631f019c
          name: 'Get livez'
          type: HTTP_AGENT
          key: kube.livez
          history: '0'
          value_type: TEXT
          preprocessing:
            - type: JAVASCRIPT
              parameters:
                - |
                  var output = [],
                  	component;
                  
                  value.split(/\n/).forEach(function (entry) {
                  	if (component = entry.match(/^\[.+\](.+)\s(\w+)$/)) {
                  		output.push({
                  			name: component[1],
                  			value: component[2]
                  		});
                  	}
                  });
                  
                  return JSON.stringify(output);
          timeout: 10s
          url: '{$KUBE.API.URL}{$KUBE.API.LIVEZ.ENDPOINT}?verbose'
          status_codes: '200, 403'
          headers:
            - name: Authorization
              value: 'Bearer {$KUBE.API.TOKEN}'
          tags:
            - tag: component
              value: raw
        - uuid: d266edd6dda34e15888b572569a1f301
          name: 'Namespace count'
          type: DEPENDENT
          key: kube.namespace.count
          description: 'The number of namespaces.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - kube_namespace_created
                - function
                - count
              error_handler: DISCARD_VALUE
          master_item:
            key: kube.state.metrics
          tags:
            - tag: component
              value: namespace
        - uuid: 968e1dcaf76645aebd4979b9ad4eca9e
          name: 'Node count'
          type: DEPENDENT
          key: kube.node.count
          description: 'The number of nodes.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - kube_node_created
                - function
                - count
              error_handler: DISCARD_VALUE
          master_item:
            key: kube.state.metrics
          tags:
            - tag: component
              value: node
        - uuid: aae78585c668466da5d0ab8d8b899828
          name: 'Node LLD'
          type: SCRIPT
          key: kube.node.lld
          history: '0'
          value_type: TEXT
          params: |
            var Kube = {
            	params: {},
            
            	setParams: function (params) {
            		['api_url', 'api_token', 'kubelet_scheme', 'kubelet_port'].forEach(function (field) {
            			if (typeof params !== 'object' || typeof params[field] === 'undefined'
            				|| params[field] === '') {
            				throw 'Required param is not set: "' + field + '".';
            			}
            		});
            		['node_filter_labels', 'node_filter_annotations'].forEach(function (field) {
            			if (typeof params !== 'object' || typeof params[field] === 'undefined') {
            				throw 'Parameter can be empty but not removed: "' + field + '".';
            			}
            		});
            
            		Kube.params = params;
            		if (typeof Kube.params.api_url === 'string' && !Kube.params.api_url.endsWith('/')) {
            			Kube.params.api_url += '/';
            		}
            
            	},
            
            	apiRequest: function (query) {
            		var request = new HttpRequest(),
            			response,
            			url = encodeURI(Kube.params.api_url + query);
            
            		if (typeof Kube.params.http_proxy !== 'undefined' && Kube.params.http_proxy !== '') {
            			request.setProxy(Kube.params.http_proxy);
            		}
            
            		request.addHeader('Content-Type: application/json');
            		request.addHeader('Authorization: Bearer ' + Kube.params.api_token);
            
            		Zabbix.log(4, '[ Kubernetes ] Sending request: ' + url);
            
            		if (Kube.params.http_proxy) {
            			Zabbix.log(4, '[ Kubernetes ] Using http proxy: ' + Kube.params.http_proxy);
            		}
            
            		response = request.get(url);
            
            		Zabbix.log(4, '[ Kubernetes ] Received response with status code ' + request.getStatus() + ': ' + response);
            
            		if (request.getStatus() < 200 || request.getStatus() >= 300) {
            			throw 'Request failed with status code ' + request.getStatus() + ': ' + response;
            
            		}
            		try {
            			response = JSON.parse(response);
            		}
            		catch (error) {
            			throw 'Failed to parse response received from Kubernetes API. Check debug log for more information.';
            		}
            		return response;
            
            	},
            
            	parseFilters: function (csv) {
            		if (!csv)
            			return [];
            
            		var filters = [];
            		const filterCapture = /([!\w\-\.\/]+)\s*:\s*(.*)/;
            		const onComma = /\s*,\s*/;
            
            		csv.split(onComma).forEach(function (kv) {
            			var match = kv.match(filterCapture);
            			if (!match) {
            				Zabbix.log(3, 'Cannot parse filter from: "' + kv + '"');
            				return;
            			}
            
            			filters.push({ key: match[1], expression: match[2] });
            		});
            
            		return filters;
            	},
            
            	filter: function (name, data, filters) {
            		if (typeof data !== 'object') {
            			return true;
            		}
            
            		return filters.every(function (filter) {
            			const filter_key = filter.key.startsWith('!') ? filter.key.substring(1) : filter.key;
            
            			if (!(filter_key in data)) {
            				return true;
            			}
            
            			const isExcludingFilter = filter.key.startsWith('!');
            			const isMatchForFilter = new RegExp(filter.expression).test(data[filter_key]);
            
            			if ((isExcludingFilter && isMatchForFilter) ||
            				(!isExcludingFilter && !isMatchForFilter)) {
            				Zabbix.log(4, '[ Kubernetes ] Discarded "' + name + '" by filter "' + filter.key + ': ' + filter.expression + '"');
            				return false;
            			}
            
            			return true;
            		});
            	},
            
            	getField: function (data, path) {
            		var steps = path.split('.');
            		for (var i = 0; i < steps.length; i++) {
            			var step = steps[i];
            			if (typeof data !== 'object' || typeof data[step] === 'undefined') {
            				throw 'Required field was not found: ' + path;
            			}
            
            			data = data[step];
            		}
            
            		return data;
            	},
            
            	getNodes: function () {
            		var result = Kube.apiRequest('api/v1/nodes');
            		if (typeof result !== 'object'
            			|| typeof result.items === 'undefined') {
            			throw 'Cannot get nodes from Kubernetes API. Check debug log for more information.';
            		};
            		var nodes = result.items,
            			IPv4 = /(?:\d{1,3}\.){3}\d{1,3}/,
            			kubeNodes = [],
            			hostname = Kube.params.api_url.match(/https?:\/\/([\w.-]+|\[[a-f0-9:]+\]|[^a-zA-Z:]+)(?::\d+)?/),
            			filterNodeLabels = Kube.parseFilters(Kube.params.node_filter_labels),
            			filterNodeAnnotations = Kube.parseFilters(Kube.params.node_filter_annotations);
            
            		if (typeof hostname[1] === 'undefined') {
            			Zabbix.log(4, '[ Kubernetes ] Received incorrect Kubernetes API url: ' + api_url + '. Expected format: <scheme>://<host>:<port>');
            			throw 'Cannot get hostname from Kubernetes API url. Check debug log for more information.';
            		};
            
            		kubeNodes = nodes.map(function (node) {
            			if (Kube.filter(Kube.getField(node, 'metadata.name'), Kube.getField(node, 'metadata.labels'), filterNodeLabels)
            				&& Kube.filter(Kube.getField(node, 'metadata.name'), Kube.getField(node, 'metadata.annotations'), filterNodeAnnotations)) {
            				Zabbix.log(4, '[ Kubernetes ] Filtered node "' + node.metadata.name + '"');
            
            				var internalIPs = Kube.getField(node, 'status.addresses').filter(function (addr) {
            					return addr.type === 'InternalIP';
            				});
            
            				var internalIP = internalIPs.length && internalIPs[0].address;
            
            				return {
            					'{#NAME}': node.metadata.name,
            					'{#IP}': internalIP,
            					'{#KUBE.KUBELET.URL}': Kube.params.kubelet_scheme + '://' + (IPv4.test(internalIP) ? internalIP : '[' + internalIP + ']') + ':' + Kube.params.kubelet_port,
            					'{#COMPONENT}': 'Kubelet',
            					'{#CLUSTER_HOSTNAME}': hostname[1]
            				};
            			}
            		});
            
            		return JSON.stringify(kubeNodes);
            
            	},
            };
            
            try {
            	Kube.setParams(JSON.parse(value));
            	return Kube.getNodes();
            }
            catch (error) {
            	error += (String(error).endsWith('.')) ? '' : '.';
            	Zabbix.log(3, '[ Kubernetes ] ERROR: ' + error);
            	return JSON.stringify({ error: error });
            }
          description: 'Generation of data for Kubelet discovery rules.'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
          timeout: 10s
          parameters:
            - name: api_token
              value: '{$KUBE.API.TOKEN}'
            - name: api_url
              value: '{$KUBE.API.URL}'
            - name: http_proxy
              value: '{$KUBE.HTTP.PROXY}'
            - name: kubelet_port
              value: '{$KUBE.KUBELET.PORT}'
            - name: kubelet_scheme
              value: '{$KUBE.KUBELET.SCHEME}'
            - name: node_filter_annotations
              value: '{$KUBE.KUBELET.FILTER.ANNOTATIONS}'
            - name: node_filter_labels
              value: '{$KUBE.KUBELET.FILTER.LABELS}'
          tags:
            - tag: component
              value: raw
        - uuid: 3a5eaef4e8134dfb9f2935f98a8b88f7
          name: 'Get readyz'
          type: HTTP_AGENT
          key: kube.readyz
          history: '0'
          value_type: TEXT
          preprocessing:
            - type: JAVASCRIPT
              parameters:
                - |
                  var output = [],
                  	component;
                  
                  value.split(/\n/).forEach(function (entry) {
                  	if (component = entry.match(/^\[.+\](.+)\s(\w+)$/)) {
                  		output.push({
                  			name: component[1],
                  			value: component[2]
                  		});
                  	}
                  });
                  
                  return JSON.stringify(output);
          timeout: 10s
          url: '{$KUBE.API.URL}{$KUBE.API.READYZ.ENDPOINT}?verbose'
          status_codes: '200, 403'
          headers:
            - name: Authorization
              value: 'Bearer {$KUBE.API.TOKEN}'
          tags:
            - tag: component
              value: raw
        - uuid: 262b0114fed14fec91d50589e97307a7
          name: 'Service count'
          type: DEPENDENT
          key: kube.service.count
          description: 'The number of services.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - kube_service_created
                - function
                - count
              error_handler: DISCARD_VALUE
          master_item:
            key: kube.state.metrics
          tags:
            - tag: component
              value: service
        - uuid: 66e69f9970ce478f8f0ff13f26b248e3
          name: 'Get state metrics'
          type: SCRIPT
          key: kube.state.metrics
          history: '0'
          value_type: TEXT
          params: |
            var Kube = {
            	params: {},
            
            	setParams: function (params) {
            		['api_url', 'api_token', 'state_endpoint_name'].forEach(function (field) {
            			if (typeof params !== 'object' || typeof params[field] === 'undefined'
            				|| params[field] === '') {
            				throw 'Required param is not set: "' + field + '".';
            			}
            		});
            
            		Kube.params = params;
            		if (typeof Kube.params.api_url === 'string' && !Kube.params.api_url.endsWith('/')) {
            			Kube.params.api_url += '/';
            		}
            	},
            
            	apiRequest: function (query) {
            		var request = new HttpRequest(),
            			response,
            			url = encodeURI(Kube.params.api_url + query);
            
            		if (typeof Kube.params.http_proxy !== 'undefined' && Kube.params.http_proxy !== '') {
            			request.setProxy(Kube.params.http_proxy);
            		}
            
            		request.addHeader('Content-Type: application/json');
            		request.addHeader('Authorization: Bearer ' + Kube.params.api_token);
            
            		Zabbix.log(4, '[ Kubernetes ] Sending request: ' + url);
            
            		if (Kube.params.http_proxy) {
            			Zabbix.log(4, '[ Kubernetes ] Using http proxy: ' + Kube.params.http_proxy);
            		}
            
            		response = request.get(url);
            
            		Zabbix.log(4, '[ Kubernetes ] Received response with status code ' + request.getStatus() + ': ' + response);
            
            		if (request.getStatus() < 200 || request.getStatus() >= 300) {
            			throw 'Request failed with status code ' + request.getStatus() + ': ' + response;
            		}
            		try {
            			response = JSON.parse(response);
            		}
            		catch (error) {
            			throw 'Failed to parse response received from Kubernetes API. Check debug log for more information.';
            		}
            		return response;
            	},
            
            	getEndpoint: function (ep) {
            		if (typeof ep.subsets[0].addresses !== 'undefined') {
            			var scheme,
            				addr,
            				port;
            			ep.subsets.forEach(function (subset) {
            				var lp = subset.ports.filter(function (port) {
            					if (port.name !== 'http' &&
            						port.name !== 'https' &&
            						port.name !== 'https-main') {
            						return false;
            					}
            					scheme = port.name.match(/https?/);
            					return true;
            				})
            				if (lp.length) {
            					port = lp[0].port
            					addr = subset.addresses[0].ip
            				}
            			})
            			return {
            				scheme: scheme || 'http',
            				address: addr || ep.subsets[0].addresses[0].ip,
            				port: port || 8080
            			}
            		}
            	},
            
            	getMetricsEndpoint: function () {
            		var result = Kube.apiRequest('api/v1/endpoints'),
            			endpoint = [];
            
            		if (typeof result !== 'object'
            			|| typeof result.items === 'undefined') {
            			throw 'Cannot get endpoints from Kubernetes API. Check debug log for more information.';
            		};
            
            		result.items.forEach(function (ep) {
            			if (ep.metadata.name === Kube.params.state_endpoint_name && Array.isArray(ep.subsets)) {
            				endpoint.push(Kube.getEndpoint(ep));
            			}
            			if (typeof Kube.params.openshift_endpoint_name !== 'undefined' && Kube.params.openshift_endpoint_name !== ''
            				&& ep.metadata.name === Kube.params.openshift_endpoint_name && Array.isArray(ep.subsets)) {
            				endpoint.push(Kube.getEndpoint(ep));
            			}
            		});
            		if (endpoint.length === 0) {
            			throw 'Cannot get state metrics endpoints from Kubernetes API. Check debug log for more information.';
            		}
            		return endpoint;
            	},
            
            	getStateMetrics: function () {
            		var metrics_endpoint = Kube.getMetricsEndpoint(),
            			IPv4 = /(?:\d{1,3}\.){3}\d{1,3}/,
            			result = '',
            			request = new HttpRequest();
            
            		request.addHeader('Content-Type: application/json');
            		request.addHeader('Authorization: Bearer ' + Kube.params.api_token);
            
            		if (typeof Kube.params.http_proxy !== 'undefined' && Kube.params.http_proxy !== '') {
            			request.setProxy(Kube.params.http_proxy);
            			Zabbix.log(4, '[ Kubernetes ] Using http proxy: ' + Kube.params.http_proxy);
            		}
            
            		metrics_endpoint.forEach(function (endpoint) {
            			var url = endpoint.scheme + '://' + (IPv4.test(endpoint.address) ? endpoint.address : '[' + endpoint.address + ']') + ':' + endpoint.port + '/metrics';
            
            			Zabbix.log(4, '[ Kubernetes ] Sending request: ' + url);
            			response = request.get(url);
            			Zabbix.log(4, '[ Kubernetes ] Received response with status code ' + request.getStatus() + ': ' + response);
            
            			if (request.getStatus() < 200 || request.getStatus() >= 300) {
            				throw 'Request failed with status code ' + request.getStatus() + ': ' + response;
            			}
            			if (response === null) {
            				throw 'Failed to get state metrics. Check debug log for more information.';
            			}
            			result += response + '\n';
            		}
            		);
            
            		return result;
            
            	}
            };
            
            try {
            	Kube.setParams(JSON.parse(value));
            
            	var stateMetrics = Kube.getStateMetrics();
            
            	return stateMetrics;
            }
            catch (error) {
            	error += (String(error).endsWith('.')) ? '' : '.';
            	Zabbix.log(3, '[ Kubernetes ] ERROR: ' + error);
            	return JSON.stringify({ error: error });
            }
          description: 'Collecting Kubernetes metrics from kube-state-metrics.'
          timeout: 10s
          parameters:
            - name: api_token
              value: '{$KUBE.API.TOKEN}'
            - name: api_url
              value: '{$KUBE.API.URL}'
            - name: http_proxy
              value: '{$KUBE.HTTP.PROXY}'
            - name: openshift_endpoint_name
              value: '{$OPENSHIFT.STATE.ENDPOINT.NAME}'
            - name: state_endpoint_name
              value: '{$KUBE.STATE.ENDPOINT.NAME}'
          tags:
            - tag: component
              value: raw
        - uuid: 3940412bea334e139a72b223197582eb
          name: 'StatefulSet count'
          type: DEPENDENT
          key: kube.statefulset.count
          description: 'The number of statefulsets.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - kube_statefulset_created
                - function
                - count
              error_handler: DISCARD_VALUE
          master_item:
            key: kube.state.metrics
          tags:
            - tag: component
              value: statefulset
      discovery_rules:
        - uuid: dbfd8959361f4cdd973ed552eb18eb86
          name: 'API servers discovery'
          type: DEPENDENT
          key: kube.api_servers.discovery
          host_prototypes:
            - uuid: a67ac5100e6d499088e4c81856f947fc
              host: 'API {#NAME}'
              name: 'API {#NAME}'
              group_links:
                - group:
                    name: Applications
              group_prototypes:
                - name: '{#CLUSTER_HOSTNAME}: Kubernetes/Components: {#COMPONENT.API}'
              templates:
                - name: 'Kubernetes API server by HTTP'
              macros:
                - macro: '{$KUBE.API.SERVER.URL}'
                  value: '{#KUBE.API.SERVER.URL}'
              tags:
                - tag: addr
                  value: '{#IP}'
              custom_interfaces: 'YES'
              interfaces:
                - ip: '{#IP}'
          master_item:
            key: kube.control_plane.lld
        - uuid: 920b56d5e9234da6b60717763e206736
          name: 'Component statuses discovery'
          type: DEPENDENT
          key: kube.componentstatuses.discovery
          item_prototypes:
            - uuid: 766e311f05f646d18eaaaa9ea9afa691
              name: 'Component [{#NAME}]: Healthy'
              type: DEPENDENT
              key: 'kube.componentstatuses.healthy[{#NAME}]'
              value_type: CHAR
              description: 'Cluster component healthy.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.items.[?(@.metadata.name == "{#NAME}")].conditions[?(@.type == "Healthy")].status.first()'
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.componentstatuses
              tags:
                - tag: component
                  value: component
                - tag: component
                  value: '{#NAME}'
                - tag: status
                  value: healthy
              trigger_prototypes:
                - uuid: 58828a692aa2418ba98c6d66a23f1506
                  expression: 'count(/Kubernetes cluster state by HTTP/kube.componentstatuses.healthy[{#NAME}],#2,"ne","True")=2 and length(last(/Kubernetes cluster state by HTTP/kube.componentstatuses.healthy[{#NAME}]))>0'
                  recovery_mode: RECOVERY_EXPRESSION
                  recovery_expression: 'count(/Kubernetes cluster state by HTTP/kube.componentstatuses.healthy[{#NAME}],#3,"eq","True")=3'
                  name: 'Kubernetes cluster state: Component [{#NAME}] is unhealthy'
                  priority: WARNING
                  tags:
                    - tag: scope
                      value: availability
          master_item:
            key: kube.componentstatuses
          lld_macro_paths:
            - lld_macro: '{#NAME}'
              path: $.metadata.name
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.items
              error_handler: DISCARD_VALUE
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
        - uuid: 08463c66bce845e7acff0d91785e0982
          name: 'Controller manager nodes discovery'
          type: DEPENDENT
          key: kube.controller_manager.discovery
          host_prototypes:
            - uuid: 9d529f3924fc4831a62fb1eec79b64d7
              host: 'Controller manager {#NAME}'
              name: 'Controller manager {#NAME}'
              group_links:
                - group:
                    name: Applications
              group_prototypes:
                - name: '{#CLUSTER_HOSTNAME}: Kubernetes/Components: {#COMPONENT.CONTROLLER}'
              templates:
                - name: 'Kubernetes Controller manager by HTTP'
              macros:
                - macro: '{$KUBE.CONTROLLER.SERVER.URL}'
                  value: '{#KUBE.CONTROLLER.SERVER.URL}'
              tags:
                - tag: addr
                  value: '{#IP}'
              custom_interfaces: 'YES'
              interfaces:
                - ip: '{#IP}'
          master_item:
            key: kube.control_plane.lld
        - uuid: 9bb7532f14dd42c6a532636126e507f9
          name: 'CronJob discovery'
          type: DEPENDENT
          key: kube.cronjob.discovery
          filter:
            evaltype: AND
            conditions:
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.MATCHES}'
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.NOT_MATCHES}'
                operator: NOT_MATCHES_REGEX
          lifetime: '0'
          item_prototypes:
            - uuid: fd1afcc4646146588fd3c22cf2f7e040
              name: 'Namespace [{#NAMESPACE}] CronJob [{#NAME}]: Completion failed'
              type: DEPENDENT
              key: 'kube.cronjob.completion.failed[{#NAMESPACE}/{#NAME}]'
              description: 'Number of jobs the execution of which has failed.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_job_failed{namespace="{#NAMESPACE}", job_name=~"{#NAME}-*", condition="true"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: cronjob
                - tag: cronjob
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
            - uuid: 5ba1dfd55c784f8597575b38399d5e36
              name: 'Namespace [{#NAMESPACE}] CronJob [{#NAME}]: Completion succeeded'
              type: DEPENDENT
              key: 'kube.cronjob.completion.succeeded[{#NAMESPACE}/{#NAME}]'
              description: 'Number of jobs the execution of which has been completed.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_job_complete{namespace="{#NAMESPACE}", job_name=~"{#NAME}-*", condition="true"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: cronjob
                - tag: cronjob
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
            - uuid: 7ae683d5a1ed4f84a09b38863bd263a7
              name: 'Namespace [{#NAMESPACE}] CronJob [{#NAME}]: Last schedule'
              type: DEPENDENT
              key: 'kube.cronjob.last_schedule_time[{#NAMESPACE}/{#NAME}]'
              units: unixtime
              description: 'LastScheduleTime keeps information of when was the last time the job was successfully scheduled.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_cronjob_status_last_schedule_time{namespace="{#NAMESPACE}", cronjob="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
                - type: MULTIPLIER
                  parameters:
                    - '1'
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: cronjob
                - tag: cronjob
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
            - uuid: 8ad7e96b34604a4991698288a7af8027
              name: 'Namespace [{#NAMESPACE}] CronJob [{#NAME}]: Next schedule'
              type: DEPENDENT
              key: 'kube.cronjob.next_schedule_time[{#NAMESPACE}/{#NAME}]'
              units: unixtime
              description: 'Next time the cronjob should be scheduled. The time after lastScheduleTime or after the cron job''s creation time if it''s never been scheduled. Use this to determine if the job is delayed.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_cronjob_next_schedule_time{namespace="{#NAMESPACE}", cronjob="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
                - type: MULTIPLIER
                  parameters:
                    - '1'
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: cronjob
                - tag: cronjob
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
            - uuid: 329e8166d1ec42cca7508580efaad366
              name: 'Namespace [{#NAMESPACE}] CronJob [{#NAME}]: Suspend'
              type: DEPENDENT
              key: 'kube.cronjob.spec_suspend[{#NAMESPACE}/{#NAME}]'
              description: 'Suspend flag tells the controller to suspend subsequent executions.'
              valuemap:
                name: 'Boolean format'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_cronjob_spec_suspend{namespace="{#NAMESPACE}", cronjob="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: cronjob
                - tag: cronjob
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
            - uuid: ce13a921915a4232971f2e29102cac64
              name: 'Namespace [{#NAMESPACE}] CronJob [{#NAME}]: Active'
              type: DEPENDENT
              key: 'kube.cronjob.status_active[{#NAMESPACE}/{#NAME}]'
              description: 'Active holds pointers to currently running jobs.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_cronjob_status_active{namespace="{#NAMESPACE}", cronjob="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: cronjob
                - tag: cronjob
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
            - uuid: 26993138717242079583b1c17d0e8dc8
              name: 'Namespace [{#NAMESPACE}] CronJob [{#NAME}]: Failed'
              type: DEPENDENT
              key: 'kube.cronjob.status_failed[{#NAMESPACE}/{#NAME}]'
              description: 'The number of pods which reached the Failed phase and the reason for failure.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_job_status_failed{namespace="{#NAMESPACE}", job_name=~"{#NAME}-*"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: cronjob
                - tag: cronjob
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
            - uuid: 9e5adc642c3a40ab80654542903cd314
              name: 'Namespace [{#NAMESPACE}] CronJob [{#NAME}]: Succeeded'
              type: DEPENDENT
              key: 'kube.cronjob.status_succeeded[{#NAMESPACE}/{#NAME}]'
              description: 'The number of pods which reached the Succeeded phase.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_job_status_succeeded{namespace="{#NAMESPACE}", job_name=~"{#NAME}-*"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: cronjob
                - tag: cronjob
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
          master_item:
            key: kube.state.metrics
          lld_macro_paths:
            - lld_macro: '{#NAMESPACE}'
              path: $.labels.namespace
            - lld_macro: '{#NAME}'
              path: $.labels.cronjob
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - kube_cronjob_created
        - uuid: 907dd8e2792e4e1591a99e4cdf65b0f0
          name: 'Daemonset discovery'
          type: DEPENDENT
          key: kube.daemonset.discovery
          filter:
            evaltype: AND
            conditions:
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.MATCHES}'
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.NOT_MATCHES}'
                operator: NOT_MATCHES_REGEX
          lifetime: '0'
          item_prototypes:
            - uuid: 61a295b5e2ec4e1f91984a74d0695c1b
              name: 'Namespace [{#NAMESPACE}] Daemonset [{#NAME}]: Desired'
              type: DEPENDENT
              key: 'kube.daemonset.desired[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'The number of nodes that should be running the daemon pod.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_daemonset_status_desired_number_scheduled{namespace="{#NAMESPACE}", daemonset="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: daemonset
                - tag: daemonset
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
            - uuid: 5393cb9b29e442198967cdd2a040d673
              name: 'Namespace [{#NAMESPACE}] Daemonset [{#NAME}]: Misscheduled'
              type: DEPENDENT
              key: 'kube.daemonset.misscheduled[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'The number of nodes that run a daemon pod but are not supposed to.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_daemonset_status_number_misscheduled{namespace="{#NAMESPACE}", daemonset="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: daemonset
                - tag: daemonset
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
            - uuid: 193ccc0290514c4594193a8bcfd60312
              name: 'Namespace [{#NAMESPACE}] Daemonset [{#NAME}]: Ready'
              type: DEPENDENT
              key: 'kube.daemonset.ready[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'The number of nodes that should be running the daemon pod and have one or more running and ready.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_daemonset_status_number_ready{namespace="{#NAMESPACE}", daemonset="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: daemonset
                - tag: daemonset
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
            - uuid: 5727ade78d394d8da1ae46b5d35b5f54
              name: 'Namespace [{#NAMESPACE}] Daemonset [{#NAME}]: Scheduled'
              type: DEPENDENT
              key: 'kube.daemonset.scheduled[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'The number of nodes that run at least one daemon pod and are supposed to.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_daemonset_status_current_number_scheduled{namespace="{#NAMESPACE}", daemonset="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: daemonset
                - tag: daemonset
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
            - uuid: d7c1ebe9e42942719dae731a2c440208
              name: 'Namespace [{#NAMESPACE}] Daemonset [{#NAME}]: Updated number scheduled'
              type: DEPENDENT
              key: 'kube.daemonset.updated[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'The total number of nodes that are running updated daemon pod.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_daemonset_status_updated_number_scheduled{namespace="{#NAMESPACE}", daemonset="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: daemonset
                - tag: daemonset
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
          master_item:
            key: kube.state.metrics
          lld_macro_paths:
            - lld_macro: '{#NAMESPACE}'
              path: $.labels.namespace
            - lld_macro: '{#NAME}'
              path: $.labels.daemonset
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - kube_daemonset_status_number_ready
        - uuid: 461770e4762f498e86f3f1c931fe27a9
          name: 'Deployment discovery'
          type: DEPENDENT
          key: kube.deployment.discovery
          filter:
            evaltype: AND
            conditions:
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.MATCHES}'
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.NOT_MATCHES}'
                operator: NOT_MATCHES_REGEX
          lifetime: '0'
          item_prototypes:
            - uuid: 943c67dc814e4b06a57fbc4ef609686a
              name: 'Namespace [{#NAMESPACE}] Deployment [{#NAME}]: Replicas'
              type: DEPENDENT
              key: 'kube.deployment.replicas[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'The number of replicas per deployment.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_deployment_status_replicas{namespace="{#NAMESPACE}", deployment="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: deployment
                - tag: deployment
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
            - uuid: 23d730bdea7f444eb5f2ee8bf5987379
              name: 'Namespace [{#NAMESPACE}] Deployment [{#NAME}]: Replicas available'
              type: DEPENDENT
              key: 'kube.deployment.replicas_available[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'The number of available replicas per deployment.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_deployment_status_replicas_available{namespace="{#NAMESPACE}", deployment="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: deployment
                - tag: deployment
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: status
                  value: available
            - uuid: b79fe110f4d64a94bb78d7f1e9b175e7
              name: 'Namespace [{#NAMESPACE}] Deployment [{#NAME}]: Replicas desired'
              type: DEPENDENT
              key: 'kube.deployment.replicas_desired[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'Number of desired pods for a deployment.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_deployment_spec_replicas{namespace="{#NAMESPACE}", deployment="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: deployment
                - tag: deployment
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
            - uuid: b6d4d557e6104f6b9e1084863cf4024d
              name: 'Namespace [{#NAMESPACE}] Deployment [{#NAME}]: Replicas mismatched'
              type: DEPENDENT
              key: 'kube.deployment.replicas_mismatched[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'The number of available replicas not matching the desired number of replicas.'
              preprocessing:
                - type: PROMETHEUS_TO_JSON
                  parameters:
                    - '{__name__=~"^kube_deployment_(spec_replicas|status_replicas_available)$", namespace="{#NAMESPACE}", deployment="{#NAME}"}'
                - type: JAVASCRIPT
                  parameters:
                    - |
                      var data = JSON.parse(value),
                      	replicas_desired,
                      	replicas_available;
                      
                      if (data.length !== 2) {
                      	throw 'Incorrect length of JSON (must be 2). Actual length: ' + data.length;
                      }
                      
                      JSON.parse(value).forEach(function (item) {
                      	if (item.name === 'kube_deployment_spec_replicas') {
                      		replicas_desired = item.value;
                      	}
                      	if (item.name === 'kube_deployment_status_replicas_available') {
                      		replicas_available = item.value;
                      	}
                      });
                      
                      return Math.abs(replicas_desired - replicas_available);
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: deployment
                - tag: deployment
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
            - uuid: 891537523f98425c8bb1566f984b535a
              name: 'Namespace [{#NAMESPACE}] Deployment [{#NAME}]: Replicas unavailable'
              type: DEPENDENT
              key: 'kube.deployment.replicas_unavailable[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'The number of unavailable replicas per deployment.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_deployment_status_replicas_unavailable{namespace="{#NAMESPACE}", deployment="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: deployment
                - tag: deployment
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: status
                  value: unavailable
            - uuid: 241480bc5e90426abbf5d2792cd846cd
              name: 'Namespace [{#NAMESPACE}] Deployment [{#NAME}]: Replicas updated'
              type: DEPENDENT
              key: 'kube.deployment.replicas_updated[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'The number of updated replicas per deployment.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_deployment_status_replicas_updated{namespace="{#NAMESPACE}", deployment="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: deployment
                - tag: deployment
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: status
                  value: updated
            - uuid: 2651b21facca4bd88929079f4372da37
              name: 'Namespace [{#NAMESPACE}] Deployment [{#NAME}]: Rollingupdate max unavailable'
              type: DEPENDENT
              key: 'kube.deployment.rollingupdate.max_unavailable[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'Maximum number of unavailable replicas during a rolling update of a deployment.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_deployment_spec_strategy_rollingupdate_max_unavailable{namespace="{#NAMESPACE}", deployment="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: deployment
                - tag: deployment
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
            - uuid: edc5635267b146d2b0a986e5820227ac
              name: 'Namespace [{#NAMESPACE}] Deployment [{#NAME}]: Paused'
              type: DEPENDENT
              key: 'kube.deployment.spec_paused[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'Whether the deployment is paused and will not be processed by the deployment controller.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_deployment_spec_paused{namespace="{#NAMESPACE}", deployment="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: deployment
                - tag: deployment
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
          trigger_prototypes:
            - uuid: aa9f828467d84252aecc00dd342b5661
              expression: |
                min(/Kubernetes cluster state by HTTP/kube.deployment.replicas_mismatched[{#NAMESPACE}/{#NAME}],{$KUBE.REPLICA.MISMATCH.EVAL_PERIOD:"deployment:{#NAMESPACE}:{#NAME}"})>0
                and last(/Kubernetes cluster state by HTTP/kube.deployment.replicas_desired[{#NAMESPACE}/{#NAME}])>=0
                and last(/Kubernetes cluster state by HTTP/kube.deployment.replicas_available[{#NAMESPACE}/{#NAME}])>=0
              name: 'Kubernetes cluster state: Namespace [{#NAMESPACE}] Deployment [{#NAME}]: Deployment replicas mismatch'
              opdata: 'Desired: {ITEM.LASTVALUE2}, available: {ITEM.LASTVALUE3}'
              priority: WARNING
              description: 'Deployment has not matched the expected number of replicas during the specified trigger evaluation period.'
              tags:
                - tag: scope
                  value: availability
          master_item:
            key: kube.state.metrics
          lld_macro_paths:
            - lld_macro: '{#NAMESPACE}'
              path: $.labels.namespace
            - lld_macro: '{#NAME}'
              path: $.labels.deployment
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - kube_deployment_spec_paused
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
        - uuid: 671a0dd7f6e54c6893094fa4360d3dd4
          name: 'Endpoint discovery'
          type: DEPENDENT
          key: kube.endpoint.discovery
          filter:
            evaltype: AND
            conditions:
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.MATCHES}'
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.NOT_MATCHES}'
                operator: NOT_MATCHES_REGEX
          lifetime: '0'
          item_prototypes:
            - uuid: d587eb7186dd425ead2c9554825ba20a
              name: 'Namespace [{#NAMESPACE}] Endpoint [{#NAME}]: Address available'
              type: DEPENDENT
              key: 'kube.endpoint.address_available[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'Number of addresses available in endpoint.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_endpoint_address_available{namespace="{#NAMESPACE}", endpoint="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: endpoint
                - tag: endpoint
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: status
                  value: available
            - uuid: 91fc21c37e144890858137f7f5c38135
              name: 'Namespace [{#NAMESPACE}] Endpoint [{#NAME}]: Address not ready'
              type: DEPENDENT
              key: 'kube.endpoint.address_not_ready[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'Number of addresses not ready in endpoint.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_endpoint_address_not_ready{namespace="{#NAMESPACE}", endpoint="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: endpoint
                - tag: endpoint
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: status
                  value: not-ready
            - uuid: f6c2a426e0154c34b2bcb98eeeb88a0d
              name: 'Namespace [{#NAMESPACE}] Endpoint [{#NAME}]: Age'
              type: DEPENDENT
              key: 'kube.endpoint.age[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              units: s
              description: 'Endpoint age (number of seconds since creation).'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_endpoint_created{namespace="{#NAMESPACE}", endpoint="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
                - type: JAVASCRIPT
                  parameters:
                    - 'return (Math.floor(Date.now()/1000)-Number(value));'
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: endpoint
                - tag: endpoint
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
          master_item:
            key: kube.state.metrics
          lld_macro_paths:
            - lld_macro: '{#NAMESPACE}'
              path: $.labels.namespace
            - lld_macro: '{#NAME}'
              path: $.labels.endpoint
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - kube_endpoint_created
        - uuid: bc6897c5abe246fdb1ba72c1e71cdb81
          name: 'Job discovery'
          type: DEPENDENT
          key: kube.job.discovery
          filter:
            evaltype: AND
            conditions:
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.MATCHES}'
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.NOT_MATCHES}'
                operator: NOT_MATCHES_REGEX
          lifetime: '0'
          item_prototypes:
            - uuid: b1fad48e204e4bf9a03c79baa0f58963
              name: 'Namespace [{#NAMESPACE}] Job [{#NAME}]: Completion failed'
              type: DEPENDENT
              key: 'kube.job.completion.failed[{#NAMESPACE}/{#NAME}]'
              description: 'Number of jobs the execution of which has failed.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_job_failed{namespace="{#NAMESPACE}", job_name="{#NAME}", condition="true"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: job
                - tag: job
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
            - uuid: 51d3653b2c7543dba04339ded6ff65dd
              name: 'Namespace [{#NAMESPACE}] Job [{#NAME}]: Completion succeeded'
              type: DEPENDENT
              key: 'kube.job.completion.succeeded[{#NAMESPACE}/{#NAME}]'
              description: 'Number of jobs the execution of which has been completed.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_job_complete{namespace="{#NAMESPACE}", job_name="{#NAME}", condition="true"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: job
                - tag: job
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
            - uuid: f175e0bd1f6b41a2b62e69df40b3fc07
              name: 'Namespace [{#NAMESPACE}] Job [{#NAME}]: Failed'
              type: DEPENDENT
              key: 'kube.job.status_failed[{#NAMESPACE}/{#NAME}]'
              description: 'The number of pods which reached the Failed phase and the reason for failure.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_job_status_failed{namespace="{#NAMESPACE}", job_name="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: job
                - tag: job
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
            - uuid: b909868367d5481d982d33d5248167ab
              name: 'Namespace [{#NAMESPACE}] Job [{#NAME}]: Succeeded'
              type: DEPENDENT
              key: 'kube.job.status_succeeded[{#NAMESPACE}/{#NAME}]'
              description: 'The number of pods which reached the Succeeded phase.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_job_status_succeeded{namespace="{#NAMESPACE}", job_name="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: job
                - tag: job
                  value: '{#NAME}'
                - tag: namespace
                  value: '{#NAMESPACE}'
          master_item:
            key: kube.state.metrics
          lld_macro_paths:
            - lld_macro: '{#NAMESPACE}'
              path: $.labels.namespace
            - lld_macro: '{#NAME}'
              path: $.labels.job_name
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - 'kube_job_owner{owner_is_controller!="true"}'
        - uuid: 11ca82627209443a96693e443d6391c1
          name: 'Kubelet discovery'
          type: DEPENDENT
          key: kube.kubelet.discovery
          filter:
            evaltype: AND
            conditions:
              - macro: '{#NAME}'
                value: '{$KUBE.LLD.FILTER.KUBELET_NODE.MATCHES}'
              - macro: '{#NAME}'
                value: '{$KUBE.LLD.FILTER.KUBELET_NODE.NOT_MATCHES}'
                operator: NOT_MATCHES_REGEX
          host_prototypes:
            - uuid: c1c4807f378a47dfa59e9bbc8e43f5e2
              host: 'Kubelet {#NAME}'
              name: 'Kubelet {#NAME}'
              group_links:
                - group:
                    name: Applications
              group_prototypes:
                - name: '{#CLUSTER_HOSTNAME}: Kubernetes/Components: {#COMPONENT}'
              templates:
                - name: 'Kubernetes Kubelet by HTTP'
              macros:
                - macro: '{$KUBE.KUBELET.URL}'
                  value: '{#KUBE.KUBELET.URL}'
              tags:
                - tag: addr
                  value: '{#IP}'
              custom_interfaces: 'YES'
              interfaces:
                - ip: '{#IP}'
          master_item:
            key: kube.node.lld
        - uuid: 438e963e02a749b5a2cc487b9fd5db05
          name: 'Livez discovery'
          type: DEPENDENT
          key: kube.livez.discovery
          item_prototypes:
            - uuid: 93548d985c1542a891bfc74f2d42d59a
              name: 'Livez [{#NAME}]: Healthcheck'
              type: DEPENDENT
              key: 'kube.livez.healthcheck[{#NAME}]'
              value_type: CHAR
              description: 'Result of livez healthcheck for component.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[?(@.name == "{#NAME}")].value.first()'
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.livez
              tags:
                - tag: component
                  value: livez
                - tag: component
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: 9fcb23d29ac3481a8613515cc2cccfcf
                  expression: 'count(/Kubernetes cluster state by HTTP/kube.livez.healthcheck[{#NAME}],#2,"ne","ok")=2 and length(last(/Kubernetes cluster state by HTTP/kube.livez.healthcheck[{#NAME}]))>0'
                  recovery_mode: RECOVERY_EXPRESSION
                  recovery_expression: 'count(/Kubernetes cluster state by HTTP/kube.livez.healthcheck[{#NAME}],#3,"eq","ok")=3'
                  name: 'Kubernetes cluster state: Livez [{#NAME}] is unhealthy'
                  priority: WARNING
                  tags:
                    - tag: scope
                      value: availability
          master_item:
            key: kube.livez
          lld_macro_paths:
            - lld_macro: '{#NAME}'
              path: $.name
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
        - uuid: 9d161120d2be48d1abb6e56107057874
          name: 'Node discovery'
          type: DEPENDENT
          key: kube.node.discovery
          filter:
            evaltype: AND
            conditions:
              - macro: '{#NAME}'
                value: '{$KUBE.LLD.FILTER.NODE.MATCHES}'
              - macro: '{#NAME}'
                value: '{$KUBE.LLD.FILTER.NODE.NOT_MATCHES}'
                operator: NOT_MATCHES_REGEX
          item_prototypes:
            - uuid: 4f994219cbe94dfe8d96af1ad5018212
              name: 'Node [{#NAME}]: CPU allocatable'
              type: DEPENDENT
              key: 'kube.node.cpu_allocatable[{#NAME}]'
              value_type: FLOAT
              units: cpu
              description: 'The CPU resources of a node that are available for scheduling.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_node_status_allocatable{node="{#NAME}", resource="cpu"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: cpu
                - tag: node
                  value: '{#NAME}'
                - tag: status
                  value: allocatable
            - uuid: 5d3ad3e1b2a547aea65b557ff2765ef7
              name: 'Node [{#NAME}]: CPU capacity'
              type: DEPENDENT
              key: 'kube.node.cpu_capacity[{#NAME}]'
              value_type: FLOAT
              units: cpu
              description: 'The capacity for CPU resources of a node.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_node_status_capacity{node="{#NAME}", resource="cpu"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: cpu
                - tag: node
                  value: '{#NAME}'
                - tag: status
                  value: capacity
            - uuid: 49440553854441f39ecbcf7052d83e51
              name: 'Node [{#NAME}]: Ephemeral storage allocatable'
              type: DEPENDENT
              key: 'kube.node.ephemeral_storage_allocatable[{#NAME}]'
              value_type: FLOAT
              units: B
              description: 'The allocatable ephemeral storage of a node that is available for scheduling.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_node_status_allocatable{node="{#NAME}", resource="ephemeral_storage"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: ephemeral-storage
                - tag: node
                  value: '{#NAME}'
                - tag: status
                  value: capacity
            - uuid: 2831a4b1bc1549198203f3e894f07a1f
              name: 'Node [{#NAME}]: Ephemeral storage capacity'
              type: DEPENDENT
              key: 'kube.node.ephemeral_storage_capacity[{#NAME}]'
              value_type: FLOAT
              units: B
              description: 'The ephemeral storage capacity of a node.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_node_status_capacity{node="{#NAME}", resource="ephemeral_storage"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: ephemeral-storage
                - tag: node
                  value: '{#NAME}'
                - tag: status
                  value: capacity
            - uuid: 0247f7ba014443a0b13a4fdd3e191062
              name: 'Node [{#NAME}]: Memory allocatable'
              type: DEPENDENT
              key: 'kube.node.memory_allocatable[{#NAME}]'
              value_type: FLOAT
              units: B
              description: 'The memory resources of a node that are available for scheduling.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_node_status_allocatable{node="{#NAME}", resource="memory"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: memory
                - tag: node
                  value: '{#NAME}'
                - tag: status
                  value: allocatable
            - uuid: 3336028952b14e2ab3dae55659156ea3
              name: 'Node [{#NAME}]: Memory capacity'
              type: DEPENDENT
              key: 'kube.node.memory_capacity[{#NAME}]'
              value_type: FLOAT
              units: B
              description: 'The capacity for memory resources of a node.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_node_status_capacity{node="{#NAME}", resource="memory"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: memory
                - tag: node
                  value: '{#NAME}'
                - tag: status
                  value: capacity
            - uuid: 049eb92c52a24c9887d7120f2a7e106c
              name: 'Node [{#NAME}]: Pods allocatable'
              type: DEPENDENT
              key: 'kube.node.pods_allocatable[{#NAME}]'
              value_type: FLOAT
              description: 'The pods resources of a node that are available for scheduling.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_node_status_allocatable{node="{#NAME}", resource="pods"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: pods
                - tag: node
                  value: '{#NAME}'
                - tag: status
                  value: allocatable
            - uuid: 163edc95ec7d41f29099b94409916d82
              name: 'Node [{#NAME}]: Pods capacity'
              type: DEPENDENT
              key: 'kube.node.pods_capacity[{#NAME}]'
              value_type: FLOAT
              description: 'The capacity for pods resources of a node.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_node_status_capacity{node="{#NAME}", resource="pods"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: pods
                - tag: node
                  value: '{#NAME}'
                - tag: status
                  value: capacity
          master_item:
            key: kube.state.metrics
          lld_macro_paths:
            - lld_macro: '{#NAME}'
              path: $.labels.node
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - kube_node_info
        - uuid: a7bf79185bab4eb8891e5a154424a96d
          name: 'PodDisruptionBudget discovery'
          type: DEPENDENT
          key: kube.pdb.discovery
          filter:
            evaltype: AND
            conditions:
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.MATCHES}'
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.NOT_MATCHES}'
                operator: NOT_MATCHES_REGEX
          lifetime: '0'
          item_prototypes:
            - uuid: 3eef1fb3311e429fa3043c9e4d88335f
              name: 'Namespace [{#NAMESPACE}] PodDisruptionBudget [{#NAME}]: Disruptions allowed'
              type: DEPENDENT
              key: 'kube.pdb.disruptions_allowed[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'Number of pod disruptions that are allowed.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_poddisruptionbudget_status_pod_disruptions_allowed{namespace="{#NAMESPACE}", poddisruptionbudget="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: pdb
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: pdb
                  value: '{#NAME}'
            - uuid: a303e07be68c40bdb7d996696af53c98
              name: 'Namespace [{#NAMESPACE}] PodDisruptionBudget [{#NAME}]: Pods desired'
              type: DEPENDENT
              key: 'kube.pdb.pods_desired[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'Minimum desired number of healthy pods.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_poddisruptionbudget_status_desired_healthy{namespace="{#NAMESPACE}", poddisruptionbudget="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: pdb
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: pdb
                  value: '{#NAME}'
            - uuid: f2a82d6de52446f594a6554137508604
              name: 'Namespace [{#NAMESPACE}] PodDisruptionBudget [{#NAME}]: Pods healthy'
              type: DEPENDENT
              key: 'kube.pdb.pods_healthy[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'Current number of healthy pods.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_poddisruptionbudget_status_current_healthy{namespace="{#NAMESPACE}", poddisruptionbudget="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: pdb
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: pdb
                  value: '{#NAME}'
            - uuid: 2c15033188ab4062a432f30c3320677f
              name: 'Namespace [{#NAMESPACE}] PodDisruptionBudget [{#NAME}]: Pods total'
              type: DEPENDENT
              key: 'kube.pdb.pods_total[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'Total number of pods counted by this disruption budget.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_poddisruptionbudget_status_expected_pods{namespace="{#NAMESPACE}", poddisruptionbudget="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: pdb
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: pdb
                  value: '{#NAME}'
          master_item:
            key: kube.state.metrics
          lld_macro_paths:
            - lld_macro: '{#NAMESPACE}'
              path: $.labels.namespace
            - lld_macro: '{#NAME}'
              path: $.labels.poddisruptionbudget
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - kube_poddisruptionbudget_created
        - uuid: d88889ab64804c4389d3755ea49b80d6
          name: 'Pod discovery'
          type: DEPENDENT
          key: kube.pod.discovery
          filter:
            evaltype: AND
            conditions:
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.MATCHES}'
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.NOT_MATCHES}'
                operator: NOT_MATCHES_REGEX
          lifetime: '0'
          item_prototypes:
            - uuid: 3a145b38d57f4164a7a9ef0dd15c530a
              name: 'Namespace [{#NAMESPACE}] Pod [{#NAME}]: Containers CPU limits'
              type: DEPENDENT
              key: 'kube.pod.containers.limits.cpu[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'The limit on CPU cores to be used by a container.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_pod_container_resource_limits{pod="{#NAME}", resource="cpu"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: pod
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: pod
                  value: '{#NAME}'
                - tag: resource
                  value: cpu
            - uuid: e1dd38e6fb484610891aef057a58daf0
              name: 'Namespace [{#NAMESPACE}] Pod [{#NAME}]: Containers memory limits'
              type: DEPENDENT
              key: 'kube.pod.containers.limits.memory[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              units: B
              description: 'The limit on memory to be used by a container.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_pod_container_resource_limits{pod="{#NAME}", resource="memory"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: pod
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: pod
                  value: '{#NAME}'
                - tag: resource
                  value: memory
            - uuid: 8465ea15f3974476924cb66df5a63e0c
              name: 'Namespace [{#NAMESPACE}] Pod [{#NAME}]: Containers CPU requests'
              type: DEPENDENT
              key: 'kube.pod.containers.requests.cpu[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'The number of requested CPU cores by a container.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_pod_container_resource_requests{pod="{#NAME}", resource="cpu"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: pod
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: pod
                  value: '{#NAME}'
                - tag: resource
                  value: cpu
            - uuid: 27379c192d0841a5adb2c2e4ae937263
              name: 'Namespace [{#NAMESPACE}] Pod [{#NAME}]: Containers memory requests'
              type: DEPENDENT
              key: 'kube.pod.containers.requests.memory[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              units: B
              description: 'The number of requested memory bytes by a container.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_pod_container_resource_requests{pod="{#NAME}", resource="memory"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: pod
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: pod
                  value: '{#NAME}'
                - tag: resource
                  value: memory
            - uuid: 1719bf9d1a1c443dbddcefb91483a77c
              name: 'Namespace [{#NAMESPACE}] Pod [{#NAME}]: Containers ready'
              type: DEPENDENT
              key: 'kube.pod.containers_ready[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'Describes whether the containers readiness check succeeded.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_pod_container_status_ready{pod="{#NAME}"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: pod
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: pod
                  value: '{#NAME}'
                - tag: status
                  value: ready
            - uuid: fbc8f3a91ec9429ca4c6d70c07480dcc
              name: 'Namespace [{#NAMESPACE}] Pod [{#NAME}]: Containers restarts'
              type: DEPENDENT
              key: 'kube.pod.containers_restarts[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'The number of container restarts.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_pod_container_status_restarts_total{pod="{#NAME}"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: pod
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: pod
                  value: '{#NAME}'
                - tag: status
                  value: restarts
              trigger_prototypes:
                - uuid: 4656457043d04f4a9b829222ad071d22
                  expression: '(last(/Kubernetes cluster state by HTTP/kube.pod.containers_restarts[{#NAMESPACE}/{#NAME}])-min(/Kubernetes cluster state by HTTP/kube.pod.containers_restarts[{#NAMESPACE}/{#NAME}],15m))>1'
                  name: 'Kubernetes cluster state: Namespace [{#NAMESPACE}] Pod [{#NAME}]: Pod is crash looping'
                  priority: WARNING
                  description: 'Containers of the pod keep restarting. This most likely indicates that the pod is in the CrashLoopBackOff state.'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: b96149f7a44d4a49903421fbc38c0101
              name: 'Namespace [{#NAMESPACE}] Pod [{#NAME}]: Containers running'
              type: DEPENDENT
              key: 'kube.pod.containers_running[{#NAMESPACE}/{#NAME}]'
              description: 'Describes whether the container is currently in running state.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_pod_container_status_running{pod="{#NAME}"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: pod
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: pod
                  value: '{#NAME}'
                - tag: status
                  value: running
            - uuid: 50785c1c96894866973ebf8491e3c320
              name: 'Namespace [{#NAMESPACE}] Pod [{#NAME}]: Containers terminated'
              type: DEPENDENT
              key: 'kube.pod.containers_terminated[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'Describes whether the container is currently in terminated state.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_pod_container_status_terminated{pod="{#NAME}"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: pod
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: pod
                  value: '{#NAME}'
                - tag: status
                  value: terminated
            - uuid: 01d80d5f171f4af2b3b1da70679e87ba
              name: 'Namespace [{#NAMESPACE}] Pod [{#NAME}]: Containers waiting'
              type: DEPENDENT
              key: 'kube.pod.containers_waiting[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'Describes whether the container is currently in waiting state.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_pod_container_status_waiting{pod="{#NAME}"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: pod
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: pod
                  value: '{#NAME}'
                - tag: status
                  value: waiting
            - uuid: dedbaa4308624b6b982a7e6b62f92d3f
              name: 'Namespace [{#NAMESPACE}] Pod [{#NAME}] Phase: Failed'
              type: DEPENDENT
              key: 'kube.pod.phase.failed[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'Pod is in failed state.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_pod_status_phase{pod="{#NAME}", phase="Failed"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: pod
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: phase
                  value: failed
                - tag: pod
                  value: '{#NAME}'
            - uuid: fa3759bb7873453b9842f3e459403163
              name: 'Namespace [{#NAMESPACE}] Pod [{#NAME}] Phase: Pending'
              type: DEPENDENT
              key: 'kube.pod.phase.pending[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'Pod is in pending state.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_pod_status_phase{pod="{#NAME}", phase="Pending"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: pod
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: phase
                  value: pending
                - tag: pod
                  value: '{#NAME}'
            - uuid: 59168479f1e246bf8da46606f3ce2a5e
              name: 'Namespace [{#NAMESPACE}] Pod [{#NAME}] Phase: Running'
              type: DEPENDENT
              key: 'kube.pod.phase.running[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'Pod is in unknown state.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_pod_status_phase{pod="{#NAME}", phase="Running"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: pod
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: phase
                  value: running
                - tag: pod
                  value: '{#NAME}'
            - uuid: 8a9451a6466f4c64b31377d850841578
              name: 'Namespace [{#NAMESPACE}] Pod [{#NAME}] Phase: Succeeded'
              type: DEPENDENT
              key: 'kube.pod.phase.succeeded[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'Pod is in succeeded state.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_pod_status_phase{pod="{#NAME}", phase="Succeeded"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: pod
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: phase
                  value: succeeded
                - tag: pod
                  value: '{#NAME}'
            - uuid: 9303dab482754a7b991b3ba4afef96e7
              name: 'Namespace [{#NAMESPACE}] Pod [{#NAME}] Phase: Unknown'
              type: DEPENDENT
              key: 'kube.pod.phase.unknown[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'Pod is in unknown state.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_pod_status_phase{pod="{#NAME}", phase="Unknown"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: pod
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: phase
                  value: unknown
                - tag: pod
                  value: '{#NAME}'
            - uuid: d946bc58d5a44aa9936b09c825a51f59
              name: 'Namespace [{#NAMESPACE}] Pod [{#NAME}]: Ready'
              type: DEPENDENT
              key: 'kube.pod.ready[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'Describes whether the pod is ready to serve requests.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_pod_status_ready{pod="{#NAME}", condition="true"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: pod
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: pod
                  value: '{#NAME}'
                - tag: status
                  value: ready
            - uuid: 0f858209a4b344de80b1382710c6f153
              name: 'Namespace [{#NAMESPACE}] Pod [{#NAME}]: Scheduled'
              type: DEPENDENT
              key: 'kube.pod.scheduled[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'Describes the status of the scheduling process for the pod.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_pod_status_scheduled{pod="{#NAME}", condition="true"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: pod
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: pod
                  value: '{#NAME}'
                - tag: status
                  value: scheduled
            - uuid: 93ba93d04ec34b5193252f19a33f5d59
              name: 'Namespace [{#NAMESPACE}] Pod [{#NAME}]: Unschedulable'
              type: DEPENDENT
              key: 'kube.pod.unschedulable[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'Describes the unschedulable status for the pod.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_pod_status_unschedulable{pod="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: pod
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: pod
                  value: '{#NAME}'
                - tag: status
                  value: unschedulable
          trigger_prototypes:
            - uuid: 5bf79dee7b974064b5848a7dcf6428c2
              expression: 'min(/Kubernetes cluster state by HTTP/kube.pod.phase.failed[{#NAMESPACE}/{#NAME}],10m)>0 or min(/Kubernetes cluster state by HTTP/kube.pod.phase.pending[{#NAMESPACE}/{#NAME}],10m)>0 or min(/Kubernetes cluster state by HTTP/kube.pod.phase.unknown[{#NAMESPACE}/{#NAME}],10m)>0'
              name: 'Kubernetes cluster state: Namespace [{#NAMESPACE}] Pod [{#NAME}]: Pod is not healthy'
              priority: HIGH
              tags:
                - tag: scope
                  value: availability
          master_item:
            key: kube.state.metrics
          lld_macro_paths:
            - lld_macro: '{#NAMESPACE}'
              path: $.labels.namespace
            - lld_macro: '{#NAME}'
              path: $.labels.pod
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - kube_pod_start_time
        - uuid: 657edb22832e43f5a084cf872c6bc6e4
          name: 'PV discovery'
          type: DEPENDENT
          key: kube.pv.discovery
          lifetime: '0'
          item_prototypes:
            - uuid: f93e620a32114a239bc622246ff57eb0
              name: 'PV [{#NAME}] Capacity bytes'
              type: DEPENDENT
              key: 'kube.pv.capacity.bytes[{#NAME}]'
              value_type: FLOAT
              units: B
              description: 'A capacity of the persistent volume in bytes.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_persistentvolume_capacity_bytes{persistentvolume="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: pv
                - tag: pv
                  value: '{#NAME}'
            - uuid: f1f7c15a30e04203b63b3f828f1e49c6
              name: 'PV status phase: Available, sum'
              type: DEPENDENT
              key: 'kube.pv.status_phase.available.sum[{#SINGLETON}]'
              discover: NO_DISCOVER
              description: 'The total amount of persistent volumes in the Available phase.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_persistentvolume_status_phase{persistentvolume=~"{$KUBE.LLD.FILTER.PV.MATCHES}", persistentvolume!~"{$KUBE.LLD.FILTER.PV.NOT_MATCHES}", phase="Available"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: phase
                - tag: component
                  value: pv
                - tag: phase
                  value: available
            - uuid: 236db4d5cb4149f691003c0b50bf2b55
              name: 'PV status phase: Bound, sum'
              type: DEPENDENT
              key: 'kube.pv.status_phase.bound.sum[{#SINGLETON}]'
              discover: NO_DISCOVER
              description: 'The total amount of persistent volumes in the Bound phase.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_persistentvolume_status_phase{persistentvolume=~"{$KUBE.LLD.FILTER.PV.MATCHES}", persistentvolume!~"{$KUBE.LLD.FILTER.PV.NOT_MATCHES}", phase="Bound"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: phase
                - tag: component
                  value: pv
                - tag: phase
                  value: bound
            - uuid: bc5e42637e454baeb38eef946093f38a
              name: 'PV status phase: Failed, sum'
              type: DEPENDENT
              key: 'kube.pv.status_phase.failed.sum[{#SINGLETON}]'
              discover: NO_DISCOVER
              description: 'The total amount of persistent volumes in the Failed phase.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_persistentvolume_status_phase{persistentvolume=~"{$KUBE.LLD.FILTER.PV.MATCHES}", persistentvolume!~"{$KUBE.LLD.FILTER.PV.NOT_MATCHES}", phase="Failed"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: phase
                - tag: component
                  value: pv
                - tag: phase
                  value: failed
            - uuid: e69e327a90094195997a28e36fe47441
              name: 'PV status phase: Pending, sum'
              type: DEPENDENT
              key: 'kube.pv.status_phase.pending.sum[{#SINGLETON}]'
              discover: NO_DISCOVER
              description: 'The total amount of persistent volumes in the Pending phase.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_persistentvolume_status_phase{persistentvolume=~"{$KUBE.LLD.FILTER.PV.MATCHES}", persistentvolume!~"{$KUBE.LLD.FILTER.PV.NOT_MATCHES}", phase="Pending"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: phase
                - tag: component
                  value: pv
                - tag: phase
                  value: pending
            - uuid: 121d33d774534d38809b014f0af20d72
              name: 'PV status phase: Released, sum'
              type: DEPENDENT
              key: 'kube.pv.status_phase.released.sum[{#SINGLETON}]'
              discover: NO_DISCOVER
              description: 'The total amount of persistent volumes in the Released phase.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_persistentvolume_status_phase{persistentvolume=~"{$KUBE.LLD.FILTER.PV.MATCHES}", persistentvolume!~"{$KUBE.LLD.FILTER.PV.NOT_MATCHES}", phase="Released"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: phase
                - tag: component
                  value: pv
                - tag: phase
                  value: released
            - uuid: f2982e1a1c4a46f08b855d6f35e60c85
              name: 'PV [{#NAME}] Status phase'
              type: DEPENDENT
              key: 'kube.pv.status_phase[{#NAME}]'
              description: 'The current status phase of the persistent volume.'
              valuemap:
                name: 'PV and PVC status phases'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_persistentvolume_status_phase{persistentvolume="{#NAME}"} == 1'
                    - label
                    - phase
                  error_handler: DISCARD_VALUE
                - type: JAVASCRIPT
                  parameters:
                    - 'return [''Available'', ''Bound'', ''Failed'', ''Lost'', ''Pending'', ''Released''].indexOf(value) + 1 || ''Problem with status processing in JS, no such PV status: '' + value;'
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: phase
                - tag: component
                  value: pv
                - tag: pv
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: ccc486f937bd454e9e7193181a998bdb
                  expression: 'count(/Kubernetes cluster state by HTTP/kube.pv.status_phase[{#NAME}],2m,,3)>=2'
                  name: 'Kubernetes cluster state: PV [{#NAME}]: PV has failed'
                  priority: WARNING
                  tags:
                    - tag: scope
                      value: availability
          master_item:
            key: kube.state.metrics
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - 'kube_persistentvolume_info{persistentvolume=~"{$KUBE.LLD.FILTER.PV.MATCHES}", persistentvolume!~"{$KUBE.LLD.FILTER.PV.NOT_MATCHES}"}'
            - type: JAVASCRIPT
              parameters:
                - |
                  var input = JSON.parse(value),
                  	output = [];
                  
                  input.forEach(function (metric) {
                  	output.push({ '{#NAME}': metric.labels.persistentvolume });
                  });
                  
                  if (output.length > 0) {
                  	output.push({ '{#SINGLETON}': '' });
                  }
                  
                  return JSON.stringify(output);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
          overrides:
            - name: 'sum items'
              step: '1'
              filter:
                conditions:
                  - macro: '{#SINGLETON}'
                    operator: EXISTS
              operations:
                - operator: REGEXP
                  value: 'status phase.*sum'
                  discover: DISCOVER
                - operator: NOT_REGEXP
                  value: 'status phase.*sum'
                  discover: NO_DISCOVER
                - operationobject: TRIGGER_PROTOTYPE
                  operator: REGEXP
                  value: '.*'
                  discover: NO_DISCOVER
        - uuid: 4143b2f294ac45a5ab570a94a626fca6
          name: 'PVC discovery'
          type: DEPENDENT
          key: kube.pvc.discovery
          filter:
            evaltype: AND
            conditions:
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.MATCHES}'
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.NOT_MATCHES}'
                operator: NOT_MATCHES_REGEX
          lifetime: '0'
          item_prototypes:
            - uuid: 9187144531f145398bfbe7281290533d
              name: 'Namespace [{#NAMESPACE}] PVC [{#NAME}] Requested storage'
              type: DEPENDENT
              key: 'kube.pvc.requested.storage[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              units: B
              description: 'The capacity of storage requested by the persistent volume claim.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_persistentvolumeclaim_resource_requests_storage_bytes{namespace="{#NAMESPACE}", persistentvolumeclaim="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: pvc
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: pvc
                  value: '{#NAME}'
            - uuid: 41bc1f54992a492da414846b91d48b0e
              name: 'Namespace [{#NAMESPACE}] PVC status phase: Bound, sum'
              type: DEPENDENT
              key: 'kube.pvc.status_phase.bound.sum[{#NAMESPACE}]'
              discover: NO_DISCOVER
              description: 'The total amount of persistent volume claims in the Bound phase.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_persistentvolumeclaim_status_phase{namespace="{#NAMESPACE}", phase="Bound"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: phase
                - tag: component
                  value: pvc
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: phase
                  value: bound
            - uuid: f3b3979c04424b908b514589c2995ff8
              name: 'Namespace [{#NAMESPACE}] PVC status phase: Lost, sum'
              type: DEPENDENT
              key: 'kube.pvc.status_phase.lost.sum[{#NAMESPACE}]'
              discover: NO_DISCOVER
              description: 'The total amount of persistent volume claims in the Lost phase.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_persistentvolumeclaim_status_phase{namespace="{#NAMESPACE}", phase="Lost"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: phase
                - tag: component
                  value: pvc
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: phase
                  value: lost
            - uuid: 237d8ee073c04c21a14269f15ab679fd
              name: 'Namespace [{#NAMESPACE}] PVC status phase: Pending, sum'
              type: DEPENDENT
              key: 'kube.pvc.status_phase.pending.sum[{#NAMESPACE}]'
              discover: NO_DISCOVER
              description: 'The total amount of persistent volume claims in the Pending phase.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_persistentvolumeclaim_status_phase{namespace="{#NAMESPACE}", phase="Pending"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: phase
                - tag: component
                  value: pvc
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: phase
                  value: pending
            - uuid: f036e514626b4610b531f9be09289daa
              name: 'Namespace [{#NAMESPACE}] PVC [{#NAME}] Status phase'
              type: DEPENDENT
              key: 'kube.pvc.status_phase[{#NAMESPACE}/{#NAME}]'
              description: 'The current status phase of the persistent volume claim.'
              valuemap:
                name: 'PV and PVC status phases'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_persistentvolumeclaim_status_phase{namespace="{#NAMESPACE}", persistentvolumeclaim="{#NAME}"} == 1'
                    - label
                    - phase
                  error_handler: DISCARD_VALUE
                - type: JAVASCRIPT
                  parameters:
                    - 'return [''Available'', ''Bound'', ''Failed'', ''Lost'', ''Pending'', ''Released''].indexOf(value) + 1 || ''Problem with status processing in JS, no such PVC status: '' + value;'
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: phase
                - tag: component
                  value: pvc
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: pvc
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: 6cdf93dad1c647239570cbb3789f1a2c
                  expression: 'count(/Kubernetes cluster state by HTTP/kube.pvc.status_phase[{#NAMESPACE}/{#NAME}],2m,,5)>=2'
                  name: 'Kubernetes cluster state: NS [{#NAMESPACE}] PVC [{#NAME}]: PVC is pending'
                  priority: WARNING
                  tags:
                    - tag: scope
                      value: availability
          master_item:
            key: kube.state.metrics
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - kube_persistentvolumeclaim_info
            - type: JAVASCRIPT
              parameters:
                - |
                  var input = JSON.parse(value),
                  	lookup = {},
                  	output = [];
                  
                  input.forEach(function (metric) {
                  	var namespace = metric.labels.namespace;
                  	if (!(lookup[namespace])) {
                  		lookup[namespace] = 1;
                  		output.push({
                  			'{#IS_SUM}': '',
                  			'{#NAMESPACE}': metric.labels.namespace
                  		});
                  	}
                  	output.push({
                  		'{#NAME}': metric.labels.persistentvolumeclaim,
                  		'{#NAMESPACE}': metric.labels.namespace
                  	});
                  });
                  
                  return JSON.stringify(output);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
          overrides:
            - name: 'sum items'
              step: '1'
              filter:
                conditions:
                  - macro: '{#IS_SUM}'
                    operator: EXISTS
              operations:
                - operator: REGEXP
                  value: 'status phase.*sum'
                  discover: DISCOVER
                - operator: NOT_REGEXP
                  value: 'status phase.*sum'
                  discover: NO_DISCOVER
                - operationobject: TRIGGER_PROTOTYPE
                  operator: REGEXP
                  value: '.*'
                  discover: NO_DISCOVER
        - uuid: ee274767c42345e3a501f43e81a3364a
          name: 'Readyz discovery'
          type: DEPENDENT
          key: kube.readyz.discovery
          item_prototypes:
            - uuid: c0693fb2709e4b01a35ca433edb84db7
              name: 'Readyz [{#NAME}]: Healthcheck'
              type: DEPENDENT
              key: 'kube.readyz.healthcheck[{#NAME}]'
              value_type: CHAR
              description: 'Result of readyz healthcheck for component.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[?(@.name == "{#NAME}")].value.first()'
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.readyz
              tags:
                - tag: component
                  value: readyz
                - tag: component
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: 1a88c2cf94d3444c9e5320776b323ce6
                  expression: 'count(/Kubernetes cluster state by HTTP/kube.readyz.healthcheck[{#NAME}],#2,"ne","ok")=2 and length(last(/Kubernetes cluster state by HTTP/kube.readyz.healthcheck[{#NAME}]))>0'
                  recovery_mode: RECOVERY_EXPRESSION
                  recovery_expression: 'count(/Kubernetes cluster state by HTTP/kube.readyz.healthcheck[{#NAME}],#3,"eq","ok")=3'
                  name: 'Kubernetes cluster state: Readyz [{#NAME}] is unhealthy'
                  priority: WARNING
                  tags:
                    - tag: scope
                      value: availability
          master_item:
            key: kube.readyz
          lld_macro_paths:
            - lld_macro: '{#NAME}'
              path: $.name
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
        - uuid: 6244f250f6cd411080221843ad1c59f2
          name: 'ReplicaSet discovery'
          type: DEPENDENT
          key: kube.replicaset.discovery
          filter:
            evaltype: AND
            conditions:
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.MATCHES}'
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.NOT_MATCHES}'
                operator: NOT_MATCHES_REGEX
          lifetime: '0'
          item_prototypes:
            - uuid: 928536dae27c4e3497627b9f5642a7a8
              name: 'Namespace [{#NAMESPACE}] ReplicaSet [{#NAME}]: Fully labeled replicas'
              type: DEPENDENT
              key: 'kube.replicaset.fully_labeled_replicas[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'The number of fully labeled replicas per ReplicaSet.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_replicaset_status_fully_labeled_replicas{namespace="{#NAMESPACE}", replicaset="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: replicaset
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: replicaset
                  value: '{#NAME}'
                - tag: status
                  value: fully-labeled
            - uuid: 4e911e4b71c342dba2227ed7ef360190
              name: 'Namespace [{#NAMESPACE}] ReplicaSet [{#NAME}]: Ready'
              type: DEPENDENT
              key: 'kube.replicaset.ready[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'The number of ready replicas per ReplicaSet.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_replicaset_status_ready_replicas{namespace="{#NAMESPACE}", replicaset="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: replicaset
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: replicaset
                  value: '{#NAME}'
                - tag: status
                  value: ready
            - uuid: 545c8486dcc9409c93c6efee0f4b2ad6
              name: 'Namespace [{#NAMESPACE}] ReplicaSet [{#NAME}]: Replicas'
              type: DEPENDENT
              key: 'kube.replicaset.replicas[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'The number of replicas per ReplicaSet.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_replicaset_status_replicas{namespace="{#NAMESPACE}", replicaset="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: replicaset
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: replicaset
                  value: '{#NAME}'
            - uuid: 30aea656c8a5470ea4566333077628b3
              name: 'Namespace [{#NAMESPACE}] ReplicaSet [{#NAME}]: Desired replicas'
              type: DEPENDENT
              key: 'kube.replicaset.replicas_desired[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'Number of desired pods for a ReplicaSet.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_replicaset_spec_replicas{namespace="{#NAMESPACE}", replicaset="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: replicaset
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: replicaset
                  value: '{#NAME}'
                - tag: status
                  value: desired
            - uuid: a249a4762874499eb83eb8864df5c357
              name: 'Namespace [{#NAMESPACE}] ReplicaSet [{#NAME}]: Replicas mismatched'
              type: DEPENDENT
              key: 'kube.replicaset.replicas_mismatched[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'The number of ready replicas not matching the desired number of replicas.'
              preprocessing:
                - type: PROMETHEUS_TO_JSON
                  parameters:
                    - '{__name__=~"^kube_replicaset_(spec_replicas|status_ready_replicas)$", namespace="{#NAMESPACE}", replicaset="{#NAME}"}'
                - type: JAVASCRIPT
                  parameters:
                    - |
                      var data = JSON.parse(value),
                      	replicas_desired,
                      	replicas_ready;
                      
                      if (data.length !== 2) {
                      	throw 'Incorrect length of JSON (must be 2). Actual length: ' + data.length;
                      }
                      
                      JSON.parse(value).forEach(function (item) {
                      	if (item.name === 'kube_replicaset_spec_replicas') {
                      		replicas_desired = item.value;
                      	}
                      	if (item.name === 'kube_replicaset_status_ready_replicas') {
                      		replicas_ready = item.value;
                      	}
                      });
                      
                      return Math.abs(replicas_desired - replicas_ready);
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: replicaset
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: replicaset
                  value: '{#NAME}'
          trigger_prototypes:
            - uuid: 8046757dbd3b459c9cd9f7bd369dd416
              expression: |
                min(/Kubernetes cluster state by HTTP/kube.replicaset.replicas_mismatched[{#NAMESPACE}/{#NAME}],{$KUBE.REPLICA.MISMATCH.EVAL_PERIOD:"replicaset:{#NAMESPACE}:{#NAME}"})>0
                and last(/Kubernetes cluster state by HTTP/kube.replicaset.replicas_desired[{#NAMESPACE}/{#NAME}])>=0
                and last(/Kubernetes cluster state by HTTP/kube.replicaset.ready[{#NAMESPACE}/{#NAME}])>=0
              name: 'Kubernetes cluster state: Namespace [{#NAMESPACE}] RS [{#NAME}]: ReplicaSet mismatch'
              opdata: 'Desired: {ITEM.LASTVALUE2}, ready: {ITEM.LASTVALUE3}'
              priority: WARNING
              description: 'ReplicaSet has not matched the expected number of replicas during the specified trigger evaluation period.'
              tags:
                - tag: scope
                  value: availability
          master_item:
            key: kube.state.metrics
          lld_macro_paths:
            - lld_macro: '{#NAMESPACE}'
              path: $.labels.namespace
            - lld_macro: '{#NAME}'
              path: $.labels.replicaset
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - kube_replicaset_status_replicas
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
        - uuid: f732cbb0e71e4ab896c973e355d7a6a4
          name: 'Scheduler servers nodes discovery'
          type: DEPENDENT
          key: kube.scheduler.discovery
          host_prototypes:
            - uuid: 46da4b85c58f4c59825e61778a64a58e
              host: 'Scheduler {#NAME}'
              name: 'Scheduler {#NAME}'
              group_links:
                - group:
                    name: Applications
              group_prototypes:
                - name: '{#CLUSTER_HOSTNAME}: Kubernetes/Components: {#COMPONENT.SCHEDULER}'
              templates:
                - name: 'Kubernetes Scheduler by HTTP'
              macros:
                - macro: '{$KUBE.SCHEDULER.SERVER.URL}'
                  value: '{#KUBE.SCHEDULER.SERVER.URL}'
              tags:
                - tag: addr
                  value: '{#IP}'
              custom_interfaces: 'YES'
              interfaces:
                - ip: '{#IP}'
          master_item:
            key: kube.control_plane.lld
        - uuid: 37812660877243e9bdbc0ffc7815578c
          name: 'StatefulSet discovery'
          type: DEPENDENT
          key: kube.statefulset.discovery
          filter:
            evaltype: AND
            conditions:
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.MATCHES}'
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.NOT_MATCHES}'
                operator: NOT_MATCHES_REGEX
          lifetime: '0'
          item_prototypes:
            - uuid: 9cc34425228f44868f3cd46450d557ca
              name: 'Namespace [{#NAMESPACE}] StatefulSet [{#NAME}]: Replicas'
              type: DEPENDENT
              key: 'kube.statefulset.replicas[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'The number of replicas per StatefulSet.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_statefulset_status_replicas{namespace="{#NAMESPACE}", statefulset="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: statefulset
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: statefulset
                  value: '{#NAME}'
            - uuid: 33e5a534b35f40c6ad7fef53212ef970
              name: 'Namespace [{#NAMESPACE}] StatefulSet [{#NAME}]: Current replicas'
              type: DEPENDENT
              key: 'kube.statefulset.replicas_current[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'The number of current replicas per StatefulSet.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_statefulset_status_replicas_current{namespace="{#NAMESPACE}", statefulset="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: statefulset
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: statefulset
                  value: '{#NAME}'
            - uuid: 3fee3afc8b924b13ae24ab4b5e793acf
              name: 'Namespace [{#NAMESPACE}] StatefulSet [{#NAME}]: Desired replicas'
              type: DEPENDENT
              key: 'kube.statefulset.replicas_desired[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'Number of desired pods for a StatefulSet.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_statefulset_replicas{namespace="{#NAMESPACE}", statefulset="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: statefulset
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: statefulset
                  value: '{#NAME}'
                - tag: status
                  value: ready
            - uuid: e2c3e03fe9bd42beab8a5d09c0a766bd
              name: 'Namespace [{#NAMESPACE}] StatefulSet [{#NAME}]: Replicas mismatched'
              type: DEPENDENT
              key: 'kube.statefulset.replicas_mismatched[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'The number of ready replicas not matching the number of replicas.'
              preprocessing:
                - type: PROMETHEUS_TO_JSON
                  parameters:
                    - '{__name__=~"^kube_statefulset_(status_replicas|status_replicas_ready)$", namespace="{#NAMESPACE}", statefulset="{#NAME}"}'
                - type: JAVASCRIPT
                  parameters:
                    - |
                      var data = JSON.parse(value),
                      	replicas,
                      	replicas_ready;
                      
                      if (data.length !== 2) {
                      	throw 'Incorrect length of JSON (must be 2). Actual length: ' + data.length;
                      }
                      
                      JSON.parse(value).forEach(function (item) {
                      	if (item.name === 'kube_statefulset_status_replicas') {
                      		replicas = item.value;
                      	}
                      	if (item.name === 'kube_statefulset_status_replicas_ready') {
                      		replicas_ready = item.value;
                      	}
                      });
                      
                      return Math.abs(replicas - replicas_ready);
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: statefulset
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: statefulset
                  value: '{#NAME}'
            - uuid: b35c1cebd902484998f383585ce29b76
              name: 'Namespace [{#NAMESPACE}] StatefulSet [{#NAME}]: Ready replicas'
              type: DEPENDENT
              key: 'kube.statefulset.replicas_ready[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'The number of ready replicas per StatefulSet.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_statefulset_status_replicas_ready{namespace="{#NAMESPACE}", statefulset="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: statefulset
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: statefulset
                  value: '{#NAME}'
                - tag: status
                  value: ready
            - uuid: b00b1cfed30e4b90b9754d543e72d7aa
              name: 'Namespace [{#NAMESPACE}] StatefulSet [{#NAME}]: Updated replicas'
              type: DEPENDENT
              key: 'kube.statefulset.replicas_updated[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'The number of updated replicas per StatefulSet.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kube_statefulset_status_replicas_updated{namespace="{#NAMESPACE}", statefulset="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: statefulset
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: statefulset
                  value: '{#NAME}'
                - tag: status
                  value: updated
          trigger_prototypes:
            - uuid: c29a27fe5a0345c8af9e0d4e99b22dcb
              expression: '(last(/Kubernetes cluster state by HTTP/kube.statefulset.replicas_ready[{#NAMESPACE}/{#NAME}]) / last(/Kubernetes cluster state by HTTP/kube.statefulset.replicas_current[{#NAMESPACE}/{#NAME}]))<>1'
              name: 'Kubernetes cluster state: Namespace [{#NAMESPACE}] StatefulSet [{#NAME}]: StatefulSet is down'
              priority: HIGH
              tags:
                - tag: scope
                  value: availability
            - uuid: 469d6933f5494ca48a212cdc364058e0
              expression: |
                min(/Kubernetes cluster state by HTTP/kube.statefulset.replicas_mismatched[{#NAMESPACE}/{#NAME}],{$KUBE.REPLICA.MISMATCH.EVAL_PERIOD:"statefulset:{#NAMESPACE}:{#NAME}"})>0
                and last(/Kubernetes cluster state by HTTP/kube.statefulset.replicas[{#NAMESPACE}/{#NAME}])>=0
                and last(/Kubernetes cluster state by HTTP/kube.statefulset.replicas_ready[{#NAMESPACE}/{#NAME}])>=0
              name: 'Kubernetes cluster state: Namespace [{#NAMESPACE}] StatefulSet [{#NAME}]: StatefulSet replicas mismatch'
              opdata: 'Replicas: {ITEM.LASTVALUE2}, ready: {ITEM.LASTVALUE3}'
              priority: WARNING
              description: 'StatefulSet has not matched the number of replicas during the specified trigger evaluation period.'
              tags:
                - tag: scope
                  value: availability
          master_item:
            key: kube.state.metrics
          lld_macro_paths:
            - lld_macro: '{#NAMESPACE}'
              path: $.labels.namespace
            - lld_macro: '{#NAME}'
              path: $.labels.statefulset
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - kube_statefulset_status_replicas
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
        - uuid: 428c4419ac8b4c91995a2aa7332b1943
          name: 'OpenShift Build discovery'
          type: DEPENDENT
          key: openshift.build.discovery
          filter:
            evaltype: AND
            conditions:
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.MATCHES}'
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.NOT_MATCHES}'
                operator: NOT_MATCHES_REGEX
          lifetime: '0'
          item_prototypes:
            - uuid: 4d1013542dcb45b3ae59fd276b0df3e0
              name: 'Namespace [{#NAMESPACE}] Build [{#NAME}]: Created'
              type: DEPENDENT
              key: 'openshift.build.created.time[{#NAMESPACE}/{#NAME}]'
              units: unixtime
              description: 'OpenShift Build Unix creation timestamp.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'openshift_build_created{namespace="{#NAMESPACE}", build="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
                - type: MULTIPLIER
                  parameters:
                    - '1'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 3h
              master_item:
                key: kube.state.metrics
              tags:
                - tag: build
                  value: '{#NAME}'
                - tag: component
                  value: build
                - tag: component
                  value: openshift
                - tag: namespace
                  value: '{#NAMESPACE}'
            - uuid: 97ebce9edb774e25943ed22416caaa0b
              name: 'Namespace [{#NAMESPACE}] Build [{#NAME}]: Generation'
              type: DEPENDENT
              key: 'openshift.build.sequence.number[{#NAMESPACE}/{#NAME}]'
              description: 'Sequence number representing a specific generation of the desired state.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'openshift_build_metadata_generation{namespace="{#NAMESPACE}", build="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: build
                  value: '{#NAME}'
                - tag: component
                  value: build
                - tag: component
                  value: openshift
                - tag: namespace
                  value: '{#NAMESPACE}'
            - uuid: 9a8bdd353a5a499c8c66468c1325ae16
              name: 'Namespace [{#NAMESPACE}] Build [{#NAME}]: Status phase'
              type: DEPENDENT
              key: 'openshift.build.status_phase[{#NAMESPACE}/{#NAME}]'
              description: 'The Build phase.'
              valuemap:
                name: 'Build status phases'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'openshift_build_status_phase{build="{#NAME}"} == 1'
                    - label
                    - build_phase
                  error_handler: DISCARD_VALUE
                - type: JAVASCRIPT
                  parameters:
                    - 'return [''complete'', ''cancelled'', ''new'', ''pending'', ''running'', ''failed'', ''error''].indexOf(value) + 1 || ''Problem with status processing in JS, no such build status: '' + value;'
              master_item:
                key: kube.state.metrics
              tags:
                - tag: build
                  value: '{#NAME}'
                - tag: component
                  value: build
                - tag: component
                  value: openshift
                - tag: namespace
                  value: '{#NAMESPACE}'
              trigger_prototypes:
                - uuid: b3364370ae954d69b7fad1ac3afd238b
                  expression: 'count(/Kubernetes cluster state by HTTP/openshift.build.status_phase[{#NAMESPACE}/{#NAME}],2m,"ge",6)>=2'
                  name: 'Kubernetes cluster state: Build [{#NAME}]: Build has failed'
                  priority: WARNING
                  tags:
                    - tag: scope
                      value: availability
          master_item:
            key: kube.state.metrics
          lld_macro_paths:
            - lld_macro: '{#NAMESPACE}'
              path: $.labels.namespace
            - lld_macro: '{#NAME}'
              path: $.labels.build
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - openshift_build_created
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
        - uuid: 974679d1b2bc4d7294baeca07bd19e07
          name: 'OpenShift BuildConfig discovery'
          type: DEPENDENT
          key: openshift.buildconfig.discovery
          filter:
            evaltype: AND
            conditions:
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.MATCHES}'
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.NOT_MATCHES}'
                operator: NOT_MATCHES_REGEX
          lifetime: '0'
          item_prototypes:
            - uuid: 09d0c8ed4d604d898f212419ccdf8324
              name: 'Namespace [{#NAMESPACE}] BuildConfig [{#NAME}]: Created'
              type: DEPENDENT
              key: 'openshift.buildconfig.created.time[{#NAMESPACE}/{#NAME}]'
              units: unixtime
              description: 'OpenShift BuildConfig Unix creation timestamp.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'openshift_buildconfig_created{namespace="{#NAMESPACE}", buildconfig="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
                - type: MULTIPLIER
                  parameters:
                    - '1'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 3h
              master_item:
                key: kube.state.metrics
              tags:
                - tag: buildconfig
                  value: '{#NAME}'
                - tag: component
                  value: buildconfig
                - tag: component
                  value: openshift
                - tag: namespace
                  value: '{#NAMESPACE}'
            - uuid: 2e90ec2497eb4eb3bf41b68282f07e6d
              name: 'Namespace [{#NAMESPACE}] BuildConfig [{#NAME}]: Generation'
              type: DEPENDENT
              key: 'openshift.buildconfig.generation[{#NAMESPACE}/{#NAME}]'
              description: 'Sequence number representing a specific generation of the desired state.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'openshift_buildconfig_metadata_generation{namespace="{#NAMESPACE}", buildconfig="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: buildconfig
                  value: '{#NAME}'
                - tag: component
                  value: buildconfig
                - tag: component
                  value: openshift
                - tag: namespace
                  value: '{#NAMESPACE}'
            - uuid: e97bf96c39d1407cbc42013bcd3a5095
              name: 'Namespace [{#NAMESPACE}] BuildConfig [{#NAME}]: Latest version'
              type: DEPENDENT
              key: 'openshift.buildconfig.status[{#NAMESPACE}/{#NAME}]'
              description: 'The latest version of BuildConfig.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'openshift_buildconfig_status_latest_version{namespace="{#NAMESPACE}", buildconfig="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 3h
              master_item:
                key: kube.state.metrics
              tags:
                - tag: buildconfig
                  value: '{#NAME}'
                - tag: component
                  value: buildconfig
                - tag: component
                  value: openshift
                - tag: namespace
                  value: '{#NAMESPACE}'
          master_item:
            key: kube.state.metrics
          lld_macro_paths:
            - lld_macro: '{#NAMESPACE}'
              path: $.labels.namespace
            - lld_macro: '{#NAME}'
              path: $.labels.buildconfig
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - openshift_buildconfig_created
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
        - uuid: d7e21c75073548078e06159ff94680c9
          name: 'OpenShift ClusterResourceQuota discovery'
          type: DEPENDENT
          key: openshift.cluster.resource.quota.discovery
          lifetime: '0'
          item_prototypes:
            - uuid: 0b3826bad61c407ab4b9e103f0a3ae18
              name: 'Quota [{#NAME}] Resource [{#RESOURCE}]: Type [{#TYPE}]]'
              type: DEPENDENT
              key: 'openshift.cluster.resource.quota[{#RESOURCE}/{#NAME}/{#TYPE}]'
              description: 'Usage about resource quota.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'openshift_clusterresourcequota_usage{name="{#NAME}", resource="{#RESOURCE}", type="{#TYPE}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: openshift
                - tag: quota
                  value: '{#NAME}'
                - tag: resource
                  value: '{#RESOURCE}'
                - tag: type
                  value: '{#TYPE}'
          master_item:
            key: kube.state.metrics
          lld_macro_paths:
            - lld_macro: '{#NAME}'
              path: $.labels.name
            - lld_macro: '{#RESOURCE}'
              path: $.labels.resource
            - lld_macro: '{#TYPE}'
              path: $.labels.type
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - openshift_clusterresourcequota_usage
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
        - uuid: 140a80726c60443ca5bb87b758924f7f
          name: 'OpenShift Route discovery'
          type: DEPENDENT
          key: openshift.route.discovery
          filter:
            evaltype: AND
            conditions:
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.MATCHES}'
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.NAMESPACE.NOT_MATCHES}'
                operator: NOT_MATCHES_REGEX
          lifetime: '0'
          item_prototypes:
            - uuid: a59550207a484b918193d4a57b08d97e
              name: 'Namespace [{#NAMESPACE}] Route [{#NAME}]: Created'
              type: DEPENDENT
              key: 'openshift.route.created.time[{#NAMESPACE}/{#NAME}]'
              units: unixtime
              description: 'OpenShift Route Unix creation timestamp.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'openshift_route_created{namespace="{#NAMESPACE}", route="{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
                - type: MULTIPLIER
                  parameters:
                    - '1'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 3h
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: openshift
                - tag: component
                  value: route
                - tag: host
                  value: '{#HOST}'
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: route
                  value: '{#NAME}'
            - uuid: d55f9134b0fa4f3ea0eea93a682ab4f9
              name: 'Namespace [{#NAMESPACE}] Route [{#NAME}]: Status'
              type: DEPENDENT
              key: 'openshift.route.status[{#NAMESPACE}/{#NAME}]'
              description: 'Information about route status.'
              valuemap:
                name: 'Boolean format'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'openshift_route_status{route="{#NAME}"} == 1'
                    - label
                    - status
                  error_handler: DISCARD_VALUE
                - type: BOOL_TO_DECIMAL
              master_item:
                key: kube.state.metrics
              tags:
                - tag: component
                  value: openshift
                - tag: component
                  value: route
                - tag: host
                  value: '{#HOST}'
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: route
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: 98a6d7ba3a4049d693f5471819ee4b2e
                  expression: 'count(/Kubernetes cluster state by HTTP/openshift.route.status[{#NAMESPACE}/{#NAME}],2m,,0)>=2'
                  name: 'Kubernetes cluster state: Route [{#NAME}] with issue: Status is false'
                  priority: WARNING
                  tags:
                    - tag: scope
                      value: availability
          master_item:
            key: kube.state.metrics
          lld_macro_paths:
            - lld_macro: '{#HOST}'
              path: $.labels.host
            - lld_macro: '{#NAMESPACE}'
              path: $.labels.namespace
            - lld_macro: '{#NAME}'
              path: $.labels.route
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - openshift_route_info
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
      tags:
        - tag: class
          value: software
        - tag: subclass
          value: automation
        - tag: subclass
          value: containers
        - tag: subclass
          value: deploy
        - tag: subclass
          value: development
        - tag: subclass
          value: virtualization
        - tag: target
          value: cluster-state
        - tag: target
          value: kubernetes
      macros:
        - macro: '{$KUBE.API.COMPONENTSTATUSES.ENDPOINT}'
          value: /api/v1/componentstatuses
          description: 'Kubernetes API componentstatuses endpoint /api/v1/componentstatuses'
          config:
            type: TEXT
            priority: '4'
            label: 'Componentstatuses Endpoint'
            description: 'The Kubernetes API componentstatuses endpoint.'
        - macro: '{$KUBE.API.LIVEZ.ENDPOINT}'
          value: /livez
          description: 'Kubernetes API livez endpoint /livez'
          config:
            type: TEXT
            priority: '3'
            label: 'Livez Endpoint'
            description: 'The Kubernetes API livez endpoint.'
        - macro: '{$KUBE.API.READYZ.ENDPOINT}'
          value: /readyz
          description: 'Kubernetes API readyz endpoint /readyz'
          config:
            type: TEXT
            priority: '5'
            label: 'Readyz Endpoint'
            description: 'The Kubernetes API readyz endpoint.'
        - macro: '{$KUBE.API.TOKEN}'
          type: SECRET_TEXT
          description: 'Service account bearer token.'
          config:
            type: TEXT
            priority: '1'
            label: 'API Token'
            description: 'Service account bearer token for authentication.'
            required: 'YES'
        - macro: '{$KUBE.API.URL}'
          value: 'https://kubernetes.default.svc.cluster.local:443'
          description: 'Kubernetes API endpoint URL in the format <scheme>://<host>:<port>'
          config:
            type: TEXT
            priority: '2'
            label: 'Kubernetes API URL'
            description: 'The Kubernetes API endpoint URL.'
            required: 'YES'
        - macro: '{$KUBE.API_SERVER.PORT}'
          value: '6443'
          description: 'Kubernetes API servers metrics endpoint port. Used in ControlPlane LLD.'
          config:
            type: TEXT
            priority: '10'
            label: 'API Server Port'
            description: 'The port for the Kubernetes API server metrics endpoint. In the range from 1 to 65535 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$KUBE.API_SERVER.SCHEME}'
          value: https
          description: 'Kubernetes API servers metrics endpoint scheme. Used in ControlPlane LLD.'
          config:
            type: LIST
            priority: '9'
            label: 'API Server Scheme'
            description: 'The scheme for the Kubernetes API server metrics endpoint.'
            options:
              - value: https
                text: HTTPS
              - value: http
                text: HTTP
        - macro: '{$KUBE.CONTROLLER_MANAGER.PORT}'
          value: '10257'
          description: 'Kubernetes Controller manager metrics endpoint port. Used in ControlPlane LLD.'
          config:
            type: TEXT
            priority: '13'
            label: 'Controller Manager Port'
            description: 'The port for the Kubernetes Controller Manager metrics endpoint. In the range from 1 to 65535 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$KUBE.CONTROLLER_MANAGER.SCHEME}'
          value: https
          description: 'Kubernetes Controller manager metrics endpoint scheme. Used in ControlPlane LLD.'
          config:
            type: LIST
            priority: '12'
            label: 'Controller Manager Scheme'
            description: 'The scheme for the Kubernetes Controller Manager metrics endpoint.'
            options:
              - value: https
                text: HTTPS
              - value: http
                text: HTTP
        - macro: '{$KUBE.CONTROL_PLANE.TAINT}'
          value: node-role.kubernetes.io/control-plane
          description: 'Taint that applies to control plane nodes. Change if needed. Used in ControlPlane LLD.'
          config:
            type: TEXT
            priority: '11'
            label: 'Control Plane Taint'
            description: 'The taint for control plane nodes.'
        - macro: '{$KUBE.HTTP.PROXY}'
          description: 'Sets the HTTP proxy to `http_proxy` value. If this parameter is empty, then no proxy is used.'
          config:
            type: TEXT
            priority: '6'
            section_name: Other
            label: 'HTTP Proxy'
            description: 'HTTP proxy to use for requests.'
        - macro: '{$KUBE.KUBELET.FILTER.ANNOTATIONS}'
          description: 'Node annotations to filter Kubelets (regex in values are supported). See the template''s README.md for details.'
          config:
            type: TEXT
            priority: '24'
            section_name: Filters
            label: 'Kubelet Annotations Filter'
            description: 'Node annotations to filter Kubelets.'
        - macro: '{$KUBE.KUBELET.FILTER.LABELS}'
          description: 'Node labels to filter Kubelets (regex in values are supported). See the template''s README.md for details.'
          config:
            type: TEXT
            priority: '25'
            section_name: Filters
            label: 'Kubelet Labels Filter'
            description: 'Node labels to filter Kubelets.'
        - macro: '{$KUBE.KUBELET.PORT}'
          value: '10250'
          description: 'Kubernetes Kubelet metrics endpoint port. Used in Kubelet LLD.'
          config:
            type: TEXT
            priority: '17'
            label: 'Kubelet Port'
            description: 'The port for the Kubernetes Kubelet metrics endpoint. In the range from 1 to 65535 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$KUBE.KUBELET.SCHEME}'
          value: https
          description: 'Kubernetes Kubelet metrics endpoint scheme. Used in Kubelet LLD.'
          config:
            type: LIST
            priority: '16'
            label: 'Kubelet Scheme'
            description: 'The scheme for the Kubernetes Kubelet metrics endpoint.'
            options:
              - value: https
                text: HTTPS
              - value: http
                text: HTTP
        - macro: '{$KUBE.LLD.FILTER.KUBELET_NODE.MATCHES}'
          value: '.*'
          description: 'Filter of discoverable Kubelets by nodename.'
          config:
            type: TEXT
            priority: '22'
            section_name: Filters
            label: 'Kubelet Node Matches Filter'
            description: 'A regex to filter discoverable Kubelets by nodename.'
        - macro: '{$KUBE.LLD.FILTER.KUBELET_NODE.NOT_MATCHES}'
          value: CHANGE_IF_NEEDED
          description: 'Filter to exclude discovered Kubelets by nodename.'
          config:
            type: TEXT
            priority: '23'
            section_name: Filters
            label: 'Kubelet Node Exclude Filter'
            description: 'A regex to exclude discovered Kubelets by nodename.'
        - macro: '{$KUBE.LLD.FILTER.NAMESPACE.MATCHES}'
          value: '.*'
          description: 'Filter of discoverable metrics by namespace.'
          config:
            type: TEXT
            priority: '18'
            section_name: Filters
            label: 'Namespace Matches Filter'
            description: 'A regex to filter discoverable metrics by namespace.'
        - macro: '{$KUBE.LLD.FILTER.NAMESPACE.NOT_MATCHES}'
          value: CHANGE_IF_NEEDED
          description: 'Filter to exclude discovered metrics by namespace.'
          config:
            type: TEXT
            priority: '19'
            section_name: Filters
            label: 'Namespace Exclude Filter'
            description: 'A regex to exclude discovered metrics by namespace.'
        - macro: '{$KUBE.LLD.FILTER.NODE.MATCHES}'
          value: '.*'
          description: 'Filter of discoverable nodes by nodename.'
          config:
            type: TEXT
            priority: '20'
            section_name: Filters
            label: 'Node Matches Filter'
            description: 'A regex to filter discoverable nodes by nodename.'
        - macro: '{$KUBE.LLD.FILTER.NODE.NOT_MATCHES}'
          value: CHANGE_IF_NEEDED
          description: 'Filter to exclude discovered nodes by nodename.'
          config:
            type: TEXT
            priority: '21'
            section_name: Filters
            label: 'Node Exclude Filter'
            description: 'A regex to exclude discovered nodes by nodename.'
        - macro: '{$KUBE.LLD.FILTER.PV.MATCHES}'
          value: '.*'
          description: 'Filter of discoverable persistent volumes by name.'
          config:
            type: TEXT
            priority: '26'
            section_name: Filters
            label: 'Persistent Volume Matches Filter'
            description: 'A regex to filter discoverable persistent volumes by name.'
        - macro: '{$KUBE.LLD.FILTER.PV.NOT_MATCHES}'
          value: CHANGE_IF_NEEDED
          description: 'Filter to exclude discovered persistent volumes by name.'
          config:
            type: TEXT
            priority: '27'
            section_name: Filters
            label: 'Persistent Volume Exclude Filter'
            description: 'A regex to exclude discovered persistent volumes by name.'
        - macro: '{$KUBE.REPLICA.MISMATCH.EVAL_PERIOD}'
          value: '#5'
          description: 'The evaluation period range which is used for calculation of expressions in trigger prototypes (time period or value range). Can be used with context.'
          config:
            type: TEXT
            priority: '28'
            section_name: Other
            label: 'Replica Mismatch Evaluation Period'
            description: 'The evaluation period range for trigger prototype calculations.'
        - macro: '{$KUBE.SCHEDULER.PORT}'
          value: '10259'
          description: 'Kubernetes Scheduler metrics endpoint port. Used in ControlPlane LLD.'
          config:
            type: TEXT
            priority: '15'
            label: 'Scheduler Port'
            description: 'The port for the Kubernetes Scheduler metrics endpoint. In the range from 1 to 65535 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$KUBE.SCHEDULER.SCHEME}'
          value: https
          description: 'Kubernetes Scheduler metrics endpoint scheme. Used in ControlPlane LLD.'
          config:
            type: LIST
            priority: '14'
            label: 'Scheduler Scheme'
            description: 'The scheme for the Kubernetes Scheduler metrics endpoint.'
            options:
              - value: https
                text: HTTPS
              - value: http
                text: HTTP
        - macro: '{$KUBE.STATE.ENDPOINT.NAME}'
          value: zabbix-kube-state-metrics
          description: 'Kubernetes state endpoint name.'
          config:
            type: TEXT
            priority: '7'
            label: 'State Endpoint Name'
            description: 'The name of the Kubernetes state endpoint.'
        - macro: '{$OPENSHIFT.STATE.ENDPOINT.NAME}'
          value: openshift-state-metrics
          description: 'OpenShift state endpoint name.'
          config:
            type: TEXT
            priority: '8'
            label: 'OpenShift State Endpoint Name'
            description: 'The name of the OpenShift state endpoint.'
      valuemaps:
        - uuid: a435f7e23050406ca40cf6f5f872b5a7
          name: 'Boolean format'
          mappings:
            - value: '0'
              newvalue: 'False'
            - value: '1'
              newvalue: 'True'
        - uuid: a315a447059e49f9bc0c3e2e9964696f
          name: 'Build status phases'
          mappings:
            - value: '1'
              newvalue: complete
            - value: '2'
              newvalue: cancelled
            - value: '3'
              newvalue: new
            - value: '4'
              newvalue: pending
            - value: '5'
              newvalue: running
            - value: '6'
              newvalue: failed
            - value: '7'
              newvalue: error
        - uuid: f5aa4a786972420b859029116aac8a2f
          name: 'PV and PVC status phases'
          mappings:
            - value: '1'
              newvalue: Available
            - value: '2'
              newvalue: Bound
            - value: '3'
              newvalue: Failed
            - value: '4'
              newvalue: Lost
            - value: '5'
              newvalue: Pending
            - value: '6'
              newvalue: Released
    - uuid: 2420a8a4fda74fbc81743aed69fafa3b
      template: 'Kubernetes Controller manager by HTTP'
      name: 'Kubernetes Controller manager by HTTP'
      description: |
        Get Kubernetes Controller manager metrics by HTTP agent from Prometheus metrics endpoint.
        
        Don't forget change macros {$KUBE.API.SERVER.URL}.
        Some metrics may not be collected depending on your Kubernetes Controller manager instance version and configuration.
        
        You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback
        
        Generated by official Zabbix template tool "Templator"
      wizard_ready: 'YES'
      readme: |
        ## Overview
        
        The template to monitor Kubernetes Controller manager by Zabbix that works without any external scripts.
        Most of the metrics are collected in one go, thanks to Zabbix bulk data collection.
        
        Template `Kubernetes Controller manager by HTTP` - collects metrics by HTTP agent from Controller manager /metrics endpoint.
        
        ## Setup
        
        Internal service metrics are collected from /metrics endpoint.
        Template needs to use Authorization via API token.
        
        Set the following fields: `Metrics endpoint URL`, `API Authorization Token`.
        
        *NOTE.* You might need to set the `--binding-address` option for Controller Manager to the address where Zabbix proxy can reach it.
        For example, for clusters created with `kubeadm` it can be set in the following manifest file (changes will be applied immediately):
        
        - /etc/kubernetes/manifests/kube-controller-manager.yaml
        
        *NOTE.* Some metrics may not be collected depending on your Kubernetes Controller manager instance version and configuration.
      vendor:
        name: Zabbix
        version: 7.4-1
      groups:
        - name: Templates/Applications
      items:
        - uuid: 774693b22f844424a93f6a56001c8cba
          name: 'REST Client requests: 2xx, rate'
          type: DEPENDENT
          key: kubernetes.controller.client_http_requests_200.rate
          value_type: FLOAT
          description: 'Number of HTTP requests with 2xx status code per second.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - 'rest_client_requests_total{code =~ "2.."}'
                - function
                - sum
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: kubernetes.controller.get_metrics
          tags:
            - tag: component
              value: rest
            - tag: http-code
              value: 2xx
        - uuid: ace0d156101b481d9f53c3f48e84bd38
          name: 'REST Client requests: 3xx, rate'
          type: DEPENDENT
          key: kubernetes.controller.client_http_requests_300.rate
          value_type: FLOAT
          description: 'Number of HTTP requests with 3xx status code per second.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - 'rest_client_requests_total{code =~ "3.."}'
                - function
                - sum
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: kubernetes.controller.get_metrics
          tags:
            - tag: component
              value: rest
            - tag: http-code
              value: 3xx
        - uuid: c6b67e4330184ca98281773c69925d98
          name: 'REST Client requests: 4xx, rate'
          type: DEPENDENT
          key: kubernetes.controller.client_http_requests_400.rate
          value_type: FLOAT
          description: 'Number of HTTP requests with 4xx status code per second.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - 'rest_client_requests_total{code =~ "4.."}'
                - function
                - sum
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: kubernetes.controller.get_metrics
          tags:
            - tag: component
              value: rest
            - tag: http-code
              value: 4xx
        - uuid: ac6397e9f62749199f857e6c859daa59
          name: 'REST Client requests: 5xx, rate'
          type: DEPENDENT
          key: kubernetes.controller.client_http_requests_500.rate
          value_type: FLOAT
          description: 'Number of HTTP requests with 5xx status code per second.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - 'rest_client_requests_total{code =~ "5.."}'
                - function
                - sum
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: kubernetes.controller.get_metrics
          tags:
            - tag: component
              value: rest
            - tag: http-code
              value: 5xx
          triggers:
            - uuid: 13c32daebddd454bb5908a9a27c3a76f
              expression: 'min(/Kubernetes Controller manager by HTTP/kubernetes.controller.client_http_requests_500.rate,5m)>{$KUBE.CONTROLLER.HTTP.CLIENT.ERROR}'
              name: 'Kubernetes Controller manager: Too many HTTP client errors'
              event_name: 'Kubernetes Controller manager: Too many HTTP client errors (over {$KUBE.CONTROLLER.HTTP.CLIENT.ERROR} for 5m)'
              priority: WARNING
              description: '"Kubernetes Controller manager is experiencing high error rate (with 5xx HTTP code).'
              tags:
                - tag: scope
                  value: availability
        - uuid: 6bde8365469f47359fcc5716207b8870
          name: CPU
          type: DEPENDENT
          key: kubernetes.controller.cpu.util
          value_type: FLOAT
          units: '%'
          description: 'Total user and system CPU usage ratio.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - process_cpu_seconds_total
                - value
                - ''
            - type: CHANGE_PER_SECOND
            - type: MULTIPLIER
              parameters:
                - '100'
          master_item:
            key: kubernetes.controller.get_metrics
          tags:
            - tag: component
              value: cpu
        - uuid: c684929ea8444a6aa24f1fb80812a6eb
          name: 'Kubernetes Controller: Get Controller metrics'
          type: HTTP_AGENT
          key: kubernetes.controller.get_metrics
          history: '0'
          value_type: TEXT
          description: 'Get raw metrics from Controller instance /metrics endpoint.'
          preprocessing:
            - type: CHECK_NOT_SUPPORTED
              parameters:
                - '-1'
          timeout: 15s
          url: '{$KUBE.CONTROLLER.SERVER.URL}'
          headers:
            - name: Authorization
              value: 'Bearer {$KUBE.API.TOKEN}'
          tags:
            - tag: component
              value: raw
        - uuid: 8e4f98354c89410ebad42af485e3f710
          name: Goroutines
          type: DEPENDENT
          key: kubernetes.controller.go_goroutines
          value_type: FLOAT
          description: 'Number of goroutines that currently exist.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - go_goroutines
                - function
                - sum
              error_handler: DISCARD_VALUE
          master_item:
            key: kubernetes.controller.get_metrics
          tags:
            - tag: component
              value: goroutines
        - uuid: f30ba3d8679b4ffd86a20427892da228
          name: 'Go threads'
          type: DEPENDENT
          key: kubernetes.controller.go_threads
          value_type: FLOAT
          description: 'Number of OS threads created.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - go_threads
                - value
                - ''
              error_handler: DISCARD_VALUE
          master_item:
            key: kubernetes.controller.get_metrics
          tags:
            - tag: component
              value: go-threads
        - uuid: b9ef0724331f4f9da830c470b8e2fea1
          name: 'Leader election status'
          type: DEPENDENT
          key: kubernetes.controller.leader_election_master_status
          value_type: FLOAT
          description: 'Gauge of if the reporting system is master of the relevant lease, 0 indicates backup, 1 indicates master.'
          valuemap:
            name: 'Leader status'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - leader_election_master_status
                - value
                - ''
              error_handler: DISCARD_VALUE
          master_item:
            key: kubernetes.controller.get_metrics
          tags:
            - tag: component
              value: leader
        - uuid: 5bb0657b329c44e6a7a6dd169551205b
          name: 'Fds max'
          type: DEPENDENT
          key: kubernetes.controller.max_fds
          value_type: FLOAT
          description: 'Maximum allowed open file descriptors.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - process_max_fds
                - value
                - ''
              error_handler: DISCARD_VALUE
          master_item:
            key: kubernetes.controller.get_metrics
          tags:
            - tag: component
              value: fds
        - uuid: 43698df9a76c410792f0fdb9d41ee42c
          name: 'Fds open'
          type: DEPENDENT
          key: kubernetes.controller.open_fds
          value_type: FLOAT
          description: 'Number of open file descriptors.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - process_open_fds
                - value
                - ''
              error_handler: DISCARD_VALUE
          master_item:
            key: kubernetes.controller.get_metrics
          tags:
            - tag: component
              value: fds
        - uuid: 7497f4f8d1d8422dad301d9d25b42150
          name: 'Resident memory, bytes'
          type: DEPENDENT
          key: kubernetes.controller.process_resident_memory_bytes
          value_type: FLOAT
          units: B
          description: 'Resident memory size in bytes.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - process_resident_memory_bytes
                - value
                - ''
              error_handler: DISCARD_VALUE
          master_item:
            key: kubernetes.controller.get_metrics
          tags:
            - tag: component
              value: memory
        - uuid: 884a7a4de05548ffbdf14629bbe5d181
          name: 'Virtual memory, bytes'
          type: DEPENDENT
          key: kubernetes.controller.process_virtual_memory_bytes
          value_type: FLOAT
          units: B
          description: 'Virtual memory size in bytes.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - process_virtual_memory_bytes
                - value
                - ''
              error_handler: DISCARD_VALUE
          master_item:
            key: kubernetes.controller.get_metrics
          tags:
            - tag: component
              value: memory
      discovery_rules:
        - uuid: 3117060c51564c2e897e3194821b137f
          name: 'Workqueue metrics discovery'
          type: DEPENDENT
          key: kubernetes.controller.workqueue.discovery
          item_prototypes:
            - uuid: 70277a128a254462ad0bf7a023738ba0
              name: '["{#NAME}"]: Workqueue duration seconds bucket, {#LE}'
              type: DEPENDENT
              key: 'kubernetes.controller.duration_seconds_bucket[{#LE},"{#NAME}"]'
              history: 1h
              value_type: FLOAT
              trends: '0'
              discover: NO_DISCOVER
              description: 'How long in seconds processing an item from workqueue takes.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'workqueue_work_duration_seconds_bucket{name = "{#NAME}",le = "{#LE}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kubernetes.controller.get_metrics
              tags:
                - tag: component
                  value: workqueue
                - tag: workqueue
                  value: '{#NAME}'
            - uuid: 8357905c82ea42b98d686eee2d9c35f6
              name: '["{#NAME}"]: Queue duration seconds bucket, {#LE}'
              type: DEPENDENT
              key: 'kubernetes.controller.queue_duration_seconds_bucket[{#LE},"{#NAME}"]'
              history: 1h
              value_type: FLOAT
              trends: '0'
              discover: NO_DISCOVER
              description: 'How long in seconds an item stays in workqueue before being requested.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'workqueue_queue_duration_seconds_bucket{name = "{#NAME}",le = "{#LE}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kubernetes.controller.get_metrics
              tags:
                - tag: component
                  value: workqueue
                - tag: workqueue
                  value: '{#NAME}'
            - uuid: 940dc936417849c7aed7ae824883fdaf
              name: '["{#NAME}"]: Workqueue adds total, rate'
              type: DEPENDENT
              key: 'kubernetes.controller.workqueue_adds_total["{#NAME}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              description: 'Total number of adds handled by workqueue per second.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'workqueue_adds_total{name = "{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
                - type: CHANGE_PER_SECOND
              master_item:
                key: kubernetes.controller.get_metrics
              tags:
                - tag: component
                  value: workqueue
                - tag: workqueue
                  value: '{#NAME}'
            - uuid: 7edfab667cdf41908bd551c0a25e4adc
              name: '["{#NAME}"]: Workqueue depth'
              type: DEPENDENT
              key: 'kubernetes.controller.workqueue_depth["{#NAME}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              description: 'Current depth of workqueue.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'workqueue_depth{name = "{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kubernetes.controller.get_metrics
              tags:
                - tag: component
                  value: workqueue
                - tag: workqueue
                  value: '{#NAME}'
            - uuid: 9a510f3b3d3547c1817b72e38340ccd2
              name: '["{#NAME}"]: Workqueue longest running processor, sec'
              type: DEPENDENT
              key: 'kubernetes.controller.workqueue_longest_running_processor_seconds["{#NAME}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              description: 'How many seconds has the longest running processor for workqueue been running.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'workqueue_longest_running_processor_seconds{name = "{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kubernetes.controller.get_metrics
              tags:
                - tag: component
                  value: workqueue
                - tag: workqueue
                  value: '{#NAME}'
            - uuid: 0657d0741d5649a2b0ad87c2f39dc243
              name: '["{#NAME}"]: Workqueue queue duration, 50p'
              type: CALCULATED
              key: 'kubernetes.controller.workqueue_queue_duration_seconds_p50["{#NAME}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kubernetes.controller.queue_duration_seconds_bucket[*,"{#NAME}"],5m,50)'
              description: '50 percentile of how long in seconds an item stays in workqueue before being requested. If there are no requests for 5 minute, item value will be discarded.'
              preprocessing:
                - type: CHECK_NOT_SUPPORTED
                  parameters:
                    - '-1'
              tags:
                - tag: component
                  value: workqueue
                - tag: workqueue
                  value: '{#NAME}'
            - uuid: 9f976d181b7f4776a271e683d9efd396
              name: '["{#NAME}"]: Workqueue queue duration, p90'
              type: CALCULATED
              key: 'kubernetes.controller.workqueue_queue_duration_seconds_p90["{#NAME}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kubernetes.controller.queue_duration_seconds_bucket[*,"{#NAME}"],5m,90)'
              description: '90 percentile of how long in seconds an item stays in workqueue before being requested, by queue.'
              tags:
                - tag: component
                  value: workqueue
                - tag: workqueue
                  value: '{#NAME}'
            - uuid: ce4b9daa161742ffb6fec0790c1dc689
              name: '["{#NAME}"]: Workqueue queue duration, p95'
              type: CALCULATED
              key: 'kubernetes.controller.workqueue_queue_duration_seconds_p95["{#NAME}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kubernetes.controller.queue_duration_seconds_bucket[*,"{#NAME}"],5m,95)'
              description: '95 percentile of how long in seconds an item stays in workqueue before being requested, by queue.'
              tags:
                - tag: component
                  value: workqueue
                - tag: workqueue
                  value: '{#NAME}'
            - uuid: 61d5f616cc474ae3adfcbd1a15fdd607
              name: '["{#NAME}"]: Workqueue queue duration, p99'
              type: CALCULATED
              key: 'kubernetes.controller.workqueue_queue_duration_seconds_p99["{#NAME}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kubernetes.controller.queue_duration_seconds_bucket[*,"{#NAME}"],5m,99)'
              description: '99 percentile of how long in seconds an item stays in workqueue before being requested, by queue.'
              tags:
                - tag: component
                  value: workqueue
                - tag: workqueue
                  value: '{#NAME}'
            - uuid: a4e25b0e8cd340d48e098b89ffcdd49a
              name: '["{#NAME}"]: Workqueue retries, rate'
              type: DEPENDENT
              key: 'kubernetes.controller.workqueue_retries_total["{#NAME}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              description: 'Total number of retries handled by workqueue per second.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'workqueue_retries_total{name = "{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
                - type: CHANGE_PER_SECOND
              master_item:
                key: kubernetes.controller.get_metrics
              tags:
                - tag: component
                  value: workqueue
                - tag: workqueue
                  value: '{#NAME}'
            - uuid: e230e1573f4042b088a8a4b2e3998d43
              name: '["{#NAME}"]: Workqueue unfinished work, sec'
              type: DEPENDENT
              key: 'kubernetes.controller.workqueue_unfinished_work_seconds["{#NAME}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              description: 'How many seconds of work has done that is in progress and hasn''t been observed by work_duration. Large values indicate stuck threads. One can deduce the number of stuck threads by observing the rate at which this increases.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'workqueue_unfinished_work_seconds{name = "{#NAME}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kubernetes.controller.get_metrics
              tags:
                - tag: component
                  value: workqueue
                - tag: workqueue
                  value: '{#NAME}'
            - uuid: 68efc8bc4fec458384e21b7b19db696c
              name: '["{#NAME}"]: Workqueue work duration, 50p'
              type: CALCULATED
              key: 'kubernetes.controller.workqueue_work_duration_seconds_p50["{#NAME}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kubernetes.controller.duration_seconds_bucket[*,"{#NAME}"],5m,50)'
              description: '50 percentiles of how long in seconds processing an item from workqueue takes, by queue.'
              tags:
                - tag: component
                  value: workqueue
                - tag: workqueue
                  value: '{#NAME}'
            - uuid: ff4f4b222dfd47f69b96513fed4393f5
              name: '["{#NAME}"]: Workqueue work duration, p90'
              type: CALCULATED
              key: 'kubernetes.controller.workqueue_work_duration_seconds_p90["{#NAME}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kubernetes.controller.duration_seconds_bucket[*,"{#NAME}"],5m,90)'
              description: '90 percentile of how long in seconds processing an item from workqueue takes, by queue.'
              tags:
                - tag: component
                  value: workqueue
                - tag: workqueue
                  value: '{#NAME}'
            - uuid: 34a688601a404d63aea3a774a9f5970a
              name: '["{#NAME}"]: Workqueue work duration, p95'
              type: CALCULATED
              key: 'kubernetes.controller.workqueue_work_duration_seconds_p95["{#NAME}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kubernetes.controller.duration_seconds_bucket[*,"{#NAME}"],5m,95)'
              description: '95 percentile of how long in seconds processing an item from workqueue takes, by queue.'
              tags:
                - tag: component
                  value: workqueue
                - tag: workqueue
                  value: '{#NAME}'
            - uuid: e5b4ea49906e4a12b01757854a5766a4
              name: '["{#NAME}"]: Workqueue work duration, p99'
              type: CALCULATED
              key: 'kubernetes.controller.workqueue_work_duration_seconds_p99["{#NAME}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kubernetes.controller.duration_seconds_bucket[*,"{#NAME}"],5m,99)'
              description: '99 percentile of how long in seconds processing an item from workqueue takes, by queue.'
              tags:
                - tag: component
                  value: workqueue
                - tag: workqueue
                  value: '{#NAME}'
          graph_prototypes:
            - uuid: 40113b2f3fe04e9dbfd4d6dc204be7ce
              name: 'Kubernetes Controller Manager: ["{#NAME}"] Workqueue add rate'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'Kubernetes Controller manager by HTTP'
                    key: 'kubernetes.controller.workqueue_adds_total["{#NAME}"]'
            - uuid: 99bd6b4904964738a2ba7f165cc78d9c
              name: 'Kubernetes Controller Manager: ["{#NAME}"] Workqueue depth'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'Kubernetes Controller manager by HTTP'
                    key: 'kubernetes.controller.workqueue_depth["{#NAME}"]'
            - uuid: 4f823f87056b42d29a284f8e2614b76f
              name: 'Kubernetes Controller Manager: ["{#NAME}"] Workqueue latency'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'Kubernetes Controller manager by HTTP'
                    key: 'kubernetes.controller.workqueue_queue_duration_seconds_p95["{#NAME}"]'
                - sortorder: '1'
                  color: F63100
                  item:
                    host: 'Kubernetes Controller manager by HTTP'
                    key: 'kubernetes.controller.workqueue_queue_duration_seconds_p99["{#NAME}"]'
                - sortorder: '2'
                  color: 00611C
                  item:
                    host: 'Kubernetes Controller manager by HTTP'
                    key: 'kubernetes.controller.workqueue_queue_duration_seconds_p90["{#NAME}"]'
                - sortorder: '3'
                  color: F7941D
                  item:
                    host: 'Kubernetes Controller manager by HTTP'
                    key: 'kubernetes.controller.workqueue_queue_duration_seconds_p50["{#NAME}"]'
                - sortorder: '4'
                  color: FC6EA3
                  item:
                    host: 'Kubernetes Controller manager by HTTP'
                    key: 'kubernetes.controller.workqueue_work_duration_seconds_p95["{#NAME}"]'
                - sortorder: '5'
                  color: 6C59DC
                  item:
                    host: 'Kubernetes Controller manager by HTTP'
                    key: 'kubernetes.controller.workqueue_work_duration_seconds_p99["{#NAME}"]'
                - sortorder: '6'
                  color: C7A72D
                  item:
                    host: 'Kubernetes Controller manager by HTTP'
                    key: 'kubernetes.controller.workqueue_work_duration_seconds_p90["{#NAME}"]'
                - sortorder: '7'
                  color: BA2A5D
                  item:
                    host: 'Kubernetes Controller manager by HTTP'
                    key: 'kubernetes.controller.workqueue_work_duration_seconds_p50["{#NAME}"]'
          master_item:
            key: kubernetes.controller.get_metrics
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - '{__name__=~ "workqueue_*", name =~ ".*"}'
            - type: JAVASCRIPT
              parameters:
                - |
                  var lookup = {},
                  	result = [];
                  
                  JSON.parse(value).forEach(function (item) {
                  	if (item.name === 'workqueue_adds_total') {
                  		var label_name = item.labels.name;
                  
                  		if (lookup[label_name]) {
                  			return;
                  		}
                  		lookup[label_name] = 1;
                  		result.push({
                  			'{#TYPE}': 'totals',
                  			'{#NAME}': label_name
                  		});
                  	}
                  	else if  (item.name === 'workqueue_work_duration_seconds_bucket') {
                  		result.push({
                  			'{#TYPE}': 'buckets',
                  			'{#NAME}': item.labels.name,
                  			'{#LE}': item.labels.le
                  		});
                  	}
                  });
                  
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
          overrides:
            - name: 'bucket item'
              step: '1'
              filter:
                conditions:
                  - macro: '{#TYPE}'
                    value: buckets
              operations:
                - operator: LIKE
                  value: bucket
                  discover: DISCOVER
            - name: 'total item'
              step: '2'
              filter:
                conditions:
                  - macro: '{#TYPE}'
                    value: totals
              operations:
                - operator: NOT_LIKE
                  value: bucket
                  discover: DISCOVER
      tags:
        - tag: class
          value: software
        - tag: subclass
          value: automation
        - tag: subclass
          value: containers
        - tag: subclass
          value: deploy
        - tag: subclass
          value: development
        - tag: subclass
          value: virtualization
        - tag: target
          value: controller-manager
        - tag: target
          value: kubernetes
      macros:
        - macro: '{$KUBE.API.TOKEN}'
          type: SECRET_TEXT
          description: 'API Authorization Token'
          config:
            type: TEXT
            priority: '1'
            label: 'API Token'
            description: 'Token used for API authorization.'
            required: 'YES'
        - macro: '{$KUBE.CONTROLLER.HTTP.CLIENT.ERROR}'
          value: '2'
          description: 'Maximum number of HTTP client requests failures used for trigger.'
          config:
            type: TEXT
            priority: '3'
            section_name: Thresholds
            label: 'HTTP Client Error Threshold'
            description: 'Maximum number of HTTP client errors allowed before triggering an alert. No less than 0.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$KUBE.CONTROLLER.SERVER.URL}'
          value: 'https://localhost:10257/metrics'
          description: 'Kubernetes Controller manager metrics endpoint URL.'
          config:
            type: TEXT
            priority: '2'
            label: 'Metrics endpoint URL'
            description: 'URL to access Kubernetes Controller manager metrics.'
      dashboards:
        - uuid: 9e088e468b7048698e737f5b4719ce33
          name: 'Controller Manager overview'
          pages:
            - name: General
              widgets:
                - type: graph
                  width: '72'
                  height: '5'
                  fields:
                    - type: GRAPH
                      name: graphid.0
                      value:
                        host: 'Kubernetes Controller manager by HTTP'
                        name: 'Kubernetes Controller Manager: Memory usage'
                    - type: STRING
                      name: reference
                      value: AAAAA
                - type: graph
                  'y': '5'
                  width: '72'
                  height: '5'
                  fields:
                    - type: GRAPH
                      name: graphid.0
                      value:
                        host: 'Kubernetes Controller manager by HTTP'
                        name: 'Kubernetes Controller Manager: REST Client query rate'
                    - type: STRING
                      name: reference
                      value: AAAAB
            - name: 'Workqueue metrics'
              widgets:
                - type: graphprototype
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'Kubernetes Controller manager by HTTP'
                        name: 'Kubernetes Controller Manager: ["{#NAME}"] Workqueue add rate'
                    - type: STRING
                      name: reference
                      value: AAAAC
                - type: graphprototype
                  'y': '5'
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'Kubernetes Controller manager by HTTP'
                        name: 'Kubernetes Controller Manager: ["{#NAME}"] Workqueue depth'
                    - type: STRING
                      name: reference
                      value: AAAAD
                - type: graphprototype
                  'y': '10'
                  width: '72'
                  height: '10'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'Kubernetes Controller manager by HTTP'
                        name: 'Kubernetes Controller Manager: ["{#NAME}"] Workqueue latency'
                    - type: STRING
                      name: reference
                      value: AAAAE
      valuemaps:
        - uuid: fa1732213d27418a88a61c964d93e9d7
          name: 'Leader status'
          mappings:
            - value: '0'
              newvalue: backup
            - value: '1'
              newvalue: master
    - uuid: e785916967c14544b59c3644c3edda3a
      template: 'Kubernetes Kubelet by HTTP'
      name: 'Kubernetes Kubelet by HTTP'
      description: |
        Get Kubernetes kubelet metrics by HTTP agent from Prometheus metrics endpoint.
        
        Don't forget change macros {$KUBE.KUBELET.URL}, {$KUBE.API.TOKEN}.
        Some metrics may not be collected depending on your Kubernetes API server instance version and configuration.
        
        You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback
        
        Generated by official Zabbix template tool "Templator"
      wizard_ready: 'YES'
      readme: |
        ## Overview
        
        The template to monitor Kubernetes Kubelet by Zabbix that works without any external scripts.
        Most of the metrics are collected in one go, thanks to Zabbix bulk data collection.
        
        Template `Kubernetes Kubelet by HTTP` - collects metrics by HTTP agent from Kubelet /metrics endpoint.
        
        ## Setup
        
        Internal service metrics are collected from /metrics endpoint.
        Template needs to use Authorization via API token.
        
        Set the following fields: `Kubelet URL`, `API Authorization Token`.
        
        *NOTE.* Some metrics may not be collected depending on your Kubernetes instance version and configuration.
      vendor:
        name: Zabbix
        version: 7.4-1
      groups:
        - name: Templates/Applications
      items:
        - uuid: 1f94bbb521cb41dfa093e1408efbb15a
          name: 'Get cadvisor metrics'
          type: HTTP_AGENT
          key: kube.cadvisor.metrics
          history: '0'
          value_type: TEXT
          description: 'Collecting raw Kubelet metrics from /metrics/cadvisor endpoint.'
          timeout: 10s
          url: '{$KUBE.KUBELET.URL}{$KUBE.KUBELET.CADVISOR.ENDPOINT}'
          status_codes: '200, 403'
          headers:
            - name: Authorization
              value: 'Bearer {$KUBE.API.TOKEN}'
          tags:
            - tag: component
              value: raw
        - uuid: 35783053a41646ffb6420f8d41880b39
          name: 'Containers ready'
          type: DEPENDENT
          key: kube.kubelet.containers.ready
          value_type: FLOAT
          description: 'The number of ready containers.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.items[*].status.containerStatuses[?(@.ready == ''true'')].length()'
          master_item:
            key: kube.pods
          tags:
            - tag: component
              value: containers
        - uuid: bc395860d45b45cb89401fc7e50bc015
          name: 'Containers restarts'
          type: DEPENDENT
          key: kube.kubelet.containers.restarts
          value_type: FLOAT
          description: 'The number of times the container has been restarted.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.items[*].status.containerStatuses[*].restartCount.sum()'
          master_item:
            key: kube.pods
          tags:
            - tag: component
              value: containers
        - uuid: e524234eea87438d9ee2a1db9f24cfbb
          name: 'Containers started'
          type: DEPENDENT
          key: kube.kubelet.containers.started
          value_type: FLOAT
          description: 'The number of started containers.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.items[*].status.containerStatuses[?(@.started == ''true'')].length()'
          master_item:
            key: kube.pods
          tags:
            - tag: component
              value: containers
        - uuid: cff44957e9a54d5d887d4f92b3e4da72
          name: 'CPU cores, total'
          type: DEPENDENT
          key: kube.kubelet.cpu.cores
          value_type: FLOAT
          description: 'The number of cores in this machine (available until kubernetes v1.18).'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - machine_cpu_cores
                - value
                - ''
          master_item:
            key: kube.cadvisor.metrics
          tags:
            - tag: component
              value: containers
        - uuid: 6735723da30d41dcb7bd46c954b2998f
          name: 'Machine memory, bytes'
          type: DEPENDENT
          key: kube.kubelet.machine.memory
          value_type: FLOAT
          units: B
          description: 'Resident memory size in bytes.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - process_resident_memory_bytes
                - value
                - ''
          master_item:
            key: kube.kubelet.metrics
          tags:
            - tag: component
              value: memory
        - uuid: c71fc79a77104ef4a0d6b89d5f7b7bad
          name: 'Get kubelet metrics'
          type: HTTP_AGENT
          key: kube.kubelet.metrics
          history: '0'
          value_type: TEXT
          description: 'Collecting raw Kubelet metrics from /metrics endpoint.'
          timeout: 10s
          url: '{$KUBE.KUBELET.URL}{$KUBE.KUBELET.METRIC.ENDPOINT}'
          status_codes: '200, 403'
          headers:
            - name: Authorization
              value: 'Bearer {$KUBE.API.TOKEN}'
          tags:
            - tag: component
              value: raw
        - uuid: 46635d3fee04488caa4b07de7709f71e
          name: 'Pods running'
          type: DEPENDENT
          key: kube.kubelet.pods.running
          value_type: FLOAT
          description: 'The number of running pods.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.items[?(@.status.phase == "Running")].length()'
          master_item:
            key: kube.pods
          tags:
            - tag: component
              value: pods
        - uuid: d1388216cb384ff08c984919572b0ffb
          name: 'File descriptors, max'
          type: DEPENDENT
          key: kube.kubelet.process_max_fds
          value_type: FLOAT
          description: 'Maximum number of open file descriptors.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - process_max_fds
                - value
                - ''
          master_item:
            key: kube.kubelet.metrics
          tags:
            - tag: component
              value: descriptors
        - uuid: dc3a6371dcb34ae5b65cbf5224d4712c
          name: 'File descriptors, open'
          type: DEPENDENT
          key: kube.kubelet.process_open_fds
          value_type: FLOAT
          description: 'Number of open file descriptors.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - process_open_fds
                - value
                - ''
          master_item:
            key: kube.kubelet.metrics
          tags:
            - tag: component
              value: descriptors
        - uuid: c382b67cf7e947fbb9c29e86446ffac5
          name: 'Virtual memory, bytes'
          type: DEPENDENT
          key: kube.kubelet.virtual.memory
          value_type: FLOAT
          units: B
          description: 'Virtual memory size in bytes.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - process_virtual_memory_bytes
                - value
                - ''
          master_item:
            key: kube.kubelet.metrics
          tags:
            - tag: component
              value: memory
        - uuid: 11da04549bd840b0a8d5c70ff0d2b46f
          name: 'Containers last state terminated'
          type: DEPENDENT
          key: kube.kublet.containers.terminated
          value_type: FLOAT
          description: 'The number of containers that were previously terminated.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.items[*].status.containerStatuses[?(@.lastState.terminated.exitCode > 0)].length()'
          master_item:
            key: kube.pods
          tags:
            - tag: component
              value: containers
        - uuid: 7c8cc6c3ed8e412eb69e7ab8e2fe7e12
          name: 'Get pods'
          type: HTTP_AGENT
          key: kube.pods
          history: '0'
          value_type: TEXT
          description: 'Collecting raw Kubelet metrics from /pods endpoint.'
          timeout: 10s
          url: '{$KUBE.KUBELET.URL}{$KUBE.KUBELET.PODS.ENDPOINT}'
          status_codes: '200, 403'
          headers:
            - name: Authorization
              value: 'Bearer {$KUBE.API.TOKEN}'
          tags:
            - tag: component
              value: raw
      discovery_rules:
        - uuid: 5f70768ebe62429a96e17576dd767382
          name: 'Container memory discovery'
          type: DEPENDENT
          key: kube.kubelet.container.memory.cache.discovery
          lifetime: '0'
          item_prototypes:
            - uuid: 8f8b1df2a801475a92604544b2019b2e
              name: 'Namespace [{#NAMESPACE}] Pod [{#POD}] Container [{#CONTAINER}]: Memory page cache'
              type: DEPENDENT
              key: 'kube.kubelet.container.memory.cache["{#CONTAINER}", "{#NAMESPACE}", "{#POD}"]'
              value_type: FLOAT
              units: B
              description: 'Number of bytes of page cache memory.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'container_memory_cache{container="{#CONTAINER}", namespace="{#NAMESPACE}", pod="{#POD}"}'
                    - value
                    - ''
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 3h
              master_item:
                key: kube.cadvisor.metrics
              tags:
                - tag: component
                  value: memory
                - tag: container
                  value: '{#CONTAINER}'
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: pod
                  value: '{#POD}'
            - uuid: 6dcf948e79b94f3f96677a7948d2dfd4
              name: 'Namespace [{#NAMESPACE}] Pod [{#POD}] Container [{#CONTAINER}]: Memory max usage'
              type: DEPENDENT
              key: 'kube.kubelet.container.memory.max_usage["{#CONTAINER}", "{#NAMESPACE}", "{#POD}"]'
              value_type: FLOAT
              units: B
              description: 'Maximum memory usage recorded in bytes.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'container_memory_max_usage_bytes{container="{#CONTAINER}", namespace="{#NAMESPACE}", pod="{#POD}"}'
                    - value
                    - ''
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 3h
              master_item:
                key: kube.cadvisor.metrics
              tags:
                - tag: component
                  value: memory
                - tag: container
                  value: '{#CONTAINER}'
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: pod
                  value: '{#POD}'
            - uuid: 47d35c31a52643c1b587efcec57f9dff
              name: 'Namespace [{#NAMESPACE}] Pod [{#POD}] Container [{#CONTAINER}]: RSS'
              type: DEPENDENT
              key: 'kube.kubelet.container.memory.rss["{#CONTAINER}", "{#NAMESPACE}", "{#POD}"]'
              value_type: FLOAT
              units: B
              description: 'Size of RSS in bytes.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'container_memory_rss{container="{#CONTAINER}", namespace="{#NAMESPACE}", pod="{#POD}"}'
                    - value
                    - ''
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 3h
              master_item:
                key: kube.cadvisor.metrics
              tags:
                - tag: component
                  value: memory
                - tag: container
                  value: '{#CONTAINER}'
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: pod
                  value: '{#POD}'
            - uuid: 2cf31296f67947ec85f576773352a25b
              name: 'Namespace [{#NAMESPACE}] Pod [{#POD}] Container [{#CONTAINER}]: Swap'
              type: DEPENDENT
              key: 'kube.kubelet.container.memory.swap["{#CONTAINER}", "{#NAMESPACE}", "{#POD}"]'
              value_type: FLOAT
              units: B
              description: 'Container swap usage in bytes.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'container_memory_swap{container="{#CONTAINER}", namespace="{#NAMESPACE}", pod="{#POD}"}'
                    - value
                    - ''
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 3h
              master_item:
                key: kube.cadvisor.metrics
              tags:
                - tag: component
                  value: memory
                - tag: container
                  value: '{#CONTAINER}'
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: pod
                  value: '{#POD}'
            - uuid: 146d17ecec7149efb20878d7e0466eeb
              name: 'Namespace [{#NAMESPACE}] Pod [{#POD}] Container [{#CONTAINER}]: Usage'
              type: DEPENDENT
              key: 'kube.kubelet.container.memory.usage["{#CONTAINER}", "{#NAMESPACE}", "{#POD}"]'
              value_type: FLOAT
              units: B
              description: 'Current memory usage in bytes, including all memory regardless of when it was accessed.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'container_memory_usage_bytes{container="{#CONTAINER}", namespace="{#NAMESPACE}", pod="{#POD}"}'
                    - value
                    - ''
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 3h
              master_item:
                key: kube.cadvisor.metrics
              tags:
                - tag: component
                  value: memory
                - tag: container
                  value: '{#CONTAINER}'
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: pod
                  value: '{#POD}'
            - uuid: d3a24d207c6d4201a5e7235f246e0c59
              name: 'Namespace [{#NAMESPACE}] Pod [{#POD}] Container [{#CONTAINER}]: Working set'
              type: DEPENDENT
              key: 'kube.kubelet.container.memory.working_set["{#CONTAINER}", "{#NAMESPACE}", "{#POD}"]'
              value_type: FLOAT
              units: B
              description: 'Current working set in bytes.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'container_memory_working_set_bytes{container="{#CONTAINER}", namespace="{#NAMESPACE}", pod="{#POD}"}'
                    - value
                    - ''
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 3h
              master_item:
                key: kube.cadvisor.metrics
              tags:
                - tag: component
                  value: memory
                - tag: container
                  value: '{#CONTAINER}'
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: pod
                  value: '{#POD}'
          master_item:
            key: kube.cadvisor.metrics
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - 'container_memory_cache{container !~ "POD", namespace =~ ".*", pod =~ ".*"}'
            - type: JAVASCRIPT
              parameters:
                - |
                  var lookup = {},
                  	result = [];
                  
                  JSON.parse(value).forEach(function (item) {
                  	var container_labels = item.labels.container + item.labels.namespace + item.labels.pod;
                  	if (item.labels.container !== '' && !lookup[container_labels]) {
                  		lookup[container_labels] = 1;
                  		result.push({
                  			'{#CONTAINER}': item.labels.container,
                  			'{#NAMESPACE}': item.labels.namespace,
                  			'{#POD}': item.labels.pod
                  		});
                  	}
                  })
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
        - uuid: b98223fcf0ee4a558035ed23de0d2616
          name: 'Pods discovery'
          type: DEPENDENT
          key: kube.kubelet.pods.discovery
          lifetime: '0'
          item_prototypes:
            - uuid: 41e8f027979a462983789f1f45a9e332
              name: 'Namespace [{#NAMESPACE}] Pod [{#NAME}] CPU: Load average, 10s'
              type: DEPENDENT
              key: 'kube.pod.container_cpu_load_average_10s[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              description: 'Pods cpu load average over the last 10 seconds.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'container_cpu_load_average_10s{container!="", container!="POD", pod="{#NAME}", namespace="{#NAMESPACE}"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
              master_item:
                key: kube.cadvisor.metrics
              tags:
                - tag: component
                  value: pod
                - tag: pod
                  value: '{#NAME}'
            - uuid: 434c913e7547435bb74c922f81f3ff7a
              name: 'Namespace [{#NAMESPACE}] Pod [{#NAME}] CPU: System seconds, total'
              type: DEPENDENT
              key: 'kube.pod.container_cpu_system_seconds_total[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              units: s
              description: 'System cpu time consumed. It is calculated from the cumulative value using the `Change per second` preprocessing step.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'container_cpu_system_seconds_total{container!="", container!="POD", pod="{#NAME}", namespace="{#NAMESPACE}"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
                - type: CHANGE_PER_SECOND
              master_item:
                key: kube.cadvisor.metrics
              tags:
                - tag: component
                  value: pod
                - tag: pod
                  value: '{#NAME}'
            - uuid: 08ae25c1a6a34fae9f3131b14c061e4d
              name: 'Namespace [{#NAMESPACE}] Pod [{#NAME}] CPU: Usage seconds, total'
              type: DEPENDENT
              key: 'kube.pod.container_cpu_usage_seconds_total[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              units: s
              description: 'Consumed cpu time. It is calculated from the cumulative value using the `Change per second` preprocessing step.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'container_cpu_usage_seconds_total{container!="", container!="POD", pod="{#NAME}", namespace="{#NAMESPACE}"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
                - type: CHANGE_PER_SECOND
              master_item:
                key: kube.cadvisor.metrics
              tags:
                - tag: component
                  value: pod
                - tag: pod
                  value: '{#NAME}'
            - uuid: e0b1c1edcc3c4738a71b46712a085ed0
              name: 'Namespace [{#NAMESPACE}] Pod [{#NAME}] CPU: User seconds, total'
              type: DEPENDENT
              key: 'kube.pod.container_cpu_user_seconds_total[{#NAMESPACE}/{#NAME}]'
              value_type: FLOAT
              units: s
              description: 'User cpu time consumed. It is calculated from the cumulative value using the `Change per second` preprocessing step.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'container_cpu_user_seconds_total{container!="", container!="POD", pod="{#NAME}", namespace="{#NAMESPACE}"}'
                    - function
                    - sum
                  error_handler: DISCARD_VALUE
                - type: CHANGE_PER_SECOND
              master_item:
                key: kube.cadvisor.metrics
              tags:
                - tag: component
                  value: pod
                - tag: pod
                  value: '{#NAME}'
          master_item:
            key: kube.pods
          lld_macro_paths:
            - lld_macro: '{#NAMESPACE}'
              path: $.metadata.namespace
            - lld_macro: '{#NAME}'
              path: $.metadata.name
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.items
              error_handler: DISCARD_VALUE
        - uuid: cb42f71e6bfb4661861e3601e31eeaa6
          name: 'REST client requests discovery'
          type: DEPENDENT
          key: kube.kubelet.rest.requests.discovery
          item_prototypes:
            - uuid: c569ce73bfb44098be3ceb8d016e3d24
              name: 'Host [{#HOST}] Request method [{#METHOD}] Code:[{#CODE}]'
              type: DEPENDENT
              key: 'kube.kubelet.rest.requests["{#CODE}", "{#HOST}", "{#METHOD}"]'
              value_type: FLOAT
              description: 'Number of HTTP requests, partitioned by status code, method, and host.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'rest_client_requests_total{code="{#CODE}", host="{#HOST}", method="{#METHOD}"}'
                    - value
                    - ''
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 3h
              master_item:
                key: kube.kubelet.metrics
              tags:
                - tag: code
                  value: '{#CODE}'
                - tag: component
                  value: requests
                - tag: host
                  value: '{#HOST}'
                - tag: method
                  value: '{#METHOD}'
          master_item:
            key: kube.kubelet.metrics
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - 'rest_client_requests_total{code =~ ".*", host =~ ".*", method =~ ".*"}'
            - type: JAVASCRIPT
              parameters:
                - |
                  var lookup = {},
                  	result = [];
                  
                  JSON.parse(value).forEach(function (item) {
                  	var request_labels = item.labels.code + item.labels.host + item.labels.method;
                  	if (!(lookup[request_labels])) {
                  		lookup[request_labels] = 1;
                  		result.push({
                  			'{#CODE}': item.labels.code,
                  			'{#HOST}': item.labels.host,
                  			'{#METHOD}': item.labels.method
                  		});
                  	}
                  })
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
        - uuid: 6feb0006bb364a8f9295495c92741c16
          name: 'Runtime operations discovery'
          type: DEPENDENT
          key: kube.kubelet.runtime_operations_bucket.discovery
          item_prototypes:
            - uuid: 13de106611a347e0907dda9ff52f3a20
              name: '[{#OP_TYPE}] Runtime operations bucket: {#LE}'
              type: DEPENDENT
              key: 'kube.kublet.runtime_ops_duration_seconds_bucket[{#LE},"{#OP_TYPE}"]'
              history: 1h
              value_type: FLOAT
              trends: '0'
              discover: NO_DISCOVER
              description: 'Duration in seconds of runtime operations. Broken down by operation type.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kubelet_runtime_operations_duration_seconds_bucket{le="{#LE}",operation_type="{#OP_TYPE}"}'
                    - function
                    - sum
              master_item:
                key: kube.kubelet.metrics
              tags:
                - tag: component
                  value: operations
            - uuid: 3d9545d396b24ef6b87eb730ad93cda7
              name: '[{#OP_TYPE}] Operations, p50'
              type: CALCULATED
              key: 'kube.kublet.runtime_ops_duration_seconds_p50["{#OP_TYPE}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kube.kublet.runtime_ops_duration_seconds_bucket[*,"{#OP_TYPE}"],5m,50)'
              description: '50 percentile of operation latency distribution in seconds for each verb.'
              tags:
                - tag: component
                  value: operations
            - uuid: 039a47a0b20741e79701fecb924e6a08
              name: '[{#OP_TYPE}] Operations, p90'
              type: CALCULATED
              key: 'kube.kublet.runtime_ops_duration_seconds_p90["{#OP_TYPE}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kube.kublet.runtime_ops_duration_seconds_bucket[*,"{#OP_TYPE}"],5m,90)'
              description: '90 percentile of operation latency distribution in seconds for each verb.'
              tags:
                - tag: component
                  value: operations
            - uuid: e846265636ac433ba2bce034aca1e394
              name: '[{#OP_TYPE}] Operations, p95'
              type: CALCULATED
              key: 'kube.kublet.runtime_ops_duration_seconds_p95["{#OP_TYPE}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kube.kublet.runtime_ops_duration_seconds_bucket[*,"{#OP_TYPE}"],5m,95)'
              description: '95 percentile of operation latency distribution in seconds for each verb.'
              tags:
                - tag: component
                  value: operations
            - uuid: 68f17a6132dd48deb3825efd2b83b6ce
              name: '[{#OP_TYPE}] Operations, p99'
              type: CALCULATED
              key: 'kube.kublet.runtime_ops_duration_seconds_p99["{#OP_TYPE}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kube.kublet.runtime_ops_duration_seconds_bucket[*,"{#OP_TYPE}"],5m,99)'
              description: '99 percentile of operation latency distribution in seconds for each verb.'
              tags:
                - tag: component
                  value: operations
            - uuid: 736abc78366e44b69234caf56abe8a4a
              name: '[{#OP_TYPE}] Runtime operations total, rate'
              type: DEPENDENT
              key: 'kube.kublet.runtime_ops_total.rate["{#OP_TYPE}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              description: 'Cumulative number of runtime operations by operation type.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'kubelet_runtime_operations_total{operation_type="{#OP_TYPE}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
                - type: CHANGE_PER_SECOND
              master_item:
                key: kube.kubelet.metrics
              tags:
                - tag: component
                  value: operations
          graph_prototypes:
            - uuid: 3a32d1b4253b48078279b24fdf8f3476
              name: 'Kubernetes: [{#OP_TYPE}] Operations latency'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'Kubernetes Kubelet by HTTP'
                    key: 'kube.kublet.runtime_ops_duration_seconds_p90["{#OP_TYPE}"]'
                - sortorder: '1'
                  color: F63100
                  item:
                    host: 'Kubernetes Kubelet by HTTP'
                    key: 'kube.kublet.runtime_ops_duration_seconds_p95["{#OP_TYPE}"]'
                - sortorder: '2'
                  color: 00611C
                  item:
                    host: 'Kubernetes Kubelet by HTTP'
                    key: 'kube.kublet.runtime_ops_duration_seconds_p99["{#OP_TYPE}"]'
                - sortorder: '3'
                  color: F7941D
                  item:
                    host: 'Kubernetes Kubelet by HTTP'
                    key: 'kube.kublet.runtime_ops_duration_seconds_p50["{#OP_TYPE}"]'
          master_item:
            key: kube.kubelet.metrics
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - '{__name__=~ "kubelet_runtime_operations_*", operation_type =~ ".*"}'
            - type: JAVASCRIPT
              parameters:
                - |
                  var lookup = {},
                  	lookup_histogram = {},
                  	result = [];
                  
                  JSON.parse(value).forEach(function (item) {
                  	if (item.name === 'kubelet_runtime_operations_total'){
                  		var op_type = item.labels.operation_type;
                  
                  		if (lookup[op_type]) {
                  			return;
                  		}
                  		lookup[op_type] = 1;
                  		result.push({
                  			'{#TYPE}': 'totals',
                  			'{#OP_TYPE}': op_type
                  		});
                  	}
                  
                  	else if (item.name === 'kubelet_runtime_operations_duration_seconds_bucket'){
                  		var labels = item.labels.operation_type + item.labels.le;
                  
                  		if (lookup_histogram[labels]) {
                  			return;
                  		}
                  		lookup_histogram[labels] = 1;
                  		result.push({
                  			'{#TYPE}': 'buckets',
                  			'{#OP_TYPE}': item.labels.operation_type,
                  			'{#LE}': item.labels.le
                  		});
                  	}
                  });
                  
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
          overrides:
            - name: 'bucket item'
              step: '1'
              filter:
                conditions:
                  - macro: '{#TYPE}'
                    value: buckets
              operations:
                - operator: LIKE
                  value: bucket
                  discover: DISCOVER
            - name: 'total item'
              step: '2'
              filter:
                conditions:
                  - macro: '{#TYPE}'
                    value: totals
              operations:
                - operator: NOT_LIKE
                  value: bucket
                  discover: DISCOVER
      tags:
        - tag: class
          value: software
        - tag: subclass
          value: automation
        - tag: subclass
          value: containers
        - tag: subclass
          value: deploy
        - tag: subclass
          value: development
        - tag: subclass
          value: virtualization
        - tag: target
          value: kubelet
        - tag: target
          value: kubernetes
      macros:
        - macro: '{$KUBE.API.TOKEN}'
          type: SECRET_TEXT
          description: 'Service account bearer token.'
          config:
            type: TEXT
            priority: '1'
            label: 'API Token'
            description: 'Service account bearer Token used for authentication.'
            required: 'YES'
        - macro: '{$KUBE.KUBELET.CADVISOR.ENDPOINT}'
          value: /metrics/cadvisor
          description: 'cAdvisor metrics from Kubelet /metrics/cadvisor endpoint.'
          config:
            type: TEXT
            priority: '4'
            label: 'cAdvisor Endpoint'
            description: 'Endpoint for retrieving cAdvisor metrics from Kubelet.'
        - macro: '{$KUBE.KUBELET.METRIC.ENDPOINT}'
          value: /metrics
          description: 'Kubelet /metrics endpoint.'
          config:
            type: TEXT
            priority: '3'
            label: 'Metrics Endpoint'
            description: 'Endpoint for retrieving Kubelet metrics.'
        - macro: '{$KUBE.KUBELET.PODS.ENDPOINT}'
          value: /pods
          description: 'Kubelet /pods endpoint.'
          config:
            type: TEXT
            priority: '5'
            label: 'Pods Endpoint'
            description: 'Endpoint for retrieving pod information from Kubelet.'
        - macro: '{$KUBE.KUBELET.URL}'
          value: 'https://localhost:10250'
          description: 'Kubernetes Kubelet instance URL.'
          config:
            type: TEXT
            priority: '2'
            label: 'Kubelet URL'
            description: 'URL for the Kubernetes Kubelet instance.'
      dashboards:
        - uuid: ecaddf40146948668ec7c75505fd8af8
          name: 'Kubelet overview'
          pages:
            - name: Operations
              widgets:
                - type: graphprototype
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'Kubernetes Kubelet by HTTP'
                        name: 'Kubernetes: [{#OP_TYPE}] Operations latency'
                    - type: STRING
                      name: reference
                      value: AAAAA
    - uuid: f397be2340734d24bc666102fbe184a5
      template: 'Kubernetes nodes by HTTP'
      name: 'Kubernetes nodes by HTTP'
      description: |
        Get Kubernetes nodes metrics by HTTP.
        Metrics are collected by requests to Kubernetes API.
        
        Don't forget to read the README.md for the correct setup of the template.
        
        You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback
        
        Generated by official Zabbix template tool "Templator"
      wizard_ready: 'YES'
      readme: |
        ## Overview
        
        The template to monitor Kubernetes nodes that work without any external scripts.
        It works without external scripts and uses the script item to make HTTP requests to the Kubernetes API.
        
        Change the values according to the environment in the file $HOME/zabbix_values.yaml.
        
        For example:
        
         -  ## Enables use of **Zabbix proxy**
            enabled: false
        
        Set the field: `Kubernetes API URL` such as `<scheme>://<host>:<port>`.
        
        Get the generated service account token using the command
        
        `kubectl get secret zabbix-service-account -n monitoring -o jsonpath={.data.token} | base64 -d`
        
        Then set it to the field: `API Authorization Token`.
        
        Set up the fields to filter the metrics of discovered nodes
        
        
        ## Setup
        
        Install the [Zabbix Helm Chart](https://git.zabbix.com/projects/ZT/repos/kubernetes-helm/browse?at=refs%2Fheads%2Fmaster) in your Kubernetes cluster.
        
        Set the following fields: `Kubernetes API URL` such as `<scheme>://<host>:<port>`.
        
        Get the generated service account token using the command
        
        `kubectl get secret zabbix-service-account -n monitoring -o jsonpath={.data.token} | base64 -d`
        
        Then set it to the field: `API Authorization Token`.
        
        Set `Nodes Endpoint Name` with Zabbix agent's endpoint name. See `kubectl -n monitoring get ep`. Default: `zabbix-zabbix-helm-chrt-agent`.
        
        Set up the fields to filter the metrics of discovered nodes and host creation based on host prototypes:
        
        - `Node Matches Filter`
        - `Node Exclusion Filter`
        - `Node Role Matches Filter`
        - `Node Role Exclusion Filter`
        
        Set up fields to filter pod metrics by namespace:
        
        - `Pod Namespace Matches Filter`
        - `Pod Namespace Exclusion Filter`
        
        **Note**, If you have a large cluster, it is highly recommended to set a filter for discoverable pods.
        
        You can use the `Node Labels Filter`, `Pod Labels Filter`, `Node Annotations Filter` and `Pod Annotations Filter` fields for advanced filtering of nodes and pods by labels and annotations.
        
        Notes about labels and annotations filters:
        
        - Values should be specified separated by commas and must have the key/value form with support for regular expressions in the value (`key1: value, key2: regexp`).
        - ECMAScript syntax is used for regular expressions.
        - Filters are applied if such a label key exists for the entity that is being filtered (it means that if you specify a key in a filter, entities which do not have this key will not be affected by the filter and will still be discovered, and only entities containing that key will be filtered by the value).
        - You can also use the exclamation point symbol (`!`) to invert the filter (`!key: value`).
        
        For example: `kubernetes.io/hostname: kubernetes-node[5-25], !node-role.kubernetes.io/ingress: .*`. As a result, the nodes 5-25 without the "ingress" role will be discovered.
        
        
        See the Kubernetes documentation for details about labels and annotations:
        
        - <https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/>
        - <https://kubernetes.io/docs/concepts/overview/working-with-objects/annotations/>
        
        **Note**, the discovered nodes will be created as separate hosts in Zabbix with the Linux template automatically assigned to them.
      vendor:
        name: Zabbix
        version: 7.4-3
      groups:
        - name: Templates/Applications
      items:
        - uuid: 70dab03a327a4dc0ab9fe8031052584d
          name: 'Get nodes'
          type: SCRIPT
          key: kube.nodes
          delay: 0;s00
          history: '0'
          value_type: TEXT
          params: |
            var Kube = {
            	params: {},
            	pods_limit: 1000,
            
            	setParams: function (params) {
            		['api_token', 'api_url'].forEach(function (field) {
            			if (typeof params !== 'object' || typeof params[field] === 'undefined'
            				|| params[field] === '') {
            				throw 'Required param is not set: "' + field + '".';
            			}
            		});
            		['endpoint_name', 'pod_filter_labels', 'pod_filter_annotations', 'node_filter_labels', 'node_filter_annotations'].forEach(function (field) {
            			if (typeof params !== 'object' || typeof params[field] === 'undefined') {
            				throw 'Parameter can be empty but not removed: "' + field + '".';
            			}
            		});
            
            		Kube.params = params;
            		if (typeof Kube.params.api_url === 'string' && !Kube.params.api_url.endsWith('/')) {
            			Kube.params.api_url += '/';
            		}
            	},
            
            	apiRequest: function (query) {
            		var request = new HttpRequest(),
            			response,
            			url = encodeURI(Kube.params.api_url + query);
            		if (typeof Kube.params.http_proxy !== 'undefined' && Kube.params.http_proxy !== '') {
            			request.setProxy(Kube.params.http_proxy);
            		}
            		request.addHeader('Content-Type: application/json');
            		request.addHeader('Authorization: Bearer ' + Kube.params.api_token);
            
            		if (Kube.params.http_proxy) {
            			Zabbix.log(4, '[ Kubernetes ] Using http proxy: ' + Kube.params.http_proxy);
            		}
            		response = request.get(url);
            
            		Zabbix.log(4, '[ Kubernetes ] Received response with status code ' + request.getStatus() + ': ' + response);
            
            		if (request.getStatus() < 200 || request.getStatus() >= 300) {
            			throw 'Request failed with status code ' + request.getStatus() + ': ' + response;
            		}
            
            		try {
            			response = JSON.parse(response);
            		}
            		catch (error) {
            			throw 'Failed to parse response received from Kubernetes API. Check debug log for more information.';
            		}
            		return response;
            	},
            
            	parseFilters: function (csv) {
            		if (!csv)
            			return [];
            
            		var filters = [];
            		const filterCapture = /([!\w\-\.\/]+)\s*:\s*(.*)/;
            		const onComma = /\s*,\s*/;
            
            		csv.split(onComma).forEach(function (kv) {
            			var match = kv.match(filterCapture);
            			if (!match) {
            				Zabbix.log(3, 'Cannot parse filter from: "' + kv + '"');
            				return;
            			}
            
            			filters.push({ key: match[1], expression: match[2] });
            		});
            
            		return filters;
            	},
            
            	filter: function (name, data, filters) {
            		if (typeof data !== 'object') {
            			return true;
            		}
            
            		return filters.every(function (filter) {
            			const filter_key = filter.key.startsWith('!') ? filter.key.substring(1) : filter.key;
            
            			if (!(filter_key in data)) {
            				return true;
            			}
            
            			const isExcludingFilter = filter.key.startsWith('!');
            			const isMatchForFilter = new RegExp(filter.expression).test(data[filter_key]);
            
            			if ((isExcludingFilter && isMatchForFilter) ||
            				(!isExcludingFilter && !isMatchForFilter)) {
            				Zabbix.log(4, '[ Kubernetes ] Discarded "' + name + '" by filter "' + filter.key + ': ' + filter.expression + '"');
            				return false;
            			}
            
            			return true;
            		});
            	},
            
            	getField: function (data, path) {
            		var steps = path.split('.');
            		for (var i = 0; i < steps.length; i++) {
            			var step = steps[i];
            			if (typeof data !== 'object' || typeof data[step] === 'undefined') {
            				throw 'Required field was not found: ' + path;
            			}
            
            			data = data[step];
            		}
            
            		return data;
            	},
            
            	getNodes: function () {
            		var result = Kube.apiRequest('api/v1/nodes'),
            			output = [],
            			filterNodeLabels = Kube.parseFilters(Kube.params.node_filter_labels),
            			filterNodeAnnotations = Kube.parseFilters(Kube.params.node_filter_annotations);
            		if (typeof result !== 'object'
            			|| typeof result.items === 'undefined') {
            			throw 'Cannot get nodes from Kubernetes API. Check debug log for more information.';
            		}
            
            		result.items.forEach(function (filternode) {
            			if (Kube.filter(Kube.getField(filternode, 'metadata.name'), Kube.getField(filternode, 'metadata.labels'), filterNodeLabels)
            				&& Kube.filter(Kube.getField(filternode, 'metadata.name'), Kube.getField(filternode, 'metadata.annotations'), filterNodeAnnotations)) {
            				Zabbix.log(4, '[ Kubernetes ] Filtered node "' + filternode.metadata.name + '"');
            
            				output.push({
            					filternode
            				});
            			}
            		});
            
            		return output;
            	},
            
            	getPods: function () {
            		var result = [],
            			continue_token,
            			Pods = [];
            
            		while (continue_token !== '') {
            			var data = Kube.apiRequest('api/v1/pods?limit=' + Kube.pods_limit
            				+ ((typeof continue_token !== 'undefined') ? '&continue=' + continue_token : ''));
            
            			if (typeof data !== 'object'
            				|| typeof data.items === 'undefined') {
            				throw 'Cannot get pods from Kubernetes API. Check debug log for more information.';
            			};
            
            			result.push.apply(result, data.items);
            			continue_token = data.metadata.continue || '';
            		}
            		result.forEach(function (pod) {
            
            			var containers = {
            				limits: { cpu: 0, memory: 0 },
            				requests: { cpu: 0, memory: 0 },
            				restartCount: 0
            			},
            				containerStatuses = [{ restartCount: 0 }];
            
            			if (typeof pod.status.hostIP === 'object'
            				|| typeof pod.status.hostIP === 'undefined') {
            				pod.status.hostIP = 'none';
            			};
            
            			Kube.getField(pod, 'spec.containers').forEach(function (container) {
            				var limits = container.resources.limits,
            					requests = container.resources.requests;
            
            				if (typeof limits !== 'undefined') {
            					containers.limits.cpu += Fmt.cpuFormat(limits.cpu);
            					containers.limits.memory += Fmt.memoryFormat(limits.memory);
            				}
            
            				if (typeof requests !== 'undefined') {
            					containers.requests.cpu += Fmt.cpuFormat(requests.cpu);
            					containers.requests.memory += Fmt.memoryFormat(requests.memory);
            				}
            			});
            
            			if (typeof pod.status.containerStatuses !== 'object'
            				|| typeof pod.status.containerStatuses === 'undefined') {
            				pod.status.containerStatuses = containerStatuses;
            			};
            			pod.status.containerStatuses.forEach(function (container) {
            				containers.restartCount += container.restartCount;
            
            			});
            
            			Pods.push({
            				'name': pod.metadata.name,
            				'nodeIP': pod.status.hostIP,
            				'namespace': pod.metadata.namespace,
            				'labels': pod.metadata.labels,
            				'annotations': pod.metadata.annotations,
            				'phase': pod.status.phase,
            				'conditions': pod.status.conditions,
            				'startTime': pod.status.startTime,
            				'containers': containers,
            				'hostname': 'none'
            			})
            		});
            		return Pods;
            	},
            
            	getEndpointIPs: function () {
            		var endpoints = Kube.apiRequest('api/v1/endpoints'),
            			endpointIPs = [];
            		if (typeof endpoints !== 'object'
            			|| typeof endpoints.items === 'undefined') {
            			throw 'Cannot get endpoints from Kubernetes API. Check debug log for more information.';
            		};
            
            		endpoints.items.forEach(function (ep) {
            			if (Kube.getField(ep, 'metadata.name') !== Kube.params.endpoint_name) {
            				return;
            			}
            			if (!Array.isArray(ep.subsets)) {
            				return;
            			}
            			endpointIPs = ep.subsets;
            
            		});
            		return endpointIPs;
            	}
            },
            
            	Fmt = {
            		factors: {
            			Ki: 1024, K: 1000,
            			Mi: 1024 ** 2, M: 1000 ** 2,
            			Gi: 1024 ** 3, G: 1000 ** 3,
            			Ti: 1024 ** 4, T: 1000 ** 4,
            		},
            
            		cpuFormat: function (cpu) {
            			if (typeof cpu === 'undefined') {
            				return 0;
            			}
            
            			if (cpu.indexOf('m') > -1) {
            				return parseInt(cpu) / 1000;
            			}
            
            			return parseInt(cpu);
            		},
            
            		memoryFormat: function (mem) {
            			if (typeof mem === 'undefined') {
            				return 0;
            			}
            
            			var pair,
            				factor;
            
            			if (pair = mem.match(/(\d+)(\w*)/)) {
            				if (factor = Fmt.factors[pair[2]]) {
            					return parseInt(pair[1]) * factor;
            				}
            
            				return mem;
            			}
            
            			return parseInt(mem);
            		}
            
            	}
            
            try {
            	Kube.setParams(JSON.parse(value));
            
            	var nodes = Kube.getNodes(),
            		pods = Kube.getPods(),
            		Pods = [],
            		hostname = Kube.params.api_url.match(/https?:\/\/([\w.-]+|\[[a-f0-9:]+\]|[^a-zA-Z:]+)(?::\d+)?/),
            		filterPodLabels = Kube.parseFilters(Kube.params.pod_filter_labels),
            		filterPodAnnotations = Kube.parseFilters(Kube.params.pod_filter_annotations),
            		endpointIPs = Kube.getEndpointIPs();
            	if (typeof hostname[1] === 'undefined') {
            		Zabbix.log(4, '[ Kubernetes ] Received incorrect Kubernetes API url: ' + api_url + '. Expected format: <scheme>://<host>:<port>');
            		throw 'Cannot get hostname from Kubernetes API url. Check debug log for more information.';
            	};
            	for (idx in nodes) {
            		var nodePodsCount = 0,
            			endpointpod = [],
            			roles = [];
            		Object.keys(nodes[idx].filternode.metadata.labels).forEach(function (label) {
            			var splitLabel = label.match(/^node-role.kubernetes.io\/([\w\.-]+)/);
            
            			if (splitLabel) {
            				roles.push(splitLabel[1]);
            			}
            		});
            		var internalIPs = Kube.getField(nodes[idx].filternode, 'status.addresses').filter(function (addr) {
            			return addr.type === 'InternalIP';
            		});
            		var internalIP = internalIPs.length && internalIPs[0].address;
            
            		var Hostname = Kube.getField(nodes[idx].filternode, 'status.addresses').filter(function (addr) {
            			return addr.type === 'Hostname';
            		});
            		var Hostname = Hostname.length && Hostname[0].address;
            
            		pods.forEach(function (pod) {
            			if (pod.nodeIP !== internalIP) {
            				return;
            			}
            			nodePodsCount++;
            			pod.hostname = Hostname;
            			Pods = pods.filter(function (f) {
            				return (f.hostname !== 'none' || f.phase === 'Pending') && (
            					Kube.filter(f.name, f.labels, filterPodLabels)
            					&& Kube.filter(f.name, f.annotations, filterPodAnnotations)
            				);
            			}
            			)
            		});
            
            		endpointIPs.forEach(function (agent) {
            			for (k in Kube.getField(agent, 'addresses')) {
            				if (Kube.getField(agent.addresses[k], 'ip') === internalIP) {
            					endpointpod = Kube.getField(agent.addresses[k], 'targetRef.name')
            				}
            				for (k in agent.notReadyAddresses) {
            					if (agent.notReadyAddresses[k].ip === internalIP) {
            						endpointpod = 'notReadyAddresses'
            					}
            				}
            
            			}
            		});
            
            		delete nodes[idx].filternode.metadata.managedFields;
            		delete nodes[idx].filternode.status.images;
            		nodes[idx].filternode.status.capacity.cpu = Fmt.cpuFormat(nodes[idx].filternode.status.capacity.cpu);
            		nodes[idx].filternode.status.capacity.memory = Fmt.memoryFormat(nodes[idx].filternode.status.capacity.memory);
            		nodes[idx].filternode.status.allocatable.cpu = Fmt.cpuFormat(nodes[idx].filternode.status.allocatable.cpu);
            		nodes[idx].filternode.status.allocatable.memory = Fmt.memoryFormat(nodes[idx].filternode.status.allocatable.memory);
            		nodes[idx].filternode.status.podsCount = nodePodsCount;
            		nodes[idx].filternode.status.roles = roles.join(', ');
            		nodes[idx].filternode.status.agent = endpointpod;
            		nodes[idx].filternode.internalIP = internalIP;
            		nodes[idx].filternode.clusterhostname = hostname[1];
            
            	}
            
            	return JSON.stringify({ nodes, Pods });
            }
            catch (error) {
            	error += (String(error).endsWith('.')) ? '' : '.';
            	Zabbix.log(3, '[ Kubernetes ] ERROR: ' + error);
            	return JSON.stringify({ error: error });
            }
          description: 'Collecting and processing cluster nodes data via Kubernetes API.'
          timeout: 10s
          parameters:
            - name: api_token
              value: '{$KUBE.API.TOKEN}'
            - name: api_url
              value: '{$KUBE.API.URL}'
            - name: endpoint_name
              value: '{$KUBE.NODES.ENDPOINT.NAME}'
            - name: http_proxy
              value: '{$KUBE.HTTP.PROXY}'
            - name: node_filter_annotations
              value: '{$KUBE.NODE.FILTER.ANNOTATIONS}'
            - name: node_filter_labels
              value: '{$KUBE.NODE.FILTER.LABELS}'
            - name: pod_filter_annotations
              value: '{$KUBE.POD.FILTER.ANNOTATIONS}'
            - name: pod_filter_labels
              value: '{$KUBE.POD.FILTER.LABELS}'
          tags:
            - tag: component
              value: raw
        - uuid: f78df5e88780418b894017086f8d9641
          name: 'Get nodes check'
          type: DEPENDENT
          key: kube.nodes.check
          value_type: CHAR
          description: 'Data collection check.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.error
              error_handler: CUSTOM_VALUE
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
          master_item:
            key: kube.nodes
          tags:
            - tag: component
              value: status
          triggers:
            - uuid: 827016cf41254f38aa58ff99e22f9e6f
              expression: 'length(last(/Kubernetes nodes by HTTP/kube.nodes.check))>0'
              name: 'Kubernetes nodes: Failed to get nodes'
              priority: WARNING
              tags:
                - tag: scope
                  value: availability
      discovery_rules:
        - uuid: f408d71f02f645f6a7e24047a57860b6
          name: 'Node discovery'
          type: DEPENDENT
          key: kube.node.discovery
          filter:
            evaltype: AND
            conditions:
              - macro: '{#NAME}'
                value: '{$KUBE.LLD.FILTER.NODE.MATCHES}'
              - macro: '{#NAME}'
                value: '{$KUBE.LLD.FILTER.NODE.NOT_MATCHES}'
                operator: NOT_MATCHES_REGEX
              - macro: '{#ROLES}'
                value: '{$KUBE.LLD.FILTER.NODE.ROLE.MATCHES}'
              - macro: '{#ROLES}'
                value: '{$KUBE.LLD.FILTER.NODE.ROLE.NOT_MATCHES}'
                operator: NOT_MATCHES_REGEX
          item_prototypes:
            - uuid: 6f986c54ff744522abd793347dba5148
              name: 'Node [{#NAME}] Addresses: External IP'
              type: DEPENDENT
              key: 'kube.node.addresses.external_ip[{#NAME}]'
              value_type: CHAR
              description: 'Typically the IP address of the node that is externally routable (available from outside the cluster).'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.status.addresses[?(@.type == "ExternalIP")].address.first()'
                  error_handler: DISCARD_VALUE
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 3h
              master_item:
                key: 'kube.node.get[{#NAME}]'
              tags:
                - tag: component
                  value: addresses
                - tag: node
                  value: '{#NAME}'
            - uuid: a6bb3067ed44446e9b4831f5be57661b
              name: 'Node [{#NAME}] Addresses: Internal IP'
              type: DEPENDENT
              key: 'kube.node.addresses.internal_ip[{#NAME}]'
              value_type: CHAR
              description: 'Typically the IP address of the node that is routable only within the cluster.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.status.addresses[?(@.type == "InternalIP")].address.first()'
                  error_handler: DISCARD_VALUE
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 3h
              master_item:
                key: 'kube.node.get[{#NAME}]'
              tags:
                - tag: component
                  value: addresses
                - tag: node
                  value: '{#NAME}'
            - uuid: 57eb59ad6e63466f993cd7064788c75d
              name: 'Node [{#NAME}] Allocatable: CPU'
              type: DEPENDENT
              key: 'kube.node.allocatable.cpu[{#NAME}]'
              value_type: FLOAT
              description: |
                Allocatable CPU.
                
                'Allocatable' on a Kubernetes node is defined as the amount of compute resources that are available for pods. The scheduler does not over-subscribe 'Allocatable'. 'CPU', 'memory' and 'ephemeral-storage' are supported as of now.
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status.allocatable.cpu
              master_item:
                key: 'kube.node.get[{#NAME}]'
              tags:
                - tag: component
                  value: allocatable
                - tag: node
                  value: '{#NAME}'
            - uuid: 843ecf5ca78148caa49f3b4cca26e4d4
              name: 'Node [{#NAME}] Allocatable: Memory'
              type: DEPENDENT
              key: 'kube.node.allocatable.memory[{#NAME}]'
              units: B
              description: |
                Allocatable Memory.
                
                'Allocatable' on a Kubernetes node is defined as the amount of compute resources that are available for pods. The scheduler does not over-subscribe 'Allocatable'. 'CPU', 'memory' and 'ephemeral-storage' are supported as of now.
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status.allocatable.memory
              master_item:
                key: 'kube.node.get[{#NAME}]'
              tags:
                - tag: component
                  value: allocatable
                - tag: node
                  value: '{#NAME}'
            - uuid: be853c34395643af828e349105e2feba
              name: 'Node [{#NAME}] Allocatable: Pods'
              type: DEPENDENT
              key: 'kube.node.allocatable.pods[{#NAME}]'
              description: 'https://kubernetes.io/docs/tasks/administer-cluster/reserve-compute-resources/'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status.allocatable.pods
              master_item:
                key: 'kube.node.get[{#NAME}]'
              tags:
                - tag: component
                  value: allocatable
                - tag: node
                  value: '{#NAME}'
            - uuid: 96c25644261446afb70ce874ff1c7b7d
              name: 'Node [{#NAME}] Capacity: CPU'
              type: DEPENDENT
              key: 'kube.node.capacity.cpu[{#NAME}]'
              value_type: FLOAT
              description: |
                CPU resource capacity.
                
                https://kubernetes.io/docs/concepts/architecture/nodes/#capacity
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status.capacity.cpu
              master_item:
                key: 'kube.node.get[{#NAME}]'
              tags:
                - tag: component
                  value: capacity
                - tag: node
                  value: '{#NAME}'
            - uuid: e890e682c3454d20b7cd3becc950279f
              name: 'Node [{#NAME}] Capacity: Memory'
              type: DEPENDENT
              key: 'kube.node.capacity.memory[{#NAME}]'
              units: B
              description: |
                Memory resource capacity.
                
                https://kubernetes.io/docs/concepts/architecture/nodes/#capacity
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status.capacity.memory
              master_item:
                key: 'kube.node.get[{#NAME}]'
              tags:
                - tag: component
                  value: capacity
                - tag: node
                  value: '{#NAME}'
            - uuid: f45997b967964ed29c29b64b94544a48
              name: 'Node [{#NAME}] Capacity: Pods'
              type: DEPENDENT
              key: 'kube.node.capacity.pods[{#NAME}]'
              description: 'https://kubernetes.io/docs/tasks/administer-cluster/reserve-compute-resources/'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status.capacity.pods
              master_item:
                key: 'kube.node.get[{#NAME}]'
              tags:
                - tag: component
                  value: capacity
                - tag: node
                  value: '{#NAME}'
            - uuid: ad5f8baa9ff44ca0ba17fc83e197420e
              name: 'Node [{#NAME}] Conditions: Disk pressure'
              type: DEPENDENT
              key: 'kube.node.conditions.diskpressure[{#NAME}]'
              description: 'True if pressure exists on the disk size - that is, if the disk capacity is low; otherwise False.'
              valuemap:
                name: 'Node conditions'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.status.conditions[?(@.type == "DiskPressure")].status.first()'
                  error_handler: DISCARD_VALUE
                - type: JAVASCRIPT
                  parameters:
                    - 'return [''True'', ''False'', ''Unknown''].indexOf(value) + 1 || ''Problem with status processing in JS'';'
              master_item:
                key: 'kube.node.get[{#NAME}]'
              tags:
                - tag: component
                  value: conditions
                - tag: node
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: 4e283f3f104a4239a0b1c24f0313ab95
                  expression: 'last(/Kubernetes nodes by HTTP/kube.node.conditions.diskpressure[{#NAME}])=1'
                  name: 'Kubernetes nodes: Node [{#NAME}] Conditions: Pressure exists on the disk size'
                  event_name: 'Kubernetes nodes: Node [{#NAME}] Conditions: Pressure exists on the disk size (state: {ITEM.VALUE})'
                  priority: WARNING
                  description: 'True - pressure exists on the disk size - that is, if the disk capacity is low; otherwise False.'
                  tags:
                    - tag: scope
                      value: performance
            - uuid: 44b60c111e2a4d0bae0de443394d0add
              name: 'Node [{#NAME}] Conditions: Memory pressure'
              type: DEPENDENT
              key: 'kube.node.conditions.memorypressure[{#NAME}]'
              description: 'True if pressure exists on the node memory - that is, if the node memory is low; otherwise False.'
              valuemap:
                name: 'Node conditions'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.status.conditions[?(@.type == "MemoryPressure")].status.first()'
                  error_handler: DISCARD_VALUE
                - type: JAVASCRIPT
                  parameters:
                    - 'return [''True'', ''False'', ''Unknown''].indexOf(value) + 1 || ''Problem with status processing in JS'';'
              master_item:
                key: 'kube.node.get[{#NAME}]'
              tags:
                - tag: component
                  value: conditions
                - tag: node
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: f580b6534bf54281912515874ca46cdf
                  expression: 'last(/Kubernetes nodes by HTTP/kube.node.conditions.memorypressure[{#NAME}])=1'
                  name: 'Kubernetes nodes: Node [{#NAME}] Conditions: Pressure exists on the node memory'
                  event_name: 'Kubernetes nodes: Node [{#NAME}] Conditions: Pressure exists on the node memory (state: {ITEM.VALUE})'
                  priority: WARNING
                  description: 'True - pressure exists on the node memory - that is, if the node memory is low; otherwise False'
                  tags:
                    - tag: scope
                      value: performance
            - uuid: 8c77db54e90d474a8ff35a98c67772d5
              name: 'Node [{#NAME}] Conditions: Network unavailable'
              type: DEPENDENT
              key: 'kube.node.conditions.networkunavailable[{#NAME}]'
              description: 'True if the network for the node is not correctly configured, otherwise False.'
              valuemap:
                name: 'Node conditions'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.status.conditions[?(@.type == "NetworkUnavailable")].status.first()'
                  error_handler: DISCARD_VALUE
                - type: JAVASCRIPT
                  parameters:
                    - 'return [''True'', ''False'', ''Unknown''].indexOf(value) + 1 || ''Problem with status processing in JS'';'
              master_item:
                key: 'kube.node.get[{#NAME}]'
              tags:
                - tag: component
                  value: conditions
                - tag: node
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: 0da0db08077a42668efcc886c155bf4e
                  expression: 'last(/Kubernetes nodes by HTTP/kube.node.conditions.networkunavailable[{#NAME}])=1'
                  name: 'Kubernetes nodes: Node [{#NAME}] Conditions: Network is not correctly configured'
                  event_name: 'Kubernetes nodes: Node [{#NAME}] Conditions: Network is not correctly configured (state: {ITEM.VALUE})'
                  priority: WARNING
                  description: 'True - the network for the node is not correctly configured, otherwise False'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: 31f02b4517e24571962fefd61e09e2a5
              name: 'Node [{#NAME}] Conditions: PID pressure'
              type: DEPENDENT
              key: 'kube.node.conditions.pidpressure[{#NAME}]'
              description: 'True if pressure exists on the processes - that is, if there are too many processes on the node; otherwise False.'
              valuemap:
                name: 'Node conditions'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.status.conditions[?(@.type == "PIDPressure")].status.first()'
                  error_handler: DISCARD_VALUE
                - type: JAVASCRIPT
                  parameters:
                    - 'return [''True'', ''False'', ''Unknown''].indexOf(value) + 1 || ''Problem with status processing in JS'';'
              master_item:
                key: 'kube.node.get[{#NAME}]'
              tags:
                - tag: component
                  value: conditions
                - tag: node
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: 5f6a7fce910e4cf79e9fc778519ad00f
                  expression: 'last(/Kubernetes nodes by HTTP/kube.node.conditions.pidpressure[{#NAME}])=1'
                  name: 'Kubernetes nodes: Node [{#NAME}] Conditions: Pressure exists on the processes'
                  event_name: 'Kubernetes nodes: Node [{#NAME}] Conditions: Pressure exists on the processes (state: {ITEM.VALUE})'
                  priority: WARNING
                  description: 'True - pressure exists on the processes - that is, if there are too many processes on the node; otherwise False'
                  tags:
                    - tag: scope
                      value: performance
            - uuid: 9341a018a45848feae0f61660ca5f849
              name: 'Node [{#NAME}] Conditions: Ready'
              type: DEPENDENT
              key: 'kube.node.conditions.ready[{#NAME}]'
              description: 'True if the node is healthy and ready to accept pods, False if the node is not healthy and is not accepting pods, and Unknown if the node controller has not heard from the node in the last node-monitor-grace-period (default is 40 seconds).'
              valuemap:
                name: 'Node conditions'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.status.conditions[?(@.type == "Ready")].status.first()'
                  error_handler: DISCARD_VALUE
                - type: JAVASCRIPT
                  parameters:
                    - 'return [''True'', ''False'', ''Unknown''].indexOf(value) + 1 || ''Problem with status processing in JS'';'
              master_item:
                key: 'kube.node.get[{#NAME}]'
              tags:
                - tag: component
                  value: conditions
                - tag: node
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: 02f873ab69fb4df49578cf5e1cbad1b8
                  expression: 'last(/Kubernetes nodes by HTTP/kube.node.conditions.ready[{#NAME}])<>1'
                  name: 'Kubernetes nodes: Node [{#NAME}] Conditions: Is not in Ready state'
                  event_name: 'Kubernetes nodes: Node [{#NAME}] Conditions: Is not in Ready state (state: {ITEM.VALUE})'
                  priority: WARNING
                  description: |
                    False - if the node is not healthy and is not accepting pods.
                    Unknown - if the node controller has not heard from the node in the last node-monitor-grace-period (default is 40 seconds).
                  tags:
                    - tag: scope
                      value: availability
            - uuid: 3d8536659ac44347b36e61f60873fa61
              name: 'Node [{#NAME}]: Get data'
              type: DEPENDENT
              key: 'kube.node.get[{#NAME}]'
              history: '0'
              value_type: CHAR
              description: 'Collecting and processing cluster by node [{#NAME}] data via Kubernetes API.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.nodes..[?(@.metadata.name == "{#NAME}")].first()'
              master_item:
                key: kube.nodes
              tags:
                - tag: component
                  value: raw
                - tag: node
                  value: '{#NAME}'
            - uuid: 8f9152074e2041d7b5cd2c6215e06832
              name: 'Node [{#NAME}] Info: Architecture'
              type: DEPENDENT
              key: 'kube.node.info.architecture[{#NAME}]'
              value_type: CHAR
              description: 'Node architecture.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status.nodeInfo.architecture
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 3h
              master_item:
                key: 'kube.node.get[{#NAME}]'
              tags:
                - tag: component
                  value: info
                - tag: node
                  value: '{#NAME}'
            - uuid: 405fe8cae9be4ea8888f378dadda8946
              name: 'Node [{#NAME}] Info: Container runtime'
              type: DEPENDENT
              key: 'kube.node.info.containerruntime[{#NAME}]'
              value_type: CHAR
              description: |
                Container runtime.
                
                https://kubernetes.io/docs/setup/production-environment/container-runtimes/
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status.nodeInfo.containerRuntimeVersion
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 3h
              master_item:
                key: 'kube.node.get[{#NAME}]'
              tags:
                - tag: component
                  value: info
                - tag: node
                  value: '{#NAME}'
            - uuid: a14e705e142f4c34bfc9175686b18754
              name: 'Node [{#NAME}] Info: Kernel version'
              type: DEPENDENT
              key: 'kube.node.info.kernelversion[{#NAME}]'
              value_type: CHAR
              description: 'Node kernel version.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status.nodeInfo.kernelVersion
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 3h
              master_item:
                key: 'kube.node.get[{#NAME}]'
              tags:
                - tag: component
                  value: info
                - tag: node
                  value: '{#NAME}'
            - uuid: f1a1ea522dfd49d09a69b9b014845f7a
              name: 'Node [{#NAME}] Info: Kubelet version'
              type: DEPENDENT
              key: 'kube.node.info.kubeletversion[{#NAME}]'
              value_type: CHAR
              description: 'Version of Kubelet.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status.nodeInfo.kubeletVersion
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 3h
              master_item:
                key: 'kube.node.get[{#NAME}]'
              tags:
                - tag: component
                  value: info
                - tag: node
                  value: '{#NAME}'
            - uuid: d39865e0754b4280926b89f19dddb740
              name: 'Node [{#NAME}] Info: KubeProxy version'
              type: DEPENDENT
              key: 'kube.node.info.kubeproxyversion[{#NAME}]'
              value_type: CHAR
              description: 'Version of KubeProxy.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status.nodeInfo.kubeProxyVersion
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 3h
              master_item:
                key: 'kube.node.get[{#NAME}]'
              tags:
                - tag: component
                  value: info
                - tag: node
                  value: '{#NAME}'
            - uuid: fe06e13c3aec4efc8f7c9539b6600097
              name: 'Node [{#NAME}] Info: Operating system'
              type: DEPENDENT
              key: 'kube.node.info.operatingsystem[{#NAME}]'
              value_type: CHAR
              description: 'Node operating system.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status.nodeInfo.operatingSystem
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 3h
              master_item:
                key: 'kube.node.get[{#NAME}]'
              tags:
                - tag: component
                  value: info
                - tag: node
                  value: '{#NAME}'
            - uuid: 1b25ffe6190c408996b87622b7b87329
              name: 'Node [{#NAME}] Info: OS image'
              type: DEPENDENT
              key: 'kube.node.info.osversion[{#NAME}]'
              value_type: CHAR
              description: 'Node OS image.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status.nodeInfo.kernelVersion
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 3h
              master_item:
                key: 'kube.node.get[{#NAME}]'
              tags:
                - tag: component
                  value: info
                - tag: node
                  value: '{#NAME}'
            - uuid: bcd18bdb8cd1466fa81bbe2e75ba996c
              name: 'Node [{#NAME}] Info: Roles'
              type: DEPENDENT
              key: 'kube.node.info.roles[{#NAME}]'
              value_type: CHAR
              description: 'Node roles.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status.roles
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 3h
              master_item:
                key: 'kube.node.get[{#NAME}]'
              tags:
                - tag: component
                  value: info
                - tag: node
                  value: '{#NAME}'
            - uuid: 1fb0ebd40fcb4e6c8a22bb646191adb2
              name: 'Node [{#NAME}] Limits: CPU'
              type: DEPENDENT
              key: 'kube.node.limits.cpu[{#NAME}]'
              value_type: FLOAT
              description: |
                Node CPU limits.
                
                https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.Pods[?(@.hostname == "{#NAME}")].containers.limits.cpu.sum()'
              master_item:
                key: kube.nodes
              tags:
                - tag: component
                  value: limits
                - tag: node
                  value: '{#NAME}'
            - uuid: e3ad703e83724cc7a5b918d9efae6e62
              name: 'Node [{#NAME}] Limits: Memory'
              type: DEPENDENT
              key: 'kube.node.limits.memory[{#NAME}]'
              units: B
              description: |
                Node Memory limits.
                
                https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.Pods[?(@.hostname == "{#NAME}")].containers.limits.memory.sum()'
              master_item:
                key: kube.nodes
              tags:
                - tag: component
                  value: limits
                - tag: node
                  value: '{#NAME}'
            - uuid: 8ea2954c99cc4e22a82c5a333146d936
              name: 'Node [{#NAME}] Requests: CPU'
              type: DEPENDENT
              key: 'kube.node.requests.cpu[{#NAME}]'
              value_type: FLOAT
              description: |
                Node CPU requests.
                
                https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.Pods[?(@.hostname == "{#NAME}")].containers.requests.cpu.sum()'
              master_item:
                key: kube.nodes
              tags:
                - tag: component
                  value: requests
                - tag: node
                  value: '{#NAME}'
            - uuid: 32f2f1d3ad084c6c9bbb96ad2fe9d98d
              name: 'Node [{#NAME}] Requests: Memory'
              type: DEPENDENT
              key: 'kube.node.requests.memory[{#NAME}]'
              units: B
              description: |
                Node Memory requests.
                
                https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.Pods[?(@.hostname == "{#NAME}")].containers.requests.memory.sum()'
              master_item:
                key: kube.nodes
              tags:
                - tag: component
                  value: requests
                - tag: node
                  value: '{#NAME}'
            - uuid: 0e30ed9718a54eb1ac643ac643471ca2
              name: 'Node [{#NAME}] Uptime'
              type: DEPENDENT
              key: 'kube.node.uptime[{#NAME}]'
              units: s
              description: 'Node uptime.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.metadata.creationTimestamp
                  error_handler: DISCARD_VALUE
                - type: JAVASCRIPT
                  parameters:
                    - 'return Math.floor((Date.now() - new Date(value)) / 1000);'
              master_item:
                key: 'kube.node.get[{#NAME}]'
              tags:
                - tag: component
                  value: uptime
                - tag: node
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: b322a8c9a4404da49c434e78822d6ac5
                  expression: 'last(/Kubernetes nodes by HTTP/kube.node.uptime[{#NAME}])<10'
                  name: 'Kubernetes nodes: Node [{#NAME}] has been restarted'
                  event_name: 'Kubernetes nodes: Node [{#NAME}] has been restarted (uptime < 10m)'
                  priority: INFO
                  description: 'Uptime is less than 10 minutes.'
                  tags:
                    - tag: scope
                      value: notice
            - uuid: 0203ec4fb37a4eb180edcba398bf470d
              name: 'Node [{#NAME}] Used: Pods'
              type: DEPENDENT
              key: 'kube.node.used.pods[{#NAME}]'
              description: 'Current number of pods on the node.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status.podsCount
              master_item:
                key: 'kube.node.get[{#NAME}]'
              tags:
                - tag: component
                  value: used
                - tag: node
                  value: '{#NAME}'
          trigger_prototypes:
            - uuid: f64efc13be2c4c53a48de40504cf064d
              expression: 'last(/Kubernetes nodes by HTTP/kube.node.limits.cpu[{#NAME}]) / last(/Kubernetes nodes by HTTP/kube.node.allocatable.cpu[{#NAME}]) > 0.9'
              name: 'Kubernetes nodes: Node [{#NAME}] Limits: Total CPU limits are too high'
              event_name: 'Kubernetes nodes: Node [{#NAME}] Limits: Total CPU limits are too high (more than 90% of allocatable)'
              opdata: 'Limits: {ITEM.LASTVALUE1}, Allocatable: {ITEM.LASTVALUE2}'
              priority: WARNING
              dependencies:
                - name: 'Kubernetes nodes: Node [{#NAME}] Limits: Total CPU limits are too high'
                  expression: 'last(/Kubernetes nodes by HTTP/kube.node.limits.cpu[{#NAME}]) / last(/Kubernetes nodes by HTTP/kube.node.allocatable.cpu[{#NAME}]) > 1'
              tags:
                - tag: scope
                  value: performance
            - uuid: 4c035b6c85574141832691e7ad264f40
              expression: 'last(/Kubernetes nodes by HTTP/kube.node.limits.cpu[{#NAME}]) / last(/Kubernetes nodes by HTTP/kube.node.allocatable.cpu[{#NAME}]) > 1'
              name: 'Kubernetes nodes: Node [{#NAME}] Limits: Total CPU limits are too high'
              event_name: 'Kubernetes nodes: Node [{#NAME}] Limits: Total CPU limits are too high (more than 100% of allocatable)'
              opdata: 'Limits: {ITEM.LASTVALUE1}, Allocatable: {ITEM.LASTVALUE2}'
              priority: AVERAGE
              tags:
                - tag: scope
                  value: performance
            - uuid: 5d0d803cfbbe42edb7d32d731ae5f741
              expression: 'last(/Kubernetes nodes by HTTP/kube.node.limits.memory[{#NAME}]) / last(/Kubernetes nodes by HTTP/kube.node.allocatable.memory[{#NAME}]) > 0.9'
              name: 'Kubernetes nodes: Node [{#NAME}] Limits: Total memory limits are too high'
              event_name: 'Kubernetes nodes: Node [{#NAME}] Limits: Total memory limits are too high (more than 90% of allocatable)'
              opdata: 'Limits: {ITEM.LASTVALUE1}, Allocatable: {ITEM.LASTVALUE2}'
              priority: WARNING
              dependencies:
                - name: 'Kubernetes nodes: Node [{#NAME}] Limits: Total memory limits are too high'
                  expression: 'last(/Kubernetes nodes by HTTP/kube.node.limits.memory[{#NAME}]) / last(/Kubernetes nodes by HTTP/kube.node.allocatable.memory[{#NAME}]) > 1'
              tags:
                - tag: scope
                  value: performance
            - uuid: 4fa15174194c476899a96fcf233a5aea
              expression: 'last(/Kubernetes nodes by HTTP/kube.node.limits.memory[{#NAME}]) / last(/Kubernetes nodes by HTTP/kube.node.allocatable.memory[{#NAME}]) > 1'
              name: 'Kubernetes nodes: Node [{#NAME}] Limits: Total memory limits are too high'
              event_name: 'Kubernetes nodes: Node [{#NAME}] Limits: Total memory limits are too high (more than 100% of allocatable)'
              opdata: 'Limits: {ITEM.LASTVALUE1}, Allocatable: {ITEM.LASTVALUE2}'
              priority: AVERAGE
              tags:
                - tag: scope
                  value: performance
            - uuid: 256cf876a4674dd09123bb388c1a9d32
              expression: 'last(/Kubernetes nodes by HTTP/kube.node.requests.cpu[{#NAME}]) / last(/Kubernetes nodes by HTTP/kube.node.allocatable.cpu[{#NAME}]) > 0.5'
              name: 'Kubernetes nodes: Node [{#NAME}] Requests: Total CPU requests are too high'
              event_name: 'Kubernetes nodes: Node [{#NAME}] Requests: Total CPU requests are too high (more than 50% of allocatable)'
              opdata: 'Requests: {ITEM.LASTVALUE1}, Allocatable: {ITEM.LASTVALUE2}'
              priority: WARNING
              dependencies:
                - name: 'Kubernetes nodes: Node [{#NAME}] Requests: Total CPU requests are too high'
                  expression: 'last(/Kubernetes nodes by HTTP/kube.node.requests.cpu[{#NAME}]) / last(/Kubernetes nodes by HTTP/kube.node.allocatable.cpu[{#NAME}]) > 0.8'
              tags:
                - tag: scope
                  value: performance
            - uuid: 7fa6901f620c4b388d550c669089dde2
              expression: 'last(/Kubernetes nodes by HTTP/kube.node.requests.cpu[{#NAME}]) / last(/Kubernetes nodes by HTTP/kube.node.allocatable.cpu[{#NAME}]) > 0.8'
              name: 'Kubernetes nodes: Node [{#NAME}] Requests: Total CPU requests are too high'
              event_name: 'Kubernetes nodes: Node [{#NAME}] Requests: Total CPU requests are too high (more than 80% of allocatable)'
              opdata: 'Requests: {ITEM.LASTVALUE1}, Allocatable: {ITEM.LASTVALUE2}'
              priority: AVERAGE
              tags:
                - tag: scope
                  value: performance
            - uuid: d73aa5aa2a9b424789181033630bb432
              expression: 'last(/Kubernetes nodes by HTTP/kube.node.requests.memory[{#NAME}]) / last(/Kubernetes nodes by HTTP/kube.node.allocatable.memory[{#NAME}]) > 0.5'
              name: 'Kubernetes nodes: Node [{#NAME}] Requests: Total memory requests are too high'
              event_name: 'Kubernetes nodes: Node [{#NAME}] Requests: Total memory requests are too high (more than 50% of allocatable)'
              opdata: 'Requests: {ITEM.LASTVALUE1}, Allocatable: {ITEM.LASTVALUE2}'
              priority: WARNING
              dependencies:
                - name: 'Kubernetes nodes: Node [{#NAME}] Requests: Total memory requests are too high'
                  expression: 'last(/Kubernetes nodes by HTTP/kube.node.requests.memory[{#NAME}]) / last(/Kubernetes nodes by HTTP/kube.node.allocatable.memory[{#NAME}]) > 0.8'
              tags:
                - tag: scope
                  value: performance
            - uuid: ad9a65c4786e48b9a4b77c1214fa2e1f
              expression: 'last(/Kubernetes nodes by HTTP/kube.node.requests.memory[{#NAME}]) / last(/Kubernetes nodes by HTTP/kube.node.allocatable.memory[{#NAME}]) > 0.8'
              name: 'Kubernetes nodes: Node [{#NAME}] Requests: Total memory requests are too high'
              event_name: 'Kubernetes nodes: Node [{#NAME}] Requests: Total memory requests are too high (more than 80% of allocatable)'
              opdata: 'Requests: {ITEM.LASTVALUE1}, Allocatable: {ITEM.LASTVALUE2}'
              priority: AVERAGE
              tags:
                - tag: scope
                  value: performance
            - uuid: 0126dfbfa9d949499e0f7689b714c855
              expression: 'last(/Kubernetes nodes by HTTP/kube.node.used.pods[{#NAME}])/ last(/Kubernetes nodes by HTTP/kube.node.capacity.pods[{#NAME}]) > 0.9'
              name: 'Kubernetes nodes: Node [{#NAME}] Used: Kubelet too many pods'
              event_name: 'Kubernetes nodes: Node [{#NAME}] Used: Kubelet too many pods (more than 95% of capacity)'
              opdata: 'Used: {ITEM.LASTVALUE1}, Capacity: {ITEM.LASTVALUE2}'
              priority: WARNING
              description: 'Kubelet is running at capacity.'
              tags:
                - tag: scope
                  value: performance
          graph_prototypes:
            - uuid: 646efb7b19f5408dba2f3fe2d6a92213
              name: 'Node [{#NAME}] Allocatable: Pod limits'
              graph_items:
                - sortorder: '1'
                  drawtype: BOLD_LINE
                  color: 4CAF50
                  item:
                    host: 'Kubernetes nodes by HTTP'
                    key: 'kube.node.allocatable.pods[{#NAME}]'
                - sortorder: '2'
                  drawtype: BOLD_LINE
                  color: AB47BC
                  item:
                    host: 'Kubernetes nodes by HTTP'
                    key: 'kube.node.capacity.pods[{#NAME}]'
                - sortorder: '3'
                  drawtype: GRADIENT_LINE
                  color: 1E88E5
                  calc_fnc: MAX
                  item:
                    host: 'Kubernetes nodes by HTTP'
                    key: 'kube.node.used.pods[{#NAME}]'
          host_prototypes:
            - uuid: bfcbf26edd704bdfaa65e244a987839e
              host: '{#NAME}'
              name: '{#NAME}'
              status: DISABLED
              discover: NO_DISCOVER
              group_links:
                - group:
                    name: Applications
              group_prototypes:
                - name: '{#CLUSTER_HOSTNAME}: Kubernetes/Nodes/Role: {#ROLES}'
              macros:
                - macro: '{$VFS.FS.FSNAME.NOT_MATCHES}'
                  value: ^/(dev|sys|run|proc|etc/.+|.+/shm|hostfs/root/var/lib/docker/.+)$
                  description: 'This macro is used in filesystems discovery. Can be overridden on the host or linked template level'
                - macro: '{$VFS.FS.FSTYPE.NOT_MATCHES}'
                  value: ^(autofs|binfmt_misc|cgroup|configfs|debugfs|devpts|devtmpfs|fusectl|hugetlbfs|mqueue|overlay|proc|procfs|pstore|rpc_pipefs|securityfs|sysfs|tracefs)$
                  description: 'This macro is used in filesystems discovery. Can be overridden on the host or linked template level'
              tags:
                - tag: addr
                  value: '{#IP}'
                - tag: arch
                  value: '{#ARCH}'
                - tag: os
                  value: '{#OS}'
                - tag: roles
                  value: '{#ROLES}'
              custom_interfaces: 'YES'
              interfaces:
                - ip: '{#IP}'
          master_item:
            key: kube.nodes
          lld_macro_paths:
            - lld_macro: '{#ARCH}'
              path: '$.metadata.labels[''kubernetes.io/arch'']'
            - lld_macro: '{#CLUSTER_HOSTNAME}'
              path: $.clusterhostname
            - lld_macro: '{#ENDPOINT}'
              path: $.status.agent
            - lld_macro: '{#IP}'
              path: $.internalIP
            - lld_macro: '{#NAME}'
              path: $.metadata.name
            - lld_macro: '{#OS}'
              path: '$.metadata.labels[''kubernetes.io/os'']'
            - lld_macro: '{#ROLES}'
              path: $.status.roles
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.nodes..filternode
          overrides:
            - name: 'Endpoints host'
              step: '1'
              filter:
                conditions:
                  - macro: '{#ENDPOINT}'
                    value: 'zabbix-agent.*'
              operations:
                - operationobject: HOST_PROTOTYPE
                  operator: REGEXP
                  discover: DISCOVER
                  status: ENABLED
        - uuid: b9dd5b50208e415da509f61ec73451c1
          name: 'Pod discovery'
          type: DEPENDENT
          key: kube.pod.discovery
          filter:
            evaltype: AND
            conditions:
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.POD.NAMESPACE.MATCHES}'
              - macro: '{#NAMESPACE}'
                value: '{$KUBE.LLD.FILTER.POD.NAMESPACE.NOT_MATCHES}'
                operator: NOT_MATCHES_REGEX
              - macro: '{#NODE}'
                value: '{$KUBE.LLD.FILTER.NODE.MATCHES}'
              - macro: '{#NODE}'
                value: '{$KUBE.LLD.FILTER.NODE.NOT_MATCHES}'
                operator: NOT_MATCHES_REGEX
          lifetime: '0'
          item_prototypes:
            - uuid: ed4ea3dbbce74404a5039aa9918b8e2b
              name: 'Node [{#NODE}] Namespace [{#NAMESPACE}] Pod [{#POD}] Conditions: Containers ready'
              type: DEPENDENT
              key: 'kube.pod.conditions.containers_ready[{#NAMESPACE}/{#POD}]'
              description: |
                All containers in the Pod are ready.
                
                https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle/#pod-conditions
              valuemap:
                name: 'Pod conditions'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.conditions[?(@.type == "ContainersReady")].status.first()'
                  error_handler: DISCARD_VALUE
                - type: JAVASCRIPT
                  parameters:
                    - 'return [''True'', ''False'', ''Unknown''].indexOf(value) + 1 || ''Problem with status processing in JS'';'
              master_item:
                key: 'kube.pod.get[{#NAMESPACE}/{#POD}]'
              tags:
                - tag: component
                  value: conditions
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: node
                  value: '{#NODE}'
                - tag: pod
                  value: '{#POD}'
            - uuid: 647ca68c325742d083e37c05e2826205
              name: 'Node [{#NODE}] Namespace [{#NAMESPACE}] Pod [{#POD}] Conditions: Initialized'
              type: DEPENDENT
              key: 'kube.pod.conditions.initialized[{#NAMESPACE}/{#POD}]'
              description: |
                All init containers have started successfully.
                
                https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle/#pod-conditions
              valuemap:
                name: 'Pod conditions'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.conditions[?(@.type == "Initialized")].status.first()'
                  error_handler: DISCARD_VALUE
                - type: JAVASCRIPT
                  parameters:
                    - 'return [''True'', ''False'', ''Unknown''].indexOf(value) + 1 || ''Problem with status processing in JS'';'
              master_item:
                key: 'kube.pod.get[{#NAMESPACE}/{#POD}]'
              tags:
                - tag: component
                  value: conditions
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: node
                  value: '{#NODE}'
                - tag: pod
                  value: '{#POD}'
            - uuid: b73a5c5d3b614815be157eb53c6afb1f
              name: 'Node [{#NODE}] Namespace [{#NAMESPACE}] Pod [{#POD}] Conditions: Ready'
              type: DEPENDENT
              key: 'kube.pod.conditions.ready[{#NAMESPACE}/{#POD}]'
              description: |
                The Pod is able to serve requests and should be added to the load balancing pools of all matching Services.
                
                https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle/#pod-conditions
              valuemap:
                name: 'Pod conditions'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.conditions[?(@.type == "Ready")].status.first()'
                  error_handler: DISCARD_VALUE
                - type: JAVASCRIPT
                  parameters:
                    - 'return [''True'', ''False'', ''Unknown''].indexOf(value) + 1 || ''Problem with status processing in JS'';'
              master_item:
                key: 'kube.pod.get[{#NAMESPACE}/{#POD}]'
              tags:
                - tag: component
                  value: conditions
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: node
                  value: '{#NODE}'
                - tag: pod
                  value: '{#POD}'
            - uuid: 5956cd1780604f0793efd7bbce2559b6
              name: 'Node [{#NODE}] Namespace [{#NAMESPACE}] Pod [{#POD}] Conditions: Scheduled'
              type: DEPENDENT
              key: 'kube.pod.conditions.scheduled[{#NAMESPACE}/{#POD}]'
              description: |
                The Pod has been scheduled to a node.
                
                https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle/#pod-conditions
              valuemap:
                name: 'Pod conditions'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.conditions[?(@.type == "PodScheduled")].status.first()'
                  error_handler: DISCARD_VALUE
                - type: JAVASCRIPT
                  parameters:
                    - 'return [''True'', ''False'', ''Unknown''].indexOf(value) + 1 || ''Problem with status processing in JS'';'
              master_item:
                key: 'kube.pod.get[{#NAMESPACE}/{#POD}]'
              tags:
                - tag: component
                  value: conditions
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: node
                  value: '{#NODE}'
                - tag: pod
                  value: '{#POD}'
            - uuid: 5fd018faebb84462bf8111861795b04e
              name: 'Node [{#NODE}] Namespace [{#NAMESPACE}] Pod [{#POD}] Containers: Restarts'
              type: DEPENDENT
              key: 'kube.pod.containers.restartcount[{#NAMESPACE}/{#POD}]'
              description: 'The number of times the container has been restarted, currently based on the number of dead containers that have not yet been removed. Note that this is calculated from dead containers. But those containers are subject to garbage collection.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.containers.restartCount
                  error_handler: DISCARD_VALUE
              master_item:
                key: 'kube.pod.get[{#NAMESPACE}/{#POD}]'
              tags:
                - tag: component
                  value: container
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: node
                  value: '{#NODE}'
                - tag: pod
                  value: '{#POD}'
              trigger_prototypes:
                - uuid: 8f1808cd67614cda959ec70e92a59235
                  expression: '(last(/Kubernetes nodes by HTTP/kube.pod.containers.restartcount[{#NAMESPACE}/{#POD}])-min(/Kubernetes nodes by HTTP/kube.pod.containers.restartcount[{#NAMESPACE}/{#POD}],15m))>1'
                  name: 'Kubernetes nodes: Node [{#NODE}] Namespace [{#NAMESPACE}] Pod [{#POD}]: Pod is crash looping'
                  priority: WARNING
                  description: 'Containers of the pod keep restarting. This most likely indicates that the pod is in the CrashLoopBackOff state.'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: 34a542538cf449f287a99052870988be
              name: 'Node [{#NODE}] Namespace [{#NAMESPACE}] Pod [{#POD}]: Get data'
              type: DEPENDENT
              key: 'kube.pod.get[{#NAMESPACE}/{#POD}]'
              history: '0'
              value_type: CHAR
              description: 'Collecting and processing cluster by node [{#NODE}] data via Kubernetes API.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.Pods[?(@.name == "{#POD}" && @.namespace == "{#NAMESPACE}")].first()'
              master_item:
                key: kube.nodes
              tags:
                - tag: component
                  value: raw
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: node
                  value: '{#NODE}'
                - tag: pod
                  value: '{#POD}'
            - uuid: 6862be81e52b4abcb319a8847b022634
              name: 'Node [{#NODE}] Namespace [{#NAMESPACE}] Pod [{#POD}] Status: Phase'
              type: DEPENDENT
              key: 'kube.pod.status.phase[{#NAMESPACE}/{#POD}]'
              description: |
                The phase of a Pod is a simple, high-level summary of where the Pod is in its lifecycle.
                
                https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-phase
              valuemap:
                name: 'Pod phase'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.phase
                  error_handler: DISCARD_VALUE
                - type: JAVASCRIPT
                  parameters:
                    - 'return [''Pending'', ''Running'', ''Succeeded'', ''Failed'', ''Unknown''].indexOf(value) + 1 || ''Problem with status processing in JS'';'
              master_item:
                key: 'kube.pod.get[{#NAMESPACE}/{#POD}]'
              tags:
                - tag: component
                  value: pod
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: node
                  value: '{#NODE}'
                - tag: pod
                  value: '{#POD}'
              trigger_prototypes:
                - uuid: e565d243bef84007b09addb22ea3d759
                  expression: 'count(/Kubernetes nodes by HTTP/kube.pod.status.phase[{#NAMESPACE}/{#POD}],10m, "regexp","^(1|4|5)$")>=9'
                  name: 'Kubernetes nodes: Node [{#NODE}] Namespace [{#NAMESPACE}] Pod [{#POD}] Status: Kubernetes Pod not healthy'
                  priority: HIGH
                  description: 'Pod has been in a non-ready state for longer than 10 minutes.'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: abb0b84204164301bb9fc6ab14284631
              name: 'Node [{#NODE}] Namespace [{#NAMESPACE}] Pod [{#POD}]: Uptime'
              type: DEPENDENT
              key: 'kube.pod.uptime[{#NAMESPACE}/{#POD}]'
              units: s
              description: 'Pod uptime.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.startTime
                  error_handler: DISCARD_VALUE
                - type: JAVASCRIPT
                  parameters:
                    - 'return Math.floor((Date.now() - new Date(value)) / 1000);'
              master_item:
                key: 'kube.pod.get[{#NAMESPACE}/{#POD}]'
              tags:
                - tag: component
                  value: uptime
                - tag: namespace
                  value: '{#NAMESPACE}'
                - tag: node
                  value: '{#NODE}'
                - tag: pod
                  value: '{#POD}'
          master_item:
            key: kube.nodes
          lld_macro_paths:
            - lld_macro: '{#NAMESPACE}'
              path: $.namespace
            - lld_macro: '{#NODE}'
              path: $.hostname
            - lld_macro: '{#POD}'
              path: $.name
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.Pods
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
      tags:
        - tag: class
          value: software
        - tag: subclass
          value: automation
        - tag: subclass
          value: containers
        - tag: subclass
          value: deploy
        - tag: subclass
          value: development
        - tag: subclass
          value: virtualization
        - tag: target
          value: kubernetes
        - tag: target
          value: nodes
      macros:
        - macro: '{$KUBE.API.TOKEN}'
          type: SECRET_TEXT
          description: 'Service account bearer token.'
          config:
            type: TEXT
            priority: '1'
            label: 'API Authorization Token'
            description: 'Service account bearer token for authentication.'
            required: 'YES'
        - macro: '{$KUBE.API.URL}'
          value: 'https://kubernetes.default.svc.cluster.local:443'
          description: 'Kubernetes API endpoint URL in the format <scheme>://<host>:<port>'
          config:
            type: TEXT
            priority: '2'
            label: 'Kubernetes API URL'
            description: 'The Kubernetes API endpoint URL.'
            required: 'YES'
        - macro: '{$KUBE.HTTP.PROXY}'
          description: 'Sets the HTTP proxy to `http_proxy` value. If this parameter is empty, then no proxy is used.'
          config:
            type: TEXT
            priority: '3'
            label: 'HTTP Proxy'
            description: 'HTTP proxy to use for requests.'
        - macro: '{$KUBE.LLD.FILTER.NODE.MATCHES}'
          value: '.*'
          description: 'Filter of discoverable nodes.'
          config:
            type: TEXT
            priority: '5'
            section_name: Filters
            label: 'Node Matches Filter'
            description: 'A regex to filter discoverable nodes.'
        - macro: '{$KUBE.LLD.FILTER.NODE.NOT_MATCHES}'
          value: CHANGE_IF_NEEDED
          description: 'Filter to exclude discovered nodes.'
          config:
            type: TEXT
            priority: '6'
            section_name: Filters
            label: 'Node Exclusion Filter'
            description: 'A regex to exclude discovered nodes.'
        - macro: '{$KUBE.LLD.FILTER.NODE.ROLE.MATCHES}'
          value: '.*'
          description: 'Filter of discoverable nodes by role.'
          config:
            type: TEXT
            priority: '7'
            section_name: Filters
            label: 'Node Role Matches Filter'
            description: 'A regex to filter discoverable nodes by role.'
        - macro: '{$KUBE.LLD.FILTER.NODE.ROLE.NOT_MATCHES}'
          value: CHANGE_IF_NEEDED
          description: 'Filter to exclude discovered node by role.'
          config:
            type: TEXT
            priority: '8'
            section_name: Filters
            label: 'Node Role Exclusion Filter'
            description: 'A regex to exclude discovered nodes by role.'
        - macro: '{$KUBE.LLD.FILTER.POD.NAMESPACE.MATCHES}'
          value: '.*'
          description: 'Filter of discoverable pods by namespace.'
          config:
            type: TEXT
            priority: '13'
            section_name: Filters
            label: 'Pod Namespace Matches Filter'
            description: 'A regex to filter discoverable pods by namespace.'
        - macro: '{$KUBE.LLD.FILTER.POD.NAMESPACE.NOT_MATCHES}'
          value: CHANGE_IF_NEEDED
          description: 'Filter to exclude discovered pods by namespace.'
          config:
            type: TEXT
            priority: '14'
            section_name: Filters
            label: 'Pod Namespace Exclusion Filter'
            description: 'A regex to exclude discovered pods by namespace.'
        - macro: '{$KUBE.NODE.FILTER.ANNOTATIONS}'
          description: 'Annotations to filter nodes (regex in values are supported). See the template''s README.md for details.'
          config:
            type: TEXT
            priority: '9'
            section_name: Filters
            label: 'Node Annotations Filter'
            description: 'Annotations to filter nodes.'
        - macro: '{$KUBE.NODE.FILTER.LABELS}'
          description: 'Labels to filter nodes (regex in values are supported). See the template''s README.md for details.'
          config:
            type: TEXT
            priority: '10'
            section_name: Filters
            label: 'Node Labels Filter'
            description: 'Labels to filter nodes.'
        - macro: '{$KUBE.NODES.ENDPOINT.NAME}'
          value: zabbix-zabbix-helm-chrt-agent
          description: 'Kubernetes nodes endpoint name. See "kubectl -n monitoring get ep".'
          config:
            type: TEXT
            priority: '4'
            label: 'Nodes Endpoint Name'
            description: 'The Kubernetes nodes endpoint name.'
        - macro: '{$KUBE.POD.FILTER.ANNOTATIONS}'
          description: 'Annotations to filter pods (regex in values are supported). See the template''s README.md for details.'
          config:
            type: TEXT
            priority: '11'
            section_name: Filters
            label: 'Pod Annotations Filter'
            description: 'Annotations to filter pods.'
        - macro: '{$KUBE.POD.FILTER.LABELS}'
          description: 'Labels to filter Pods (regex in values are supported). See the template''s README.md for details.'
          config:
            type: TEXT
            priority: '12'
            section_name: Filters
            label: 'Pod Labels Filter'
            description: 'Labels to filter pods.'
      valuemaps:
        - uuid: 785b20f8979341c4b470870ec8f50414
          name: 'Node conditions'
          mappings:
            - value: '1'
              newvalue: 'True'
            - value: '2'
              newvalue: 'False'
            - value: '3'
              newvalue: Unknown
        - uuid: f93e30e125de4909b52e7c38bc3f2c97
          name: 'Pod conditions'
          mappings:
            - value: '1'
              newvalue: 'True'
            - value: '2'
              newvalue: 'False'
            - value: '3'
              newvalue: Unknown
        - uuid: 21ff77dde5964dcfb4bb2ae202a5f33c
          name: 'Pod phase'
          mappings:
            - value: '1'
              newvalue: Pending
            - value: '2'
              newvalue: Running
            - value: '3'
              newvalue: Succeeded
            - value: '4'
              newvalue: Failed
            - value: '5'
              newvalue: Unknown
    - uuid: ece96efdf0a045b99ede7978fa9366d6
      template: 'Kubernetes Scheduler by HTTP'
      name: 'Kubernetes Scheduler by HTTP'
      description: |
        Get Kubernetes Scheduler metrics by HTTP agent from Prometheus metrics endpoint.
        
        Don't forget change macros {$KUBE.API.SERVER.URL}.
        Some metrics may not be collected depending on your Kubernetes Scheduler instance version and configuration.
        
        You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback
        
        Generated by official Zabbix template tool "Templator"
      wizard_ready: 'YES'
      readme: |
        ## Overview
        
        The template to monitor Kubernetes Scheduler by Zabbix that works without any external scripts.
        Most of the metrics are collected in one go, thanks to Zabbix bulk data collection.
        
        Template `Kubernetes Scheduler by HTTP` - collects metrics by HTTP agent from Scheduler /metrics endpoint.
        
        ## Setup
        
        Internal service metrics are collected from /metrics endpoint.
        Template needs to use Authorization via API token.
        
        Set the following fields: `Scheduler metrics endpoint URL`, `API Authorization Token`.
        
        *NOTE.* You might need to set the `--binding-address` option for Scheduler to the address where Zabbix proxy can reach it.
        For example, for clusters created with `kubeadm` it can be set in the following manifest file (changes will be applied immediately):
        
        - /etc/kubernetes/manifests/kube-scheduler.yaml
        
        *NOTE.* Some metrics may not be collected depending on your Kubernetes Scheduler instance version and configuration.
      vendor:
        name: Zabbix
        version: 7.4-1
      groups:
        - name: Templates/Applications
      items:
        - uuid: 87e91f23320043549457a5b2ab8ddf74
          name: 'REST Client requests: 2xx, rate'
          type: DEPENDENT
          key: kubernetes.scheduler.client_http_requests_200.rate
          value_type: FLOAT
          description: 'Number of HTTP requests with 2xx status code per second.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - 'rest_client_requests_total{code =~ "2.."}'
                - function
                - sum
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: kubernetes.scheduler.get_metrics
          tags:
            - tag: component
              value: rest
            - tag: http-code
              value: 2xx
        - uuid: b790f8c9a6b44f54837a6b3cb1dcec41
          name: 'REST Client requests: 3xx, rate'
          type: DEPENDENT
          key: kubernetes.scheduler.client_http_requests_300.rate
          value_type: FLOAT
          description: 'Number of HTTP requests with 3xx status code per second.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - 'rest_client_requests_total{code =~ "3.."}'
                - function
                - sum
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: kubernetes.scheduler.get_metrics
          tags:
            - tag: component
              value: rest
            - tag: http-code
              value: 3xx
        - uuid: 84e09cb3134b492b983649bc29da11ee
          name: 'REST Client requests: 4xx, rate'
          type: DEPENDENT
          key: kubernetes.scheduler.client_http_requests_400.rate
          value_type: FLOAT
          description: 'Number of HTTP requests with 4xx status code per second.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - 'rest_client_requests_total{code =~ "4.."}'
                - function
                - sum
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: kubernetes.scheduler.get_metrics
          tags:
            - tag: component
              value: rest
            - tag: http-code
              value: 4xx
        - uuid: d94fce6ae59b4735b93e1ccfb9084dc2
          name: 'REST Client requests: 5xx, rate'
          type: DEPENDENT
          key: kubernetes.scheduler.client_http_requests_500.rate
          value_type: FLOAT
          description: 'Number of HTTP requests with 5xx status code per second.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - 'rest_client_requests_total{code =~ "5.."}'
                - function
                - sum
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: kubernetes.scheduler.get_metrics
          tags:
            - tag: component
              value: rest
            - tag: http-code
              value: 5xx
          triggers:
            - uuid: ea92474a61214053b2cd20775817010e
              expression: 'min(/Kubernetes Scheduler by HTTP/kubernetes.scheduler.client_http_requests_500.rate,5m)>{$KUBE.SCHEDULER.HTTP.CLIENT.ERROR}'
              name: 'Kubernetes Scheduler: Too many REST Client errors'
              event_name: 'Kubernetes Scheduler: Too many REST Client errors (over {$KUBE.SCHEDULER.HTTP.CLIENT.ERROR} for 5m)'
              priority: WARNING
              description: '"Kubernetes Scheduler REST Client requests is experiencing high error rate (with 5xx HTTP code).'
              tags:
                - tag: scope
                  value: availability
        - uuid: b1d79dbb773d47668476a12ca8ee3d08
          name: CPU
          type: DEPENDENT
          key: kubernetes.scheduler.cpu.util
          value_type: FLOAT
          units: '%'
          description: 'Total user and system CPU usage ratio.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - process_cpu_seconds_total
                - value
                - ''
            - type: CHANGE_PER_SECOND
            - type: MULTIPLIER
              parameters:
                - '100'
          master_item:
            key: kubernetes.scheduler.get_metrics
          tags:
            - tag: component
              value: cpu
        - uuid: 2534eacdaf9b44d68388b366da40af59
          name: 'Get Scheduler metrics'
          type: HTTP_AGENT
          key: kubernetes.scheduler.get_metrics
          history: '0'
          value_type: TEXT
          description: 'Get raw metrics from Scheduler instance /metrics endpoint.'
          preprocessing:
            - type: CHECK_NOT_SUPPORTED
              parameters:
                - '-1'
          timeout: 15s
          url: '{$KUBE.SCHEDULER.SERVER.URL}'
          headers:
            - name: Authorization
              value: 'Bearer {$KUBE.API.TOKEN}'
          tags:
            - tag: component
              value: raw
        - uuid: a21ec7ee8a76449f99199777d35cdd03
          name: Goroutines
          type: DEPENDENT
          key: kubernetes.scheduler.go_goroutines
          value_type: FLOAT
          description: 'Number of goroutines that currently exist.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - go_goroutines
                - function
                - sum
              error_handler: DISCARD_VALUE
          master_item:
            key: kubernetes.scheduler.get_metrics
          tags:
            - tag: component
              value: goroutines
        - uuid: d7493f23748f440b8cae127e6ff70bb7
          name: 'Go threads'
          type: DEPENDENT
          key: kubernetes.scheduler.go_threads
          value_type: FLOAT
          description: 'Number of OS threads created.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - go_threads
                - value
                - ''
              error_handler: DISCARD_VALUE
          master_item:
            key: kubernetes.scheduler.get_metrics
          tags:
            - tag: component
              value: go-threads
        - uuid: 11471cff0d664bdb906cf54821af9710
          name: 'Fds max'
          type: DEPENDENT
          key: kubernetes.scheduler.max_fds
          value_type: FLOAT
          description: 'Maximum allowed open file descriptors.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - process_max_fds
                - value
                - ''
              error_handler: DISCARD_VALUE
          master_item:
            key: kubernetes.scheduler.get_metrics
          tags:
            - tag: component
              value: fds
        - uuid: 2aa6fb05cb3e4f33a05ebf331be1ed54
          name: 'Fds open'
          type: DEPENDENT
          key: kubernetes.scheduler.open_fds
          value_type: FLOAT
          description: 'Number of open file descriptors.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - process_open_fds
                - value
                - ''
              error_handler: DISCARD_VALUE
          master_item:
            key: kubernetes.scheduler.get_metrics
          tags:
            - tag: component
              value: fds
        - uuid: f8272f957dc447f19876395994050edd
          name: 'Resident memory, bytes'
          type: DEPENDENT
          key: kubernetes.scheduler.process_resident_memory_bytes
          value_type: FLOAT
          units: B
          description: 'Resident memory size in bytes.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - process_resident_memory_bytes
                - value
                - ''
              error_handler: DISCARD_VALUE
          master_item:
            key: kubernetes.scheduler.get_metrics
          tags:
            - tag: component
              value: memory
        - uuid: 0319ccb3efb94aeba6181c1f34cc999a
          name: 'Virtual memory, bytes'
          type: DEPENDENT
          key: kubernetes.scheduler.process_virtual_memory_bytes
          value_type: FLOAT
          units: B
          description: 'Virtual memory size in bytes.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - process_virtual_memory_bytes
                - value
                - ''
              error_handler: DISCARD_VALUE
          master_item:
            key: kubernetes.scheduler.get_metrics
          tags:
            - tag: component
              value: memory
        - uuid: f198d7705dd34d52b57a31aa8b5a423a
          name: 'Schedule attempts: error'
          type: DEPENDENT
          key: kubernetes.scheduler.scheduler_schedule_attempts.error.rate
          value_type: FLOAT
          description: 'Number of attempts to schedule pods with result "error" per second.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - 'scheduler_schedule_attempts_total{result = "error"}'
                - function
                - sum
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: kubernetes.scheduler.get_metrics
          tags:
            - tag: component
              value: scheduler
          triggers:
            - uuid: 9116327bc14f4f189ca867b43187f6bd
              expression: 'min(/Kubernetes Scheduler by HTTP/kubernetes.scheduler.scheduler_schedule_attempts.error.rate,5m)>{$KUBE.SCHEDULER.ERROR}'
              name: 'Kubernetes Scheduler: Too many schedule attempts with errors'
              event_name: 'Kubernetes Scheduler: Too many schedule attempts with errors (over {$KUBE.SCHEDULER.ERROR} for 5m)'
              priority: WARNING
              description: 'Number of attempts to schedule pods with ''error'' result is too high. ''error'' means an internal scheduler problem.'
              tags:
                - tag: scope
                  value: performance
        - uuid: d5c901849f134b40b077c50e02415fff
          name: 'Schedule attempts: scheduled'
          type: DEPENDENT
          key: kubernetes.scheduler.scheduler_schedule_attempts.scheduled.rate
          value_type: FLOAT
          description: 'Number of attempts to schedule pods with result "scheduled" per second.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - 'scheduler_schedule_attempts_total{result = "scheduled"}'
                - function
                - sum
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: kubernetes.scheduler.get_metrics
          tags:
            - tag: component
              value: scheduler
        - uuid: 5736a89200684c709c22f9fb3711bb83
          name: 'Schedule attempts: unschedulable'
          type: DEPENDENT
          key: kubernetes.scheduler.scheduler_schedule_attempts.unschedulable.rate
          value_type: FLOAT
          description: 'Number of attempts to schedule pods with result "unschedulable" per second.'
          preprocessing:
            - type: PROMETHEUS_PATTERN
              parameters:
                - 'scheduler_schedule_attempts_total{result = "unschedulable"}'
                - function
                - sum
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: kubernetes.scheduler.get_metrics
          tags:
            - tag: component
              value: scheduler
          triggers:
            - uuid: 16efba4ba322416fa2b8986273b83904
              expression: 'min(/Kubernetes Scheduler by HTTP/kubernetes.scheduler.scheduler_schedule_attempts.unschedulable.rate,5m)>{$KUBE.SCHEDULER.UNSCHEDULABLE}'
              name: 'Kubernetes Scheduler: Too many unschedulable pods'
              event_name: 'Kubernetes Scheduler: Too many unschedulable pods (over {$KUBE.SCHEDULER.UNSCHEDULABLE} for 5m)'
              priority: WARNING
              description: 'Number of attempts to schedule pods with ''unschedulable'' result is too high. ''unschedulable'' means a pod could not be scheduled.'
              tags:
                - tag: scope
                  value: performance
      discovery_rules:
        - uuid: 0dacff4b5ab841569642350388f4e534
          name: 'e2e scheduling histogram'
          type: DEPENDENT
          key: kubernetes.controller.e2e_scheduling.discovery
          description: 'Discovery raw data and percentile items of e2e scheduling latency.'
          item_prototypes:
            - uuid: eaeb8c321626466bbf7c08008a82b9c8
              name: '["{#RESULT}"]: e2e scheduling seconds bucket, {#LE}'
              type: DEPENDENT
              key: 'kubernetes.scheduler.e2e_scheduling_bucket[{#LE},"{#RESULT}"]'
              history: 1h
              value_type: FLOAT
              trends: '0'
              discover: NO_DISCOVER
              description: 'E2e scheduling latency in seconds (scheduling algorithm + binding)'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'scheduler_e2e_scheduling_duration_seconds_bucket{result = "{#RESULT}",le = "{#LE}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kubernetes.scheduler.get_metrics
              tags:
                - tag: component
                  value: e2e-scheduling
                - tag: result
                  value: '{#RESULT}'
            - uuid: b8fd5b4454484f4298e2c2b1e5c832c5
              name: '["{#RESULT}"]: e2e scheduling, p50'
              type: CALCULATED
              key: 'kubernetes.scheduler.e2e_scheduling_p50["{#RESULT}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kubernetes.scheduler.e2e_scheduling_bucket[*,"{#RESULT}"],5m,50)'
              description: '50 percentile of e2e scheduling latency.'
              tags:
                - tag: component
                  value: e2e-scheduling
                - tag: result
                  value: '{#RESULT}'
            - uuid: 01edd56cd1c94d4b80589d91349e4be5
              name: '["{#RESULT}"]: e2e scheduling, p90'
              type: CALCULATED
              key: 'kubernetes.scheduler.e2e_scheduling_p90["{#RESULT}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kubernetes.scheduler.e2e_scheduling_bucket[*,"{#RESULT}"],5m,90)'
              description: '90 percentile of e2e scheduling latency.'
              tags:
                - tag: component
                  value: e2e-scheduling
                - tag: result
                  value: '{#RESULT}'
            - uuid: 706fc27da4d34a4e9189c566c7aa96ff
              name: '["{#RESULT}"]: e2e scheduling, p95'
              type: CALCULATED
              key: 'kubernetes.scheduler.e2e_scheduling_p95["{#RESULT}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kubernetes.scheduler.e2e_scheduling_bucket[*,"{#RESULT}"],5m,95)'
              description: '95 percentile of e2e scheduling latency.'
              tags:
                - tag: component
                  value: e2e-scheduling
                - tag: result
                  value: '{#RESULT}'
            - uuid: 829627aeab764590b3a17e6b10c56709
              name: '["{#RESULT}"]: e2e scheduling, p99'
              type: CALCULATED
              key: 'kubernetes.scheduler.e2e_scheduling_p99["{#RESULT}"]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kubernetes.scheduler.e2e_scheduling_bucket[*,"{#RESULT}"],5m,99)'
              description: '95 percentile of e2e scheduling latency.'
              tags:
                - tag: component
                  value: e2e-scheduling
                - tag: result
                  value: '{#RESULT}'
          graph_prototypes:
            - uuid: be0cb738e2a346f8a24cabf0f76a6e6a
              name: 'Kubernetes Scheduler: ["{#RESULT}"] E2e latency'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'Kubernetes Scheduler by HTTP'
                    key: 'kubernetes.scheduler.e2e_scheduling_p50["{#RESULT}"]'
                - sortorder: '1'
                  color: F63100
                  item:
                    host: 'Kubernetes Scheduler by HTTP'
                    key: 'kubernetes.scheduler.e2e_scheduling_p90["{#RESULT}"]'
                - sortorder: '2'
                  color: 00611C
                  item:
                    host: 'Kubernetes Scheduler by HTTP'
                    key: 'kubernetes.scheduler.e2e_scheduling_p95["{#RESULT}"]'
                - sortorder: '3'
                  color: F7941D
                  item:
                    host: 'Kubernetes Scheduler by HTTP'
                    key: 'kubernetes.scheduler.e2e_scheduling_p99["{#RESULT}"]'
          master_item:
            key: kubernetes.scheduler.get_metrics
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - '{__name__=~ "scheduler_e2e_scheduling_duration_*", result =~ ".*"}'
            - type: JAVASCRIPT
              parameters:
                - |
                  var lookup = {},
                  	result = [];
                  
                  JSON.parse(value).forEach(function (item) {
                  	if (item.name === "scheduler_e2e_scheduling_duration_seconds_count"){
                  		var label_result = item.labels.result;
                  
                  		if (lookup[label_result]) {
                  			return;
                  		}
                  		lookup[label_result] = 1;
                  		result.push({
                  			'{#TYPE}': 'totals',
                  			'{#RESULT}': label_result
                  		});
                  
                  	  }
                  	else if  (item.name === "scheduler_e2e_scheduling_duration_seconds_bucket"){
                  		result.push({
                  			'{#TYPE}': 'buckets',
                  			'{#RESULT}': item.labels.result,
                  			'{#LE}': item.labels.le
                  		});
                  	}
                  });
                  
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
          overrides:
            - name: 'bucket item'
              step: '1'
              filter:
                conditions:
                  - macro: '{#TYPE}'
                    value: buckets
              operations:
                - operator: LIKE
                  value: bucket
                  discover: DISCOVER
            - name: 'total item'
              step: '2'
              filter:
                conditions:
                  - macro: '{#TYPE}'
                    value: totals
              operations:
                - operator: NOT_LIKE
                  value: bucket
                  discover: DISCOVER
        - uuid: 8cfc88eb0f6b4ae09d93bd9fc275659d
          name: 'Binding histogram'
          type: DEPENDENT
          key: kubernetes.scheduler.binding.discovery
          description: 'Discovery raw data of binding latency.'
          item_prototypes:
            - uuid: 17a3d7122cd844ea905059020532907b
              name: 'Binding duration bucket, {#LE}'
              type: DEPENDENT
              key: 'kubernetes.scheduler.binding_duration[{#LE}]'
              history: 1h
              value_type: FLOAT
              trends: '0'
              discover: NO_DISCOVER
              description: 'Binding latency in seconds.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'scheduler_binding_duration_seconds_bucket{le = "{#LE}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kubernetes.scheduler.get_metrics
              tags:
                - tag: component
                  value: binding
            - uuid: 5f40c030c1964ff7ab7786cee97bee81
              name: 'Binding duration, p50'
              type: CALCULATED
              key: 'kubernetes.scheduler.binding_duration_p50[{#SINGLETON}]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kubernetes.scheduler.binding_duration[*],5m,50)'
              description: '50 percentile of binding latency in seconds.'
              tags:
                - tag: component
                  value: binding
            - uuid: 19ba0e215a9f4e13b3079fcdaf124cc5
              name: 'Binding duration, p90'
              type: CALCULATED
              key: 'kubernetes.scheduler.binding_duration_p90[{#SINGLETON}]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kubernetes.scheduler.binding_duration[*],5m,90)'
              description: '90 percentile of binding latency in seconds.'
              tags:
                - tag: component
                  value: binding
            - uuid: b24d657a1568437fac77535a80d63bc3
              name: 'Binding duration, p95'
              type: CALCULATED
              key: 'kubernetes.scheduler.binding_duration_p95[{#SINGLETON}]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kubernetes.scheduler.binding_duration[*],5m,95)'
              description: '99 percentile of binding latency in seconds.'
              tags:
                - tag: component
                  value: binding
            - uuid: 258d5d4b6534488a92ba29185e3ca56f
              name: 'Binding duration, p99'
              type: CALCULATED
              key: 'kubernetes.scheduler.binding_duration_p99[{#SINGLETON}]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kubernetes.scheduler.binding_duration[*],5m,99)'
              description: '95 percentile of binding latency in seconds.'
              tags:
                - tag: component
                  value: binding
          graph_prototypes:
            - uuid: 1c8da2cb32ae4dfaa0d16cff0cecfc43
              name: 'Kubernetes Scheduler: [{#SINGLETON}]Binding latency'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'Kubernetes Scheduler by HTTP'
                    key: 'kubernetes.scheduler.binding_duration_p50[{#SINGLETON}]'
                - sortorder: '1'
                  color: F63100
                  item:
                    host: 'Kubernetes Scheduler by HTTP'
                    key: 'kubernetes.scheduler.binding_duration_p90[{#SINGLETON}]'
                - sortorder: '2'
                  color: 00611C
                  item:
                    host: 'Kubernetes Scheduler by HTTP'
                    key: 'kubernetes.scheduler.binding_duration_p95[{#SINGLETON}]'
                - sortorder: '3'
                  color: F7941D
                  item:
                    host: 'Kubernetes Scheduler by HTTP'
                    key: 'kubernetes.scheduler.binding_duration_p99[{#SINGLETON}]'
          master_item:
            key: kubernetes.scheduler.get_metrics
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - '{__name__=~ "scheduler_binding_duration_seconds_*"}'
            - type: JAVASCRIPT
              parameters:
                - |
                  var lookup = {},
                  	result = [];
                  JSON.parse(value).forEach(function (item) {
                  	if (item.name === "scheduler_binding_duration_seconds_count"){
                  		result.push({
                  			'{#TYPE}': 'totals',
                  			'{#SINGLETON}': ''
                  		});
                  
                  	  }
                  	else if  (item.name === "scheduler_binding_duration_seconds_bucket"){
                  		result.push({
                  			'{#TYPE}': 'buckets',
                  			'{#LE}': item.labels.le
                  		});
                  	}
                  });
                  
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
          overrides:
            - name: 'bucket item'
              step: '1'
              filter:
                conditions:
                  - macro: '{#TYPE}'
                    value: buckets
              operations:
                - operator: LIKE
                  value: bucket
                  discover: DISCOVER
            - name: 'total item'
              step: '2'
              filter:
                conditions:
                  - macro: '{#TYPE}'
                    value: totals
              operations:
                - operator: NOT_LIKE
                  value: bucket
                  discover: DISCOVER
        - uuid: 5d4a17f09a7e4ad3b4ac72c30bac5e7d
          name: 'Scheduling algorithm histogram'
          type: DEPENDENT
          key: kubernetes.scheduler.scheduling_algorithm.discovery
          description: 'Discovery raw data of scheduling algorithm latency.'
          item_prototypes:
            - uuid: c794f7fbd7494bb69d9c51140c443236
              name: 'Scheduling algorithm duration bucket, {#LE}'
              type: DEPENDENT
              key: 'kubernetes.scheduler.scheduling_algorithm_duration[{#LE}]'
              history: 1h
              value_type: FLOAT
              trends: '0'
              discover: NO_DISCOVER
              description: 'Scheduling algorithm latency in seconds.'
              preprocessing:
                - type: PROMETHEUS_PATTERN
                  parameters:
                    - 'scheduler_scheduling_algorithm_duration_seconds_bucket{le = "{#LE}"}'
                    - value
                    - ''
                  error_handler: DISCARD_VALUE
              master_item:
                key: kubernetes.scheduler.get_metrics
              tags:
                - tag: component
                  value: scheduling-algorithm
            - uuid: 3df35ee6e86a424f89f51bb74cb40b9d
              name: 'Scheduling algorithm duration, p50'
              type: CALCULATED
              key: 'kubernetes.scheduler.scheduling_algorithm_duration_p50[{#SINGLETON}]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kubernetes.scheduler.scheduling_algorithm_duration[*],5m,50)'
              description: '50 percentile of scheduling algorithm latency in seconds.'
              tags:
                - tag: component
                  value: scheduling-algorithm
            - uuid: 2368f2c98f3641bdbd030d94ca53a4dd
              name: 'Scheduling algorithm duration, p90'
              type: CALCULATED
              key: 'kubernetes.scheduler.scheduling_algorithm_duration_p90[{#SINGLETON}]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kubernetes.scheduler.scheduling_algorithm_duration[*],5m,90)'
              description: '90 percentile of scheduling algorithm latency in seconds.'
              tags:
                - tag: component
                  value: scheduling-algorithm
            - uuid: 6ca6a2480c4343a8b9a4e6598ec86501
              name: 'Scheduling algorithm duration, p95'
              type: CALCULATED
              key: 'kubernetes.scheduler.scheduling_algorithm_duration_p95[{#SINGLETON}]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kubernetes.scheduler.scheduling_algorithm_duration[*],5m,95)'
              description: '95 percentile of scheduling algorithm latency in seconds.'
              tags:
                - tag: component
                  value: scheduling-algorithm
            - uuid: 955f0989372c4f9d82ad364b09f5efea
              name: 'Scheduling algorithm duration, p99'
              type: CALCULATED
              key: 'kubernetes.scheduler.scheduling_algorithm_duration_p99[{#SINGLETON}]'
              value_type: FLOAT
              discover: NO_DISCOVER
              units: s
              params: 'bucket_percentile(//kubernetes.scheduler.scheduling_algorithm_duration[*],5m,99)'
              description: '99 percentile of scheduling algorithm latency in seconds.'
              tags:
                - tag: component
                  value: scheduling-algorithm
          graph_prototypes:
            - uuid: 94607df22a1c49e5aa290fd50e9c2238
              name: 'Kubernetes Scheduler: [{#SINGLETON}]Scheduling algorithm duration'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'Kubernetes Scheduler by HTTP'
                    key: 'kubernetes.scheduler.scheduling_algorithm_duration_p50[{#SINGLETON}]'
                - sortorder: '1'
                  color: F63100
                  item:
                    host: 'Kubernetes Scheduler by HTTP'
                    key: 'kubernetes.scheduler.scheduling_algorithm_duration_p90[{#SINGLETON}]'
                - sortorder: '2'
                  color: 00611C
                  item:
                    host: 'Kubernetes Scheduler by HTTP'
                    key: 'kubernetes.scheduler.scheduling_algorithm_duration_p95[{#SINGLETON}]'
                - sortorder: '3'
                  color: F7941D
                  item:
                    host: 'Kubernetes Scheduler by HTTP'
                    key: 'kubernetes.scheduler.scheduling_algorithm_duration_p99[{#SINGLETON}]'
          master_item:
            key: kubernetes.scheduler.get_metrics
          preprocessing:
            - type: PROMETHEUS_TO_JSON
              parameters:
                - '{__name__=~ "scheduler_scheduling_algorithm_duration_seconds_*"}'
            - type: JAVASCRIPT
              parameters:
                - |
                  var lookup = {},
                  	result = [];
                  JSON.parse(value).forEach(function (item) {
                  	if (item.name === "scheduler_scheduling_algorithm_duration_seconds_count"){
                  		result.push({
                  			'{#TYPE}': 'totals',
                  			'{#SINGLETON}': ''
                  		});
                  
                  	  }
                  	else if  (item.name === "scheduler_scheduling_algorithm_duration_seconds_bucket"){
                  		result.push({
                  			'{#TYPE}': 'buckets',
                  			'{#LE}': item.labels.le
                  		});
                  	}
                  });
                  
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
          overrides:
            - name: 'bucket item'
              step: '1'
              filter:
                conditions:
                  - macro: '{#TYPE}'
                    value: buckets
              operations:
                - operator: LIKE
                  value: bucket
                  discover: DISCOVER
            - name: 'total item'
              step: '2'
              filter:
                conditions:
                  - macro: '{#TYPE}'
                    value: totals
              operations:
                - operator: NOT_LIKE
                  value: bucket
                  discover: DISCOVER
      tags:
        - tag: class
          value: software
        - tag: subclass
          value: automation
        - tag: subclass
          value: containers
        - tag: subclass
          value: deploy
        - tag: subclass
          value: development
        - tag: subclass
          value: virtualization
        - tag: target
          value: kubernetes
        - tag: target
          value: scheduler
      macros:
        - macro: '{$KUBE.API.TOKEN}'
          type: SECRET_TEXT
          description: 'API Authorization Token.'
          config:
            type: TEXT
            priority: '1'
            label: 'API Authorization Token'
            description: 'Token used for API authorization.'
            required: 'YES'
        - macro: '{$KUBE.SCHEDULER.ERROR}'
          value: '2'
          description: 'Maximum number of scheduling failures with ''error'' used for trigger.'
          config:
            type: TEXT
            priority: '5'
            section_name: Thresholds
            label: 'Scheduling error threshold'
            description: 'Maximum number of scheduling failures with errors allowed before triggering an alert. No less than 0.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$KUBE.SCHEDULER.HTTP.CLIENT.ERROR}'
          value: '2'
          description: 'Maximum number of HTTP client requests failures used for trigger.'
          config:
            type: TEXT
            priority: '3'
            label: 'HTTP client error threshold'
            description: 'Maximum number of HTTP client request failures allowed before triggering an alert. No less than 0.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$KUBE.SCHEDULER.SERVER.URL}'
          value: 'https://localhost:10259/metrics'
          description: 'Kubernetes Scheduler metrics endpoint URL.'
          config:
            type: TEXT
            priority: '2'
            label: 'Scheduler metrics endpoint URL'
            description: 'URL to access Kubernetes Scheduler metrics.'
        - macro: '{$KUBE.SCHEDULER.UNSCHEDULABLE}'
          value: '2'
          description: 'Maximum number of scheduling failures with ''unschedulable'' used for trigger.'
          config:
            type: TEXT
            priority: '4'
            section_name: Thresholds
            label: 'Unschedulable scheduling failures threshold'
            description: 'Maximum number of unschedulable scheduling failures allowed before triggering an alert. No less than 0.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
      dashboards:
        - uuid: 2292bfff871944bda9471a2ea714d04e
          name: 'Scheduler overview'
          pages:
            - name: General
              widgets:
                - type: graph
                  width: '72'
                  height: '5'
                  fields:
                    - type: GRAPH
                      name: graphid.0
                      value:
                        host: 'Kubernetes Scheduler by HTTP'
                        name: 'Kubernetes Scheduler: Memory usage'
                    - type: STRING
                      name: reference
                      value: AAAAA
                - type: graph
                  'y': '5'
                  width: '72'
                  height: '5'
                  fields:
                    - type: GRAPH
                      name: graphid.0
                      value:
                        host: 'Kubernetes Scheduler by HTTP'
                        name: 'Kubernetes Scheduler: REST Client query rate'
                    - type: STRING
                      name: reference
                      value: AAAAB
                - type: graph
                  'y': '10'
                  width: '72'
                  height: '5'
                  fields:
                    - type: GRAPH
                      name: graphid.0
                      value:
                        host: 'Kubernetes Scheduler by HTTP'
                        name: 'Kubernetes Scheduler: Scheduling attempts rate'
                    - type: STRING
                      name: reference
                      value: AAAAC
            - name: Latencies
              widgets:
                - type: graphprototype
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'Kubernetes Scheduler by HTTP'
                        name: 'Kubernetes Scheduler: [{#SINGLETON}]Binding latency'
                    - type: STRING
                      name: reference
                      value: AAAAD
                - type: graphprototype
                  'y': '5'
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'Kubernetes Scheduler by HTTP'
                        name: 'Kubernetes Scheduler: ["{#RESULT}"] E2e latency'
                    - type: STRING
                      name: reference
                      value: AAAAE
                - type: graphprototype
                  'y': '10'
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'Kubernetes Scheduler by HTTP'
                        name: 'Kubernetes Scheduler: [{#SINGLETON}]Scheduling algorithm duration'
                    - type: STRING
                      name: reference
                      value: AAAAF
    - uuid: 13d5bb0a4ae84228bff408aab5be338e
      template: 'Nginx by HTTP'
      name: 'Nginx by HTTP'
      description: |
        This template is developed to monitor Nginx by Zabbix that works without any external scripts.
        Most of the metrics are collected in one go, thanks to Zabbix bulk data collection.
        
        The template collects metrics by polling the module 'ngx_http_stub_status_module' with HTTP agent remotely:
        https://nginx.ru/en/docs/http/ngx_http_stub_status_module.html
        
        Active connections: 291
        server accepts handled requests
        16630948 16630948 31070465
        Reading: 6 Writing: 179 Waiting: 106
        
        Setup:
        
        1. See the setup instructions for 'ngx_http_stub_status_module':
        https://nginx.ru/en/docs/http/ngx_http_stub_status_module.html
        
        Test the availability of the 'http_stub_status_module' with 'nginx -V 2>&1 | grep -o with-http_stub_status_module'.
        
        Example configuration of Nginx:
        
        location = /basic_status {
            stub_status;
            allow <IP of your Zabbix server/proxy>;
            deny all;
        }
        
        2. Set the hostname or IP address of the Nginx host or Nginx container in the '{$NGINX.STUB_STATUS.HOST}' macro. You can also change the status page port in the '{$NGINX.STUB_STATUS.PORT}' macro, the status page scheme in the '{$NGINX.STUB_STATUS.SCHEME}' macro and the status page path in the '{$NGINX.STUB_STATUS.PATH}' macro if necessary.
        
        You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/384765-discussion-thread-for-official-zabbix-template-nginx
        
        Generated by official Zabbix template tool "Templator"
      wizard_ready: 'YES'
      readme: |
        ## Overview
        
        This template is developed to monitor Nginx by Zabbix that works without any external scripts.
        Most of the metrics are collected in one go, thanks to Zabbix bulk data collection.
        
        The template collects metrics by polling the module [`ngx_http_stub_status_module`](https://nginx.ru/en/docs/http/ngx_http_stub_status_module.html) with HTTP agent remotely:
        
        ```text
        Active connections: 291
        server accepts handled requests
        16630948 16630948 31070465
        Reading: 6 Writing: 179 Waiting: 106
        ```
        
        ## Setup
        
        1. See the setup instructions for [`ngx_http_stub_status_module`](https://nginx.ru/en/docs/http/ngx_http_stub_status_module.html).
        
        Test the availability of the `http_stub_status_module` with `nginx -V 2>&1 | grep -o with-http_stub_status_module`.
        
        Example configuration of Nginx:
        
        ```text
        location = /basic_status {
            stub_status;
            allow <IP of your Zabbix server/proxy>;
            deny all;
        }
        ```
        
        2. Set the hostname or IP address of the Nginx host or Nginx container in the `Nginx status host` host wizard configuration field. You can also change the status page port in the `Nginx status page path` field, select the status page scheme in the `Request scheme` field and change the status page path in the `Nginx status page path` field if necessary.
        
        Example answer from Nginx:
        
        ```text
        Active connections: 291
        server accepts handled requests
        16630948 16630948 31070465
        Reading: 6 Writing: 179 Waiting: 106
        ```
      vendor:
        name: Zabbix
        version: 7.4-1
      groups:
        - name: Templates/Applications
      items:
        - uuid: 18c6209295b347e2a96ef11b147139d8
          name: 'Service response time'
          type: SIMPLE
          key: 'net.tcp.service.perf[http,"{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PORT}"]'
          value_type: FLOAT
          units: s
          tags:
            - tag: component
              value: application
            - tag: component
              value: health
          triggers:
            - uuid: fc1f7927b8864996986c1da44df57279
              expression: 'min(/Nginx by HTTP/net.tcp.service.perf[http,"{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PORT}"],5m)>{$NGINX.RESPONSE_TIME.MAX.WARN}'
              name: 'Nginx: Service response time is too high'
              event_name: 'Nginx: Service response time is too high (over {$NGINX.RESPONSE_TIME.MAX.WARN}s for 5m)'
              priority: WARNING
              manual_close: 'YES'
              dependencies:
                - name: 'Nginx: Service is down'
                  expression: 'last(/Nginx by HTTP/net.tcp.service[http,"{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PORT}"])=0'
              tags:
                - tag: scope
                  value: performance
        - uuid: e4a09193bc8f42f2888ece83f89f84af
          name: 'Service status'
          type: SIMPLE
          key: 'net.tcp.service[http,"{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PORT}"]'
          valuemap:
            name: 'Service state'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 10m
          tags:
            - tag: component
              value: application
            - tag: component
              value: health
          triggers:
            - uuid: 7b3de87ba0ea425280d42235bb626b8b
              expression: 'last(/Nginx by HTTP/net.tcp.service[http,"{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PORT}"])=0'
              name: 'Nginx: Service is down'
              priority: AVERAGE
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: availability
        - uuid: e054b58ebbbe4b45961ba697b468ab9e
          name: 'Connections accepted per second'
          type: DEPENDENT
          key: nginx.connections.accepted.rate
          value_type: FLOAT
          description: 'The total number of accepted client connections.'
          preprocessing:
            - type: REGEX
              parameters:
                - 'server accepts handled requests\s+([0-9]+) ([0-9]+) ([0-9]+)'
                - \1
            - type: CHANGE_PER_SECOND
          master_item:
            key: nginx.get_stub_status
          tags:
            - tag: component
              value: connections
        - uuid: 2e4b049ab60947d9a05165f67388e531
          name: 'Connections active'
          type: DEPENDENT
          key: nginx.connections.active
          description: 'The current number of active client connections including waiting connections.'
          preprocessing:
            - type: REGEX
              parameters:
                - 'Active connections: ([0-9]+)'
                - \1
          master_item:
            key: nginx.get_stub_status
          tags:
            - tag: component
              value: connections
        - uuid: eecc0e887a744627be7f3b01cec6d46e
          name: 'Connections dropped per second'
          type: DEPENDENT
          key: nginx.connections.dropped.rate
          value_type: FLOAT
          description: 'The total number of dropped client connections.'
          preprocessing:
            - type: JAVASCRIPT
              parameters:
                - |
                  var a = value.match(/server accepts handled requests\s+([0-9]+) ([0-9]+) ([0-9]+)/)
                  if (a) {
                  	return a[1]-a[2]
                  }
            - type: CHANGE_PER_SECOND
          master_item:
            key: nginx.get_stub_status
          tags:
            - tag: component
              value: connections
          triggers:
            - uuid: 79767fbc18594069a1fc0cbec832f8ff
              expression: 'min(/Nginx by HTTP/nginx.connections.dropped.rate,5m) > {$NGINX.DROP_RATE.MAX.WARN}'
              name: 'Nginx: High connections drop rate'
              event_name: 'Nginx: High connections drop rate (more than {$NGINX.DROP_RATE.MAX.WARN} for 5m)'
              opdata: 'Current rate: {ITEM.LASTVALUE1}'
              priority: WARNING
              description: 'The rate of dropping connections has been greater than {$NGINX.DROP_RATE.MAX.WARN} for the last 5 minutes.'
              dependencies:
                - name: 'Nginx: Service is down'
                  expression: 'last(/Nginx by HTTP/net.tcp.service[http,"{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PORT}"])=0'
              tags:
                - tag: scope
                  value: performance
        - uuid: a53cf4f2d2ad4a84a70ff57df6299adc
          name: 'Connections handled per second'
          type: DEPENDENT
          key: nginx.connections.handled.rate
          value_type: FLOAT
          description: 'The total number of handled connections. Generally, the parameter value is the same as for the accepted connections, unless some resource limits have been reached (for example, the `worker_connections limit`).'
          preprocessing:
            - type: REGEX
              parameters:
                - 'server accepts handled requests\s+([0-9]+) ([0-9]+) ([0-9]+)'
                - \2
            - type: CHANGE_PER_SECOND
          master_item:
            key: nginx.get_stub_status
          tags:
            - tag: component
              value: connections
        - uuid: 73493cbf8508419a8fed3abff8cc5851
          name: 'Connections reading'
          type: DEPENDENT
          key: nginx.connections.reading
          description: 'The current number of connections where Nginx is reading the request header.'
          preprocessing:
            - type: REGEX
              parameters:
                - 'Reading: ([0-9]+) Writing: ([0-9]+) Waiting: ([0-9]+)'
                - \1
          master_item:
            key: nginx.get_stub_status
          tags:
            - tag: component
              value: connections
        - uuid: cf393814511a48b498da8aab94d7ca00
          name: 'Connections waiting'
          type: DEPENDENT
          key: nginx.connections.waiting
          description: 'The current number of idle client connections waiting for a request.'
          preprocessing:
            - type: REGEX
              parameters:
                - 'Reading: ([0-9]+) Writing: ([0-9]+) Waiting: ([0-9]+)'
                - \3
          master_item:
            key: nginx.get_stub_status
          tags:
            - tag: component
              value: connections
        - uuid: b0d63efb16984042945fe42e192f7d4e
          name: 'Connections writing'
          type: DEPENDENT
          key: nginx.connections.writing
          description: 'The current number of connections where Nginx is writing a response back to the client.'
          preprocessing:
            - type: REGEX
              parameters:
                - 'Reading: ([0-9]+) Writing: ([0-9]+) Waiting: ([0-9]+)'
                - \2
          master_item:
            key: nginx.get_stub_status
          tags:
            - tag: component
              value: connections
        - uuid: 86f93d1941d147fe94d754eddd3e8ff2
          name: 'Get stub status page'
          type: HTTP_AGENT
          key: nginx.get_stub_status
          history: 1h
          value_type: TEXT
          description: |
            The following status information is provided:
            `Active connections` - the current number of active client connections including waiting connections.
            `Accepted` - the total number of accepted client connections.
            `Handled` - the total number of handled connections. Generally, the parameter value is the same as for the accepted connections, unless some resource limits have been reached (for example, the `worker_connections` limit).
            `Requests` - the total number of client requests.
            `Reading` - the current number of connections where Nginx is reading the request header.
            `Writing` - the current number of connections where Nginx is writing a response back to the client.
            `Waiting` - the current number of idle client connections waiting for a request.
            
            See also [Module ngx_http_stub_status_module](https://nginx.org/en/docs/http/ngx_http_stub_status_module.html).
          url: '{$NGINX.STUB_STATUS.SCHEME}://{$NGINX.STUB_STATUS.HOST}:{$NGINX.STUB_STATUS.PORT}/{$NGINX.STUB_STATUS.PATH}'
          retrieve_mode: BOTH
          tags:
            - tag: component
              value: application
            - tag: component
              value: health
          triggers:
            - uuid: 78e0a6322a1941469a0e108a9367c420
              expression: |
                find(/Nginx by HTTP/nginx.get_stub_status,,"iregexp","HTTP\\/[\\d.]+\\s+200")=0 or
                nodata(/Nginx by HTTP/nginx.get_stub_status,30m)=1
              name: 'Nginx: Failed to fetch stub status page'
              event_name: 'Nginx: Failed to fetch stub status page (or no data for 30m)'
              priority: WARNING
              description: 'Zabbix has not received any data for items for the last 30 minutes.'
              manual_close: 'YES'
              dependencies:
                - name: 'Nginx: Service is down'
                  expression: 'last(/Nginx by HTTP/net.tcp.service[http,"{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PORT}"])=0'
              tags:
                - tag: scope
                  value: availability
        - uuid: 071b3d77324740a59045be19da231d76
          name: 'Requests total'
          type: DEPENDENT
          key: nginx.requests.total
          description: 'The total number of client requests.'
          preprocessing:
            - type: REGEX
              parameters:
                - 'server accepts handled requests\s+([0-9]+) ([0-9]+) ([0-9]+)'
                - \3
          master_item:
            key: nginx.get_stub_status
          tags:
            - tag: component
              value: requests
        - uuid: 81b17056ec664f9f926a74ee390ab9c1
          name: 'Requests per second'
          type: DEPENDENT
          key: nginx.requests.total.rate
          value_type: FLOAT
          description: 'The total number of client requests.'
          preprocessing:
            - type: REGEX
              parameters:
                - 'server accepts handled requests\s+([0-9]+) ([0-9]+) ([0-9]+)'
                - \3
            - type: CHANGE_PER_SECOND
          master_item:
            key: nginx.get_stub_status
          tags:
            - tag: component
              value: requests
        - uuid: 716b627d6d894ac2af3ae8c4aeaa8c0c
          name: Version
          type: DEPENDENT
          key: nginx.version
          value_type: CHAR
          preprocessing:
            - type: REGEX
              parameters:
                - '(?i)Server: nginx\/(.+(?<!\r))'
                - \1
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: nginx.get_stub_status
          tags:
            - tag: component
              value: application
          triggers:
            - uuid: 0f2689d4967a446e98a107b933179817
              expression: 'last(/Nginx by HTTP/nginx.version,#1)<>last(/Nginx by HTTP/nginx.version,#2) and length(last(/Nginx by HTTP/nginx.version))>0'
              name: 'Nginx: Version has changed'
              event_name: 'Nginx: Version has changed (new version: {ITEM.VALUE})'
              priority: INFO
              description: 'The Nginx version has changed. Acknowledge to close the problem manually.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
      tags:
        - tag: class
          value: software
        - tag: subclass
          value: webserver
        - tag: target
          value: nginx
      macros:
        - macro: '{$NGINX.DROP_RATE.MAX.WARN}'
          value: '1'
          description: 'The critical rate of the dropped connections for a trigger expression.'
          config:
            type: TEXT
            priority: '6'
            section_name: Thresholds
            label: 'Critical rate of the dropped connections'
            description: 'Critical rate of the dropped connections for a trigger expression. No less than 0.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$NGINX.RESPONSE_TIME.MAX.WARN}'
          value: '10'
          description: 'The maximum response time of Nginx expressed in seconds for a trigger expression.'
          config:
            type: TEXT
            priority: '5'
            section_name: Thresholds
            label: 'Maximum Nginx response time'
            description: 'Maximum response time of Nginx expressed in seconds for a trigger expression. No less than 0.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$NGINX.STUB_STATUS.HOST}'
          description: 'The hostname or IP address of the Nginx host or Nginx container of a stub_status.'
          config:
            type: TEXT
            priority: '1'
            label: 'Nginx status host'
            description: 'Hostname or IP address of the Nginx host or Nginx container of a stub_status.'
            required: 'YES'
        - macro: '{$NGINX.STUB_STATUS.PATH}'
          value: basic_status
          description: 'The path of the `Nginx stub_status` page.'
          config:
            type: TEXT
            priority: '3'
            label: 'Nginx status page path'
            description: 'Path of the `Nginx stub_status` page.'
            required: 'YES'
        - macro: '{$NGINX.STUB_STATUS.PORT}'
          value: '80'
          description: 'The port of the `Nginx stub_status` host or container.'
          config:
            type: TEXT
            priority: '4'
            label: 'Nginx status page port'
            description: 'Port of the `Nginx stub_status` host or container. In the range from 1 to 65535 inclusive.'
            required: 'YES'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$NGINX.STUB_STATUS.SCHEME}'
          value: http
          description: 'The protocol http or https of Nginx stub_status host or container.'
          config:
            type: LIST
            priority: '2'
            label: 'Request scheme'
            description: 'Protocol of Nginx stub_status host or container.'
            required: 'YES'
            options:
              - value: http
                text: HTTP
              - value: https
                text: HTTPS
      dashboards:
        - uuid: 7d0bf76f09204bb7ba9ee995bf161d46
          name: 'Nginx performance'
          pages:
            - widgets:
                - type: graph
                  width: '36'
                  height: '5'
                  fields:
                    - type: GRAPH
                      name: graphid.0
                      value:
                        host: 'Nginx by HTTP'
                        name: 'Nginx: Connections by state'
                    - type: STRING
                      name: reference
                      value: AAAAA
                - type: graph
                  'y': '5'
                  width: '36'
                  height: '5'
                  fields:
                    - type: GRAPH
                      name: graphid.0
                      value:
                        host: 'Nginx by HTTP'
                        name: 'Nginx: Connections per second'
                    - type: STRING
                      name: reference
                      value: AAAAC
                - type: graph
                  x: '36'
                  width: '36'
                  height: '5'
                  fields:
                    - type: GRAPH
                      name: graphid.0
                      value:
                        host: 'Nginx by HTTP'
                        name: 'Nginx: Requests per second'
                    - type: STRING
                      name: reference
                      value: AAAAB
      valuemaps:
        - uuid: 5c0883d194e8494498474106c22be2ca
          name: 'Service state'
          mappings:
            - value: '0'
              newvalue: Down
            - value: '1'
              newvalue: Up
    - uuid: 27f6424905884dbb96ab9210d987a56c
      template: 'Nginx by Zabbix agent'
      name: 'Nginx by Zabbix agent'
      description: |
        Get metrics from stub status module using Zabbix agent running on Linux
        https://nginx.ru/en/docs/http/ngx_http_stub_status_module.html
        
        You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/384765-discussion-thread-for-official-zabbix-template-nginx
        
        Generated by official Zabbix template tool "Templator"
      wizard_ready: 'YES'
      readme: |
        ## Overview
        
        This template is developed to monitor Nginx by Zabbix that works without any external scripts.
        Most of the metrics are collected in one go, thanks to Zabbix bulk data collection.
        
        The template `Nginx by Zabbix agent` - collects metrics by polling the [Module ngx_http_stub_status_module](https://nginx.ru/en/docs/http/ngx_http_stub_status_module.html) locally with Zabbix agent:
        
        ```text
        Active connections: 291
        server accepts handled requests
        16630948 16630948 31070465
        Reading: 6 Writing: 179 Waiting: 106
        ```
        
        Note that this template doesn't support HTTPS and redirects (limitations of `web.page.get`).
        
        It also uses Zabbix agent to collect `Nginx` Linux process statistics, such as CPU usage, memory usage and whether the process is running or not.
        
        
        ## Setup
        
        See the setup instructions for [ngx_http_stub_status_module](https://nginx.ru/en/docs/http/ngx_http_stub_status_module.html).
        Test the availability of the `http_stub_status_module` `nginx -V 2>&1 | grep -o with-http_stub_status_module`.
        
        Example configuration of Nginx:
        ```text
        location = /basic_status {
            stub_status;
            allow 127.0.0.1;
            allow ::1;
            deny all;
        }
        ```
        
        If you use another location, then don't forget to change the `Nginx status page path` host wizard configuration field.
        
        Example answer from Nginx:
        ```text
        Active connections: 291
        server accepts handled requests
        16630948 16630948 31070465
        Reading: 6 Writing: 179 Waiting: 106
        ```
        
        Note that this template doesn't support https and redirects (limitations of web.page.get).
      vendor:
        name: Zabbix
        version: 7.4-1
      groups:
        - name: Templates/Applications
      items:
        - uuid: 75a7795df3034835bcfd143f7c3e9b94
          name: 'Service response time'
          key: 'net.tcp.service.perf[http,"{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PORT}"]'
          value_type: FLOAT
          units: s
          tags:
            - tag: component
              value: application
            - tag: component
              value: health
        - uuid: f06e76888f464e13b7cc4c3db33e8131
          name: 'Service status'
          key: 'net.tcp.service[http,"{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PORT}"]'
          valuemap:
            name: 'Service state'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 10m
          tags:
            - tag: component
              value: application
            - tag: component
              value: health
        - uuid: 9e2be446ac79491c8be1bcd789392066
          name: 'Connections accepted per second'
          type: DEPENDENT
          key: nginx.connections.accepted.rate
          value_type: FLOAT
          description: 'The total number of accepted client connections.'
          preprocessing:
            - type: REGEX
              parameters:
                - 'server accepts handled requests\s+([0-9]+) ([0-9]+) ([0-9]+)'
                - \1
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"]'
          tags:
            - tag: component
              value: connections
        - uuid: 436f2dc87cda418eb8f19ed6910c7bd0
          name: 'Connections active'
          type: DEPENDENT
          key: nginx.connections.active
          description: 'The current number of active client connections including waiting connections.'
          preprocessing:
            - type: REGEX
              parameters:
                - 'Active connections: ([0-9]+)'
                - \1
          master_item:
            key: 'web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"]'
          tags:
            - tag: component
              value: connections
        - uuid: 4027e6db5e024aff98056faa2d4b43cd
          name: 'Connections dropped per second'
          type: DEPENDENT
          key: nginx.connections.dropped.rate
          value_type: FLOAT
          description: 'The total number of dropped client connections.'
          preprocessing:
            - type: JAVASCRIPT
              parameters:
                - |
                  var a = value.match(/server accepts handled requests\s+([0-9]+) ([0-9]+) ([0-9]+)/)
                  if (a) {
                  	return a[1]-a[2]
                  }
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"]'
          tags:
            - tag: component
              value: connections
        - uuid: 06191636a7104e1bb40d197493b80958
          name: 'Connections handled per second'
          type: DEPENDENT
          key: nginx.connections.handled.rate
          value_type: FLOAT
          description: 'The total number of handled connections. Generally, the parameter value is the same as for the accepted connections, unless some resource limits have been reached (for example, the `worker_connections limit`).'
          preprocessing:
            - type: REGEX
              parameters:
                - 'server accepts handled requests\s+([0-9]+) ([0-9]+) ([0-9]+)'
                - \2
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"]'
          tags:
            - tag: component
              value: connections
        - uuid: f5925c78389143c7924432483a5c716c
          name: 'Connections reading'
          type: DEPENDENT
          key: nginx.connections.reading
          description: 'The current number of connections where Nginx is reading the request header.'
          preprocessing:
            - type: REGEX
              parameters:
                - 'Reading: ([0-9]+) Writing: ([0-9]+) Waiting: ([0-9]+)'
                - \1
          master_item:
            key: 'web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"]'
          tags:
            - tag: component
              value: connections
        - uuid: d6cfa828ba344ffe948d8d985b849316
          name: 'Connections waiting'
          type: DEPENDENT
          key: nginx.connections.waiting
          description: 'The current number of idle client connections waiting for a request.'
          preprocessing:
            - type: REGEX
              parameters:
                - 'Reading: ([0-9]+) Writing: ([0-9]+) Waiting: ([0-9]+)'
                - \3
          master_item:
            key: 'web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"]'
          tags:
            - tag: component
              value: connections
        - uuid: c038a572f73f4a418ddcc5aeb8b0a547
          name: 'Connections writing'
          type: DEPENDENT
          key: nginx.connections.writing
          description: 'The current number of connections where Nginx is writing a response back to the client.'
          preprocessing:
            - type: REGEX
              parameters:
                - 'Reading: ([0-9]+) Writing: ([0-9]+) Waiting: ([0-9]+)'
                - \2
          master_item:
            key: 'web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"]'
          tags:
            - tag: component
              value: connections
        - uuid: b28444fb9b834d03a72036882c80b921
          name: 'Requests total'
          type: DEPENDENT
          key: nginx.requests.total
          description: 'The total number of client requests.'
          preprocessing:
            - type: REGEX
              parameters:
                - 'server accepts handled requests\s+([0-9]+) ([0-9]+) ([0-9]+)'
                - \3
          master_item:
            key: 'web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"]'
          tags:
            - tag: component
              value: requests
        - uuid: 2600a696278f490f86cadd8c8836f269
          name: 'Requests per second'
          type: DEPENDENT
          key: nginx.requests.total.rate
          value_type: FLOAT
          description: 'The total number of client requests.'
          preprocessing:
            - type: REGEX
              parameters:
                - 'server accepts handled requests\s+([0-9]+) ([0-9]+) ([0-9]+)'
                - \3
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"]'
          tags:
            - tag: component
              value: requests
        - uuid: 3dcc81006977478f92be6dd040d66eb5
          name: Version
          type: DEPENDENT
          key: nginx.version
          value_type: CHAR
          preprocessing:
            - type: REGEX
              parameters:
                - '(?i)Server: nginx\/(.+(?<!\r))'
                - \1
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: 'web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"]'
          tags:
            - tag: component
              value: application
          triggers:
            - uuid: 7ad80c508f2f48b59f7659c673db9f36
              expression: 'last(/Nginx by Zabbix agent/nginx.version,#1)<>last(/Nginx by Zabbix agent/nginx.version,#2) and length(last(/Nginx by Zabbix agent/nginx.version))>0'
              name: 'Nginx: Version has changed'
              event_name: 'Nginx: Version has changed (new version: {ITEM.VALUE})'
              priority: INFO
              description: 'The Nginx version has changed. Acknowledge to close the problem manually.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: d43b4b99b6084076a4feb1fde51ecc40
          name: 'Get processes summary'
          key: 'proc.get[{$NGINX.PROCESS.NAME.PARAMETER},,,summary]'
          history: '0'
          value_type: TEXT
          description: 'The aggregated data of summary metrics for all processes.'
          tags:
            - tag: component
              value: raw
        - uuid: 52a23a9f6d60490c8f5565b938154f61
          name: 'Get stub status page'
          key: 'web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"]'
          history: 1h
          value_type: TEXT
          description: |
            The following status information is provided:
            `Active connections` - the current number of active client connections including waiting connections.
            `Accepted` - the total number of accepted client connections.
            `Handled` - the total number of handled connections. Generally, the parameter value is the same as for the accepted connections, unless some resource limits have been reached (for example, the `worker_connections` limit).
            `Requests` - the total number of client requests.
            `Reading` - the current number of connections where Nginx is reading the request header.
            `Writing` - the current number of connections where Nginx is writing a response back to the client.
            `Waiting` - the current number of idle client connections waiting for a request.
            
            See also [Module ngx_http_stub_status_module](https://nginx.org/en/docs/http/ngx_http_stub_status_module.html).
          tags:
            - tag: component
              value: application
            - tag: component
              value: health
      discovery_rules:
        - uuid: f4a898f929c54b3493506e68703fa2cc
          name: 'Nginx process discovery'
          type: DEPENDENT
          key: nginx.proc.discovery
          filter:
            evaltype: AND
            conditions:
              - macro: '{#NGINX.NAME}'
                value: '{$NGINX.PROCESS_NAME}'
          description: 'The discovery of Nginx process summary.'
          item_prototypes:
            - uuid: 632e441011674f04886096475180dcbb
              name: 'Get process data'
              type: DEPENDENT
              key: 'nginx.proc.get[{#NGINX.NAME}]'
              history: '0'
              value_type: TEXT
              description: 'The summary metrics aggregated by a process {#NGINX.NAME}.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[?(@["name"]=="{#NGINX.NAME}")].first()'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: 'Failed to retrieve process {#NGINX.NAME} data'
              master_item:
                key: 'proc.get[{$NGINX.PROCESS.NAME.PARAMETER},,,summary]'
              tags:
                - tag: component
                  value: raw
            - uuid: ba3da6baccee4b31947bf20d3cae0e5f
              name: 'Number of running processes'
              type: DEPENDENT
              key: 'nginx.proc.num[{#NGINX.NAME}]'
              description: 'The number of running processes {#NGINX.NAME}.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.processes
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '0'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'nginx.proc.get[{#NGINX.NAME}]'
              tags:
                - tag: component
                  value: system
              trigger_prototypes:
                - uuid: 903e6a1f30154ee49df3f8d87e0164cc
                  expression: 'last(/Nginx by Zabbix agent/nginx.proc.num[{#NGINX.NAME}])=0'
                  name: 'Nginx: Process is not running'
                  priority: HIGH
                  tags:
                    - tag: scope
                      value: availability
            - uuid: 5887d0062bed4233a03d4f408fac7163
              name: 'Memory usage, %'
              type: DEPENDENT
              key: 'nginx.proc.pmem[{#NGINX.NAME}]'
              value_type: FLOAT
              units: '%'
              description: 'The percentage of real memory used by a process {#NGINX.NAME}.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.pmem
                  error_handler: DISCARD_VALUE
              master_item:
                key: 'nginx.proc.get[{#NGINX.NAME}]'
              tags:
                - tag: component
                  value: memory
            - uuid: 64d208475c034bae953a64cde1833ebb
              name: 'Memory usage (rss)'
              type: DEPENDENT
              key: 'nginx.proc.rss[{#NGINX.NAME}]'
              units: B
              description: 'The summary of resident set size memory used by a process {#NGINX.NAME} expressed in bytes.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.rss
                  error_handler: DISCARD_VALUE
              master_item:
                key: 'nginx.proc.get[{#NGINX.NAME}]'
              tags:
                - tag: component
                  value: memory
            - uuid: 21fccb0286fb407c85f1972e994c698e
              name: 'Memory usage (vsize)'
              type: DEPENDENT
              key: 'nginx.proc.vmem[{#NGINX.NAME}]'
              units: B
              description: 'The summary of virtual memory used by a process {#NGINX.NAME} expressed in bytes.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.vsize
                  error_handler: DISCARD_VALUE
              master_item:
                key: 'nginx.proc.get[{#NGINX.NAME}]'
              tags:
                - tag: component
                  value: memory
            - uuid: 84c95c1955bf4ccaa12a060a9acdb478
              name: 'CPU utilization'
              key: 'proc.cpu.util[{#NGINX.NAME}]'
              value_type: FLOAT
              units: '%'
              description: 'The percentage of the CPU utilization by a process {#NGINX.NAME}.'
              tags:
                - tag: component
                  value: cpu
          trigger_prototypes:
            - uuid: a497b80eb03f469c9552881b498003b2
              expression: |
                (find(/Nginx by Zabbix agent/web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"],,"iregexp","HTTP\\/[\\d.]+\\s+200")=0 or
                nodata(/Nginx by Zabbix agent/web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"],30m)) and last(/Nginx by Zabbix agent/nginx.proc.num[{#NGINX.NAME}])>0
              name: 'Nginx: Failed to fetch stub status page'
              event_name: 'Nginx: Failed to fetch stub status page (or no data for 30m)'
              priority: WARNING
              description: 'Zabbix has not received any data for items for the last 30 minutes.'
              manual_close: 'YES'
              dependencies:
                - name: 'Nginx: Service is down'
                  expression: 'last(/Nginx by Zabbix agent/net.tcp.service[http,"{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PORT}"])=0 and last(/Nginx by Zabbix agent/nginx.proc.num[{#NGINX.NAME}])>0'
              tags:
                - tag: scope
                  value: availability
            - uuid: f2d431fa9bc446608caa3f80ef27c41b
              expression: 'min(/Nginx by Zabbix agent/nginx.connections.dropped.rate,5m) > {$NGINX.DROP_RATE.MAX.WARN} and last(/Nginx by Zabbix agent/nginx.proc.num[{#NGINX.NAME}])>0'
              name: 'Nginx: High connections drop rate'
              event_name: 'Nginx: High connections drop rate (more than {$NGINX.DROP_RATE.MAX.WARN} for 5m)'
              opdata: 'Current rate: {ITEM.LASTVALUE1}'
              priority: WARNING
              description: 'The rate of dropping connections has been greater than {$NGINX.DROP_RATE.MAX.WARN} for the last 5 minutes.'
              dependencies:
                - name: 'Nginx: Service is down'
                  expression: 'last(/Nginx by Zabbix agent/net.tcp.service[http,"{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PORT}"])=0 and last(/Nginx by Zabbix agent/nginx.proc.num[{#NGINX.NAME}])>0'
              tags:
                - tag: scope
                  value: performance
            - uuid: c043191c22f34522ba4f83430d9f88b1
              expression: 'last(/Nginx by Zabbix agent/net.tcp.service[http,"{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PORT}"])=0 and last(/Nginx by Zabbix agent/nginx.proc.num[{#NGINX.NAME}])>0'
              name: 'Nginx: Service is down'
              priority: AVERAGE
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: availability
            - uuid: f5db329410a14609a5f3e883ca493cc8
              expression: 'min(/Nginx by Zabbix agent/net.tcp.service.perf[http,"{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PORT}"],5m)>{$NGINX.RESPONSE_TIME.MAX.WARN} and last(/Nginx by Zabbix agent/nginx.proc.num[{#NGINX.NAME}])>0'
              name: 'Nginx: Service response time is too high'
              event_name: 'Nginx: Service response time is too high (over {$NGINX.RESPONSE_TIME.MAX.WARN}s for 5m)'
              priority: WARNING
              manual_close: 'YES'
              dependencies:
                - name: 'Nginx: Service is down'
                  expression: 'last(/Nginx by Zabbix agent/net.tcp.service[http,"{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PORT}"])=0 and last(/Nginx by Zabbix agent/nginx.proc.num[{#NGINX.NAME}])>0'
              tags:
                - tag: scope
                  value: performance
          graph_prototypes:
            - uuid: 69ca908afa1d468d983a263d06910925
              name: 'Nginx: Memory usage[{#NGINX.NAME}]'
              graph_items:
                - drawtype: BOLD_LINE
                  color: 199C0D
                  item:
                    host: 'Nginx by Zabbix agent'
                    key: 'nginx.proc.vmem[{#NGINX.NAME}]'
                - sortorder: '1'
                  drawtype: BOLD_LINE
                  color: F63100
                  item:
                    host: 'Nginx by Zabbix agent'
                    key: 'nginx.proc.rss[{#NGINX.NAME}]'
          master_item:
            key: 'proc.get[{$NGINX.PROCESS.NAME.PARAMETER},,,summary]'
          lld_macro_paths:
            - lld_macro: '{#NGINX.NAME}'
              path: $.name
      tags:
        - tag: class
          value: software
        - tag: subclass
          value: webserver
        - tag: target
          value: nginx
      macros:
        - macro: '{$NGINX.DROP_RATE.MAX.WARN}'
          value: '1'
          description: 'The critical rate of the dropped connections for a trigger expression.'
          config:
            type: TEXT
            priority: '7'
            section_name: Thresholds
            label: 'Critical rate of the dropped connections'
            description: 'Critical rate of the dropped connections for a trigger expression. No less than 0.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$NGINX.PROCESS.NAME.PARAMETER}'
          description: 'The process name of the Nginx server used in the item key `proc.get`. It could be specified if the correct process name is known.'
          config:
            type: TEXT
            priority: '5'
            label: 'Nginx process name'
            description: 'Process name of the Nginx server Used in the item key `proc.get`.'
        - macro: '{$NGINX.PROCESS_NAME}'
          value: nginx
          description: 'The process name filter for the Nginx process discovery.'
          config:
            type: TEXT
            priority: '4'
            section_name: Filters
            label: 'Nginx process name LLD filter'
            description: 'Process name filter for the Nginx process discovery.'
        - macro: '{$NGINX.RESPONSE_TIME.MAX.WARN}'
          value: '10'
          description: 'The maximum response time of Nginx expressed in seconds for a trigger expression.'
          config:
            type: TEXT
            priority: '6'
            section_name: Thresholds
            label: 'Maximum Nginx response time'
            description: 'Maximum response time of Nginx expressed in seconds for a trigger expression. No less than 0.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$NGINX.STUB_STATUS.HOST}'
          value: localhost
          description: 'The hostname or IP address of the Nginx host or Nginx container of `astub_status`.'
          config:
            type: TEXT
            priority: '1'
            label: 'Nginx status host'
            description: 'Hostname or IP address of the Nginx host or Nginx container of a stub_status.'
            required: 'YES'
        - macro: '{$NGINX.STUB_STATUS.PATH}'
          value: basic_status
          description: 'The path of the `Nginx stub_status` page.'
          config:
            type: TEXT
            priority: '2'
            label: 'Nginx status page path'
            description: 'Path of the `Nginx stub_status` page.'
            required: 'YES'
        - macro: '{$NGINX.STUB_STATUS.PORT}'
          value: '80'
          description: 'The port of the `Nginx stub_status` host or container.'
          config:
            type: TEXT
            priority: '3'
            label: 'Nginx status page port'
            description: 'Port of the `Nginx stub_status` host or container. In the range from 1 to 65535 inclusive.'
            required: 'YES'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
      dashboards:
        - uuid: 9d071e3a148c405e85c53ef25d54efaf
          name: 'Nginx performance'
          pages:
            - widgets:
                - type: graph
                  width: '36'
                  height: '5'
                  fields:
                    - type: GRAPH
                      name: graphid.0
                      value:
                        host: 'Nginx by Zabbix agent'
                        name: 'Nginx: Connections by state'
                    - type: STRING
                      name: reference
                      value: AAAAA
                - type: graph
                  'y': '5'
                  width: '36'
                  height: '5'
                  fields:
                    - type: GRAPH
                      name: graphid.0
                      value:
                        host: 'Nginx by Zabbix agent'
                        name: 'Nginx: Connections per second'
                    - type: STRING
                      name: reference
                      value: AAAAC
                - type: graph
                  x: '36'
                  width: '36'
                  height: '5'
                  fields:
                    - type: GRAPH
                      name: graphid.0
                      value:
                        host: 'Nginx by Zabbix agent'
                        name: 'Nginx: Requests per second'
                    - type: STRING
                      name: reference
                      value: AAAAB
      valuemaps:
        - uuid: 53c8528c18814f30a45d1540ab9e5c00
          name: 'Service state'
          mappings:
            - value: '0'
              newvalue: Down
            - value: '1'
              newvalue: Up
    - uuid: d2cebb67b4d94a12a072db85e7be6a33
      template: 'Nginx by Zabbix agent active'
      name: 'Nginx by Zabbix agent active'
      description: |
        Get metrics from stub status module using Zabbix agent running on Linux
        https://nginx.ru/en/docs/http/ngx_http_stub_status_module.html
        
        You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/384765-discussion-thread-for-official-zabbix-template-nginx
        
        Generated by official Zabbix template tool "Templator"
      wizard_ready: 'YES'
      readme: |
        ## Overview
        
        This template is developed to monitor Nginx by Zabbix that works without any external scripts.
        Most of the metrics are collected in one go, thanks to Zabbix bulk data collection.
        
        The template `Nginx by Zabbix agent` - collects metrics by polling the [Module ngx_http_stub_status_module](https://nginx.ru/en/docs/http/ngx_http_stub_status_module.html) locally with Zabbix agent:
        
        ```text
        Active connections: 291
        server accepts handled requests
        16630948 16630948 31070465
        Reading: 6 Writing: 179 Waiting: 106
        ```
        
        Note that this template doesn't support HTTPS and redirects (limitations of `web.page.get`).
        
        It also uses Zabbix agent to collect `Nginx` Linux process statistics, such as CPU usage, memory usage and whether the process is running or not.
        
        
        ## Setup
        
        See the setup instructions for [ngx_http_stub_status_module](https://nginx.ru/en/docs/http/ngx_http_stub_status_module.html).
        Test the availability of the `http_stub_status_module` `nginx -V 2>&1 | grep -o with-http_stub_status_module`.
        
        Example configuration of Nginx:
        ```text
        location = /basic_status {
            stub_status;
            allow 127.0.0.1;
            allow ::1;
            deny all;
        }
        ```
        
        If you use another location, then don't forget to change the `Nginx status page path` host wizard configuration field.
        
        Example answer from Nginx:
        ```text
        Active connections: 291
        server accepts handled requests
        16630948 16630948 31070465
        Reading: 6 Writing: 179 Waiting: 106
        ```
        
        Note that this template doesn't support https and redirects (limitations of web.page.get).
      vendor:
        name: Zabbix
        version: 7.4-1
      groups:
        - name: Templates/Applications
      items:
        - uuid: 09762f260f544f57afa5157c6bc632a3
          name: 'Service response time'
          type: ZABBIX_ACTIVE
          key: 'net.tcp.service.perf[http,"{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PORT}"]'
          value_type: FLOAT
          units: s
          tags:
            - tag: component
              value: application
            - tag: component
              value: health
        - uuid: b68e4123d7c9483c9f77bc9c27fd0e7c
          name: 'Service status'
          type: ZABBIX_ACTIVE
          key: 'net.tcp.service[http,"{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PORT}"]'
          valuemap:
            name: 'Service state'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 10m
          tags:
            - tag: component
              value: application
            - tag: component
              value: health
        - uuid: 8db87e1a5a6e478eb4e554b477abb5a4
          name: 'Connections accepted per second'
          type: DEPENDENT
          key: nginx.connections.accepted.rate
          value_type: FLOAT
          description: 'The total number of accepted client connections.'
          preprocessing:
            - type: REGEX
              parameters:
                - 'server accepts handled requests\s+([0-9]+) ([0-9]+) ([0-9]+)'
                - \1
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"]'
          tags:
            - tag: component
              value: connections
        - uuid: cdc0f7d6ad334a219221d7c0b7bf866c
          name: 'Connections active'
          type: DEPENDENT
          key: nginx.connections.active
          description: 'The current number of active client connections including waiting connections.'
          preprocessing:
            - type: REGEX
              parameters:
                - 'Active connections: ([0-9]+)'
                - \1
          master_item:
            key: 'web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"]'
          tags:
            - tag: component
              value: connections
        - uuid: 7dea09085ee84f79837e6f43485f39df
          name: 'Connections dropped per second'
          type: DEPENDENT
          key: nginx.connections.dropped.rate
          value_type: FLOAT
          description: 'The total number of dropped client connections.'
          preprocessing:
            - type: JAVASCRIPT
              parameters:
                - |
                  var a = value.match(/server accepts handled requests\s+([0-9]+) ([0-9]+) ([0-9]+)/)
                  if (a) {
                  	return a[1]-a[2]
                  }
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"]'
          tags:
            - tag: component
              value: connections
        - uuid: eb25d53ee75148fa890054b116fb8960
          name: 'Connections handled per second'
          type: DEPENDENT
          key: nginx.connections.handled.rate
          value_type: FLOAT
          description: 'The total number of handled connections. Generally, the parameter value is the same as for the accepted connections, unless some resource limits have been reached (for example, the `worker_connections limit`).'
          preprocessing:
            - type: REGEX
              parameters:
                - 'server accepts handled requests\s+([0-9]+) ([0-9]+) ([0-9]+)'
                - \2
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"]'
          tags:
            - tag: component
              value: connections
        - uuid: 22d33954da1243c8a2c015f873f7cff3
          name: 'Connections reading'
          type: DEPENDENT
          key: nginx.connections.reading
          description: 'The current number of connections where Nginx is reading the request header.'
          preprocessing:
            - type: REGEX
              parameters:
                - 'Reading: ([0-9]+) Writing: ([0-9]+) Waiting: ([0-9]+)'
                - \1
          master_item:
            key: 'web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"]'
          tags:
            - tag: component
              value: connections
        - uuid: 92c8ccf4863d46e1848fe2c61e0a86e2
          name: 'Connections waiting'
          type: DEPENDENT
          key: nginx.connections.waiting
          description: 'The current number of idle client connections waiting for a request.'
          preprocessing:
            - type: REGEX
              parameters:
                - 'Reading: ([0-9]+) Writing: ([0-9]+) Waiting: ([0-9]+)'
                - \3
          master_item:
            key: 'web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"]'
          tags:
            - tag: component
              value: connections
        - uuid: e5c99f0d7d714168a5ecd100aa42a63a
          name: 'Connections writing'
          type: DEPENDENT
          key: nginx.connections.writing
          description: 'The current number of connections where Nginx is writing a response back to the client.'
          preprocessing:
            - type: REGEX
              parameters:
                - 'Reading: ([0-9]+) Writing: ([0-9]+) Waiting: ([0-9]+)'
                - \2
          master_item:
            key: 'web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"]'
          tags:
            - tag: component
              value: connections
        - uuid: 9276808621ea44e19afd6e42ed4002ee
          name: 'Requests total'
          type: DEPENDENT
          key: nginx.requests.total
          description: 'The total number of client requests.'
          preprocessing:
            - type: REGEX
              parameters:
                - 'server accepts handled requests\s+([0-9]+) ([0-9]+) ([0-9]+)'
                - \3
          master_item:
            key: 'web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"]'
          tags:
            - tag: component
              value: requests
        - uuid: bc688f502c2940d584f22ace27342b92
          name: 'Requests per second'
          type: DEPENDENT
          key: nginx.requests.total.rate
          value_type: FLOAT
          description: 'The total number of client requests.'
          preprocessing:
            - type: REGEX
              parameters:
                - 'server accepts handled requests\s+([0-9]+) ([0-9]+) ([0-9]+)'
                - \3
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"]'
          tags:
            - tag: component
              value: requests
        - uuid: 3667a75132654b01b1e0aff6ed059353
          name: Version
          type: DEPENDENT
          key: nginx.version
          value_type: CHAR
          preprocessing:
            - type: REGEX
              parameters:
                - '(?i)Server: nginx\/(.+(?<!\r))'
                - \1
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: 'web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"]'
          tags:
            - tag: component
              value: application
          triggers:
            - uuid: bc987aa081b543b2becd7c0863553f27
              expression: 'last(/Nginx by Zabbix agent active/nginx.version,#1)<>last(/Nginx by Zabbix agent active/nginx.version,#2) and length(last(/Nginx by Zabbix agent active/nginx.version))>0'
              name: 'Nginx: Version has changed'
              event_name: 'Nginx: Version has changed (new version: {ITEM.VALUE})'
              priority: INFO
              description: 'The Nginx version has changed. Acknowledge to close the problem manually.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: 94bb17445cf14e909fede8b7060c0211
          name: 'Get processes summary'
          type: ZABBIX_ACTIVE
          key: 'proc.get[{$NGINX.PROCESS.NAME.PARAMETER},,,summary]'
          history: '0'
          value_type: TEXT
          description: 'The aggregated data of summary metrics for all processes.'
          tags:
            - tag: component
              value: raw
        - uuid: 04ed4f82a84b4a81aa8d1682e7a70b5f
          name: 'Get stub status page'
          type: ZABBIX_ACTIVE
          key: 'web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"]'
          history: 1h
          value_type: TEXT
          description: |
            The following status information is provided:
            `Active connections` - the current number of active client connections including waiting connections.
            `Accepted` - the total number of accepted client connections.
            `Handled` - the total number of handled connections. Generally, the parameter value is the same as for the accepted connections, unless some resource limits have been reached (for example, the `worker_connections` limit).
            `Requests` - the total number of client requests.
            `Reading` - the current number of connections where Nginx is reading the request header.
            `Writing` - the current number of connections where Nginx is writing a response back to the client.
            `Waiting` - the current number of idle client connections waiting for a request.
            
            See also [Module ngx_http_stub_status_module](https://nginx.org/en/docs/http/ngx_http_stub_status_module.html).
          tags:
            - tag: component
              value: application
            - tag: component
              value: health
      discovery_rules:
        - uuid: b0fa23a0c13b4c11b79369d6cfadc0bb
          name: 'Nginx process discovery'
          type: DEPENDENT
          key: nginx.proc.discovery
          filter:
            evaltype: AND
            conditions:
              - macro: '{#NGINX.NAME}'
                value: '{$NGINX.PROCESS_NAME}'
          description: 'The discovery of Nginx process summary.'
          item_prototypes:
            - uuid: 4a897c7bc31f4413b8c0d0eb050d0eac
              name: 'Get process data'
              type: DEPENDENT
              key: 'nginx.proc.get[{#NGINX.NAME}]'
              history: '0'
              value_type: TEXT
              description: 'The summary metrics aggregated by a process {#NGINX.NAME}.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[?(@["name"]=="{#NGINX.NAME}")].first()'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: 'Failed to retrieve process {#NGINX.NAME} data'
              master_item:
                key: 'proc.get[{$NGINX.PROCESS.NAME.PARAMETER},,,summary]'
              tags:
                - tag: component
                  value: raw
            - uuid: f75fa5d7714941d0b25c9e8767a7a7f7
              name: 'Number of running processes'
              type: DEPENDENT
              key: 'nginx.proc.num[{#NGINX.NAME}]'
              description: 'The number of running processes {#NGINX.NAME}.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.processes
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '0'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'nginx.proc.get[{#NGINX.NAME}]'
              tags:
                - tag: component
                  value: system
              trigger_prototypes:
                - uuid: c95c9632cded4bf48df1c736ec7078c5
                  expression: 'last(/Nginx by Zabbix agent active/nginx.proc.num[{#NGINX.NAME}])=0'
                  name: 'Nginx: Process is not running'
                  priority: HIGH
                  tags:
                    - tag: scope
                      value: availability
            - uuid: 73bee8a0acc84c678a0b1974dbb82964
              name: 'Memory usage, %'
              type: DEPENDENT
              key: 'nginx.proc.pmem[{#NGINX.NAME}]'
              value_type: FLOAT
              units: '%'
              description: 'The percentage of real memory used by a process {#NGINX.NAME}.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.pmem
                  error_handler: DISCARD_VALUE
              master_item:
                key: 'nginx.proc.get[{#NGINX.NAME}]'
              tags:
                - tag: component
                  value: memory
            - uuid: e799880b7374482196780173461213af
              name: 'Memory usage (rss)'
              type: DEPENDENT
              key: 'nginx.proc.rss[{#NGINX.NAME}]'
              units: B
              description: 'The summary of resident set size memory used by a process {#NGINX.NAME} expressed in bytes.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.rss
                  error_handler: DISCARD_VALUE
              master_item:
                key: 'nginx.proc.get[{#NGINX.NAME}]'
              tags:
                - tag: component
                  value: memory
            - uuid: d993483fab9a41f5b5a6457e09647288
              name: 'Memory usage (vsize)'
              type: DEPENDENT
              key: 'nginx.proc.vmem[{#NGINX.NAME}]'
              units: B
              description: 'The summary of virtual memory used by a process {#NGINX.NAME} expressed in bytes.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.vsize
                  error_handler: DISCARD_VALUE
              master_item:
                key: 'nginx.proc.get[{#NGINX.NAME}]'
              tags:
                - tag: component
                  value: memory
            - uuid: 6045ce9aba4747f2a6a1475fc3f8b428
              name: 'CPU utilization'
              type: ZABBIX_ACTIVE
              key: 'proc.cpu.util[{#NGINX.NAME}]'
              value_type: FLOAT
              units: '%'
              description: 'The percentage of the CPU utilization by a process {#NGINX.NAME}.'
              tags:
                - tag: component
                  value: cpu
          trigger_prototypes:
            - uuid: 17f59999c0ee40788aa20979f396616b
              expression: |
                (find(/Nginx by Zabbix agent active/web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"],,"iregexp","HTTP\\/[\\d.]+\\s+200")=0 or
                nodata(/Nginx by Zabbix agent active/web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"],30m)) and last(/Nginx by Zabbix agent active/nginx.proc.num[{#NGINX.NAME}])>0
              name: 'Nginx: Failed to fetch stub status page'
              event_name: 'Nginx: Failed to fetch stub status page (or no data for 30m)'
              priority: WARNING
              description: 'Zabbix has not received any data for items for the last 30 minutes.'
              manual_close: 'YES'
              dependencies:
                - name: 'Nginx: Service is down'
                  expression: 'last(/Nginx by Zabbix agent active/net.tcp.service[http,"{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PORT}"])=0 and last(/Nginx by Zabbix agent active/nginx.proc.num[{#NGINX.NAME}])>0'
              tags:
                - tag: scope
                  value: availability
            - uuid: ff0d5f7f9ae740e3966af8cba9856a00
              expression: 'min(/Nginx by Zabbix agent active/nginx.connections.dropped.rate,5m) > {$NGINX.DROP_RATE.MAX.WARN} and last(/Nginx by Zabbix agent active/nginx.proc.num[{#NGINX.NAME}])>0'
              name: 'Nginx: High connections drop rate'
              event_name: 'Nginx: High connections drop rate (more than {$NGINX.DROP_RATE.MAX.WARN} for 5m)'
              opdata: 'Current rate: {ITEM.LASTVALUE1}'
              priority: WARNING
              description: 'The rate of dropping connections has been greater than {$NGINX.DROP_RATE.MAX.WARN} for the last 5 minutes.'
              dependencies:
                - name: 'Nginx: Service is down'
                  expression: 'last(/Nginx by Zabbix agent active/net.tcp.service[http,"{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PORT}"])=0 and last(/Nginx by Zabbix agent active/nginx.proc.num[{#NGINX.NAME}])>0'
              tags:
                - tag: scope
                  value: performance
            - uuid: 5ed915dd28814134bcbf78738ad8173c
              expression: 'last(/Nginx by Zabbix agent active/net.tcp.service[http,"{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PORT}"])=0 and last(/Nginx by Zabbix agent active/nginx.proc.num[{#NGINX.NAME}])>0'
              name: 'Nginx: Service is down'
              priority: AVERAGE
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: availability
            - uuid: bc6c56323e694cd391f6a80ebbac0c35
              expression: 'min(/Nginx by Zabbix agent active/net.tcp.service.perf[http,"{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PORT}"],5m)>{$NGINX.RESPONSE_TIME.MAX.WARN} and last(/Nginx by Zabbix agent active/nginx.proc.num[{#NGINX.NAME}])>0'
              name: 'Nginx: Service response time is too high'
              event_name: 'Nginx: Service response time is too high (over {$NGINX.RESPONSE_TIME.MAX.WARN}s for 5m)'
              priority: WARNING
              manual_close: 'YES'
              dependencies:
                - name: 'Nginx: Service is down'
                  expression: 'last(/Nginx by Zabbix agent active/net.tcp.service[http,"{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PORT}"])=0 and last(/Nginx by Zabbix agent active/nginx.proc.num[{#NGINX.NAME}])>0'
              tags:
                - tag: scope
                  value: performance
          graph_prototypes:
            - uuid: 60d7f859559246fe902edd8a12ab4c70
              name: 'Nginx: Memory usage[{#NGINX.NAME}]'
              graph_items:
                - drawtype: BOLD_LINE
                  color: 199C0D
                  item:
                    host: 'Nginx by Zabbix agent active'
                    key: 'nginx.proc.vmem[{#NGINX.NAME}]'
                - sortorder: '1'
                  drawtype: BOLD_LINE
                  color: F63100
                  item:
                    host: 'Nginx by Zabbix agent active'
                    key: 'nginx.proc.rss[{#NGINX.NAME}]'
          master_item:
            key: 'proc.get[{$NGINX.PROCESS.NAME.PARAMETER},,,summary]'
          lld_macro_paths:
            - lld_macro: '{#NGINX.NAME}'
              path: $.name
      tags:
        - tag: class
          value: software
        - tag: subclass
          value: webserver
        - tag: target
          value: nginx
      macros:
        - macro: '{$NGINX.DROP_RATE.MAX.WARN}'
          value: '1'
          description: 'The critical rate of the dropped connections for a trigger expression.'
          config:
            type: TEXT
            priority: '7'
            section_name: Thresholds
            label: 'Critical rate of the dropped connections'
            description: 'Critical rate of the dropped connections for a trigger expression. No less than 0.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$NGINX.PROCESS.NAME.PARAMETER}'
          description: 'The process name of the Nginx server used in the item key `proc.get`. It could be specified if the correct process name is known.'
          config:
            type: TEXT
            priority: '5'
            label: 'Nginx process name'
            description: 'Process name of the Nginx server Used in the item key `proc.get`.'
        - macro: '{$NGINX.PROCESS_NAME}'
          value: nginx
          description: 'The process name filter for the Nginx process discovery.'
          config:
            type: TEXT
            priority: '4'
            section_name: Filters
            label: 'Nginx process name LLD filter'
            description: 'Process name filter for the Nginx process discovery.'
        - macro: '{$NGINX.RESPONSE_TIME.MAX.WARN}'
          value: '10'
          description: 'The maximum response time of Nginx expressed in seconds for a trigger expression.'
          config:
            type: TEXT
            priority: '6'
            section_name: Thresholds
            label: 'Maximum Nginx response time'
            description: 'Maximum response time of Nginx expressed in seconds for a trigger expression. No less than 0.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$NGINX.STUB_STATUS.HOST}'
          value: localhost
          description: 'The hostname or IP address of the Nginx host or Nginx container of `astub_status`.'
          config:
            type: TEXT
            priority: '1'
            label: 'Nginx status host'
            description: 'Hostname or IP address of the Nginx host or Nginx container of a stub_status.'
            required: 'YES'
        - macro: '{$NGINX.STUB_STATUS.PATH}'
          value: basic_status
          description: 'The path of the `Nginx stub_status` page.'
          config:
            type: TEXT
            priority: '2'
            label: 'Nginx status page path'
            description: 'Path of the `Nginx stub_status` page.'
            required: 'YES'
        - macro: '{$NGINX.STUB_STATUS.PORT}'
          value: '80'
          description: 'The port of the `Nginx stub_status` host or container.'
          config:
            type: TEXT
            priority: '3'
            label: 'Nginx status page port'
            description: 'Port of the `Nginx stub_status` host or container. In the range from 1 to 65535 inclusive.'
            required: 'YES'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
      dashboards:
        - uuid: d066178c8aa942a5b82e7a6fdbd21880
          name: 'Nginx performance'
          pages:
            - widgets:
                - type: graph
                  width: '36'
                  height: '5'
                  fields:
                    - type: GRAPH
                      name: graphid.0
                      value:
                        host: 'Nginx by Zabbix agent active'
                        name: 'Nginx: Connections by state'
                    - type: STRING
                      name: reference
                      value: AAAAA
                - type: graph
                  'y': '5'
                  width: '36'
                  height: '5'
                  fields:
                    - type: GRAPH
                      name: graphid.0
                      value:
                        host: 'Nginx by Zabbix agent active'
                        name: 'Nginx: Connections per second'
                    - type: STRING
                      name: reference
                      value: AAAAC
                - type: graph
                  x: '36'
                  width: '36'
                  height: '5'
                  fields:
                    - type: GRAPH
                      name: graphid.0
                      value:
                        host: 'Nginx by Zabbix agent active'
                        name: 'Nginx: Requests per second'
                    - type: STRING
                      name: reference
                      value: AAAAB
      valuemaps:
        - uuid: 664f36475a624b6bbf6a23c430baaa9b
          name: 'Service state'
          mappings:
            - value: '0'
              newvalue: Down
            - value: '1'
              newvalue: Up
    - uuid: 970c2342146549768e6b91a26089bcdf
      template: 'Remote Zabbix proxy health'
      name: 'Remote Zabbix proxy health'
      description: |
        This template is designed to monitor internal Zabbix metrics on the remote Zabbix proxy.
        
        Specify the address of the remote Zabbix proxy by updating the {$ZABBIX.PROXY.ADDRESS} and {$ZABBIX.PROXY.PORT} macros. Don't forget to adjust the "StatsAllowedIP" parameter in the remote proxy's configuration file to allow the collection of statistics.
        
        Generated by official Zabbix template tool "Templator"
      wizard_ready: 'YES'
      readme: |
        ## Overview
        
        This template is designed to monitor internal Zabbix metrics on the remote Zabbix proxy.
        
        ## Setup
        
        Specify the address of the remote Zabbix proxy as the values for the `Zabbix proxy Address` and `Zabbix proxy Port` configuration fields. Don't forget to adjust the `StatsAllowedIP` parameter in the remote proxy's configuration file to allow the collection of statistics.
      vendor:
        name: Zabbix
        version: 7.4-3
      groups:
        - name: Templates/Applications
      items:
        - uuid: 061bac7060704850b42ae063aba8c076
          name: 'Discovery queue'
          type: DEPENDENT
          key: discovery_queue
          description: 'The count of values enqueued in the discovery queue.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.discovery_queue
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "discoverer" processes started. Please check "StartDiscoverers" parameter in the server configuration file.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: e6654e9406b74b28909dc166b2805125
          name: 'Preprocessing queue'
          type: DEPENDENT
          key: preprocessing_queue
          description: 'The number of values enqueued in the preprocessing queue.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.preprocessing_queue
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: 55b74e2521be4ec4bd74f28fafa1fc89
          name: 'Utilization of agent poller data collector processes, in %'
          type: DEPENDENT
          key: process.agent_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the agent poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''agent poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes agent poller not started'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: c35b8290fb2840e9bb403f54ad0e7b97
              expression: 'avg(/Remote Zabbix proxy health/process.agent_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"agent poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.agent_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"agent poller"}'
              name: 'Zabbix proxy: Utilization of agent poller processes is high'
              event_name: 'Zabbix proxy: Utilization of agent poller processes over {$ZABBIX.PROXY.UTIL.MAX:"agent poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the agent poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 189d41565cdf4f459468c43d1b1d0961
          name: 'Utilization of availability manager internal processes, in %'
          type: DEPENDENT
          key: process.availability_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the availability manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''availability manager''].busy.avg'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 77e66d2f6b0e48fa8a7ec5dd213eab35
              expression: 'avg(/Remote Zabbix proxy health/process.availability_manager.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"availability manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.availability_manager.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"availability manager"}'
              name: 'Zabbix proxy: Utilization of availability manager processes is high'
              event_name: 'Zabbix proxy: Utilization of availability manager processes over {$ZABBIX.PROXY.UTIL.MAX:"availability manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the availability manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: e71c85b839d2447ba9a8bec8aa0fb794
          name: 'Utilization of browser poller data collector processes, in %'
          type: DEPENDENT
          key: process.browser_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the browser poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''browser poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "browser poller" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 8458680e160d4f2ba1d1d2c20453dfe4
              expression: 'avg(/Remote Zabbix proxy health/process.browser_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"browser poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.browser_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"browser poller"}'
              name: 'Zabbix proxy: Utilization of browser poller processes is high'
              event_name: 'Zabbix proxy: Utilization of browser poller processes over {$ZABBIX.PROXY.UTIL.MAX:"browser poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the browser poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 457a086236ab40eda5c9758eabacb73d
          name: 'Utilization of configuration syncer internal processes, in %'
          type: DEPENDENT
          key: process.configuration_syncer.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the configuration syncer processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''configuration syncer''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes configuration syncer not started'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 67089f59f77641c8ab487e2c44d563a2
              expression: 'avg(/Remote Zabbix proxy health/process.configuration_syncer.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"configuration syncer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.configuration_syncer.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"configuration syncer"}'
              name: 'Zabbix proxy: Utilization of configuration syncer processes is high'
              event_name: 'Zabbix proxy: Utilization of configuration syncer processes over {$ZABBIX.PROXY.UTIL.MAX:"configuration syncer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the configuration syncer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: ff9c1cb7fb234ad2b793c4f296b79834
          name: 'Utilization of data sender internal processes, in %'
          type: DEPENDENT
          key: process.data_sender.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the data sender processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''data sender''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes data sender not started'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: f2208ef37274449fb2b61f5f55e615f1
              expression: 'avg(/Remote Zabbix proxy health/process.data_sender.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"data sender"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.data_sender.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"data sender"}'
              name: 'Zabbix proxy: Utilization of data sender processes is high'
              event_name: 'Zabbix proxy: Utilization of data sender processes over {$ZABBIX.PROXY.UTIL.MAX:"data sender"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the data sender, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 879ef97241444ef9ac679e7f601557a0
          name: 'Utilization of discovery manager internal processes, in %'
          type: DEPENDENT
          key: process.discovery_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the discovery manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''discovery manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "discovery manager" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 8d0651ac99ba4c28b9525885e04ecb98
              expression: 'avg(/Remote Zabbix proxy health/process.discovery_manager.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"discovery manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.discovery_manager.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"discovery manager"}'
              name: 'Zabbix proxy: Utilization of discovery manager processes is high'
              event_name: 'Zabbix proxy: Utilization of discovery manager processes over {$ZABBIX.PROXY.UTIL.MAX:"discovery manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the discovery manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 59ab4f96b9704b94b95cdb2f96c3736f
          name: 'Utilization of discovery worker internal processes, in %'
          type: DEPENDENT
          key: process.discovery_worker.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the discovery worker processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''discovery worker''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "discovery worker" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 63c45f37a5cd41c091ba3af451325220
              expression: 'avg(/Remote Zabbix proxy health/process.discovery_worker.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"discovery worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.discovery_worker.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"discovery worker"}'
              name: 'Zabbix proxy: Utilization of discovery worker processes is high'
              event_name: 'Zabbix proxy: Utilization of discovery worker processes over {$ZABBIX.PROXY.UTIL.MAX:"discovery worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the discovery worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: c710e445710b4d98bd4ebcd5770c7d5a
          name: 'Utilization of history syncer internal processes, in %'
          type: DEPENDENT
          key: process.history_syncer.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the history syncer processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''history syncer''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes history syncer not started'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 872ca8a02ff948d0ab4f5000249bbf5b
              expression: 'avg(/Remote Zabbix proxy health/process.history_syncer.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"history syncer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.history_syncer.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"history syncer"}'
              name: 'Zabbix proxy: Utilization of history syncer processes is high'
              event_name: 'Zabbix proxy: Utilization of history syncer processes over {$ZABBIX.PROXY.UTIL.MAX:"history syncer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the history syncer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 50c3587febc14c118ca2868c24e42770
          name: 'Utilization of housekeeper internal processes, in %'
          type: DEPENDENT
          key: process.housekeeper.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the housekeeper processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''housekeeper''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes housekeeper not started'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 43d8ef15170e4edd80eea85ad9990d73
              expression: 'avg(/Remote Zabbix proxy health/process.housekeeper.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"housekeeper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.housekeeper.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"housekeeper"}'
              name: 'Zabbix proxy: Utilization of housekeeper processes is high'
              event_name: 'Zabbix proxy: Utilization of housekeeper processes over {$ZABBIX.PROXY.UTIL.MAX:"housekeeper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the housekeeper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: b93aad197c1d411f8845ae7c591d1759
          name: 'Utilization of http agent poller data collector processes, in %'
          type: DEPENDENT
          key: process.http_agent_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the http agent poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''http agent poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes http agent poller not started'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 460ddec16c564c6dbc706b21747aa622
              expression: 'avg(/Remote Zabbix proxy health/process.http_agent_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"http agent poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.http_agent_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"http agent poller"}'
              name: 'Zabbix proxy: Utilization of http agent poller processes is high'
              event_name: 'Zabbix proxy: Utilization of http agent poller processes over {$ZABBIX.PROXY.UTIL.MAX:"http agent poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the http agent poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 4f335477bd654368a7870dc5cd21e114
          name: 'Utilization of http poller data collector processes, in %'
          type: DEPENDENT
          key: process.http_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the http poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''http poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes http poller not started'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 9c391ba5350d401b9ca56f7cd29cd457
              expression: 'avg(/Remote Zabbix proxy health/process.http_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"http poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.http_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"http poller"}'
              name: 'Zabbix proxy: Utilization of http poller processes is high'
              event_name: 'Zabbix proxy: Utilization of http poller processes over {$ZABBIX.PROXY.UTIL.MAX:"http poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the http poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: f03927fd354a490e95521e5922a19ad3
          name: 'Utilization of icmp pinger data collector processes, in %'
          type: DEPENDENT
          key: process.icmp_pinger.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the icmp pinger processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''icmp pinger''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes icmp pinger not started'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 8a0abc8ff0dd42b0926b5840fe5b0e2f
              expression: 'avg(/Remote Zabbix proxy health/process.icmp_pinger.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"icmp pinger"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.icmp_pinger.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"icmp pinger"}'
              name: 'Zabbix proxy: Utilization of icmp pinger processes is high'
              event_name: 'Zabbix proxy: Utilization of icmp pinger processes over {$ZABBIX.PROXY.UTIL.MAX:"icmp pinger"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the icmp pinger, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 2474dabb131247f0bce1d43075cee215
          name: 'Utilization of internal poller data collector processes, in %'
          type: DEPENDENT
          key: process.internal_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the internal poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''internal poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "internal poller" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 5bea08baaad04d4e8d15540e931e0336
              expression: 'avg(/Remote Zabbix proxy health/process.internal_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"internal poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.internal_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"internal poller"}'
              name: 'Zabbix proxy: Utilization of internal poller processes is high'
              event_name: 'Zabbix proxy: Utilization of internal poller processes over {$ZABBIX.PROXY.UTIL.MAX:"internal poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the internal poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: fb560cce51714f9c8b5164f7587930e5
          name: 'Utilization of ipmi manager internal processes, in %'
          type: DEPENDENT
          key: process.ipmi_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the ipmi manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''ipmi manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes ipmi manager not started'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: a2aed809416b46beba8ed63554d9b7d5
              expression: 'avg(/Remote Zabbix proxy health/process.ipmi_manager.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"ipmi manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.ipmi_manager.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"ipmi manager"}'
              name: 'Zabbix proxy: Utilization of ipmi manager processes is high'
              event_name: 'Zabbix proxy: Utilization of ipmi manager processes over {$ZABBIX.PROXY.UTIL.MAX:"ipmi manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the ipmi manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: c4ff983246e7450f96af03da274df151
          name: 'Utilization of ipmi poller data collector processes, in %'
          type: DEPENDENT
          key: process.ipmi_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the ipmi poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''ipmi poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes ipmi poller not started'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: e7c748c36e5740d684a5c4c68682f321
              expression: 'avg(/Remote Zabbix proxy health/process.ipmi_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"ipmi poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.ipmi_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"ipmi poller"}'
              name: 'Zabbix proxy: Utilization of ipmi poller processes is high'
              event_name: 'Zabbix proxy: Utilization of ipmi poller processes over {$ZABBIX.PROXY.UTIL.MAX:"ipmi poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the ipmi poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: c37b027a671449dca92cfbf1b15e711f
          name: 'Utilization of java poller data collector processes, in %'
          type: DEPENDENT
          key: process.java_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the java poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''java poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes java poller not started'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: ef46070fc30b46c7be1ce3574e578449
              expression: 'avg(/Remote Zabbix proxy health/process.java_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"java poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.java_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"java poller"}'
              name: 'Zabbix proxy: Utilization of java poller processes is high'
              event_name: 'Zabbix proxy: Utilization of java poller processes over {$ZABBIX.PROXY.UTIL.MAX:"java poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the java poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 7c0d7d097e004d0db25eab55ceb6b87c
          name: 'Utilization of ODBC poller data collector processes, in %'
          type: DEPENDENT
          key: process.odbc_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the ODBC poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''odbc poller''].busy.avg'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 7f83ff01200c4862aa22057b079da6f8
              expression: 'avg(/Remote Zabbix proxy health/process.odbc_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"ODBC poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.odbc_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"ODBC poller"}'
              name: 'Zabbix proxy: Utilization of ODBC poller processes is high'
              event_name: 'Zabbix proxy: Utilization of ODBC poller processes over {$ZABBIX.PROXY.UTIL.MAX:"ODBC poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the ODBC poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: e44b8cc43d5c49c5a81ed33c5cc44c82
          name: 'Utilization of poller data collector processes, in %'
          type: DEPENDENT
          key: process.poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes poller not started'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 6afb9db9e11842c28c059abd31c7a134
              expression: 'avg(/Remote Zabbix proxy health/process.poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"poller"}'
              name: 'Zabbix proxy: Utilization of poller processes is high'
              event_name: 'Zabbix proxy: Utilization of poller processes over {$ZABBIX.PROXY.UTIL.MAX:"poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: c4746528d75a41898a7ded21701de019
          name: 'Utilization of preprocessing manager internal processes, in %'
          type: DEPENDENT
          key: process.preprocessing_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the preprocessing manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''preprocessing manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes preprocessing manager not started'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 4c681b0775b54fd79e4aba669e219967
              expression: 'avg(/Remote Zabbix proxy health/process.preprocessing_manager.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"preprocessing manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.preprocessing_manager.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"preprocessing manager"}'
              name: 'Zabbix proxy: Utilization of preprocessing manager processes is high'
              event_name: 'Zabbix proxy: Utilization of preprocessing manager processes over {$ZABBIX.PROXY.UTIL.MAX:"preprocessing manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the preprocessing manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 5b10c9859c3443459b5e993015ae68fc
          name: 'Utilization of preprocessing worker internal processes, in %'
          type: DEPENDENT
          key: process.preprocessing_worker.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the preprocessing worker processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''preprocessing worker''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes preprocessing worker not started'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: f1c97c56e2d04cabaaa4c9b41e2bbad3
              expression: 'avg(/Remote Zabbix proxy health/process.preprocessing_worker.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"preprocessing worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.preprocessing_worker.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"preprocessing worker"}'
              name: 'Zabbix proxy: Utilization of preprocessing worker processes is high'
              event_name: 'Zabbix proxy: Utilization of preprocessing worker processes over {$ZABBIX.PROXY.UTIL.MAX:"preprocessing worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the preprocessing worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: fbfe2a05b2914c9d8b1b39aa7320aaf3
          name: 'Utilization of self-monitoring internal processes, in %'
          type: DEPENDENT
          key: process.self-monitoring.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the self-monitoring processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''self-monitoring''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes self-monitoring not started'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: fee719ea91524972897c19ce4b17bd54
              expression: 'avg(/Remote Zabbix proxy health/process.self-monitoring.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"self-monitoring"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.self-monitoring.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"self-monitoring"}'
              name: 'Zabbix proxy: Utilization of self-monitoring processes is high'
              event_name: 'Zabbix proxy: Utilization of self-monitoring processes over {$ZABBIX.PROXY.UTIL.MAX:"self-monitoring"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the self-monitoring, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: f31066273dde41c2aee2a319c1a1af9a
          name: 'Utilization of snmp poller data collector processes, in %'
          type: DEPENDENT
          key: process.snmp_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the snmp poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''snmp poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes snmp poller not started'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: e9c89574068443f89c369df8618506e6
              expression: 'avg(/Remote Zabbix proxy health/process.snmp_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"snmp poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.snmp_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"snmp poller"}'
              name: 'Zabbix proxy: Utilization of snmp poller processes is high'
              event_name: 'Zabbix proxy: Utilization of snmp poller processes over {$ZABBIX.PROXY.UTIL.MAX:"snmp poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the snmp poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 3c06aed8f9ca4790b23132498e32701f
          name: 'Utilization of snmp trapper data collector processes, in %'
          type: DEPENDENT
          key: process.snmp_trapper.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the snmp trapper processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''snmp trapper''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes snmp trapper not started'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 9ca70574386f4b968bcda64a5d267d58
              expression: 'avg(/Remote Zabbix proxy health/process.snmp_trapper.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"snmp trapper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.snmp_trapper.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"snmp trapper"}'
              name: 'Zabbix proxy: Utilization of snmp trapper processes is high'
              event_name: 'Zabbix proxy: Utilization of snmp trapper processes over {$ZABBIX.PROXY.UTIL.MAX:"snmp trapper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the snmp trapper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 48ab13daaf0541bdbf317226c753472c
          name: 'Utilization of task manager internal processes, in %'
          type: DEPENDENT
          key: process.task_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the task manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''task manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes task manager not started'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 9d7d15a747484530a61102175cbc4478
              expression: 'avg(/Remote Zabbix proxy health/process.task_manager.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"task manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.task_manager.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"task manager"}'
              name: 'Zabbix proxy: Utilization of task manager processes is high'
              event_name: 'Zabbix proxy: Utilization of task manager processes over {$ZABBIX.PROXY.UTIL.MAX:"task manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the task manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: d37a6ebb128d4221a34c8d78736ea90b
          name: 'Utilization of trapper data collector processes, in %'
          type: DEPENDENT
          key: process.trapper.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the trapper processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''trapper''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes trapper not started'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 49a9e3e1b17146f7861daf6994956d4f
              expression: 'avg(/Remote Zabbix proxy health/process.trapper.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"trapper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.trapper.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"trapper"}'
              name: 'Zabbix proxy: Utilization of trapper processes is high'
              event_name: 'Zabbix proxy: Utilization of trapper processes over {$ZABBIX.PROXY.UTIL.MAX:"trapper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the trapper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: a0c56d8570eb4cb39e119fc61d7092d1
          name: 'Utilization of unreachable poller data collector processes, in %'
          type: DEPENDENT
          key: process.unreachable_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the unreachable poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''unreachable poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes unreachable poller not started'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: e446ec803eaf4ace9b7d1fdc7a89cba6
              expression: 'avg(/Remote Zabbix proxy health/process.unreachable_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"unreachable poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.unreachable_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"unreachable poller"}'
              name: 'Zabbix proxy: Utilization of unreachable poller processes is high'
              event_name: 'Zabbix proxy: Utilization of unreachable poller processes over {$ZABBIX.PROXY.UTIL.MAX:"unreachable poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the unreachable poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 54d7e2578b594022ad406b40c9dd57fe
          name: 'Utilization of vmware collector data collector processes, in %'
          type: DEPENDENT
          key: process.vmware_collector.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the vmware collector processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''vmware collector''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes vmware collector not started'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 30147687074f45e7ab0dce81a1b7cf07
              expression: 'avg(/Remote Zabbix proxy health/process.vmware_collector.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"vmware collector"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix proxy health/process.vmware_collector.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"vmware collector"}'
              name: 'Zabbix proxy: Utilization of vmware collector processes is high'
              event_name: 'Zabbix proxy: Utilization of vmware collector processes over {$ZABBIX.PROXY.UTIL.MAX:"vmware collector"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the vmware collector, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 0e27243e5c844357a57a1c32869863a4
          name: 'Proxy memory buffer, % used'
          type: DEPENDENT
          key: proxy_buffer.buffer.pused
          value_type: FLOAT
          units: '%'
          description: |
            Statistics and availability of Zabbix proxy memory buffer usage statistics. Percentage of used proxy memory buffer.
            Proxy memory buffer is used to store the new historical data and upload from it without accessing database.
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.wcache.[''proxy buffer''].memory.pused'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Proxy memory buffer is disabled.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 4c04e5a21a91485e9562ef951877a5f3
              expression: 'max(/Remote Zabbix proxy health/proxy_buffer.buffer.pused,10m)>{$ZABBIX.PROXY.UTIL.MAX:"proxy buffer"}'
              name: 'Zabbix proxy: Excessive proxy memory buffer usage'
              event_name: 'Zabbix proxy: More than {$ZABBIX.PROXY.UTIL.MAX:"proxy buffer"}% used in the proxy memory buffer'
              priority: AVERAGE
              description: 'Consider increasing ProxyMemoryBufferSize in the zabbix_proxy.conf configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 4bfed9e5c4b449c490a26ea67f1106cd
          name: 'Proxy buffer, state changes'
          type: DEPENDENT
          key: proxy_buffer.state.changes
          description: 'The number of state changes between disk/memory buffer modes since proxy start.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.wcache.[''proxy buffer''].[''state change'']'
              error_handler: CUSTOM_VALUE
              error_handler_params: '0'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: ddca62888fab477a84b215812c7bf57d
          name: 'Proxy buffer, state'
          type: DEPENDENT
          key: proxy_buffer.state.current
          description: |
            The current working state of proxy buffer where the new data is being stored. Possible values:
            
              0 - disk (also returned when memory buffer is disabled);
              1 - memory.
          valuemap:
            name: 'Proxy buffer mode'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.wcache.[''proxy buffer''].state'
              error_handler: CUSTOM_VALUE
              error_handler_params: '0'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: a283182189c4414c9a123f7511603009
          name: 'Zabbix proxy check'
          type: DEPENDENT
          key: proxy_check
          trends: '0'
          description: 'Flag indicating whether it is a proxy or not.'
          valuemap:
            name: 'Zabbix proxy check'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.triggers
              error_handler: CUSTOM_VALUE
              error_handler_params: '0'
            - type: IN_RANGE
              parameters:
                - ''
                - '0'
              error_handler: CUSTOM_VALUE
              error_handler_params: '1'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 7c54b686ce754537b7f379ec1af4e630
              expression: 'last(/Remote Zabbix proxy health/proxy_check)=1'
              name: 'Zabbix proxy: Wrong template assigned'
              event_name: 'Zabbix proxy: Zabbix proxy template is assigned to Zabbix server'
              priority: DISASTER
              description: 'Check that the template has been selected correctly.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: 72dd891d7ced4cefb7de988dadf81f3b
          name: 'Configuration cache, % used'
          type: DEPENDENT
          key: rcache.buffer.pused
          value_type: FLOAT
          units: '%'
          description: 'The availability statistics of Zabbix configuration cache. The percentage of used data buffer.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.rcache.pused
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 6aaad09f92f3419c9aa7164f2191a45a
              expression: 'max(/Remote Zabbix proxy health/rcache.buffer.pused,10m)>{$ZABBIX.PROXY.UTIL.MAX:"configuration cache"}'
              name: 'Zabbix proxy: Excessive configuration cache usage'
              event_name: 'Zabbix proxy: More than {$ZABBIX.PROXY.UTIL.MAX:"configuration cache"}% used in the configuration cache'
              priority: AVERAGE
              description: 'Consider increasing `CacheSize` in the `zabbix_proxy.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
            - uuid: 2f314a33e06444d88fd99b5442b10a9e
              expression: 'nodata(/Remote Zabbix proxy health/rcache.buffer.pused,{$ZABBIX.PROXY.NODATA_TIMEOUT})=1'
              name: 'Zabbix proxy: Failed to fetch stats data'
              event_name: 'Zabbix proxy: Failed to fetch stats data (or no data for {$ZABBIX.PROXY.NODATA_TIMEOUT})'
              priority: WARNING
              description: 'Zabbix has not received statistics data for `{$ZABBIX.PROXY.NODATA_TIMEOUT}`.'
              tags:
                - tag: scope
                  value: availability
        - uuid: 0df481994c454884b6be2e2132248af7
          name: 'Required VPS'
          type: DEPENDENT
          key: requiredperformance
          value_type: FLOAT
          units: '!vps'
          description: 'The required performance of a proxy (the number of values that need to be collected per second).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.requiredperformance
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 12h
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: 28d87aef584644e9a3adcde33966b4e1
          name: Uptime
          type: DEPENDENT
          key: uptime
          units: uptime
          description: 'Uptime of the Zabbix proxy process in seconds.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.uptime
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 8940efd3c68b4ded80ea1e89d55dfa7c
              expression: 'last(/Remote Zabbix proxy health/uptime)<10m'
              name: 'Zabbix proxy: {HOST.NAME} has been restarted'
              event_name: 'Zabbix proxy: {HOST.NAME} has been restarted (uptime < 10m)'
              priority: INFO
              description: 'Uptime is less than 10 minutes.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: ba19f24c2e234ac89a12a4a7aceeff93
          name: Version
          type: DEPENDENT
          key: version
          value_type: CHAR
          description: 'The version of Zabbix proxy.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.version
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 224ec99fda0d443cba8a6c75da5a27cb
              expression: 'last(/Remote Zabbix proxy health/version,#1)<>last(/Remote Zabbix proxy health/version,#2) and length(last(/Remote Zabbix proxy health/version))>0'
              name: 'Zabbix proxy: Version has changed'
              event_name: 'Zabbix proxy: Version has changed (new version: {ITEM.VALUE})'
              priority: INFO
              description: 'Zabbix proxy version has changed. Acknowledge to close the problem manually.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: 7e6ffd55fe6842219f6e0d3c81ffa309
          name: 'VMware cache, % used'
          type: DEPENDENT
          key: vmware.buffer.pused
          value_type: FLOAT
          units: '%'
          description: 'The availability statistics of Zabbix vmware cache. The percentage of used data buffer.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.vmware.pused
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No vmware collector processes started'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: ac2a42046de340e1968802d92678947c
              expression: 'max(/Remote Zabbix proxy health/vmware.buffer.pused,10m)>{$ZABBIX.PROXY.UTIL.MAX:"vmware cache"}'
              name: 'Zabbix proxy: Excessive vmware cache usage'
              event_name: 'Zabbix proxy: More than {$ZABBIX.PROXY.UTIL.MAX:"vmware cache"}% used in the vmware cache'
              priority: AVERAGE
              description: 'Consider increasing `VMwareCacheSize` in the `zabbix_proxy.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 2abf18f2a9c9412ca81d615f45d4ca5f
          name: 'History write cache, % used'
          type: DEPENDENT
          key: wcache.history.pused
          value_type: FLOAT
          units: '%'
          description: |
            The statistics and availability of Zabbix write cache. The percentage of used history buffer.
            The history cache is used to store item values. A high number indicates database performance problems.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.history.pused
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: c14095c38d17486fa8fde22bd5a9d737
              expression: 'max(/Remote Zabbix proxy health/wcache.history.pused,10m)>{$ZABBIX.PROXY.UTIL.MAX:"history cache"}'
              name: 'Zabbix proxy: Excessive history cache usage'
              event_name: 'Zabbix proxy: More than {$ZABBIX.PROXY.UTIL.MAX:"history cache"}% used in the history cache'
              priority: AVERAGE
              description: 'Consider increasing `HistoryCacheSize` in the `zabbix_proxy.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: a907ff2d6d8e4389b116eb3ec01dacfe
          name: 'History index cache, % used'
          type: DEPENDENT
          key: wcache.index.pused
          value_type: FLOAT
          units: '%'
          description: |
            The statistics and availability of Zabbix write cache. The percentage of used history index buffer.
            The history index cache is used to index values stored in the history cache.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.index.pused
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 43f9a4fc049e45e5b8bbb0980b518dd0
              expression: 'max(/Remote Zabbix proxy health/wcache.index.pused,10m)>{$ZABBIX.PROXY.UTIL.MAX:"index cache"}'
              name: 'Zabbix proxy: Excessive history index cache usage'
              event_name: 'Zabbix proxy: More than {$ZABBIX.PROXY.UTIL.MAX:"index cache"}% used in the history index cache'
              priority: AVERAGE
              description: 'Consider increasing `HistoryIndexCacheSize` in the `zabbix_proxy.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 0238a93001a3438988b9b5cc4cbcc68e
          name: 'Number of processed values per second'
          type: DEPENDENT
          key: wcache.values
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The total number of values processed by Zabbix server or Zabbix proxy, except unsupported items.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.all
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: f20ff449693a479895b7f3b450b93787
          name: 'Number of processed numeric (float) values per second'
          type: DEPENDENT
          key: wcache.values.float
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed numeric (float) values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.float
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: b20b00f97a424b8e9c69ebb749a94d65
          name: 'Number of processed log values per second'
          type: DEPENDENT
          key: wcache.values.log
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed log values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.log
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 927b1387d969466eba000855837887c7
          name: 'Number of processed not supported values per second'
          type: DEPENDENT
          key: wcache.values.not_supported
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of times the item processing resulted in an item becoming unsupported or remaining in that state.
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.wcache.values[''not supported'']'
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 334584cfea704011b8ae70436e47e2ff
          name: 'Number of processed character values per second'
          type: DEPENDENT
          key: wcache.values.str
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed character values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.str
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 35b053f8ce89430b989387eb3075b582
          name: 'Number of processed text values per second'
          type: DEPENDENT
          key: wcache.values.text
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed text values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.text
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: c53f480b861249c4a1ca12571faa4487
          name: 'Number of processed numeric (unsigned) values per second'
          type: DEPENDENT
          key: wcache.values.uint
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed numeric (unsigned) values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.uint
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: c9b9ee0faefd4cefbac32f548539266e
          name: 'Queue over 10 minutes'
          type: INTERNAL
          key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT},queue,10m]'
          description: 'The number of monitored items in the queue that are delayed by at least 10 minutes.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.queue
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 71cd927153ef4b8480a8f13fc6b4def8
              expression: 'min(/Remote Zabbix proxy health/zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT},queue,10m],10m)>100'
              name: 'Zabbix proxy: More than 100 items have been missing data for over 10 minutes'
              priority: WARNING
              description: 'Indicates potential issues with network connectivity, agent failures, or unresponsive monitored resources that require attention.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 128bcd3c019946b593f3256858cf8397
          name: Queue
          type: INTERNAL
          key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT},queue]'
          description: 'The number of monitored items in the queue that are delayed by at least 6 seconds.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.queue
          tags:
            - tag: component
              value: system
        - uuid: c3d4e015efe7459f8207096a04b296f0
          name: 'Zabbix stats'
          type: INTERNAL
          key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          history: '0'
          value_type: TEXT
          description: 'Zabbix server statistics master item.'
          tags:
            - tag: component
              value: raw
      tags:
        - tag: class
          value: software
        - tag: subclass
          value: logging
        - tag: subclass
          value: monitoring
        - tag: target
          value: proxy
        - tag: target
          value: zabbix
      macros:
        - macro: '{$ZABBIX.PROXY.ADDRESS}'
          description: 'IP/DNS of the remote Zabbix proxy (default is 127.0.0.1).'
          config:
            type: TEXT
            priority: '1'
            label: 'Zabbix proxy Address'
            description: 'IP or DNS of the remote Zabbix proxy from which data should be collected.'
            required: 'YES'
        - macro: '{$ZABBIX.PROXY.NODATA_TIMEOUT}'
          value: 5m
          description: 'The time threshold after which statistics are considered unavailable. Used in trigger expressions.'
          config:
            type: TEXT
            priority: '5'
            section_name: Thresholds
            label: 'Time since the last statistic was received'
            description: 'Threshold value of time since the last statistic was received from the remote proxy.'
        - macro: '{$ZABBIX.PROXY.PORT}'
          description: 'Port of the remote Zabbix proxy (default is 10051).'
          config:
            type: TEXT
            priority: '2'
            label: 'Zabbix proxy Port'
            description: 'Port of the remote Zabbix proxy from which data should be collected. In the range from 1 to 65535 inclusive.'
            required: 'YES'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$ZABBIX.PROXY.UTIL.MAX}'
          value: '75'
          description: 'Default maximum threshold for percentage utilization triggers (use macro context for specification).'
          config:
            type: TEXT
            priority: '4'
            section_name: Thresholds
            label: 'Maximum process utilization percentage'
            description: 'Default maximum threshold for process utilization triggers. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$ZABBIX.PROXY.UTIL.MIN}'
          value: '65'
          description: 'Default minimum threshold for percentage utilization triggers (use macro context for specification).'
          config:
            type: TEXT
            priority: '3'
            section_name: Thresholds
            label: 'Minimum process utilization percentage'
            description: 'Default minimum threshold for process utilization triggers. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
      dashboards:
        - uuid: cd580518d9d5434296a1ed9701b71a77
          name: 'Remote Zabbix proxy health'
          auto_start: 'NO'
          pages:
            - name: Performance
              widgets:
                - type: svggraph
                  name: 'Cache usage, in %'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.1
                      value: e31a1c
                    - type: STRING
                      name: ds.0.color.2
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.3
                      value: b15928
                    - type: STRING
                      name: ds.0.color.4
                      value: a6cee3
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: rcache.buffer.pused
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: wcache.index.pused
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: wcache.history.pused
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: vmware.buffer.pused
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: proxy_buffer.buffer.pused
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACA
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Server performance'
                  'y': '6'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.1
                      value: e31a1c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: wcache.values
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: 'zabbix[stats,{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT},queue]'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACC
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Values processed'
                  'y': '11'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.2
                      value: e31a1c
                    - type: STRING
                      name: ds.0.color.3
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.4
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.5
                      value: b15928
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: wcache.values.uint
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: wcache.values.float
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: wcache.values.not_supported
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: wcache.values.str
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: wcache.values.log
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: wcache.values.text
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACD
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Internal queues'
                  x: '36'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: ffff99
                    - type: STRING
                      name: ds.0.color.1
                      value: 6a3d9a
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: preprocessing_queue
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: discovery_queue
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACB
                    - type: INTEGER
                      name: show_problems
                      value: '1'
            - name: Processes
              widgets:
                - type: svggraph
                  name: 'Utilization: Discovery processes'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 7e57c2
                    - type: STRING
                      name: ds.0.color.1
                      value: 1f78b4
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.discovery_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.discovery_worker.avg.busy
                    - type: INTEGER
                      name: ds.1.axisy
                      value: '1'
                    - type: STRING
                      name: ds.1.color.0
                      value: ff465c
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: discovery_queue
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABH
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Synchronous gathering processes'
                  'y': '6'
                  width: '72'
                  height: '7'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.2
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.3
                      value: b15928
                    - type: STRING
                      name: ds.0.color.4
                      value: 17becf
                    - type: STRING
                      name: ds.0.color.5
                      value: a6cee3
                    - type: STRING
                      name: ds.0.color.6
                      value: fb9a99
                    - type: STRING
                      name: ds.0.color.7
                      value: bcbd22
                    - type: STRING
                      name: ds.0.color.8
                      value: fdbf6f
                    - type: STRING
                      name: ds.0.color.9
                      value: e31a1c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.internal_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.ipmi_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.ipmi_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.http_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.java_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.6
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.vmware_collector.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.7
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.browser_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.8
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.odbc_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.9
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.icmp_pinger.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABJ
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Asynchronous gathering processes'
                  'y': '13'
                  width: '72'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: bcbd22
                    - type: STRING
                      name: ds.0.color.2
                      value: 6a3d9a
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.agent_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.http_agent_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.snmp_poller.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABK
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Internal processes: Core'
                  'y': '19'
                  width: '72'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: e31a1c
                    - type: STRING
                      name: ds.0.color.2
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.3
                      value: b15928
                    - type: STRING
                      name: ds.0.color.4
                      value: a6cee3
                    - type: STRING
                      name: ds.0.color.5
                      value: fdbf6f
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.configuration_syncer.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.history_syncer.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.self-monitoring.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.task_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.data_sender.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.housekeeper.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '6'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABL
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Gathering processes: Trappers'
                  'y': '25'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: cab2d6
                    - type: STRING
                      name: ds.0.color.1
                      value: fdbf6f
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.trapper.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.snmp_trapper.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABM
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Data exchange with server'
                  'y': '30'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: cab2d6
                    - type: STRING
                      name: ds.0.color.1
                      value: '000080'
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.trapper.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.data_sender.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABO
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Preprocessing processes'
                  x: '36'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: fdbf6f
                    - type: STRING
                      name: ds.0.color.1
                      value: 7e57c2
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.preprocessing_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.preprocessing_worker.avg.busy
                    - type: INTEGER
                      name: ds.1.axisy
                      value: '1'
                    - type: STRING
                      name: ds.1.color.0
                      value: ff465c
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.1.fill
                      value: '2'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: preprocessing_queue
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABI
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Availability processes'
                  x: '36'
                  'y': '25'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.1
                      value: b15928
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.unreachable_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: process.availability_manager.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABN
                    - type: INTEGER
                      name: show_problems
                      value: '1'
            - name: Statuses
              widgets:
                - type: item
                  name: 'Zabbix proxy version'
                  width: '18'
                  height: '3'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: version
                    - type: INTEGER
                      name: show.0
                      value: '2'
                    - type: INTEGER
                      name: show.1
                      value: '3'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: time_h_pos
                      value: '2'
                    - type: INTEGER
                      name: time_size
                      value: '9'
                    - type: INTEGER
                      name: time_v_pos
                      value: '2'
                    - type: INTEGER
                      name: value_size
                      value: '25'
                - type: item
                  name: Uptime
                  x: '18'
                  width: '18'
                  height: '3'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: uptime
                    - type: INTEGER
                      name: show.0
                      value: '2'
                    - type: INTEGER
                      name: show.1
                      value: '3'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: time_h_pos
                      value: '2'
                    - type: INTEGER
                      name: time_size
                      value: '9'
                    - type: INTEGER
                      name: time_v_pos
                      value: '2'
                    - type: INTEGER
                      name: value_size
                      value: '25'
                - type: item
                  name: 'Proxy buffer state'
                  x: '36'
                  width: '18'
                  height: '3'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'Remote Zabbix proxy health'
                        key: proxy_buffer.state.current
                    - type: INTEGER
                      name: show.0
                      value: '2'
                    - type: INTEGER
                      name: show.1
                      value: '3'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: time_h_pos
                      value: '2'
                    - type: INTEGER
                      name: time_size
                      value: '9'
                    - type: INTEGER
                      name: time_v_pos
                      value: '2'
                    - type: INTEGER
                      name: value_size
                      value: '25'
      valuemaps:
        - uuid: 70f06f62852c428b94f1f2447d58a6c8
          name: 'Proxy buffer mode'
          mappings:
            - value: '0'
              newvalue: Disk
            - value: '1'
              newvalue: Memory
        - uuid: d9fa93ed96d1497c9049f8f30267e9ed
          name: 'Zabbix proxy check'
          mappings:
            - value: '0'
              newvalue: 'True'
            - value: '1'
              newvalue: 'False'
    - uuid: 79b16cbbe593444eae3de66de0cb566b
      template: 'Remote Zabbix server health'
      name: 'Remote Zabbix server health'
      description: |
        This template is designed to monitor internal Zabbix metrics on the remote Zabbix server.
        
        Specify the address of the remote Zabbix server by changing the {$ZABBIX.SERVER.ADDRESS} and {$ZABBIX.SERVER.PORT} macros. Don't forget to adjust the "StatsAllowedIP" parameter in the remote server's configuration file to allow the collection of statistics.
        
        Generated by official Zabbix template tool "Templator"
      wizard_ready: 'YES'
      readme: |
        ## Overview
        
        This template is designed to monitor internal Zabbix metrics on the remote Zabbix server.
        
        ## Setup
        
        Specify the address of the remote Zabbix server as the values for the `Zabbix server Address` and `Zabbix server Port` configuration fields. Don't forget to adjust the `StatsAllowedIP` parameter in the remote server's configuration file to allow the collection of statistics.
      vendor:
        name: Zabbix
        version: 7.4-5
      groups:
        - name: Templates/Applications
      items:
        - uuid: 94235a52be114cb6a99cfc90834144e7
          name: 'Connector queue'
          type: DEPENDENT
          key: connector_queue
          description: 'The count of values enqueued in the connector queue.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.connector_queue
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "connector" processes started. Please check "StartConnectors" parameter in the server configuration file.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: c417ffdf78144a01811935d31e02af69
          name: 'Discovery queue'
          type: DEPENDENT
          key: discovery_queue
          description: 'The count of values enqueued in the discovery queue.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.discovery_queue
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "discoverer" processes started. Please check "StartDiscoverers" parameter in the server configuration file.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: adcf44e5179644b0bee34103d3d3688e
          name: 'LLD queue'
          type: DEPENDENT
          key: lld_queue
          description: 'The number of values enqueued in the low-level discovery processing queue.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.lld_queue
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: 9881f258f69d459195b5a19c56c523a8
          name: 'Preprocessing queue'
          type: DEPENDENT
          key: preprocessing_queue
          description: 'The number of values enqueued in the preprocessing queue.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.preprocessing.queue
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: 2f59c93854b746229eea6362c45d2a59
          name: 'Preprocessing throughput'
          type: DEPENDENT
          key: preprocessing_throughput
          value_type: FLOAT
          units: Bps
          description: 'Reflects the throughput of the preprocessing.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.preprocessing.queued.size
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: f9ce1b8b5b384a7ebbf0a1c6d19948b1
          name: 'Utilization of agent poller data collector processes, in %'
          type: DEPENDENT
          key: process.agent_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the agent poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''agent poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "agent poller" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: f47c5db67da54295950939e7f18ed062
              expression: 'avg(/Remote Zabbix server health/process.agent_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"agent poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.agent_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"agent poller"}'
              name: 'Zabbix server: Utilization of agent poller processes is high'
              event_name: 'Zabbix server: Utilization of agent poller processes over {$ZABBIX.SERVER.UTIL.MAX:"agent poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the agent poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: d8071d9c280c468cb70b19be50c756a5
          name: 'Utilization of alerter internal processes, in %'
          type: DEPENDENT
          key: process.alerter.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the alerter processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''alerter''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "alerter" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: d4aae59fe9294da5b1c724b051af1683
              expression: 'avg(/Remote Zabbix server health/process.alerter.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"alerter"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.alerter.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"alerter"}'
              name: 'Zabbix server: Utilization of alerter processes is high'
              event_name: 'Zabbix server: Utilization of alerter processes over {$ZABBIX.SERVER.UTIL.MAX:"alerter"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the alerter, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 14347f8309934849a2ac13974e4b66d1
          name: 'Utilization of alert manager internal processes, in %'
          type: DEPENDENT
          key: process.alert_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the alert manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''alert manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "alert manager" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 310f33d488ae4f5faa245c96f8dc583c
              expression: 'avg(/Remote Zabbix server health/process.alert_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"alert manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.alert_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"alert manager"}'
              name: 'Zabbix server: Utilization of alert manager processes is high'
              event_name: 'Zabbix server: Utilization of alert manager processes over {$ZABBIX.SERVER.UTIL.MAX:"alert manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the alert manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 236699e6400c4ae3a20868c79fd35027
          name: 'Utilization of alert syncer internal processes, in %'
          type: DEPENDENT
          key: process.alert_syncer.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the alert syncer processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''alert syncer''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "alert syncer" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 0eb23de05fac4aeab4ee4aa337545b16
              expression: 'avg(/Remote Zabbix server health/process.alert_syncer.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"alert syncer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.alert_syncer.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"alert syncer"}'
              name: 'Zabbix server: Utilization of alert syncer processes is high'
              event_name: 'Zabbix server: Utilization of alert syncer processes over {$ZABBIX.SERVER.UTIL.MAX:"alert syncer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the alert syncer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 44ae7bbbca5346a4926bf1208e00deb8
          name: 'Utilization of availability manager internal processes, in %'
          type: DEPENDENT
          key: process.availability_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the availability manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''availability manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "availability manager" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: ae06acfebdb3452b88359f1634c53876
              expression: 'avg(/Remote Zabbix server health/process.availability_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"availability manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.availability_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"availability manager"}'
              name: 'Zabbix server: Utilization of availability manager processes is high'
              event_name: 'Zabbix server: Utilization of availability manager processes over {$ZABBIX.SERVER.UTIL.MAX:"availability manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the availability manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 2270009e1b4c4cbb9cce4001b46df2ce
          name: 'Utilization of browser poller data collector processes, in %'
          type: DEPENDENT
          key: process.browser_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the browser poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''browser poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "browser poller" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 5c41e353d4a4442d992240214443ee4d
              expression: 'avg(/Remote Zabbix server health/process.browser_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"browser poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.browser_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"browser poller"}'
              name: 'Zabbix server: Utilization of browser poller processes is high'
              event_name: 'Zabbix server: Utilization of browser poller processes over {$ZABBIX.SERVER.UTIL.MAX:"browser poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the browser poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 439e81aed41e4fd7ba7f2e4a97ca1a91
          name: 'Utilization of configuration syncer internal processes, in %'
          type: DEPENDENT
          key: process.configuration_syncer.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the configuration syncer processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''configuration syncer''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "configuration syncer" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: f1caa410beea429eb91daaec8f027eb3
              expression: 'avg(/Remote Zabbix server health/process.configuration_syncer.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"configuration syncer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.configuration_syncer.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"configuration syncer"}'
              name: 'Zabbix server: Utilization of configuration syncer processes is high'
              event_name: 'Zabbix server: Utilization of configuration syncer processes over {$ZABBIX.SERVER.UTIL.MAX:"configuration syncer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the configuration syncer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: f8946a8a36774b00a01645ae77228a55
          name: 'Utilization of configuration syncer worker internal processes, in %'
          type: DEPENDENT
          key: process.configuration_syncer_worker.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the configuration syncer worker processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''configuration syncer worker''].busy.avg'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 4b33128b800f4d1384127b61a7dd7492
              expression: 'avg(/Remote Zabbix server health/process.configuration_syncer_worker.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"configuration syncer worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.configuration_syncer_worker.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"configuration syncer worker"}'
              name: 'Zabbix server: Utilization of configuration syncer worker processes is high'
              event_name: 'Zabbix server: Utilization of configuration syncer worker processes over {$ZABBIX.SERVER.UTIL.MAX:"configuration syncer worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the configuration syncer worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: b7564d4eb40848dbb299e74cd525a07d
          name: 'Utilization of connector manager internal processes, in %'
          type: DEPENDENT
          key: process.connector_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the connector manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''connector manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "connector manager" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: abe4c864b41a4a43b2ce963ed55a3f17
              expression: 'avg(/Remote Zabbix server health/process.connector_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"connector manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.connector_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"connector manager"}'
              name: 'Zabbix server: Utilization of connector manager processes is high'
              event_name: 'Zabbix server: Utilization of connector manager processes over {$ZABBIX.SERVER.UTIL.MAX:"connector manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the connector manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 9a75eee4853a44b1b5087e0fea6c5bcb
          name: 'Utilization of connector worker internal processes, in %'
          type: DEPENDENT
          key: process.connector_worker.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the connector worker processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''connector worker''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "connector worker" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: ba984299c08f44b2a99c6fee187bcf01
              expression: 'avg(/Remote Zabbix server health/process.connector_worker.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"connector worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.connector_worker.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"connector worker"}'
              name: 'Zabbix server: Utilization of connector worker processes is high'
              event_name: 'Zabbix server: Utilization of connector worker processes over {$ZABBIX.SERVER.UTIL.MAX:"connector worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the connector worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 09c61eeecc354f2da1a8efcc100d5f5c
          name: 'Utilization of discovery manager internal processes, in %'
          type: DEPENDENT
          key: process.discovery_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the discovery manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''discovery manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "discovery manager" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 96418e054e834497baffbd9ed0a4f6bf
              expression: 'avg(/Remote Zabbix server health/process.discovery_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"discovery manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.discovery_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"discovery manager"}'
              name: 'Zabbix server: Utilization of discovery manager processes is high'
              event_name: 'Zabbix server: Utilization of discovery manager processes over {$ZABBIX.SERVER.UTIL.MAX:"discovery manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the discovery manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 6bfbac5f75c54f2c87a35f1786ed73e8
          name: 'Utilization of discovery worker internal processes, in %'
          type: DEPENDENT
          key: process.discovery_worker.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the discovery worker processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''discovery worker''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "discovery worker" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: fd92a81e2c614aa8826f7ff92fad801a
              expression: 'avg(/Remote Zabbix server health/process.discovery_worker.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"discovery worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.discovery_worker.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"discovery worker"}'
              name: 'Zabbix server: Utilization of discovery worker processes is high'
              event_name: 'Zabbix server: Utilization of discovery worker processes over {$ZABBIX.SERVER.UTIL.MAX:"discovery worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the discovery worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: d8110a23217142b9b10f2eda00a96f39
          name: 'Utilization of escalator internal processes, in %'
          type: DEPENDENT
          key: process.escalator.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the escalator processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''escalator''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "escalator" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: de07be1b10d9446abed4a387dd4980dd
              expression: 'avg(/Remote Zabbix server health/process.escalator.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"escalator"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.escalator.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"escalator"}'
              name: 'Zabbix server: Utilization of escalator processes is high'
              event_name: 'Zabbix server: Utilization of escalator processes over {$ZABBIX.SERVER.UTIL.MAX:"escalator"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the escalator, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: edefe2732df14bc3933b8e1ff65fbd21
          name: 'Utilization of history poller internal processes, in %'
          type: DEPENDENT
          key: process.history_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the history poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''history poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "history poller" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 655c59a6151d4ce985a833d9f91efc2a
              expression: 'avg(/Remote Zabbix server health/process.history_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"history poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.history_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"history poller"}'
              name: 'Zabbix server: Utilization of history poller processes is high'
              event_name: 'Zabbix server: Utilization of history poller processes over {$ZABBIX.SERVER.UTIL.MAX:"history poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the history poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 2b651866c6f04880888a770e9a08a167
          name: 'Utilization of history syncer internal processes, in %'
          type: DEPENDENT
          key: process.history_syncer.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the history syncer processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''history syncer''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "history syncer" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: b8e6a6ce3667459bad05afa850e99bc0
              expression: 'avg(/Remote Zabbix server health/process.history_syncer.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"history syncer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.history_syncer.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"history syncer"}'
              name: 'Zabbix server: Utilization of history syncer processes is high'
              event_name: 'Zabbix server: Utilization of history syncer processes over {$ZABBIX.SERVER.UTIL.MAX:"history syncer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the history syncer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 8eb5b40740a349fbb14ed39dd840fc85
          name: 'Utilization of housekeeper internal processes, in %'
          type: DEPENDENT
          key: process.housekeeper.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the housekeeper processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''housekeeper''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "housekeeper" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: b879623a755e4b79972c2ad3189886a2
              expression: 'avg(/Remote Zabbix server health/process.housekeeper.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"housekeeper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.housekeeper.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"housekeeper"}'
              name: 'Zabbix server: Utilization of housekeeper processes is high'
              event_name: 'Zabbix server: Utilization of housekeeper processes over {$ZABBIX.SERVER.UTIL.MAX:"housekeeper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the housekeeper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 1d0a012bf32d43e2b7af6307dd0bf39f
          name: 'Utilization of http agent poller data collector processes, in %'
          type: DEPENDENT
          key: process.http_agent_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the http agent poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''http agent poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "http agent poller" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 79604a0e6fe040b391f00d97ad11f56c
              expression: 'avg(/Remote Zabbix server health/process.http_agent_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"http agent poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.http_agent_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"http agent poller"}'
              name: 'Zabbix server: Utilization of http agent poller processes is high'
              event_name: 'Zabbix server: Utilization of http agent poller processes over {$ZABBIX.SERVER.UTIL.MAX:"http agent poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the http agent poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 02371dc53214403dbf34ff9e970408ef
          name: 'Utilization of http poller data collector processes, in %'
          type: DEPENDENT
          key: process.http_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the http poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''http poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "http poller" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: f7b4217cdd4b46b1949a5e6ac5fc3d02
              expression: 'avg(/Remote Zabbix server health/process.http_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"http poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.http_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"http poller"}'
              name: 'Zabbix server: Utilization of http poller processes is high'
              event_name: 'Zabbix server: Utilization of http poller processes over {$ZABBIX.SERVER.UTIL.MAX:"http poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the http poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 3a2dfedfac164b69a01105137eefd5e9
          name: 'Utilization of icmp pinger data collector processes, in %'
          type: DEPENDENT
          key: process.icmp_pinger.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the icmp pinger processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''icmp pinger''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "icmp pinger" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 312d404ff20740f38385ebe7c3e36d8f
              expression: 'avg(/Remote Zabbix server health/process.icmp_pinger.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"icmp pinger"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.icmp_pinger.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"icmp pinger"}'
              name: 'Zabbix server: Utilization of icmp pinger processes is high'
              event_name: 'Zabbix server: Utilization of icmp pinger processes over {$ZABBIX.SERVER.UTIL.MAX:"icmp pinger"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the icmp pinger, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: c8257547b30e424b9b6893896b2d8dd7
          name: 'Utilization of internal poller data collector processes, in %'
          type: DEPENDENT
          key: process.internal_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the internal poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''internal poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "internal poller" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: a84501d9e5b74b4990a896f8719b980d
              expression: 'avg(/Remote Zabbix server health/process.internal_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"internal poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.internal_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"internal poller"}'
              name: 'Zabbix server: Utilization of internal poller processes is high'
              event_name: 'Zabbix server: Utilization of internal poller processes over {$ZABBIX.SERVER.UTIL.MAX:"internal poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the internal poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 52a05106bc5e4e05b04142827f394662
          name: 'Utilization of ipmi manager internal processes, in %'
          type: DEPENDENT
          key: process.ipmi_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the ipmi manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''ipmi manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "ipmi manager" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 3fe728ab8de9447c899b2a919b885cec
              expression: 'avg(/Remote Zabbix server health/process.ipmi_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"ipmi manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.ipmi_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"ipmi manager"}'
              name: 'Zabbix server: Utilization of ipmi manager processes is high'
              event_name: 'Zabbix server: Utilization of ipmi manager processes over {$ZABBIX.SERVER.UTIL.MAX:"ipmi manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the ipmi manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 849f8b11cc984c758c4947fe256e3310
          name: 'Utilization of ipmi poller data collector processes, in %'
          type: DEPENDENT
          key: process.ipmi_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the ipmi poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''ipmi poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "ipmi poller" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: dbf27d6a629a4a2cb75e04849b93ac0f
              expression: 'avg(/Remote Zabbix server health/process.ipmi_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"ipmi poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.ipmi_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"ipmi poller"}'
              name: 'Zabbix server: Utilization of ipmi poller processes is high'
              event_name: 'Zabbix server: Utilization of ipmi poller processes over {$ZABBIX.SERVER.UTIL.MAX:"ipmi poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the ipmi poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: e55654715f8143c597c858d7eb522e31
          name: 'Utilization of java poller data collector processes, in %'
          type: DEPENDENT
          key: process.java_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the java poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''java poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "java poller" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 304a2dcf77c8494fb18f52cc6bae73a9
              expression: 'avg(/Remote Zabbix server health/process.java_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"java poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.java_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"java poller"}'
              name: 'Zabbix server: Utilization of java poller processes is high'
              event_name: 'Zabbix server: Utilization of java poller processes over {$ZABBIX.SERVER.UTIL.MAX:"java poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the java poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: b8504e03317649399dabfffc2758d77c
          name: 'Utilization of LLD manager internal processes, in %'
          type: DEPENDENT
          key: process.lld_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the LLD manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''lld manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "LLD manager" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 4027f813da2549cfb99e1bb5e04e1d28
              expression: 'avg(/Remote Zabbix server health/process.lld_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"LLD manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.lld_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"LLD manager"}'
              name: 'Zabbix server: Utilization of LLD manager processes is high'
              event_name: 'Zabbix server: Utilization of LLD manager processes over {$ZABBIX.SERVER.UTIL.MAX:"LLD manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the LLD manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: c4d708a59d314de6814f4936ec6b0a99
          name: 'Utilization of LLD worker internal processes, in %'
          type: DEPENDENT
          key: process.lld_worker.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the LLD worker processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''lld worker''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "LLD worker" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: ef1e836e906e4cf79b9fc8a11818c0a6
              expression: 'avg(/Remote Zabbix server health/process.lld_worker.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"LLD worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.lld_worker.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"LLD worker"}'
              name: 'Zabbix server: Utilization of LLD worker processes is high'
              event_name: 'Zabbix server: Utilization of LLD worker processes over {$ZABBIX.SERVER.UTIL.MAX:"LLD worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the LLD worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 8a21a0281ae24e0788edc8c9b875a421
          name: 'Utilization of ODBC poller data collector processes, in %'
          type: DEPENDENT
          key: process.odbc_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the ODBC poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''odbc poller''].busy.avg'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: eadd70080005430c8b11666d7e93a095
              expression: 'avg(/Remote Zabbix server health/process.odbc_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"ODBC poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.odbc_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"ODBC poller"}'
              name: 'Zabbix server: Utilization of ODBC poller processes is high'
              event_name: 'Zabbix server: Utilization of ODBC poller processes over {$ZABBIX.SERVER.UTIL.MAX:"ODBC poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the ODBC poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 61df12fa054b46f4b50596807dbc90c3
          name: 'Utilization of poller data collector processes, in %'
          type: DEPENDENT
          key: process.poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "poller" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 689ed5dd9bbd4873a825dfa675378d50
              expression: 'avg(/Remote Zabbix server health/process.poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"poller"}'
              name: 'Zabbix server: Utilization of poller processes is high'
              event_name: 'Zabbix server: Utilization of poller processes over {$ZABBIX.SERVER.UTIL.MAX:"poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 42e9efb8e5e54b26b84372dc53e823b3
          name: 'Utilization of preprocessing manager internal processes, in %'
          type: DEPENDENT
          key: process.preprocessing_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the preprocessing manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''preprocessing manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "preprocessing manager" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: b43f04a35e17415bb81bfb59357d45ac
              expression: 'avg(/Remote Zabbix server health/process.preprocessing_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"preprocessing manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.preprocessing_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"preprocessing manager"}'
              name: 'Zabbix server: Utilization of preprocessing manager processes is high'
              event_name: 'Zabbix server: Utilization of preprocessing manager processes over {$ZABBIX.SERVER.UTIL.MAX:"preprocessing manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the preprocessing manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 90bd4b46d63845b98a2c430aac157ea5
          name: 'Utilization of preprocessing worker internal processes, in %'
          type: DEPENDENT
          key: process.preprocessing_worker.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the preprocessing worker processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''preprocessing worker''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "preprocessing worker" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 1c28310eb72047449437ee94854029fa
              expression: 'avg(/Remote Zabbix server health/process.preprocessing_worker.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"preprocessing worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.preprocessing_worker.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"preprocessing worker"}'
              name: 'Zabbix server: Utilization of preprocessing worker processes is high'
              event_name: 'Zabbix server: Utilization of preprocessing worker processes over {$ZABBIX.SERVER.UTIL.MAX:"preprocessing worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the preprocessing worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: c75afd4bc7794328a96ac261dc4776aa
          name: 'Utilization of proxy group manager internal processes, in %'
          type: DEPENDENT
          key: process.proxy_group_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the proxy group manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''proxy group manager''].busy.avg'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 06bdef8b23c3459c99e180afdb1a8b2c
              expression: 'avg(/Remote Zabbix server health/process.proxy_group_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"proxy group manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.proxy_group_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"proxy group manager"}'
              name: 'Zabbix server: Utilization of proxy group manager processes is high'
              event_name: 'Zabbix server: Utilization of proxy group manager processes over {$ZABBIX.SERVER.UTIL.MAX:"proxy group manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the proxy group manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 4c5eb5acc8a447afa47d732988dafbd9
          name: 'Utilization of proxy poller data collector processes, in %'
          type: DEPENDENT
          key: process.proxy_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the proxy poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''proxy poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "proxy poller" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: c0d2c7c008cb45ee8b032b7c83018ae1
              expression: 'avg(/Remote Zabbix server health/process.proxy_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"proxy poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.proxy_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"proxy poller"}'
              name: 'Zabbix server: Utilization of proxy poller processes is high'
              event_name: 'Zabbix server: Utilization of proxy poller processes over {$ZABBIX.SERVER.UTIL.MAX:"proxy poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the proxy poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 032c86725d7d479e8e0a8cf0ea14b349
          name: 'Utilization of report manager internal processes, in %'
          type: DEPENDENT
          key: process.report_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the report manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''report manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "report manager" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 32d6f18edd5a45e1999f294f227c600f
              expression: 'avg(/Remote Zabbix server health/process.report_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"report manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.report_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"report manager"}'
              name: 'Zabbix server: Utilization of report manager processes is high'
              event_name: 'Zabbix server: Utilization of report manager processes over {$ZABBIX.SERVER.UTIL.MAX:"report manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the report manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 0a91377a6d5a460aa716164b201db6c0
          name: 'Utilization of report writer internal processes, in %'
          type: DEPENDENT
          key: process.report_writer.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the report writer processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''report writer''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "report writer" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 83fa871d54f74c89a7c85d429d40da53
              expression: 'avg(/Remote Zabbix server health/process.report_writer.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"report writer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.report_writer.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"report writer"}'
              name: 'Zabbix server: Utilization of report writer processes is high'
              event_name: 'Zabbix server: Utilization of report writer processes over {$ZABBIX.SERVER.UTIL.MAX:"report writer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the report writer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 044bb995bcae42568979fd958383fc60
          name: 'Utilization of self-monitoring internal processes, in %'
          type: DEPENDENT
          key: process.self-monitoring.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the self-monitoring processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''self-monitoring''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "self-monitoring" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 0d9b8d1f2d7d454ab472320ac172252c
              expression: 'avg(/Remote Zabbix server health/process.self-monitoring.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"self-monitoring"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.self-monitoring.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"self-monitoring"}'
              name: 'Zabbix server: Utilization of self-monitoring processes is high'
              event_name: 'Zabbix server: Utilization of self-monitoring processes over {$ZABBIX.SERVER.UTIL.MAX:"self-monitoring"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the self-monitoring, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 99da1d8bd47447d282542d40c1edea00
          name: 'Utilization of service manager internal processes, in %'
          type: DEPENDENT
          key: process.service_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the service manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''service manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "service manager" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 001c9e2027ca4e7c8f5dc5b78681c573
              expression: 'avg(/Remote Zabbix server health/process.service_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"service manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.service_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"service manager"}'
              name: 'Zabbix server: Utilization of service manager processes is high'
              event_name: 'Zabbix server: Utilization of service manager processes over {$ZABBIX.SERVER.UTIL.MAX:"service manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the service manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: faec2628848140549aa8cb1cb247b4ea
          name: 'Utilization of snmp poller data collector processes, in %'
          type: DEPENDENT
          key: process.snmp_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the snmp poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''snmp poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "snmp poller" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 18407657b6a647e292a3625180ccb313
              expression: 'avg(/Remote Zabbix server health/process.snmp_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"snmp poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.snmp_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"snmp poller"}'
              name: 'Zabbix server: Utilization of snmp poller processes is high'
              event_name: 'Zabbix server: Utilization of snmp poller processes over {$ZABBIX.SERVER.UTIL.MAX:"snmp poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the snmp poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 643036d74a10414f94dc357efbbd42b2
          name: 'Utilization of snmp trapper data collector processes, in %'
          type: DEPENDENT
          key: process.snmp_trapper.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the snmp trapper processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''snmp trapper''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "snmp trapper" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 4726331c52284261aa3f347448c1c3c5
              expression: 'avg(/Remote Zabbix server health/process.snmp_trapper.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"snmp trapper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.snmp_trapper.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"snmp trapper"}'
              name: 'Zabbix server: Utilization of snmp trapper processes is high'
              event_name: 'Zabbix server: Utilization of snmp trapper processes over {$ZABBIX.SERVER.UTIL.MAX:"snmp trapper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the snmp trapper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 7fad0515db154228b5baabb51d647a9f
          name: 'Utilization of task manager internal processes, in %'
          type: DEPENDENT
          key: process.task_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the task manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''task manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "task manager" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 07d29e82b74a4cc5b0d701458af302b7
              expression: 'avg(/Remote Zabbix server health/process.task_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"task manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.task_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"task manager"}'
              name: 'Zabbix server: Utilization of task manager processes is high'
              event_name: 'Zabbix server: Utilization of task manager processes over {$ZABBIX.SERVER.UTIL.MAX:"task manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the task manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 105eae2d56d34d91b540f93009a575aa
          name: 'Utilization of timer internal processes, in %'
          type: DEPENDENT
          key: process.timer.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the timer processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''timer''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "timer" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 72f3b3f143a94f5a9b4b2c509425954e
              expression: 'avg(/Remote Zabbix server health/process.timer.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"timer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.timer.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"timer"}'
              name: 'Zabbix server: Utilization of timer processes is high'
              event_name: 'Zabbix server: Utilization of timer processes over {$ZABBIX.SERVER.UTIL.MAX:"timer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the timer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 9c90b3a087e1495caa17a00bebb70145
          name: 'Utilization of trapper data collector processes, in %'
          type: DEPENDENT
          key: process.trapper.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the trapper processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''trapper''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "trapper" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: d31285f177224c4cb570373f6a730019
              expression: 'avg(/Remote Zabbix server health/process.trapper.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"trapper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.trapper.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"trapper"}'
              name: 'Zabbix server: Utilization of trapper processes is high'
              event_name: 'Zabbix server: Utilization of trapper processes over {$ZABBIX.SERVER.UTIL.MAX:"trapper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the trapper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 56dca0db33264d4b9c8fd769fbdff7b5
          name: 'Utilization of trigger housekeeper internal processes, in %'
          type: DEPENDENT
          key: process.trigger_housekeeper.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the trigger housekeeper processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''trigger housekeeper''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "trigger housekeeper" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 9c0daf6e85884122aa8c5b8432709c92
              expression: 'avg(/Remote Zabbix server health/process.trigger_housekeeper.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"trigger housekeeper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.trigger_housekeeper.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"trigger housekeeper"}'
              name: 'Zabbix server: Utilization of trigger housekeeper processes is high'
              event_name: 'Zabbix server: Utilization of trigger housekeeper processes over {$ZABBIX.SERVER.UTIL.MAX:"trigger housekeeper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the trigger housekeeper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 8d43954f6b9843009353c560a4f84157
          name: 'Utilization of unreachable poller data collector processes, in %'
          type: DEPENDENT
          key: process.unreachable_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the unreachable poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''unreachable poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "unreachable poller" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: d254ccddc7dd4e1ebf1eaa5113270e85
              expression: 'avg(/Remote Zabbix server health/process.unreachable_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"unreachable poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.unreachable_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"unreachable poller"}'
              name: 'Zabbix server: Utilization of unreachable poller processes is high'
              event_name: 'Zabbix server: Utilization of unreachable poller processes over {$ZABBIX.SERVER.UTIL.MAX:"unreachable poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the unreachable poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 9f02a181362b42b882d869353fae93ce
          name: 'Utilization of vmware collector data collector processes, in %'
          type: DEPENDENT
          key: process.vmware_collector.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the vmware collector processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''vmware collector''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "vmware collector" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 5929cfbe23494a41a20a4c05854f9578
              expression: 'avg(/Remote Zabbix server health/process.vmware_collector.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"vmware collector"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Remote Zabbix server health/process.vmware_collector.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"vmware collector"}'
              name: 'Zabbix server: Utilization of vmware collector processes is high'
              event_name: 'Zabbix server: Utilization of vmware collector processes over {$ZABBIX.SERVER.UTIL.MAX:"vmware collector"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the vmware collector, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 750964513e1d44d7b138980d6cac2188
          name: 'Configuration cache, % used'
          type: DEPENDENT
          key: rcache.buffer.pused
          value_type: FLOAT
          units: '%'
          description: 'The availability statistics of Zabbix configuration cache. The percentage of used data buffer.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.rcache.pused
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 9d5f36b486ab4781a5f58210143785e9
              expression: 'max(/Remote Zabbix server health/rcache.buffer.pused,10m)>{$ZABBIX.SERVER.UTIL.MAX:"configuration cache"}'
              name: 'Zabbix server: Excessive configuration cache usage'
              event_name: 'Zabbix server: More than {$ZABBIX.SERVER.UTIL.MAX:"configuration cache"}% used in the configuration cache'
              priority: AVERAGE
              description: 'Consider increasing `CacheSize` in the `zabbix_server.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
            - uuid: 07fbcbe743f84727838c982a51d36441
              expression: 'nodata(/Remote Zabbix server health/rcache.buffer.pused,{$ZABBIX.SERVER.NODATA_TIMEOUT})=1'
              name: 'Zabbix server: Failed to fetch stats data'
              event_name: 'Zabbix server: Failed to fetch stats data (or no data for {$ZABBIX.SERVER.NODATA_TIMEOUT})'
              priority: WARNING
              description: 'Zabbix has not received statistics data for `{$ZABBIX.SERVER.NODATA_TIMEOUT}`.'
              tags:
                - tag: scope
                  value: availability
        - uuid: b6f47aa7b1b7407da7acd634a9859038
          name: 'Zabbix server check'
          type: DEPENDENT
          key: server_check
          trends: '0'
          description: 'Flag indicating whether it is a server or not.'
          valuemap:
            name: 'Zabbix server check'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.triggers
              error_handler: CUSTOM_VALUE
              error_handler_params: '0'
            - type: IN_RANGE
              parameters:
                - ''
                - '0'
              error_handler: CUSTOM_VALUE
              error_handler_params: '1'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 49e7153a96e74b60aad73cd91a792098
              expression: 'last(/Remote Zabbix server health/server_check)=0'
              name: 'Zabbix server: Wrong template assigned'
              event_name: 'Zabbix server: Zabbix server template is assigned to Zabbix proxy'
              priority: DISASTER
              description: 'Check that the template has been selected correctly.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: 1625b3470fbf4bd7aa5b7051e328b37c
          name: 'Trend function cache, % of unique requests'
          type: DEPENDENT
          key: tcache.pitems
          value_type: FLOAT
          units: '%'
          description: |
            The effectiveness statistics of the Zabbix trend function cache. The percentage of cached items calculated from the sum of the cached items plus requests.
            A low percentage most likely means that the cache size can be reduced.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.tcache.pitems
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Not supported in this version.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: 2c8bf95e97dd48679e34591c72626c90
          name: 'Trend function cache, % of misses'
          type: DEPENDENT
          key: tcache.pmisses
          value_type: FLOAT
          units: '%'
          description: 'The effectiveness statistics of the Zabbix trend function cache. The percentage of cache misses.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.tcache.pmisses
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Not supported in this version.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: 9f9d8d1fcd08498698e37b5889502b47
          name: 'Value cache, % used'
          type: DEPENDENT
          key: vcache.buffer.pused
          value_type: FLOAT
          units: '%'
          description: 'The availability statistics of Zabbix value cache. The percentage of used data buffer.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.vcache.buffer.pused
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: d35671cd02034aeba3c7c71ed618f4ee
              expression: 'max(/Remote Zabbix server health/vcache.buffer.pused,10m)>{$ZABBIX.SERVER.UTIL.MAX:"value cache"}'
              name: 'Zabbix server: Excessive value cache usage'
              event_name: 'Zabbix server: More than {$ZABBIX.SERVER.UTIL.MAX:"value cache"}% used in the value cache'
              priority: AVERAGE
              description: 'Consider increasing `ValueCacheSize` in the `zabbix_server.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 9bd0079126974bf2a61f552de2cdf880
          name: 'Value cache hits'
          type: DEPENDENT
          key: vcache.cache.hits
          value_type: FLOAT
          units: '!vps'
          description: 'The effectiveness statistics of Zabbix value cache. The number of cache hits (history values taken from the cache).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.vcache.cache.hits
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: e8c372778d4e434e98d3fba5ea603a50
          name: 'Value cache misses'
          type: DEPENDENT
          key: vcache.cache.misses
          value_type: FLOAT
          units: '!vps'
          description: 'The effectiveness statistics of Zabbix value cache. The number of cache misses (history values taken from the database).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.vcache.cache.misses
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: 1a1daeb7267f4ed4bf75c70699d487b6
          name: 'Value cache operating mode'
          type: DEPENDENT
          key: vcache.cache.mode
          units: '!vps'
          description: 'The operating mode of the value cache.'
          valuemap:
            name: 'Value cache operating mode'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.vcache.cache.mode
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 95e8823159fc4baeb13d656be176ac16
              expression: 'last(/Remote Zabbix server health/vcache.cache.mode)=1'
              name: 'Zabbix server: Zabbix value cache working in low-memory mode'
              priority: HIGH
              description: 'Once low-memory mode has been switched on, the value cache will remain in this state for 24 hours, even if the problem that triggered this mode is resolved sooner.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: f0eab81aaf464b809ea4d487548e57c6
          name: Version
          type: DEPENDENT
          key: version
          value_type: CHAR
          description: 'The version of Zabbix server.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.version
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 93a52f22c79b40539fcd3a26183daad9
              expression: 'last(/Remote Zabbix server health/version,#1)<>last(/Remote Zabbix server health/version,#2) and length(last(/Remote Zabbix server health/version))>0'
              name: 'Zabbix server: Version has changed'
              event_name: 'Zabbix server: Version has changed (new version: {ITEM.VALUE})'
              priority: INFO
              description: 'Zabbix server version has changed. Acknowledge to close the problem manually.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: 9e2b2133916e4ce29ed4e9ca07c74123
          name: 'VMware cache, % used'
          type: DEPENDENT
          key: vmware.buffer.pused
          value_type: FLOAT
          units: '%'
          description: 'The availability statistics of Zabbix vmware cache. The percentage of used data buffer.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.vmware.pused
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "vmware collector" processes started.'
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 08e6c62dd52b4a0694be910c4f4fa997
              expression: 'max(/Remote Zabbix server health/vmware.buffer.pused,10m)>{$ZABBIX.SERVER.UTIL.MAX:"vmware cache"}'
              name: 'Zabbix server: Excessive vmware cache usage'
              event_name: 'Zabbix server: More than {$ZABBIX.SERVER.UTIL.MAX:"vmware cache"}% used in the vmware cache'
              priority: AVERAGE
              description: 'Consider increasing `VMwareCacheSize` in the `zabbix_server.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 850743f411d9458cbf5d6de410d15edc
          name: 'Number of values synchronized with the database per second'
          type: DEPENDENT
          key: vps.written
          value_type: FLOAT
          units: '!vps'
          description: 'Average quantity of values written to the database, recalculated once per minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.vps.written_total
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 98f47a07e2ba4294a9eb2aa1df2ba9f3
          name: 'History write cache, % used'
          type: DEPENDENT
          key: wcache.history.pused
          value_type: FLOAT
          units: '%'
          description: |
            The statistics and availability of Zabbix write cache. The percentage of used history buffer.
            The history cache is used to store item values. A high number indicates database performance problems.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.history.pused
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: a66914bd7f2e4442a8b555deacebb4c9
              expression: 'max(/Remote Zabbix server health/wcache.history.pused,10m)>{$ZABBIX.SERVER.UTIL.MAX:"history cache"}'
              name: 'Zabbix server: Excessive history cache usage'
              event_name: 'Zabbix server: More than {$ZABBIX.SERVER.UTIL.MAX:"history cache"}% used in the history cache'
              priority: AVERAGE
              description: 'Consider increasing `HistoryCacheSize` in the `zabbix_server.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: b1add70210a44b668f06cc3e062173ad
          name: 'History index cache, % used'
          type: DEPENDENT
          key: wcache.index.pused
          value_type: FLOAT
          units: '%'
          description: |
            The statistics and availability of Zabbix write cache. The percentage of used history index buffer.
            The history index cache is used to index values stored in the history cache.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.index.pused
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 6aedbc1768ed4f949890248af98fdaa2
              expression: 'max(/Remote Zabbix server health/wcache.index.pused,10m)>{$ZABBIX.SERVER.UTIL.MAX:"index cache"}'
              name: 'Zabbix server: Excessive history index cache usage'
              event_name: 'Zabbix server: More than {$ZABBIX.SERVER.UTIL.MAX:"index cache"}% used in the history index cache'
              priority: AVERAGE
              description: 'Consider increasing `HistoryIndexCacheSize` in the `zabbix_server.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 1f79208bb2ec4e4eb26e6e1b95c3635e
          name: 'Trend write cache, % used'
          type: DEPENDENT
          key: wcache.trend.pused
          value_type: FLOAT
          units: '%'
          description: |
            The statistics and availability of Zabbix write cache. The percentage of used trend buffer.
            The trend cache stores the aggregate of all items that have received data for the current hour.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.trend.pused
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 742a4938fdd24026921b375a67cea921
              expression: 'max(/Remote Zabbix server health/wcache.trend.pused,10m)>{$ZABBIX.SERVER.UTIL.MAX:"trend cache"}'
              name: 'Zabbix server: Excessive trends cache usage'
              event_name: 'Zabbix server: More than {$ZABBIX.SERVER.UTIL.MAX:"trend cache"}% used in the trends cache'
              priority: AVERAGE
              description: 'Consider increasing `TrendCacheSize` in the `zabbix_server.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 34fe014843974248a98a45596ce43e1a
          name: 'Number of processed values per second'
          type: DEPENDENT
          key: wcache.values
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The total number of values processed by Zabbix server or Zabbix proxy, except unsupported items.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.all
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 206f4fcb1e6d4e468a172e330f56b8aa
          name: 'Number of processed numeric (float) values per second'
          type: DEPENDENT
          key: wcache.values.float
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed numeric (float) values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.float
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: e2f3dc320d54446b80862eabe6fa0be5
          name: 'Number of processed log values per second'
          type: DEPENDENT
          key: wcache.values.log
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed log values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.log
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 82e088caf6e14c1cab700ad7fcc96263
          name: 'Number of processed not supported values per second'
          type: DEPENDENT
          key: wcache.values.not_supported
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of times the item processing resulted in an item becoming unsupported or remaining in that state.
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.wcache.values[''not supported'']'
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 99415cd1920a4e7f8b99f3c71e7eba97
          name: 'Number of processed character values per second'
          type: DEPENDENT
          key: wcache.values.str
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed character values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.str
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 7172378f31a44a36a095a2c2afed763b
          name: 'Number of processed text values per second'
          type: DEPENDENT
          key: wcache.values.text
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed text values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.text
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 7865ba7a928945f4a148acf623b72537
          name: 'Number of processed numeric (unsigned) values per second'
          type: DEPENDENT
          key: wcache.values.uint
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed numeric (unsigned) values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.uint
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 1e6a7ebfc0de47fd823ff59458317172
          name: 'Zabbix proxies stats'
          type: DEPENDENT
          key: zabbix.proxies.stats
          history: '0'
          value_type: TEXT
          description: 'The master item of Zabbix proxies'' statistics.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.proxy
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: raw
        - uuid: 95c8bab7640a4227b8ce6cac06e1a08b
          name: 'Queue over 10 minutes'
          type: INTERNAL
          key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT},queue,10m]'
          description: 'The number of monitored items in the queue that are delayed by at least 10 minutes.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.queue
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: c8eddec1bb9740bb8ca05f74bd023fcc
              expression: 'min(/Remote Zabbix server health/zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT},queue,10m],10m)>100'
              name: 'Zabbix server: More than 100 items have been missing data for over 10 minutes'
              priority: WARNING
              description: 'Indicates potential issues with network connectivity, agent failures, or unresponsive monitored resources that require attention.'
              tags:
                - tag: scope
                  value: performance
        - uuid: c140ebe6c0404ee6b17b5ada2de09f28
          name: Queue
          type: INTERNAL
          key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT},queue]'
          description: 'The number of monitored items in the queue that are delayed by at least 6 seconds.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.queue
          tags:
            - tag: component
              value: system
        - uuid: b9a588fee45047b6b991015e7e83f3f2
          name: 'Zabbix stats'
          type: INTERNAL
          key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          history: '0'
          value_type: TEXT
          description: 'The master item of Zabbix server statistics.'
          tags:
            - tag: component
              value: raw
      discovery_rules:
        - uuid: 0557f879881a4d558410444737ae3738
          name: 'High availability cluster node discovery'
          type: DEPENDENT
          key: zabbix.nodes.discovery
          description: 'LLD rule with item and trigger prototypes for node discovery.'
          item_prototypes:
            - uuid: caca3ccdcec141a3a9c3233ba72b8d0d
              name: 'Cluster node [{#NODE.NAME}]: Address'
              type: DEPENDENT
              key: 'zabbix.node.address[{#NODE.ID}]'
              value_type: CHAR
              description: 'The IPv4 address of a node.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.address
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.node.stats[{#NODE.ID}]'
              tags:
                - tag: component
                  value: cluster
                - tag: node-id
                  value: '{#NODE.ID}'
                - tag: node-name
                  value: '{#NODE.NAME}'
            - uuid: a9ded61c4dba4abb9213aec9af00a604
              name: 'Cluster node [{#NODE.NAME}]: Last access age'
              type: DEPENDENT
              key: 'zabbix.node.lastaccess.age[{#NODE.ID}]'
              units: uptime
              description: 'The time between the database''s `unix_timestamp()` and the last access time.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.lastaccess_age
              master_item:
                key: 'zabbix.node.stats[{#NODE.ID}]'
              tags:
                - tag: component
                  value: cluster
                - tag: node-id
                  value: '{#NODE.ID}'
                - tag: node-name
                  value: '{#NODE.NAME}'
            - uuid: 0968e4fe51eb4c2b98a508090014aba0
              name: 'Cluster node [{#NODE.NAME}]: Last access time'
              type: DEPENDENT
              key: 'zabbix.node.lastaccess.time[{#NODE.ID}]'
              units: unixtime
              description: 'Last access time.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.lastaccess
              master_item:
                key: 'zabbix.node.stats[{#NODE.ID}]'
              tags:
                - tag: component
                  value: cluster
                - tag: node-id
                  value: '{#NODE.ID}'
                - tag: node-name
                  value: '{#NODE.NAME}'
            - uuid: 525b8142186b488eacb5db7a6044b3c4
              name: 'Cluster node [{#NODE.NAME}]: Stats'
              type: DEPENDENT
              key: 'zabbix.node.stats[{#NODE.ID}]'
              history: '0'
              value_type: TEXT
              description: 'Provides the statistics of a node.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.data.ha[?(@.id=="{#NODE.ID}")].first()'
              master_item:
                key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
              tags:
                - tag: component
                  value: cluster
                - tag: component
                  value: raw
                - tag: node-id
                  value: '{#NODE.ID}'
                - tag: node-name
                  value: '{#NODE.NAME}'
            - uuid: 2b629362886546cab34396352b93835a
              name: 'Cluster node [{#NODE.NAME}]: Status'
              type: DEPENDENT
              key: 'zabbix.nodes.status[{#NODE.ID}]'
              description: 'The status of a node.'
              valuemap:
                name: 'Cluster node status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.node.stats[{#NODE.ID}]'
              tags:
                - tag: component
                  value: cluster
                - tag: node-id
                  value: '{#NODE.ID}'
                - tag: node-name
                  value: '{#NODE.NAME}'
              trigger_prototypes:
                - uuid: 5d68b55175924cb4adde600a019496c4
                  expression: 'last(/Remote Zabbix server health/zabbix.nodes.status[{#NODE.ID}],#1)<>last(/Remote Zabbix server health/zabbix.nodes.status[{#NODE.ID}],#2)'
                  name: 'Zabbix server: Cluster node [{#NODE.NAME}]: Status changed'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: INFO
                  description: 'The state of the node has changed. Acknowledge to close the problem manually.'
                  manual_close: 'YES'
                  tags:
                    - tag: scope
                      value: availability
          master_item:
            key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          lld_macro_paths:
            - lld_macro: '{#NODE.ID}'
              path: $.id
            - lld_macro: '{#NODE.NAME}'
              path: $.name
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.ha
            - type: JAVASCRIPT
              parameters:
                - |
                  var hacluster = JSON.parse(value);
                  
                  result = hacluster.map(function (hanode) {
                  	return {
                  		'id': hanode.id,
                  		'name': hanode.name
                  	};
                  });
                  
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
        - uuid: db52e7ced392405184955a884ad9dd00
          name: 'Zabbix proxy discovery'
          type: DEPENDENT
          key: zabbix.proxy.discovery
          description: 'LLD rule with item and trigger prototypes for proxy discovery.'
          item_prototypes:
            - uuid: b1fe4bb454a543a78cfa84810e320b46
              name: 'Proxy [{#PROXY.NAME}]: Certificate'
              type: DEPENDENT
              key: 'zabbix.proxy.cert[{#PROXY.NAME}]'
              description: 'The encryption status for connections from a proxy.'
              valuemap:
                name: 'Service state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.cert
                - type: JAVASCRIPT
                  parameters:
                    - 'return value === ''false'' ? 0 : 1'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: fb38b7fa4daa4ab28338f96d9f903ff8
              name: 'Proxy [{#PROXY.NAME}]: Compatibility'
              type: DEPENDENT
              key: 'zabbix.proxy.compatibility[{#PROXY.NAME}]'
              description: |
                Version of proxy compared to Zabbix server version.
                
                Possible values:
                0 - Undefined;
                1 - Current version (proxy and server have the same major version);
                2 - Outdated version (proxy version is older than server version, but is partially supported);
                3 - Unsupported version (proxy version is older than server previous LTS release version or server major version is older than proxy major version).
              valuemap:
                name: Compatibility
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.compatibility
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
              trigger_prototypes:
                - uuid: 84365975ffa5450db47edd42adbae719
                  expression: 'last(/Remote Zabbix server health/zabbix.proxy.compatibility[{#PROXY.NAME}],#1)=3'
                  name: 'Zabbix server: Proxy [{#PROXY.NAME}]: Zabbix proxy is not supported'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: HIGH
                  description: 'Zabbix proxy version is older than server previous LTS release version or server major version is older than proxy major version.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 53dbaf21b8934ea9bada97431d4b3e23
                  expression: 'last(/Remote Zabbix server health/zabbix.proxy.compatibility[{#PROXY.NAME}],#1)=2'
                  name: 'Zabbix server: Proxy [{#PROXY.NAME}]: Zabbix proxy is outdated'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: WARNING
                  description: 'Zabbix proxy version is older than server version, but is partially supported. Only data collection and remote execution is available.'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: 7c5a679fd7a34abca9d70e87150bb682
              name: 'Proxy [{#PROXY.NAME}]: Compression'
              type: DEPENDENT
              key: 'zabbix.proxy.compression[{#PROXY.NAME}]'
              description: 'The compression status of a proxy.'
              valuemap:
                name: 'Service state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.compression
                - type: JAVASCRIPT
                  parameters:
                    - 'return value === ''false'' ? 0 : 1'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 5db51524aa24458eaa1fa318adc77430
              name: 'Proxy [{#PROXY.NAME}]: Host count'
              type: DEPENDENT
              key: 'zabbix.proxy.hosts[{#PROXY.NAME}]'
              description: 'The number of enabled hosts assigned to a proxy.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.hosts
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 84c3d0ad89574545b0756a6385c09961
              name: 'Proxy [{#PROXY.NAME}]: Item count'
              type: DEPENDENT
              key: 'zabbix.proxy.items[{#PROXY.NAME}]'
              description: 'The number of enabled items on enabled hosts assigned to a proxy.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.items
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 41f1158a246942379cd425bb9293636f
              name: 'Proxy [{#PROXY.NAME}]: Last seen, in seconds'
              type: DEPENDENT
              key: 'zabbix.proxy.last_seen[{#PROXY.NAME}]'
              value_type: FLOAT
              description: 'The time when a proxy was last seen by a server.'
              valuemap:
                name: 'Last seen'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.last_seen
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
              trigger_prototypes:
                - uuid: 21bf9805e0de4e3ba674de388834958e
                  expression: 'last(/Remote Zabbix server health/zabbix.proxy.last_seen[{#PROXY.NAME}],#1)>{$ZABBIX.PROXY.LAST_SEEN.MAX}'
                  name: 'Zabbix server: Proxy [{#PROXY.NAME}]: Zabbix proxy last seen'
                  event_name: 'Zabbix server: Proxy [{#PROXY.NAME}]: Zabbix proxy last seen more than {$ZABBIX.PROXY.LAST_SEEN.MAX} seconds ago'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: WARNING
                  description: 'Zabbix proxy is not updating the configuration data.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: d58a33ae396943009d359bb0cae9baba
                  expression: 'last(/Remote Zabbix server health/zabbix.proxy.last_seen[{#PROXY.NAME}],#1)=-1'
                  name: 'Zabbix server: Proxy [{#PROXY.NAME}]: Zabbix proxy never seen'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: WARNING
                  description: 'Zabbix proxy is not updating the configuration data.'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: 56c5b47e6fa444a596db755d60b0cbaa
              name: 'Proxy [{#PROXY.NAME}]: Mode'
              type: DEPENDENT
              key: 'zabbix.proxy.mode[{#PROXY.NAME}]'
              description: 'The mode of Zabbix proxy.'
              valuemap:
                name: 'Proxy mode'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.passive
                - type: JAVASCRIPT
                  parameters:
                    - 'return value === ''false'' ? 0 : 1'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: a3b5f778c9b2450aad72ec97b6a52d50
              name: 'Proxy [{#PROXY.NAME}]: PSK'
              type: DEPENDENT
              key: 'zabbix.proxy.psk[{#PROXY.NAME}]'
              description: 'The encryption status for connections from a proxy.'
              valuemap:
                name: 'Service state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.psk
                - type: JAVASCRIPT
                  parameters:
                    - 'return value === ''false'' ? 0 : 1'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 8f93b4b7a5bc4c8a9a2a0fefdb0d8274
              name: 'Proxy [{#PROXY.NAME}]: Required VPS'
              type: DEPENDENT
              key: 'zabbix.proxy.requiredperformance[{#PROXY.NAME}]'
              value_type: FLOAT
              units: '!vps'
              description: 'The required performance of a proxy (the number of values that need to be collected per second).'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.requiredperformance
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 285d4a878d3e43cc930d5a82bb103f13
              name: 'Proxy [{#PROXY.NAME}]: Stats'
              type: DEPENDENT
              key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              history: '0'
              value_type: TEXT
              description: 'The statistics for the discovered proxy.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[?(@.name=="{#PROXY.NAME}")].first()'
              master_item:
                key: zabbix.proxies.stats
              tags:
                - tag: component
                  value: proxy
                - tag: component
                  value: raw
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: c3b50d734d944d0fbb59b29324e28554
              name: 'Proxy [{#PROXY.NAME}]: Unencrypted'
              type: DEPENDENT
              key: 'zabbix.proxy.unencrypted[{#PROXY.NAME}]'
              description: 'The encryption status for connections from a proxy.'
              valuemap:
                name: 'Service state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.unencrypted
                - type: JAVASCRIPT
                  parameters:
                    - 'return value === ''false'' ? 0 : 1'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 6486e23a16ba495d9fc40305425e8010
              name: 'Proxy [{#PROXY.NAME}]: Version'
              type: DEPENDENT
              key: 'zabbix.proxy.version[{#PROXY.NAME}]'
              value_type: CHAR
              description: 'A version of Zabbix proxy.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.version
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
          master_item:
            key: zabbix.proxies.stats
          lld_macro_paths:
            - lld_macro: '{#PROXY.GROUP}'
              path: $.proxy_group
            - lld_macro: '{#PROXY.NAME}'
              path: $.name
          preprocessing:
            - type: JAVASCRIPT
              parameters:
                - |
                  var proxies = JSON.parse(value);
                  
                  result = proxies.map(function (proxy) {
                  	return {
                  		'name': proxy.name,
                  		'proxy_group': proxy.proxy_group
                  	};
                  });
                  
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
          overrides:
            - name: 'Tag proxy-group if exists'
              step: '1'
              filter:
                conditions:
                  - macro: '{#PROXY.GROUP}'
                    operator: EXISTS
              operations:
                - operator: REGEXP
                  tags:
                    - tag: proxy-group
                      value: '{#PROXY.GROUP}'
      tags:
        - tag: class
          value: software
        - tag: subclass
          value: logging
        - tag: subclass
          value: monitoring
        - tag: target
          value: server
        - tag: target
          value: zabbix
      macros:
        - macro: '{$ZABBIX.PROXY.LAST_SEEN.MAX}'
          value: '600'
          description: 'The maximum number of seconds that Zabbix proxy has not been seen.'
          config:
            type: TEXT
            priority: '3'
            section_name: Thresholds
            label: 'Seconds since the last Zabbix proxy seen'
            description: 'Threshold value of time since the last Zabbix proxy seen for triggers. No less than 0.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$ZABBIX.SERVER.ADDRESS}'
          description: 'IP/DNS of the remote Zabbix server (default is 127.0.0.1).'
          config:
            type: TEXT
            priority: '1'
            label: 'Zabbix server Address'
            description: 'IP or DNS of the remote Zabbix server from which data should be collected.'
            required: 'YES'
        - macro: '{$ZABBIX.SERVER.NODATA_TIMEOUT}'
          value: 5m
          description: 'The time threshold after which statistics are considered unavailable. Used in trigger expressions.'
          config:
            type: TEXT
            priority: '4'
            section_name: Thresholds
            label: 'Time since the last statistic was received'
            description: 'Threshold value of time since the last statistic was received from the remote server.'
        - macro: '{$ZABBIX.SERVER.PORT}'
          description: 'Port of the remote Zabbix server (default is 10051).'
          config:
            type: TEXT
            priority: '2'
            label: 'Zabbix server Port'
            description: 'Port of the remote Zabbix server from which data should be collected. In the range from 1 to 65535 inclusive.'
            required: 'YES'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$ZABBIX.SERVER.UTIL.MAX}'
          value: '75'
          description: 'Default maximum threshold for percentage utilization triggers (use macro context for specification).'
          config:
            type: TEXT
            priority: '6'
            section_name: Thresholds
            label: 'Maximum process utilization percentage'
            description: 'Default maximum threshold for process utilization triggers. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$ZABBIX.SERVER.UTIL.MAX:"value cache"}'
          value: '95'
          description: 'Maximum threshold for value cache utilization triggers.'
          config:
            type: TEXT
            priority: '7'
            section_name: Thresholds
            label: 'Maximum value cache utilization percentage'
            description: 'Threshold for the value cache utilization trigger. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$ZABBIX.SERVER.UTIL.MIN}'
          value: '65'
          description: 'Default minimum threshold for percentage utilization triggers (use macro context for specification).'
          config:
            type: TEXT
            priority: '5'
            section_name: Thresholds
            label: 'Minimum process utilization percentage'
            description: 'Default minimum threshold for process utilization triggers. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
      dashboards:
        - uuid: 6a654650e39d4968918df85f9be47584
          name: 'Remote Zabbix server health'
          auto_start: 'NO'
          pages:
            - name: Performance
              widgets:
                - type: svggraph
                  name: 'Cache usage, in %'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.2
                      value: e31a1c
                    - type: STRING
                      name: ds.0.color.3
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.4
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.5
                      value: b15928
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix server health'
                        key: wcache.trend.pused
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix server health'
                        key: rcache.buffer.pused
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Remote Zabbix server health'
                        key: wcache.index.pused
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Remote Zabbix server health'
                        key: wcache.history.pused
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Remote Zabbix server health'
                        key: vcache.buffer.pused
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Remote Zabbix server health'
                        key: vmware.buffer.pused
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACA
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Server performance'
                  'y': '6'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.1
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.2
                      value: e31a1c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix server health'
                        key: wcache.values
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix server health'
                        key: vps.written
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Remote Zabbix server health'
                        key: 'zabbix[stats,{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT},queue]'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACC
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Values processed'
                  'y': '11'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.2
                      value: e31a1c
                    - type: STRING
                      name: ds.0.color.3
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.4
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.5
                      value: b15928
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix server health'
                        key: wcache.values.uint
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix server health'
                        key: wcache.values.float
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Remote Zabbix server health'
                        key: wcache.values.not_supported
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Remote Zabbix server health'
                        key: wcache.values.str
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Remote Zabbix server health'
                        key: wcache.values.log
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Remote Zabbix server health'
                        key: wcache.values.text
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACD
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Value cache effectiveness'
                  'y': '16'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.1
                      value: e31a1c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix server health'
                        key: vcache.cache.hits
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix server health'
                        key: vcache.cache.misses
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACE
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Internal queues'
                  x: '36'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: ffca58
                    - type: STRING
                      name: ds.0.color.1
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.2
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.3
                      value: d62728
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix server health'
                        key: preprocessing_queue
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix server health'
                        key: lld_queue
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Remote Zabbix server health'
                        key: discovery_queue
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Remote Zabbix server health'
                        key: connector_queue
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACB
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Trend cache effectiveness, in %'
                  x: '36'
                  'y': '16'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: ffca58
                    - type: STRING
                      name: ds.0.color.1
                      value: e31a1c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix server health'
                        key: tcache.pitems
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix server health'
                        key: tcache.pmisses
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACF
                    - type: INTEGER
                      name: show_problems
                      value: '1'
            - name: Processes
              widgets:
                - type: svggraph
                  name: 'Utilization: LLD processes'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: ffca58
                    - type: STRING
                      name: ds.0.color.1
                      value: 7e57c2
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.lld_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.lld_worker.avg.busy
                    - type: INTEGER
                      name: ds.1.axisy
                      value: '1'
                    - type: STRING
                      name: ds.1.color.0
                      value: ff465c
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.1.fill
                      value: '2'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'Remote Zabbix server health'
                        key: lld_queue
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABI
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Preprocessing processes'
                  'y': '6'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: ffca58
                    - type: STRING
                      name: ds.0.color.1
                      value: 7e57c2
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.preprocessing_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.preprocessing_worker.avg.busy
                    - type: INTEGER
                      name: ds.1.axisy
                      value: '1'
                    - type: STRING
                      name: ds.1.color.0
                      value: ff465c
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.1.fill
                      value: '2'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'Remote Zabbix server health'
                        key: preprocessing_queue
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABK
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Synchronous gathering processes'
                  'y': '12'
                  width: '72'
                  height: '7'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.2
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.3
                      value: b15928
                    - type: STRING
                      name: ds.0.color.4
                      value: 17becf
                    - type: STRING
                      name: ds.0.color.5
                      value: a6cee3
                    - type: STRING
                      name: ds.0.color.6
                      value: fb9a99
                    - type: STRING
                      name: ds.0.color.7
                      value: bcbd22
                    - type: STRING
                      name: ds.0.color.8
                      value: ffca58
                    - type: STRING
                      name: ds.0.color.9
                      value: e31a1c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.internal_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.ipmi_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.ipmi_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.http_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.java_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.6
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.vmware_collector.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.7
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.browser_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.8
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.odbc_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.9
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.icmp_pinger.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABM
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Asynchronous gathering processes'
                  'y': '19'
                  width: '72'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: bcbd22
                    - type: STRING
                      name: ds.0.color.2
                      value: 6a3d9a
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.agent_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.http_agent_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.snmp_poller.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABN
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Internal processes: Core'
                  'y': '25'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.2
                      value: e31a1c
                    - type: STRING
                      name: ds.0.color.3
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.4
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.5
                      value: b15928
                    - type: STRING
                      name: ds.0.color.6
                      value: a6cee3
                    - type: STRING
                      name: ds.0.color.7
                      value: ff465c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.configuration_syncer.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.configuration_syncer_worker.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.history_syncer.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.self-monitoring.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.service_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.task_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.6
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.timer.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.7
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.history_poller.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '8'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABO
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Gathering processes: Trappers'
                  'y': '31'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: cab2d6
                    - type: STRING
                      name: ds.0.color.1
                      value: ffca58
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.trapper.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.snmp_trapper.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABQ
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Alerting processes'
                  'y': '36'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 17becf
                    - type: STRING
                      name: ds.0.color.1
                      value: bcbd22
                    - type: STRING
                      name: ds.0.color.2
                      value: d62728
                    - type: STRING
                      name: ds.0.color.3
                      value: ff7f00
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.alert_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.alert_syncer.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.alerter.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.escalator.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '4'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABS
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Proxy management and data exchange'
                  'y': '41'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: cab2d6
                    - type: STRING
                      name: ds.0.color.1
                      value: '000080'
                    - type: STRING
                      name: ds.0.color.2
                      value: '808000'
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.trapper.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.proxy_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.proxy_group_manager.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABU
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Preprocessing throughput'
                  'y': '46'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: '808000'
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix server health'
                        key: preprocessing_throughput
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABV
                - type: svggraph
                  name: 'Utilization: Discovery processes'
                  x: '36'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 7e57c2
                    - type: STRING
                      name: ds.0.color.1
                      value: 1f78b4
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.discovery_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.discovery_worker.avg.busy
                    - type: INTEGER
                      name: ds.1.axisy
                      value: '1'
                    - type: STRING
                      name: ds.1.color.0
                      value: ff465c
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'Remote Zabbix server health'
                        key: discovery_queue
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABJ
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Connector processes'
                  x: '36'
                  'y': '6'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: b2df8a
                    - type: STRING
                      name: ds.0.color.1
                      value: ffca58
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.connector_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.connector_worker.avg.busy
                    - type: INTEGER
                      name: ds.1.axisy
                      value: '1'
                    - type: STRING
                      name: ds.1.color.0
                      value: ff465c
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'Remote Zabbix server health'
                        key: connector_queue
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABL
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Internal processes: Housekeeping'
                  x: '36'
                  'y': '25'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: ffca58
                    - type: STRING
                      name: ds.0.color.1
                      value: cab2d6
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.housekeeper.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.trigger_housekeeper.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABP
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Availability processes'
                  x: '36'
                  'y': '31'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.1
                      value: b15928
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.unreachable_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.availability_manager.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABR
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Reporting processes'
                  x: '36'
                  'y': '36'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: e377c2
                    - type: STRING
                      name: ds.0.color.1
                      value: ffdf00
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.report_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Remote Zabbix server health'
                        key: process.report_writer.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABT
                    - type: INTEGER
                      name: show_problems
                      value: '1'
            - name: Statuses
              widgets:
                - type: item
                  name: 'Zabbix server version'
                  width: '16'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'Remote Zabbix server health'
                        key: version
                    - type: INTEGER
                      name: show.0
                      value: '2'
                    - type: INTEGER
                      name: show.1
                      value: '3'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: time_h_pos
                      value: '2'
                    - type: INTEGER
                      name: time_size
                      value: '9'
                    - type: INTEGER
                      name: time_v_pos
                      value: '2'
                    - type: INTEGER
                      name: value_size
                      value: '25'
                - type: honeycomb
                  name: 'High availability: Node state'
                  x: '16'
                  width: '56'
                  height: '5'
                  fields:
                    - type: STRING
                      name: items.0
                      value: 'Cluster node [*]: Status'
                    - type: STRING
                      name: primary_label
                      value: '{{ITEM.NAME}.regsub("Cluster node \[(.*)]: Status","\1")}'
                    - type: STRING
                      name: reference
                      value: BAAAA
                    - type: INTEGER
                      name: secondary_label_decimal_places
                      value: '0'
                    - type: STRING
                      name: thresholds.0.color
                      value: b2df8a
                    - type: STRING
                      name: thresholds.0.threshold
                      value: '0'
                    - type: STRING
                      name: thresholds.1.color
                      value: '878787'
                    - type: STRING
                      name: thresholds.1.threshold
                      value: '1'
                    - type: STRING
                      name: thresholds.2.color
                      value: e31a1c
                    - type: STRING
                      name: thresholds.2.threshold
                      value: '2'
                    - type: STRING
                      name: thresholds.3.color
                      value: 33a02c
                    - type: STRING
                      name: thresholds.3.threshold
                      value: '3'
      valuemaps:
        - uuid: 25ab0f5c570b4a7e9d15bd41db79fe25
          name: 'Cluster node status'
          mappings:
            - value: '0'
              newvalue: Standby
            - value: '1'
              newvalue: Stopped
            - value: '2'
              newvalue: Unavailable
            - value: '3'
              newvalue: Active
        - uuid: 2498ad0b91d742888acccd435ba52962
          name: Compatibility
          mappings:
            - value: '0'
              newvalue: Undefined
            - value: '1'
              newvalue: Current
            - value: '2'
              newvalue: Outdated
            - value: '3'
              newvalue: Unsupported
        - uuid: 53d1560f612540d98a2983516b4b9f8c
          name: 'Last seen'
          mappings:
            - value: '-1'
              newvalue: Never
        - uuid: cdbd6c1bc69b4dcf925a1048a970139b
          name: 'Proxy mode'
          mappings:
            - value: '0'
              newvalue: Active
            - value: '1'
              newvalue: Passive
        - uuid: 7a5e7def958c4f16b9380d4b81f609c9
          name: 'Service state'
          mappings:
            - value: '0'
              newvalue: 'Off'
            - value: '1'
              newvalue: 'On'
        - uuid: 5dff563dde3c45d8b6d92525111384c6
          name: 'Value cache operating mode'
          mappings:
            - value: '0'
              newvalue: Normal
            - value: '1'
              newvalue: 'Low memory'
        - uuid: 4eaa5f12801d43d9a5cfa2bca736ccc3
          name: 'Zabbix server check'
          mappings:
            - value: '0'
              newvalue: 'False'
            - value: '1'
              newvalue: 'True'
    - uuid: 56079badd056419383cc26e6a4fcc7e0
      template: VMware
      name: VMware
      description: |
        You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/
        
        Note: To enable discovery of hardware sensors of VMware Hypervisors, set the macro '{$VMWARE.HV.SENSOR.DISCOVERY}' to the value 'true' on the discovered host level.
        
        Note: To create custom performance counter see documentation: https://www.zabbix.com/documentation/7.4/manual/vm_monitoring/vmware_keys#footnotes
        
        Note: To get all supported counters and generate path for custom performance counter see documentation: https://www.zabbix.com/documentation/7.4/manual/appendix/items/perf_counters
        
        Generated by official Zabbix template tool "Templator"
      wizard_ready: 'YES'
      readme: |
        ## Overview
        
        This template set is designed for the effortless deployment of VMware vCenter and ESX hypervisor monitoring and doesn't require any external scripts.
        
        - The template "VMware Guest" is used in discovery and normally should not be manually linked to a host.
        - The template "VMware Hypervisor" can be used in discovery as well as manually linked to a host.
        
        For additional information, please see [Zabbix documentation on VM monitoring](https://www.zabbix.com/documentation/7.4/manual/vm_monitoring).
        
        ## Setup
        
        1. Compile Zabbix server with the required options (`--with-libxml2` and `--with-libcurl`)
        2. Set the `StartVMwareCollectors` option in the Zabbix server configuration file to "1" or more
        3. Create a new host
        4. If you want to use a separate user for monitoring, make sure that the user is a member of the `SystemConfiguration.ReadOnly` and `vStatsGroup` groups
        Set the host wizard configuration fields required for VMware authentication: `VMware URL`, `VMware username` and `VMware password`
        5. Link the template to the host created earlier
        
        Note: To enable discovery of hardware sensors of VMware hypervisors, set the host wizard configuration field `Monitoring of hardware sensors` to the selected state.
        
        Additional resources:
        - How to [create a custom performance counter](https://www.zabbix.com/documentation/7.4/manual/vm_monitoring/vmware_keys#footnotes)
        - How to get all supported counters and [generate a path for the custom performance counter](https://www.zabbix.com/documentation/7.4/manual/appendix/items/perf_counters)
      vendor:
        name: Zabbix
        version: 7.4-2
      groups:
        - name: Templates/Applications
      items:
        - uuid: 5a0c711cae454f0e92a492dd1718101f
          name: 'Get alarms'
          type: SIMPLE
          key: 'vmware.alarms.get[{$VMWARE.URL}]'
          history: '0'
          value_type: TEXT
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Get alarm status.'
          tags:
            - tag: component
              value: raw
        - uuid: 5ce209f4d94f460488a74a92a52d92b1
          name: 'Event log'
          type: SIMPLE
          key: 'vmware.eventlog[{$VMWARE.URL},skip]'
          value_type: LOG
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Collect VMware event log. See also: https://www.zabbix.com/documentation/7.4/manual/config/items/preprocessing/examples#filtering_vmware_event_log_records'
          tags:
            - tag: component
              value: log
        - uuid: ee2edadb8ce943ef81d25dbbba8667a4
          name: 'Full name'
          type: SIMPLE
          key: 'vmware.fullname[{$VMWARE.URL}]'
          delay: 1h
          value_type: CHAR
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'VMware service full name.'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          tags:
            - tag: component
              value: system
        - uuid: 91756015645746e68b3f85b4cd1b5abd
          name: 'Overall Health VC State error check'
          type: DEPENDENT
          key: vmware.health.check
          value_type: CHAR
          description: 'Data collection error check.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.error
              error_handler: CUSTOM_VALUE
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
          master_item:
            key: vmware.health.get
          tags:
            - tag: component
              value: status
          triggers:
            - uuid: a11ed3829afb48fb99b9feb2dab4a45d
              expression: length(last(/VMware/vmware.health.check))>0
              name: 'VMware: Failed to get Overall Health VC State'
              opdata: 'Current error: {ITEM.LASTVALUE}'
              priority: WARNING
              description: 'Failed to get data. Check debug log for more information.'
              tags:
                - tag: scope
                  value: availability
        - uuid: 889333d3225147e1b1604119050a121f
          name: 'Get Overall Health VC State'
          type: SCRIPT
          key: vmware.health.get
          history: '0'
          value_type: TEXT
          params: |
            var Vcenter = {
            	 params: {},
            	 vmware_api_session_id: '',
            	 health_status: '',
            	 error_msg: '',
            
            	 setParams: function (params) {
            		  ['url', 'username', 'password'].forEach(function (field) {
            			  if (typeof params !== 'object' || typeof params[field] === 'undefined' || params[field] === '') {
            				  throw 'Required param is not set: ' + field + '.';
            			  }
            		  });
            
            		  if (params['url'].endsWith('/')) {
            			   params['url'] = params['url'].slice(0,-1);
            		  }
            		  params['url'] = params['url'].replace('/sdk','');
            
            		  Vcenter.params = params;
            	 },
            
            	 isGtOrEqVersion: function (first_version, second_version) {
            		  var first = first_version.split('.').map(Number),
            			  second = second_version.split('.').map(Number);
            
            		  if (first.length > second.length) {
            			  const max_componens_length = first.length
            		  }
            		  else {
            			  const max_componens_length = second.length
            		  }
            
            		  var num_components = first.length;
            		  while (num_components < max_componens_length) {
            			  first.push(0);
            			  num_components = num_components +1;
            		  }
            
            		  var num_components = second.length;
            		  while (num_components < max_componens_length) {
            			  second.push(0);
            			  num_components = num_components +1;
            		  }
            
            		  if (first[0] > second[0] ||
            			  (first[0] === second[0] && first[1] > second[1]) ||
            			  (first[0] === second[0] && first[1] === second[1] && first[2] >= second[2])) {
            			  return true;
            		  }
            
            		  return false;
            	  },
            
            	 login: function () {
            		  var response, request = new HttpRequest();
            		  request.setHttpAuth(HTTPAUTH_BASIC, Vcenter.params.username, Vcenter.params.password);
            		  request.addHeader('Accept: application/json');
            		  request.addHeader('Content-Type: application/json');
            
            		  response = request.post(Vcenter.params.url + '/api/session', '');
            		  if (request.getStatus() >= 200 && request.getStatus() < 300 && (!JSON.parse(response).error)) {
            			   Vcenter.vmware_api_session_id = Vcenter.removeQuotes(response);
            			   return true;
            		  }
            
            		  response = request.post(Vcenter.params.url + '/rest/com/vmware/cis/session', '');
            		  if (request.getStatus() >= 200 && request.getStatus() < 300) {
            			   Vcenter.vmware_api_session_id = JSON.parse(response).value;
            			   return true;
            		  }
            
            		  return false;
            	 },
            
            	 logout: function () {
            		  path = '/rest/com/vmware/cis/session';
            		  if (Vcenter.vmware_api_version && Vcenter.isGtOrEqVersion(Vcenter.vmware_api_version, '7.0.2')) {
            			   path = '/api/session';
            		  }
            
            		  Vcenter.request(Vcenter.params.url + path, 'delete');
            	 },
            
            	 get_version: function () {
            		  path = '/rest/appliance/system/version';
            
            		  try {
            			   Vcenter.vmware_api_version = Vcenter.request(Vcenter.params.url + path, 'get').version;
            			   return true;
            		  }
            		  catch (error) {
            			   return false;
            		  }
            	 },
            
            	 removeQuotes: function (str){
            		  if (str.startsWith('"') && str.endsWith('"')) {
            			  return str.slice(1, -1);
            		  }
            
            		  return str;
            	 },
            
            	 getHealthStatus: function () {
            		  path = '/api/appliance/health/system';
            		  if (!Vcenter.isGtOrEqVersion(Vcenter.vmware_api_version, '7.0.2')) {
            			   path = '/rest/appliance/health/system';
            		  }
            
            		  result = Vcenter.removeQuotes(Vcenter.request(Vcenter.params.url + path, 'get'));
            
            		  const idx = [
            			   'green',
            			   'yellow',
            			   'orange',
            			   'red',
            			   'gray'
            			   ].indexOf(result.toLowerCase());
            		  Vcenter.health_status = idx !== -1 ? idx : 5;
            	 },
            
            	 request: function (url, method) {
            		  var response, request = new HttpRequest();
            
            		  if (typeof Vcenter.params.proxy !== 'undefined' && Vcenter.params.proxy !== '') {
            			   request.setProxy(Vcenter.params.proxy);
            		  }
            
            		  request.setHttpAuth(HTTPAUTH_NONE);
            		  request.addHeader("Cookie: vmware-api-session-id=" + Vcenter.vmware_api_session_id);
            
            		  Zabbix.log(4, '[ VMware vCenter ] Sending request: ' + url);
            
            		  switch (method) {
            			   case 'get':
            				   response = request.get(url);
            				   break;
            
            			   case 'post':
            				   response = request.post(url);
            				   break;
            
            			   case 'delete':
            					response = request.delete(url);
            					break;
            
            			   default:
            				   throw 'Unsupported HTTP request method: ' + method;
            		  }
            
            		  Zabbix.log(4, '[ VMware vCenter ] Received response with status code ' + request.getStatus() + ': ' + response);
            
            		  if (request.getStatus() < 200 || request.getStatus() >= 300) {
            			   throw 'Cannot connect to VMware vCenter. Check debug log for more information.';
            		  }
            
            		  if (method !== 'delete' && JSON.parse(response).value) {
            			   return JSON.parse(response).value;
            		  }
            		  else {
            			   return response;
            		  }
            	 }
            };
            
            try {
            	 Vcenter.setParams(JSON.parse(value));
            	 
            	 if (Vcenter.login() && Vcenter.get_version() && Vcenter.isGtOrEqVersion(Vcenter.vmware_api_version, '6.5.0')) {
            		  Vcenter.getHealthStatus();
            	 }
            	 else {
            		  Vcenter.health_status = 6;
            	 }
            
            	 if (Vcenter.vmware_api_session_id) {
            		  Vcenter.logout();
            	 }
            }
            catch (error) {
            	 Zabbix.log(3, '[ VMware vCenter ] ERROR: ' + error);
            	 Vcenter.error_msg = 'Failed to get data from API:' + error;
            }
            
            return JSON.stringify({'health': Vcenter.health_status, 'error': Vcenter.error_msg});
          description: 'Gets overall health of the system. This item works only with VMware vCenter versions above 6.5.'
          timeout: '10'
          parameters:
            - name: password
              value: '{$VMWARE.PASSWORD}'
            - name: proxy
              value: '{$VMWARE.PROXY}'
            - name: url
              value: '{$VMWARE.URL}'
            - name: username
              value: '{$VMWARE.USERNAME}'
          tags:
            - tag: component
              value: raw
        - uuid: 2d18e0c8b8284c1bafd4bd131dcb640d
          name: 'Overall Health VC State'
          type: DEPENDENT
          key: vmware.health.state
          description: |
            VMware Overall health of system. One of the following:
            - Gray: No health data is available for this service.
            - Green: Service is healthy.
            - Yellow: The service is in a healthy state, but experiencing some level of problems.
            - Orange: The service health is degraded. The service might have serious problems.
            - Red: The service is unavailable, not functioning properly, or will stop functioning soon.
            - Not available: The health status is unavailable (not supported on the vCenter or ESXi side).
          valuemap:
            name: 'VMware Overall Health VC State'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.health
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
          master_item:
            key: vmware.health.get
          tags:
            - tag: component
              value: health
          triggers:
            - uuid: 4058114acbc743e087f5b10e22c997d1
              expression: 'last(/VMware/vmware.health.state)>0 and last(/VMware/vmware.health.state)<>6'
              name: 'VMware: Overall Health VC State is not Green'
              opdata: 'Current Overall Health VC State: {ITEM.LASTVALUE}'
              priority: AVERAGE
              description: 'One or more components in the appliance might be in an unusable status and the appliance might soon become unresponsive.'
              tags:
                - tag: scope
                  value: availability
                - tag: scope
                  value: performance
        - uuid: a0ec9145f2234fbea79a28c57ebdb44d
          name: Version
          type: SIMPLE
          key: 'vmware.version[{$VMWARE.URL}]'
          delay: 1h
          value_type: CHAR
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'VMware service version.'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          tags:
            - tag: component
              value: system
      discovery_rules:
        - uuid: a1f545a8acb5423884a3ef46b0aaa1c6
          name: 'VMware alarm discovery'
          type: DEPENDENT
          key: vmware.alarms.discovery
          lifetime: '0'
          description: 'Discovery of alarms.'
          item_prototypes:
            - uuid: b52727a894964058a5f0a9701e3f7edb
              name: '{#VMWARE.ALARMS.NAME}'
              type: DEPENDENT
              key: 'vmware.alarms.status["{#VMWARE.ALARMS.KEY}"]'
              value_type: CHAR
              description: 'VMware alarm status.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[?(@.key == "{#VMWARE.ALARMS.KEY}")].key.first()'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '-1'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'vmware.alarms.get[{$VMWARE.URL}]'
              tags:
                - tag: component
                  value: alarms
              trigger_prototypes:
                - uuid: ec5711e1881149ffbf67325f16b960a4
                  expression: 'last(/VMware/vmware.alarms.status["{#VMWARE.ALARMS.KEY}"])<>-1'
                  name: 'VMware: {#VMWARE.ALARMS.NAME}'
                  description: '{#VMWARE.ALARMS.DESC}'
                  tags:
                    - tag: scope
                      value: notice
          master_item:
            key: 'vmware.alarms.get[{$VMWARE.URL}]'
          lld_macro_paths:
            - lld_macro: '{#VMWARE.ALARMS.DESC}'
              path: $.description
            - lld_macro: '{#VMWARE.ALARMS.KEY}'
              path: $.key
            - lld_macro: '{#VMWARE.ALARMS.NAME}'
              path: $.name
            - lld_macro: '{#VMWARE.ALARMS.STATUS}'
              path: $.overall_status
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
          overrides:
            - name: 'Trigger priority red'
              step: '1'
              filter:
                conditions:
                  - macro: '{#VMWARE.ALARMS.STATUS}'
                    value: red
              operations:
                - operationobject: TRIGGER_PROTOTYPE
                  operator: REGEXP
                  value: 'VMware: *'
                  severity: HIGH
            - name: 'Trigger priority yellow'
              step: '2'
              filter:
                conditions:
                  - macro: '{#VMWARE.ALARMS.STATUS}'
                    value: yellow
              operations:
                - operationobject: TRIGGER_PROTOTYPE
                  operator: REGEXP
                  value: 'VMware: *'
                  severity: WARNING
            - name: 'Trigger priority green'
              step: '3'
              filter:
                conditions:
                  - macro: '{#VMWARE.ALARMS.STATUS}'
                    value: green
              operations:
                - operationobject: TRIGGER_PROTOTYPE
                  operator: REGEXP
                  value: 'VMware: *'
                  severity: INFO
        - uuid: 16ffc933cce74cf28a6edf306aa99782
          name: 'VMware cluster discovery'
          type: SIMPLE
          key: 'vmware.cluster.discovery[{$VMWARE.URL}]'
          delay: 1h
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Discovery of clusters.'
          item_prototypes:
            - uuid: 46111f91dd564a459dbc1d396e2e6c76
              name: 'Status of [{#CLUSTER.NAME}] cluster'
              type: SIMPLE
              key: 'vmware.cluster.status[{$VMWARE.URL},{#CLUSTER.NAME}]'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: |
                VMware cluster status. One of the following:
                - Gray: Unknown;
                - Green: OK;
                - Yellow: It might have a problem;
                - Red: It has a problem.
              valuemap:
                name: 'VMware status'
              tags:
                - tag: cluster
                  value: '{#CLUSTER.NAME}'
                - tag: component
                  value: cluster
              trigger_prototypes:
                - uuid: 9f7bcea84eb54fe5b79481267e6db341
                  expression: 'last(/VMware/vmware.cluster.status[{$VMWARE.URL},{#CLUSTER.NAME}])=3'
                  name: 'VMware: The [{#CLUSTER.NAME}] status is Red'
                  priority: HIGH
                  description: 'A cluster enabled for DRS becomes invalid (red) when the tree is no longer internally consistent, that is, when resource constraints are not observed. See also: https://docs.vmware.com/en/VMware-vSphere/8.0/vsphere-resource-management/GUID-C7417CAA-BD38-41D0-9529-9E7A5898BB12.html'
                  tags:
                    - tag: scope
                      value: availability
                    - tag: scope
                      value: performance
                - uuid: bf1e7838597241228506c5cfb7063950
                  expression: 'last(/VMware/vmware.cluster.status[{$VMWARE.URL},{#CLUSTER.NAME}])=2'
                  name: 'VMware: The [{#CLUSTER.NAME}] status is Yellow'
                  priority: AVERAGE
                  description: 'A cluster becomes overcommitted (yellow) when the tree of resource pools and virtual machines is internally consistent but the cluster does not have the capacity to support all the resources reserved by the child resource pools. See also: https://docs.vmware.com/en/VMware-vSphere/8.0/vsphere-resource-management/GUID-ED8240A0-FB54-4A31-BD3D-F23FE740F10C.html'
                  dependencies:
                    - name: 'VMware: The [{#CLUSTER.NAME}] status is Red'
                      expression: 'last(/VMware/vmware.cluster.status[{$VMWARE.URL},{#CLUSTER.NAME}])=3'
                  tags:
                    - tag: scope
                      value: availability
                    - tag: scope
                      value: performance
        - uuid: 8fb6a45cbe074b0cb6df53758e2c6623
          name: 'VMware datastore discovery'
          type: SIMPLE
          key: 'vmware.datastore.discovery[{$VMWARE.URL}]'
          delay: 1h
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Discovery of VMware datastores.'
          item_prototypes:
            - uuid: 4b61838ba4c34e709b25081ae5b059b5
              name: 'Average read latency of the datastore [{#DATASTORE}]'
              type: SIMPLE
              key: 'vmware.datastore.read[{$VMWARE.URL},{#DATASTORE.UUID},latency]'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'Amount of time for a read operation from the datastore (milliseconds).'
              tags:
                - tag: component
                  value: datastore
                - tag: datastore
                  value: '{#DATASTORE}'
                - tag: type
                  value: '{#DATASTORE.TYPE}'
            - uuid: 54c2631edeb04ef39701ad3bf03be1af
              name: 'Average read IOPS of the datastore [{#DATASTORE}]'
              type: SIMPLE
              key: 'vmware.datastore.read[{$VMWARE.URL},{#DATASTORE.UUID},rps]'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'IOPS for a read operation from the datastore (milliseconds).'
              tags:
                - tag: component
                  value: datastore
                - tag: datastore
                  value: '{#DATASTORE}'
                - tag: type
                  value: '{#DATASTORE.TYPE}'
            - uuid: 5355c401dc244bc588ccd18767577c93
              name: 'Free space on datastore [{#DATASTORE}] (percentage)'
              type: SIMPLE
              key: 'vmware.datastore.size[{$VMWARE.URL},{#DATASTORE.UUID},pfree]'
              delay: 5m
              value_type: FLOAT
              units: '%'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'VMware datastore free space (percentage from the total).'
              tags:
                - tag: component
                  value: datastore
                - tag: datastore
                  value: '{#DATASTORE}'
                - tag: type
                  value: '{#DATASTORE.TYPE}'
              trigger_prototypes:
                - uuid: 8783e6c0bb394763afecddfd49929a01
                  expression: 'last(/VMware/vmware.datastore.size[{$VMWARE.URL},{#DATASTORE.UUID},pfree])<{$VMWARE.DATASTORE.SPACE.CRIT}'
                  name: 'VMware: [{#DATASTORE}]: Free space is critically low'
                  event_name: 'VMware: Datastore free space is critically low ([{#DATASTORE}] free space < {$VMWARE.DATASTORE.SPACE.CRIT}%)'
                  priority: HIGH
                  description: 'Datastore free space has fallen below the critical threshold.'
                  tags:
                    - tag: scope
                      value: capacity
                - uuid: 201980a75d734a42b3fbe1b0d3c9f55c
                  expression: 'last(/VMware/vmware.datastore.size[{$VMWARE.URL},{#DATASTORE.UUID},pfree])<{$VMWARE.DATASTORE.SPACE.WARN}'
                  name: 'VMware: [{#DATASTORE}]: Free space is low'
                  event_name: 'VMware: Datastore free space is low ([{#DATASTORE}] free space < {$VMWARE.DATASTORE.SPACE.WARN}%)'
                  priority: WARNING
                  description: 'Datastore free space has fallen below the warning threshold.'
                  dependencies:
                    - name: 'VMware: [{#DATASTORE}]: Free space is critically low'
                      expression: 'last(/VMware/vmware.datastore.size[{$VMWARE.URL},{#DATASTORE.UUID},pfree])<{$VMWARE.DATASTORE.SPACE.CRIT}'
                  tags:
                    - tag: scope
                      value: capacity
            - uuid: 84f13c4fde2d4a17baaf0c8c1eb4f2c0
              name: 'Total size of datastore [{#DATASTORE}]'
              type: SIMPLE
              key: 'vmware.datastore.size[{$VMWARE.URL},{#DATASTORE.UUID}]'
              delay: 5m
              units: B
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'VMware datastore space in bytes.'
              preprocessing:
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              tags:
                - tag: component
                  value: datastore
                - tag: datastore
                  value: '{#DATASTORE}'
                - tag: type
                  value: '{#DATASTORE.TYPE}'
            - uuid: 540cd0fbc56c4b8ea19f2ff5839ce00d
              name: 'Average write latency of the datastore [{#DATASTORE}]'
              type: SIMPLE
              key: 'vmware.datastore.write[{$VMWARE.URL},{#DATASTORE.UUID},latency]'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'Amount of time for a write operation to the datastore (milliseconds).'
              tags:
                - tag: component
                  value: datastore
                - tag: datastore
                  value: '{#DATASTORE}'
                - tag: type
                  value: '{#DATASTORE.TYPE}'
            - uuid: 0026edd933404faf992d08628c9ab364
              name: 'Average write IOPS of the datastore [{#DATASTORE}]'
              type: SIMPLE
              key: 'vmware.datastore.write[{$VMWARE.URL},{#DATASTORE.UUID},rps]'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'IOPS for a write operation to the datastore (milliseconds).'
              tags:
                - tag: component
                  value: datastore
                - tag: datastore
                  value: '{#DATASTORE}'
                - tag: type
                  value: '{#DATASTORE.TYPE}'
          overrides:
            - name: 'Disable IO perfCounter'
              step: '1'
              filter:
                conditions:
                  - macro: '{#DATASTORE.TYPE}'
                    value: vsan|nfs
              operations:
                - operator: LIKE
                  value: Average
                  discover: NO_DISCOVER
        - uuid: a5bc075e89f248e7b411d8f960897a08
          name: 'VMware hypervisor discovery'
          type: SIMPLE
          key: 'vmware.hv.discovery[{$VMWARE.URL}]'
          delay: 1h
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Discovery of hypervisors.'
          host_prototypes:
            - uuid: 051a1469d4d045cbbf818fcc843a352e
              host: '{#HV.UUID}'
              name: '{#HV.NAME}'
              group_links:
                - group:
                    name: Applications
              group_prototypes:
                - name: '{#CLUSTER.NAME} (hypervisor)'
                - name: '{#DATACENTER.NAME}'
              templates:
                - name: 'VMware Hypervisor'
              macros:
                - macro: '{$VMWARE.HV.UUID}'
                  value: '{#HV.UUID}'
                  description: 'UUID of hypervisor.'
              custom_interfaces: 'YES'
              interfaces:
                - ip: '{#HV.IP}'
        - uuid: 9fd559f4e88c4677a1b874634dd686f5
          name: 'VMware VM discovery'
          type: SIMPLE
          key: 'vmware.vm.discovery[{$VMWARE.URL}]'
          delay: 1h
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          filter:
            evaltype: AND
            conditions:
              - macro: '{#VM.POWERSTATE}'
                value: '{$VMWARE.VM.POWERSTATE}'
          description: 'Discovery of guest virtual machines.'
          host_prototypes:
            - uuid: 23b9ae9d6f33414880db1cb107115810
              host: '{#VM.UUID}'
              name: '{#VM.NAME}'
              group_links:
                - group:
                    name: Applications
              group_prototypes:
                - name: '{#CLUSTER.NAME} (vm)'
                - name: '{#DATACENTER.NAME}/{#VM.FOLDER} (vm)'
                - name: '{#HV.NAME}'
              templates:
                - name: 'VMware Guest'
              macros:
                - macro: '{$VMWARE.VM.UUID}'
                  value: '{#VM.UUID}'
                  description: 'UUID of guest virtual machine.'
              custom_interfaces: 'YES'
              interfaces:
                - ip: '{#VM.IP}'
      tags:
        - tag: class
          value: software
        - tag: subclass
          value: virtualization
        - tag: target
          value: vmware
      macros:
        - macro: '{$VMWARE.DATASTORE.SPACE.CRIT}'
          value: '10'
          description: 'The critical threshold of the datastore free space.'
          config:
            type: TEXT
            priority: '6'
            section_name: Thresholds
            label: 'Critical datastore free space threshold'
            description: 'Critical threshold of the datastore free space. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$VMWARE.DATASTORE.SPACE.WARN}'
          value: '20'
          description: 'The warning threshold of the datastore free space.'
          config:
            type: TEXT
            priority: '5'
            section_name: Thresholds
            label: 'Warning datastore free space threshold'
            description: 'Warning threshold of the datastore free space. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$VMWARE.HV.SENSOR.DISCOVERY}'
          value: 'false'
          description: 'Set "true"/"false" to enable or disable monitoring of hardware sensors.'
          config:
            type: CHECKBOX
            priority: '7'
            section_name: Filters
            label: 'Monitoring of hardware sensors'
            description: 'Whether it is necessary to monitor of hardware sensors.'
            options:
              - checked: 'true'
                unchecked: 'false'
        - macro: '{$VMWARE.HV.SENSOR.DISCOVERY.NAME.MATCHES}'
          value: '.*'
          description: 'Sets the regex string of hardware sensor names to be allowed in discovery.'
          config:
            type: TEXT
            priority: '8'
            section_name: Filters
            label: 'Include hardware sensors filter'
            description: 'Regex string to include hardware sensors by sensors name.'
        - macro: '{$VMWARE.HV.SENSOR.DISCOVERY.NAME.NOT_MATCHES}'
          value: CHANGE_IF_NEEDED
          description: 'Sets the regex string of hardware sensor names to be ignored in discovery.'
          config:
            type: TEXT
            priority: '9'
            section_name: Filters
            label: 'Exclude hardware sensors filter'
            description: 'Regex string to exclude hardware sensors by sensors name.'
        - macro: '{$VMWARE.PASSWORD}'
          type: SECRET_TEXT
          description: 'VMware service `{$USERNAME}` user password.'
          config:
            type: TEXT
            priority: '3'
            label: 'VMware password'
            required: 'YES'
        - macro: '{$VMWARE.PROXY}'
          description: 'Sets the HTTP proxy for script items. If this parameter is empty, then no proxy is used.'
          config:
            type: TEXT
            priority: '4'
            section_name: Other
            label: 'HTTP proxy'
            description: 'HTTP proxy to use for requests.'
        - macro: '{$VMWARE.URL}'
          description: 'VMware service (vCenter or ESX hypervisor) SDK URL (https://servername/sdk).'
          config:
            type: TEXT
            priority: '1'
            label: 'VMware URL'
            description: 'URL for vCenter or ESX hypervisor (https://servername/sdk).'
            required: 'YES'
        - macro: '{$VMWARE.USERNAME}'
          description: 'VMware service user name.'
          config:
            type: TEXT
            priority: '2'
            label: 'VMware username'
            required: 'YES'
        - macro: '{$VMWARE.VM.POWERSTATE}'
          value: poweredOn|poweredOff|suspended
          description: 'Possibility to filter out VMs by power state.'
          config:
            type: TEXT
            priority: '10'
            section_name: Filters
            label: 'VMs power state filter'
            description: 'Regex string with desired power state of VMs for discovering.'
      dashboards:
        - uuid: 00e64ad19fff4dc9af2ab2c0c1ccc290
          name: Overview
          pages:
            - name: 'VMware: Overview'
              widgets:
                - type: honeycomb
                  name: 'Overall status'
                  width: '15'
                  height: '4'
                  hide_header: 'YES'
                  fields:
                    - type: STRING
                      name: items.0
                      value: 'Overall Health VC State'
                    - type: STRING
                      name: primary_label
                      value: 'Overall status'
                    - type: STRING
                      name: reference
                      value: AAAAA
                    - type: STRING
                      name: thresholds.0.color
                      value: 80FF00
                    - type: STRING
                      name: thresholds.0.threshold
                      value: '0'
                    - type: STRING
                      name: thresholds.1.color
                      value: FFFF00
                    - type: STRING
                      name: thresholds.1.threshold
                      value: '1'
                    - type: STRING
                      name: thresholds.2.color
                      value: FFBF00
                    - type: STRING
                      name: thresholds.2.threshold
                      value: '2'
                    - type: STRING
                      name: thresholds.3.color
                      value: FF465C
                    - type: STRING
                      name: thresholds.3.threshold
                      value: '3'
                    - type: STRING
                      name: thresholds.4.color
                      value: D2D2D2
                    - type: STRING
                      name: thresholds.4.threshold
                      value: '4'
                    - type: STRING
                      name: thresholds.5.color
                      value: D2D2D2
                    - type: STRING
                      name: thresholds.5.threshold
                      value: '5'
                    - type: STRING
                      name: thresholds.6.color
                      value: 90A4AE
                    - type: STRING
                      name: thresholds.6.threshold
                      value: '6'
                - type: honeycomb
                  name: 'Total size of datastore'
                  'y': '4'
                  width: '36'
                  height: '8'
                  fields:
                    - type: STRING
                      name: bg_color
                      value: 81D4FA
                    - type: STRING
                      name: items.0
                      value: 'Total size of datastore*'
                    - type: STRING
                      name: primary_label
                      value: '{{ITEM.NAME}.regsub("datastore.\[(.*)\]", \1)}'
                    - type: INTEGER
                      name: primary_label_size_type
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAAB
                - type: item
                  name: 'Full name'
                  x: '15'
                  width: '57'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: VMware
                        key: 'vmware.fullname[{$VMWARE.URL}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                    - type: INTEGER
                      name: value_size
                      value: '35'
                - type: item
                  name: Version
                  x: '15'
                  'y': '2'
                  width: '57'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: VMware
                        key: 'vmware.version[{$VMWARE.URL}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                    - type: INTEGER
                      name: value_size
                      value: '35'
                - type: honeycomb
                  name: 'Free space on datastore'
                  x: '36'
                  'y': '4'
                  width: '36'
                  height: '8'
                  fields:
                    - type: STRING
                      name: items.0
                      value: 'Free space on datastore*'
                    - type: STRING
                      name: primary_label
                      value: '{{ITEM.NAME}.regsub("datastore.\[(.*)\]", \1)}'
                    - type: INTEGER
                      name: primary_label_size_type
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAAC
                    - type: STRING
                      name: thresholds.0.color
                      value: FF465C
                    - type: STRING
                      name: thresholds.0.threshold
                      value: '10'
                    - type: STRING
                      name: thresholds.1.color
                      value: FFD54F
                    - type: STRING
                      name: thresholds.1.threshold
                      value: '20'
                    - type: STRING
                      name: thresholds.2.color
                      value: 0EC9AC
                    - type: STRING
                      name: thresholds.2.threshold
                      value: '30'
            - name: 'VMware: Datastore'
              widgets:
                - type: graphprototype
                  name: 'Average read IOps of the datastore'
                  width: '36'
                  height: '6'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: ITEM_PROTOTYPE
                      name: itemid.0
                      value:
                        host: VMware
                        key: 'vmware.datastore.read[{$VMWARE.URL},{#DATASTORE.UUID},rps]'
                    - type: STRING
                      name: reference
                      value: AAAAD
                    - type: INTEGER
                      name: source_type
                      value: '3'
                - type: graphprototype
                  name: 'Average read latency of the datastore'
                  'y': '6'
                  width: '36'
                  height: '6'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: ITEM_PROTOTYPE
                      name: itemid.0
                      value:
                        host: VMware
                        key: 'vmware.datastore.read[{$VMWARE.URL},{#DATASTORE.UUID},latency]'
                    - type: STRING
                      name: reference
                      value: AAAAE
                    - type: INTEGER
                      name: source_type
                      value: '3'
                - type: graphprototype
                  name: 'Average write IOps of the datastore'
                  x: '36'
                  width: '36'
                  height: '6'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: ITEM_PROTOTYPE
                      name: itemid.0
                      value:
                        host: VMware
                        key: 'vmware.datastore.write[{$VMWARE.URL},{#DATASTORE.UUID},rps]'
                    - type: STRING
                      name: reference
                      value: AAAAF
                    - type: INTEGER
                      name: source_type
                      value: '3'
                - type: graphprototype
                  name: 'Average write latency of the datastore'
                  x: '36'
                  'y': '6'
                  width: '36'
                  height: '6'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: ITEM_PROTOTYPE
                      name: itemid.0
                      value:
                        host: VMware
                        key: 'vmware.datastore.write[{$VMWARE.URL},{#DATASTORE.UUID},latency]'
                    - type: STRING
                      name: reference
                      value: AAAAG
                    - type: INTEGER
                      name: source_type
                      value: '3'
      valuemaps:
        - uuid: 7e24ccef9d754cb4805df5b1f27f4ef4
          name: 'VMware Overall Health VC State'
          mappings:
            - value: '0'
              newvalue: Green
            - value: '1'
              newvalue: Yellow
            - value: '2'
              newvalue: Orange
            - value: '3'
              newvalue: Red
            - value: '4'
              newvalue: Gray
            - value: '5'
              newvalue: Unknown
            - value: '6'
              newvalue: 'Not available'
        - uuid: 3c59c22905054d42ac4ee8b72fe5f270
          name: 'VMware status'
          mappings:
            - value: '0'
              newvalue: Gray
            - value: '1'
              newvalue: Green
            - value: '2'
              newvalue: Yellow
            - value: '3'
              newvalue: Red
    - uuid: ca02e82e6c414d0aa7aedc8d78468a49
      template: 'VMware FQDN'
      name: 'VMware FQDN'
      description: |
        You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/
        
        Note: To enable discovery of hardware sensors of VMware Hypervisors, set the macro '{$VMWARE.HV.SENSOR.DISCOVERY}' to the value 'true' on the discovered host level.
        
        Note: To create custom performance counter see documentation: https://www.zabbix.com/documentation/7.4/manual/vm_monitoring/vmware_keys#footnotes
        
        Note: To get all supported counters and generate path for custom performance counter see documentation: https://www.zabbix.com/documentation/7.4/manual/appendix/items/perf_counters
        
        Generated by official Zabbix template tool "Templator"
      wizard_ready: 'YES'
      readme: |
        ## Overview
        
        This template set is designed for the effortless deployment of VMware vCenter and ESX hypervisor monitoring and doesn't require any external scripts.
        
        - The template "VMware Guest" is used in discovery and normally should not be manually linked to a host.
        - The template "VMware Hypervisor" can be used in discovery as well as manually linked to a host.
        
        For additional information, please see [Zabbix documentation on VM monitoring](https://www.zabbix.com/documentation/7.4/manual/vm_monitoring).
        
        ## Setup
        
        1. Compile Zabbix server with the required options (`--with-libxml2` and `--with-libcurl`)
        2. Set the `StartVMwareCollectors` option in the Zabbix server configuration file to "1" or more
        3. Create a new host
        4. If you want to use a separate user for monitoring, make sure that the user is a member of the `SystemConfiguration.ReadOnly` and `vStatsGroup` groups
        Set the host wizard configuration fields required for VMware authentication: `VMware URL`, `VMware username` and `VMware password`
        5. Link the template to the host created earlier
        
        Note: To enable discovery of hardware sensors of VMware hypervisors, set the host wizard configuration field `Monitoring of hardware sensors` to the selected state.
        
        Additional resources:
        - How to [create a custom performance counter](https://www.zabbix.com/documentation/7.4/manual/vm_monitoring/vmware_keys#footnotes)
        - How to get all supported counters and [generate a path for the custom performance counter](https://www.zabbix.com/documentation/7.4/manual/appendix/items/perf_counters)
      vendor:
        name: Zabbix
        version: 7.4-2
      groups:
        - name: Templates/Applications
      items:
        - uuid: b9e3684632314721aed3119df6a06976
          name: 'Get alarms'
          type: SIMPLE
          key: 'vmware.alarms.get[{$VMWARE.URL}]'
          history: '0'
          value_type: TEXT
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Get alarm status.'
          tags:
            - tag: component
              value: raw
        - uuid: 64b8a28c1a904540930ebfec5af04872
          name: 'Event log'
          type: SIMPLE
          key: 'vmware.eventlog[{$VMWARE.URL},skip]'
          value_type: LOG
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Collect VMware event log. See also: https://www.zabbix.com/documentation/7.4/manual/config/items/preprocessing/examples#filtering_vmware_event_log_records'
          tags:
            - tag: component
              value: log
        - uuid: ebb8417eceb541b1b51909c745642f05
          name: 'Full name'
          type: SIMPLE
          key: 'vmware.fullname[{$VMWARE.URL}]'
          delay: 1h
          value_type: CHAR
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'VMware service full name.'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          tags:
            - tag: component
              value: system
        - uuid: 7d326d9241ae4d2ebd768b56d3826c4f
          name: 'Overall Health VC State error check'
          type: DEPENDENT
          key: vmware.health.check
          value_type: CHAR
          description: 'Data collection error check.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.error
              error_handler: CUSTOM_VALUE
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
          master_item:
            key: vmware.health.get
          tags:
            - tag: component
              value: status
          triggers:
            - uuid: 7fe1b44b0e7549d8af9030a1c58b2aa3
              expression: 'length(last(/VMware FQDN/vmware.health.check))>0'
              name: 'VMware FQDN: Failed to get Overall Health VC State'
              opdata: 'Current error: {ITEM.LASTVALUE}'
              priority: WARNING
              description: 'Failed to get data. Check debug log for more information.'
              tags:
                - tag: scope
                  value: availability
        - uuid: 7445c01436234092ad5d093d872b0682
          name: 'Get Overall Health VC State'
          type: SCRIPT
          key: vmware.health.get
          history: '0'
          value_type: TEXT
          params: |
            var Vcenter = {
            	 params: {},
            	 vmware_api_session_id: '',
            	 health_status: '',
            	 error_msg: '',
            
            	 setParams: function (params) {
            		  ['url', 'username', 'password'].forEach(function (field) {
            			  if (typeof params !== 'object' || typeof params[field] === 'undefined' || params[field] === '') {
            				  throw 'Required param is not set: ' + field + '.';
            			  }
            		  });
            
            		  if (params['url'].endsWith('/')) {
            			   params['url'] = params['url'].slice(0,-1);
            		  }
            		  params['url'] = params['url'].replace('/sdk','');
            
            		  Vcenter.params = params;
            	 },
            
            	 isGtOrEqVersion: function (first_version, second_version) {
            		  var first = first_version.split('.').map(Number),
            			  second = second_version.split('.').map(Number);
            
            		  if (first.length > second.length) {
            			  const max_componens_length = first.length
            		  }
            		  else {
            			  const max_componens_length = second.length
            		  }
            
            		  var num_components = first.length;
            		  while (num_components < max_componens_length) {
            			  first.push(0);
            			  num_components = num_components +1;
            		  }
            
            		  var num_components = second.length;
            		  while (num_components < max_componens_length) {
            			  second.push(0);
            			  num_components = num_components +1;
            		  }
            
            		  if (first[0] > second[0] ||
            			  (first[0] === second[0] && first[1] > second[1]) ||
            			  (first[0] === second[0] && first[1] === second[1] && first[2] >= second[2])) {
            			  return true;
            		  }
            
            		  return false;
            	  },
            
            	 login: function () {
            		  var response, request = new HttpRequest();
            		  request.setHttpAuth(HTTPAUTH_BASIC, Vcenter.params.username, Vcenter.params.password);
            		  request.addHeader('Accept: application/json');
            		  request.addHeader('Content-Type: application/json');
            
            		  response = request.post(Vcenter.params.url + '/api/session', '');
            		  if (request.getStatus() >= 200 && request.getStatus() < 300 && (!JSON.parse(response).error)) {
            			   Vcenter.vmware_api_session_id = Vcenter.removeQuotes(response);
            			   return true;
            		  }
            
            		  response = request.post(Vcenter.params.url + '/rest/com/vmware/cis/session', '');
            		  if (request.getStatus() >= 200 && request.getStatus() < 300) {
            			   Vcenter.vmware_api_session_id = JSON.parse(response).value;
            			   return true;
            		  }
            
            		  return false;
            	 },
            
            	 logout: function () {
            		  path = '/rest/com/vmware/cis/session';
            		  if (Vcenter.vmware_api_version && Vcenter.isGtOrEqVersion(Vcenter.vmware_api_version, '7.0.2')) {
            			   path = '/api/session';
            		  }
            
            		  Vcenter.request(Vcenter.params.url + path, 'delete');
            	 },
            
            	 get_version: function () {
            		  path = '/rest/appliance/system/version';
            
            		  try {
            			   Vcenter.vmware_api_version = Vcenter.request(Vcenter.params.url + path, 'get').version;
            			   return true;
            		  }
            		  catch (error) {
            			   return false;
            		  }
            	 },
            
            	 removeQuotes: function (str){
            		  if (str.startsWith('"') && str.endsWith('"')) {
            			  return str.slice(1, -1);
            		  }
            
            		  return str;
            	 },
            
            	 getHealthStatus: function () {
            		  path = '/api/appliance/health/system';
            		  if (!Vcenter.isGtOrEqVersion(Vcenter.vmware_api_version, '7.0.2')) {
            			   path = '/rest/appliance/health/system';
            		  }
            
            		  result = Vcenter.removeQuotes(Vcenter.request(Vcenter.params.url + path, 'get'));
            
            		  const idx = [
            			   'green',
            			   'yellow',
            			   'orange',
            			   'red',
            			   'gray'
            			   ].indexOf(result.toLowerCase());
            		  Vcenter.health_status = idx !== -1 ? idx : 5;
            	 },
            
            	 request: function (url, method) {
            		  var response, request = new HttpRequest();
            
            		  if (typeof Vcenter.params.proxy !== 'undefined' && Vcenter.params.proxy !== '') {
            			   request.setProxy(Vcenter.params.proxy);
            		  }
            
            		  request.setHttpAuth(HTTPAUTH_NONE);
            		  request.addHeader("Cookie: vmware-api-session-id=" + Vcenter.vmware_api_session_id);
            
            		  Zabbix.log(4, '[ VMware vCenter ] Sending request: ' + url);
            
            		  switch (method) {
            			   case 'get':
            				   response = request.get(url);
            				   break;
            
            			   case 'post':
            				   response = request.post(url);
            				   break;
            
            			   case 'delete':
            					response = request.delete(url);
            					break;
            
            			   default:
            				   throw 'Unsupported HTTP request method: ' + method;
            		  }
            
            		  Zabbix.log(4, '[ VMware vCenter ] Received response with status code ' + request.getStatus() + ': ' + response);
            
            		  if (request.getStatus() < 200 || request.getStatus() >= 300) {
            			   throw 'Cannot connect to VMware vCenter. Check debug log for more information.';
            		  }
            
            		  if (method !== 'delete' && JSON.parse(response).value) {
            			   return JSON.parse(response).value;
            		  }
            		  else {
            			   return response;
            		  }
            	 }
            };
            
            try {
            	 Vcenter.setParams(JSON.parse(value));
            	 
            	 if (Vcenter.login() && Vcenter.get_version() && Vcenter.isGtOrEqVersion(Vcenter.vmware_api_version, '6.5.0')) {
            		  Vcenter.getHealthStatus();
            	 }
            	 else {
            		  Vcenter.health_status = 6;
            	 }
            
            	 if (Vcenter.vmware_api_session_id) {
            		  Vcenter.logout();
            	 }
            }
            catch (error) {
            	 Zabbix.log(3, '[ VMware vCenter ] ERROR: ' + error);
            	 Vcenter.error_msg = 'Failed to get data from API:' + error;
            }
            
            return JSON.stringify({'health': Vcenter.health_status, 'error': Vcenter.error_msg});
          description: 'Gets overall health of the system. This item works only with VMware vCenter versions above 6.5.'
          timeout: '10'
          parameters:
            - name: password
              value: '{$VMWARE.PASSWORD}'
            - name: proxy
              value: '{$VMWARE.PROXY}'
            - name: url
              value: '{$VMWARE.URL}'
            - name: username
              value: '{$VMWARE.USERNAME}'
          tags:
            - tag: component
              value: raw
        - uuid: 5007e23b563f4d9fb47de91d349a563a
          name: 'Overall Health VC State'
          type: DEPENDENT
          key: vmware.health.state
          description: |
            VMware Overall health of system. One of the following:
            - Gray: No health data is available for this service.
            - Green: Service is healthy.
            - Yellow: The service is in a healthy state, but experiencing some level of problems.
            - Orange: The service health is degraded. The service might have serious problems.
            - Red: The service is unavailable, not functioning properly, or will stop functioning soon.
            - Not available: The health status is unavailable (not supported on the vCenter or ESXi side).
          valuemap:
            name: 'VMware Overall Health VC State'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.health
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 3h
          master_item:
            key: vmware.health.get
          tags:
            - tag: component
              value: health
          triggers:
            - uuid: 426ea642132848b8b77d42d2235c244c
              expression: 'last(/VMware FQDN/vmware.health.state)>0 and last(/VMware FQDN/vmware.health.state)<>6'
              name: 'VMware FQDN: Overall Health VC State is not Green'
              opdata: 'Current Overall Health VC State: {ITEM.LASTVALUE}'
              priority: AVERAGE
              description: 'One or more components in the appliance might be in an unusable status and the appliance might soon become unresponsive.'
              tags:
                - tag: scope
                  value: availability
                - tag: scope
                  value: performance
        - uuid: edfdedd78e9c4c299a1555bd13b2f677
          name: Version
          type: SIMPLE
          key: 'vmware.version[{$VMWARE.URL}]'
          delay: 1h
          value_type: CHAR
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'VMware service version.'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          tags:
            - tag: component
              value: system
      discovery_rules:
        - uuid: e108f082ec8a4283a5650fdcff4cacad
          name: 'VMware alarm discovery'
          type: DEPENDENT
          key: vmware.alarms.discovery
          lifetime: '0'
          description: 'Discovery of alarms.'
          item_prototypes:
            - uuid: 8e08a252b7344e10850bd177045e9a55
              name: '{#VMWARE.ALARMS.NAME}'
              type: DEPENDENT
              key: 'vmware.alarms.status["{#VMWARE.ALARMS.KEY}"]'
              value_type: CHAR
              description: 'VMware alarm status.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[?(@.key == "{#VMWARE.ALARMS.KEY}")].key.first()'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '-1'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'vmware.alarms.get[{$VMWARE.URL}]'
              tags:
                - tag: component
                  value: alarms
              trigger_prototypes:
                - uuid: 156400a8c7c04b25b99c540824168a36
                  expression: 'last(/VMware FQDN/vmware.alarms.status["{#VMWARE.ALARMS.KEY}"])<>-1'
                  name: 'VMware FQDN: {#VMWARE.ALARMS.NAME}'
                  description: '{#VMWARE.ALARMS.DESC}'
                  tags:
                    - tag: scope
                      value: notice
          master_item:
            key: 'vmware.alarms.get[{$VMWARE.URL}]'
          lld_macro_paths:
            - lld_macro: '{#VMWARE.ALARMS.DESC}'
              path: $.description
            - lld_macro: '{#VMWARE.ALARMS.KEY}'
              path: $.key
            - lld_macro: '{#VMWARE.ALARMS.NAME}'
              path: $.name
            - lld_macro: '{#VMWARE.ALARMS.STATUS}'
              path: $.overall_status
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
          overrides:
            - name: 'Trigger priority red'
              step: '1'
              filter:
                conditions:
                  - macro: '{#VMWARE.ALARMS.STATUS}'
                    value: red
              operations:
                - operationobject: TRIGGER_PROTOTYPE
                  operator: REGEXP
                  value: 'VMware: *'
                  severity: HIGH
            - name: 'Trigger priority yellow'
              step: '2'
              filter:
                conditions:
                  - macro: '{#VMWARE.ALARMS.STATUS}'
                    value: yellow
              operations:
                - operationobject: TRIGGER_PROTOTYPE
                  operator: REGEXP
                  value: 'VMware: *'
                  severity: WARNING
            - name: 'Trigger priority green'
              step: '3'
              filter:
                conditions:
                  - macro: '{#VMWARE.ALARMS.STATUS}'
                    value: green
              operations:
                - operationobject: TRIGGER_PROTOTYPE
                  operator: REGEXP
                  value: 'VMware: *'
                  severity: INFO
        - uuid: dc0a844c06f7456b8643f9f9672e6b8e
          name: 'VMware cluster discovery'
          type: SIMPLE
          key: 'vmware.cluster.discovery[{$VMWARE.URL}]'
          delay: 1h
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Discovery of clusters.'
          item_prototypes:
            - uuid: 41fbb29592f9495e92d88240ce2ba7a5
              name: 'Status of [{#CLUSTER.NAME}] cluster'
              type: SIMPLE
              key: 'vmware.cluster.status[{$VMWARE.URL},{#CLUSTER.NAME}]'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: |
                VMware cluster status. One of the following:
                - Gray: Unknown;
                - Green: OK;
                - Yellow: It might have a problem;
                - Red: It has a problem.
              valuemap:
                name: 'VMware status'
              tags:
                - tag: cluster
                  value: '{#CLUSTER.NAME}'
                - tag: component
                  value: cluster
              trigger_prototypes:
                - uuid: 962adf853de24f589e34df7ddd560885
                  expression: 'last(/VMware FQDN/vmware.cluster.status[{$VMWARE.URL},{#CLUSTER.NAME}])=3'
                  name: 'VMware FQDN: The [{#CLUSTER.NAME}] status is Red'
                  priority: HIGH
                  description: 'A cluster enabled for DRS becomes invalid (red) when the tree is no longer internally consistent, that is, when resource constraints are not observed. See also: https://docs.vmware.com/en/VMware-vSphere/8.0/vsphere-resource-management/GUID-C7417CAA-BD38-41D0-9529-9E7A5898BB12.html'
                  tags:
                    - tag: scope
                      value: availability
                    - tag: scope
                      value: performance
                - uuid: 44d12ca67931452194d1e1071136015d
                  expression: 'last(/VMware FQDN/vmware.cluster.status[{$VMWARE.URL},{#CLUSTER.NAME}])=2'
                  name: 'VMware FQDN: The [{#CLUSTER.NAME}] status is Yellow'
                  priority: AVERAGE
                  description: 'A cluster becomes overcommitted (yellow) when the tree of resource pools and virtual machines is internally consistent but the cluster does not have the capacity to support all the resources reserved by the child resource pools. See also: https://docs.vmware.com/en/VMware-vSphere/8.0/vsphere-resource-management/GUID-ED8240A0-FB54-4A31-BD3D-F23FE740F10C.html'
                  dependencies:
                    - name: 'VMware FQDN: The [{#CLUSTER.NAME}] status is Red'
                      expression: 'last(/VMware FQDN/vmware.cluster.status[{$VMWARE.URL},{#CLUSTER.NAME}])=3'
                  tags:
                    - tag: scope
                      value: availability
                    - tag: scope
                      value: performance
        - uuid: 3cd02594ee644dbe88bdfc4f4257ae05
          name: 'VMware datastore discovery'
          type: SIMPLE
          key: 'vmware.datastore.discovery[{$VMWARE.URL}]'
          delay: 1h
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Discovery of VMware datastores.'
          item_prototypes:
            - uuid: 0ed09f26cbad4d96bea297da4215d73b
              name: 'Average read latency of the datastore [{#DATASTORE}]'
              type: SIMPLE
              key: 'vmware.datastore.read[{$VMWARE.URL},{#DATASTORE.UUID},latency]'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'Amount of time for a read operation from the datastore (milliseconds).'
              tags:
                - tag: component
                  value: datastore
                - tag: datastore
                  value: '{#DATASTORE}'
                - tag: type
                  value: '{#DATASTORE.TYPE}'
            - uuid: c2687322c7914ec3b5519b73f1723aeb
              name: 'Average read IOPS of the datastore [{#DATASTORE}]'
              type: SIMPLE
              key: 'vmware.datastore.read[{$VMWARE.URL},{#DATASTORE.UUID},rps]'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'IOPS for a read operation from the datastore (milliseconds).'
              tags:
                - tag: component
                  value: datastore
                - tag: datastore
                  value: '{#DATASTORE}'
                - tag: type
                  value: '{#DATASTORE.TYPE}'
            - uuid: a2b1785fc773404e9ce69bcd868c5b88
              name: 'Free space on datastore [{#DATASTORE}] (percentage)'
              type: SIMPLE
              key: 'vmware.datastore.size[{$VMWARE.URL},{#DATASTORE.UUID},pfree]'
              delay: 5m
              value_type: FLOAT
              units: '%'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'VMware datastore free space (percentage from the total).'
              tags:
                - tag: component
                  value: datastore
                - tag: datastore
                  value: '{#DATASTORE}'
                - tag: type
                  value: '{#DATASTORE.TYPE}'
              trigger_prototypes:
                - uuid: 8eaaf5e25c464162acf2c93c2fab4606
                  expression: 'last(/VMware FQDN/vmware.datastore.size[{$VMWARE.URL},{#DATASTORE.UUID},pfree])<{$VMWARE.DATASTORE.SPACE.CRIT}'
                  name: 'VMware FQDN: [{#DATASTORE}]: Free space is critically low'
                  event_name: 'VMware FQDN: Datastore free space is critically low ([{#DATASTORE}] free space < {$VMWARE.DATASTORE.SPACE.CRIT}%)'
                  priority: HIGH
                  description: 'Datastore free space has fallen below the critical threshold.'
                  tags:
                    - tag: scope
                      value: capacity
                - uuid: 574963524fda419baae5d07c32f2fb89
                  expression: 'last(/VMware FQDN/vmware.datastore.size[{$VMWARE.URL},{#DATASTORE.UUID},pfree])<{$VMWARE.DATASTORE.SPACE.WARN}'
                  name: 'VMware FQDN: [{#DATASTORE}]: Free space is low'
                  event_name: 'VMware FQDN: Datastore free space is low ([{#DATASTORE}] free space < {$VMWARE.DATASTORE.SPACE.WARN}%)'
                  priority: WARNING
                  description: 'Datastore free space has fallen below the warning threshold.'
                  dependencies:
                    - name: 'VMware FQDN: [{#DATASTORE}]: Free space is critically low'
                      expression: 'last(/VMware FQDN/vmware.datastore.size[{$VMWARE.URL},{#DATASTORE.UUID},pfree])<{$VMWARE.DATASTORE.SPACE.CRIT}'
                  tags:
                    - tag: scope
                      value: capacity
            - uuid: 78fb4b4b0eec44a99207f8354773269d
              name: 'Total size of datastore [{#DATASTORE}]'
              type: SIMPLE
              key: 'vmware.datastore.size[{$VMWARE.URL},{#DATASTORE.UUID}]'
              delay: 5m
              units: B
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'VMware datastore space in bytes.'
              preprocessing:
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              tags:
                - tag: component
                  value: datastore
                - tag: datastore
                  value: '{#DATASTORE}'
                - tag: type
                  value: '{#DATASTORE.TYPE}'
            - uuid: d9570c0822cc4996a7dda1ddb9426404
              name: 'Average write latency of the datastore [{#DATASTORE}]'
              type: SIMPLE
              key: 'vmware.datastore.write[{$VMWARE.URL},{#DATASTORE.UUID},latency]'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'Amount of time for a write operation to the datastore (milliseconds).'
              tags:
                - tag: component
                  value: datastore
                - tag: datastore
                  value: '{#DATASTORE}'
                - tag: type
                  value: '{#DATASTORE.TYPE}'
            - uuid: a72c4a6247be4f968c1740de556732bd
              name: 'Average write IOPS of the datastore [{#DATASTORE}]'
              type: SIMPLE
              key: 'vmware.datastore.write[{$VMWARE.URL},{#DATASTORE.UUID},rps]'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'IOPS for a write operation to the datastore (milliseconds).'
              tags:
                - tag: component
                  value: datastore
                - tag: datastore
                  value: '{#DATASTORE}'
                - tag: type
                  value: '{#DATASTORE.TYPE}'
          overrides:
            - name: 'Disable IO perfCounter'
              step: '1'
              filter:
                conditions:
                  - macro: '{#DATASTORE.TYPE}'
                    value: vsan|nfs
              operations:
                - operator: LIKE
                  value: Average
                  discover: NO_DISCOVER
        - uuid: 988bb85b325449b29780eeda15c73620
          name: 'VMware hypervisor discovery'
          type: SIMPLE
          key: 'vmware.hv.discovery[{$VMWARE.URL}]'
          delay: 1h
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Discovery of hypervisors.'
          host_prototypes:
            - uuid: 51cf7ea3e6a74f7e8dde628dbc5347a3
              host: '{#HV.UUID}'
              name: '{#HV.NAME}'
              group_links:
                - group:
                    name: Applications
              group_prototypes:
                - name: '{#CLUSTER.NAME} (hypervisor)'
                - name: '{#DATACENTER.NAME}'
              templates:
                - name: 'VMware Hypervisor'
              macros:
                - macro: '{$VMWARE.HV.UUID}'
                  value: '{#HV.UUID}'
                  description: 'UUID of hypervisor.'
              custom_interfaces: 'YES'
              interfaces:
                - ip: '{#HV.IP}'
        - uuid: a7e2f6830442433cbe515e8bd72ee0b8
          name: 'VMware VM FQDN discovery'
          type: SIMPLE
          key: 'vmware.vm.discovery[{$VMWARE.URL}]'
          delay: 1h
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          filter:
            evaltype: AND
            conditions:
              - macro: '{#VM.DNS}'
                value: ^$
                operator: NOT_MATCHES_REGEX
              - macro: '{#VM.POWERSTATE}'
                value: '{$VMWARE.VM.POWERSTATE}'
          description: 'Discovery of guest virtual machines.'
          host_prototypes:
            - uuid: a12e25c500a14fcf99295c207371ca1b
              host: '{#VM.DNS}'
              name: '{#VM.NAME}'
              group_links:
                - group:
                    name: Applications
              group_prototypes:
                - name: '{#CLUSTER.NAME} (vm)'
                - name: '{#DATACENTER.NAME}/{#VM.FOLDER} (vm)'
                - name: '{#HV.NAME}'
              templates:
                - name: 'VMware Guest'
              macros:
                - macro: '{$VMWARE.VM.UUID}'
                  value: '{#VM.UUID}'
                  description: 'UUID of guest virtual machine.'
              custom_interfaces: 'YES'
              interfaces:
                - ip: '{#VM.IP}'
      tags:
        - tag: class
          value: software
        - tag: subclass
          value: virtualization
        - tag: target
          value: vmware
        - tag: target
          value: vmware-fqdn
      macros:
        - macro: '{$VMWARE.DATASTORE.SPACE.CRIT}'
          value: '10'
          description: 'The critical threshold of the datastore free space.'
          config:
            type: TEXT
            priority: '6'
            section_name: Thresholds
            label: 'Critical datastore free space threshold'
            description: 'Critical threshold of the datastore free space. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$VMWARE.DATASTORE.SPACE.WARN}'
          value: '20'
          description: 'The warning threshold of the datastore free space.'
          config:
            type: TEXT
            priority: '5'
            section_name: Thresholds
            label: 'Warning datastore free space threshold'
            description: 'Warning threshold of the datastore free space. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$VMWARE.HV.SENSOR.DISCOVERY}'
          value: 'false'
          description: 'Set "true"/"false" to enable or disable monitoring of hardware sensors.'
          config:
            type: CHECKBOX
            priority: '7'
            section_name: Filters
            label: 'Monitoring of hardware sensors'
            description: 'Whether it is necessary to monitor of hardware sensors.'
            options:
              - checked: 'true'
                unchecked: 'false'
        - macro: '{$VMWARE.HV.SENSOR.DISCOVERY.NAME.MATCHES}'
          value: '.*'
          description: 'Sets the regex string of hardware sensor names to be allowed in discovery.'
          config:
            type: TEXT
            priority: '8'
            section_name: Filters
            label: 'Include hardware sensors filter'
            description: 'Regex string to include hardware sensors by sensors name.'
        - macro: '{$VMWARE.HV.SENSOR.DISCOVERY.NAME.NOT_MATCHES}'
          value: CHANGE_IF_NEEDED
          description: 'Sets the regex string of hardware sensor names to be ignored in discovery.'
          config:
            type: TEXT
            priority: '9'
            section_name: Filters
            label: 'Exclude hardware sensors filter'
            description: 'Regex string to exclude hardware sensors by sensors name.'
        - macro: '{$VMWARE.PASSWORD}'
          type: SECRET_TEXT
          description: 'VMware service `{$USERNAME}` user password.'
          config:
            type: TEXT
            priority: '3'
            label: 'VMware password'
            required: 'YES'
        - macro: '{$VMWARE.PROXY}'
          description: 'Sets the HTTP proxy for script items. If this parameter is empty, then no proxy is used.'
          config:
            type: TEXT
            priority: '4'
            section_name: Other
            label: 'HTTP proxy'
            description: 'HTTP proxy to use for requests.'
        - macro: '{$VMWARE.URL}'
          description: 'VMware service (vCenter or ESX hypervisor) SDK URL (https://servername/sdk).'
          config:
            type: TEXT
            priority: '1'
            label: 'VMware URL'
            description: 'URL for vCenter or ESX hypervisor (https://servername/sdk).'
            required: 'YES'
        - macro: '{$VMWARE.USERNAME}'
          description: 'VMware service user name.'
          config:
            type: TEXT
            priority: '2'
            label: 'VMware username'
            required: 'YES'
        - macro: '{$VMWARE.VM.POWERSTATE}'
          value: poweredOn|poweredOff|suspended
          description: 'Possibility to filter out VMs by power state.'
          config:
            type: TEXT
            priority: '10'
            section_name: Filters
            label: 'VMs power state filter'
            description: 'Regex string with desired power state of VMs for discovering.'
      dashboards:
        - uuid: 90bc032e4b384e4891f6067267343abc
          name: Overview
          pages:
            - name: 'VMware: Overview'
              widgets:
                - type: honeycomb
                  name: 'Overall status'
                  width: '15'
                  height: '4'
                  hide_header: 'YES'
                  fields:
                    - type: STRING
                      name: items.0
                      value: 'Overall Health VC State'
                    - type: STRING
                      name: primary_label
                      value: 'Overall status'
                    - type: STRING
                      name: reference
                      value: AAAAA
                    - type: STRING
                      name: thresholds.0.color
                      value: 80FF00
                    - type: STRING
                      name: thresholds.0.threshold
                      value: '0'
                    - type: STRING
                      name: thresholds.1.color
                      value: FFFF00
                    - type: STRING
                      name: thresholds.1.threshold
                      value: '1'
                    - type: STRING
                      name: thresholds.2.color
                      value: FFBF00
                    - type: STRING
                      name: thresholds.2.threshold
                      value: '2'
                    - type: STRING
                      name: thresholds.3.color
                      value: FF465C
                    - type: STRING
                      name: thresholds.3.threshold
                      value: '3'
                    - type: STRING
                      name: thresholds.4.color
                      value: D2D2D2
                    - type: STRING
                      name: thresholds.4.threshold
                      value: '4'
                    - type: STRING
                      name: thresholds.5.color
                      value: D2D2D2
                    - type: STRING
                      name: thresholds.5.threshold
                      value: '5'
                    - type: STRING
                      name: thresholds.6.color
                      value: 90A4AE
                    - type: STRING
                      name: thresholds.6.threshold
                      value: '6'
                - type: honeycomb
                  name: 'Total size of datastore'
                  'y': '4'
                  width: '36'
                  height: '8'
                  fields:
                    - type: STRING
                      name: bg_color
                      value: 81D4FA
                    - type: STRING
                      name: items.0
                      value: 'Total size of datastore*'
                    - type: STRING
                      name: primary_label
                      value: '{{ITEM.NAME}.regsub("datastore.\[(.*)\]", \1)}'
                    - type: INTEGER
                      name: primary_label_size_type
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAAB
                - type: item
                  name: 'Full name'
                  x: '15'
                  width: '57'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware FQDN'
                        key: 'vmware.fullname[{$VMWARE.URL}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                    - type: INTEGER
                      name: value_size
                      value: '35'
                - type: item
                  name: Version
                  x: '15'
                  'y': '2'
                  width: '57'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware FQDN'
                        key: 'vmware.version[{$VMWARE.URL}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                    - type: INTEGER
                      name: value_size
                      value: '35'
                - type: honeycomb
                  name: 'Free space on datastore'
                  x: '36'
                  'y': '4'
                  width: '36'
                  height: '8'
                  fields:
                    - type: STRING
                      name: items.0
                      value: 'Free space on datastore*'
                    - type: STRING
                      name: primary_label
                      value: '{{ITEM.NAME}.regsub("datastore.\[(.*)\]", \1)}'
                    - type: INTEGER
                      name: primary_label_size_type
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAAC
                    - type: STRING
                      name: thresholds.0.color
                      value: FF465C
                    - type: STRING
                      name: thresholds.0.threshold
                      value: '10'
                    - type: STRING
                      name: thresholds.1.color
                      value: FFD54F
                    - type: STRING
                      name: thresholds.1.threshold
                      value: '20'
                    - type: STRING
                      name: thresholds.2.color
                      value: 0EC9AC
                    - type: STRING
                      name: thresholds.2.threshold
                      value: '30'
            - name: 'VMware: Datastore'
              widgets:
                - type: graphprototype
                  name: 'Average read IOps of the datastore'
                  width: '36'
                  height: '6'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: ITEM_PROTOTYPE
                      name: itemid.0
                      value:
                        host: 'VMware FQDN'
                        key: 'vmware.datastore.read[{$VMWARE.URL},{#DATASTORE.UUID},rps]'
                    - type: STRING
                      name: reference
                      value: AAAAD
                    - type: INTEGER
                      name: source_type
                      value: '3'
                - type: graphprototype
                  name: 'Average read latency of the datastore'
                  'y': '6'
                  width: '36'
                  height: '6'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: ITEM_PROTOTYPE
                      name: itemid.0
                      value:
                        host: 'VMware FQDN'
                        key: 'vmware.datastore.read[{$VMWARE.URL},{#DATASTORE.UUID},latency]'
                    - type: STRING
                      name: reference
                      value: AAAAE
                    - type: INTEGER
                      name: source_type
                      value: '3'
                - type: graphprototype
                  name: 'Average write IOps of the datastore'
                  x: '36'
                  width: '36'
                  height: '6'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: ITEM_PROTOTYPE
                      name: itemid.0
                      value:
                        host: 'VMware FQDN'
                        key: 'vmware.datastore.write[{$VMWARE.URL},{#DATASTORE.UUID},rps]'
                    - type: STRING
                      name: reference
                      value: AAAAF
                    - type: INTEGER
                      name: source_type
                      value: '3'
                - type: graphprototype
                  name: 'Average write latency of the datastore'
                  x: '36'
                  'y': '6'
                  width: '36'
                  height: '6'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: ITEM_PROTOTYPE
                      name: itemid.0
                      value:
                        host: 'VMware FQDN'
                        key: 'vmware.datastore.write[{$VMWARE.URL},{#DATASTORE.UUID},latency]'
                    - type: STRING
                      name: reference
                      value: AAAAG
                    - type: INTEGER
                      name: source_type
                      value: '3'
      valuemaps:
        - uuid: 30aec8e3198e4b91b1182514be8a8f6b
          name: 'VMware Overall Health VC State'
          mappings:
            - value: '0'
              newvalue: Green
            - value: '1'
              newvalue: Yellow
            - value: '2'
              newvalue: Orange
            - value: '3'
              newvalue: Red
            - value: '4'
              newvalue: Gray
            - value: '5'
              newvalue: Unknown
            - value: '6'
              newvalue: 'Not available'
        - uuid: 5e5e3b01ef334bd39441568ebd0c31c0
          name: 'VMware status'
          mappings:
            - value: '0'
              newvalue: Gray
            - value: '1'
              newvalue: Green
            - value: '2'
              newvalue: Yellow
            - value: '3'
              newvalue: Red
    - uuid: 7942fb93ae3b47cf9ca0ea4beb0675ce
      template: 'VMware Guest'
      name: 'VMware Guest'
      description: |
        Note: To enable trigger for free space for guest VM, set macro '{$VMWARE.VM.FS.TRIGGER.USED}' to the value '1' on the discovered host level.
        
        Generated by official Zabbix template tool "Templator"
      vendor:
        name: Zabbix
        version: 7.4-3
      groups:
        - name: Templates/Applications
      items:
        - uuid: 061eed2d40d5427092b50172ea0a9c41
          name: 'Cluster name'
          type: SIMPLE
          key: 'vmware.vm.cluster.name[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          delay: 1h
          value_type: CHAR
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Cluster name of the guest VM.'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          tags:
            - tag: component
              value: cluster
        - uuid: 20332e3c1ea54266a02ad500bc9ec1ca
          name: 'Snapshot consolidation needed'
          type: SIMPLE
          key: 'vmware.vm.consolidationneeded[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: |
            Displays whether snapshot consolidation is needed or not. One of the following:
            - True;
            - False.
          valuemap:
            name: 'VMware Consolidation'
          preprocessing:
            - type: JAVASCRIPT
              parameters:
                - |
                  const idx = [
                  	'true',
                  	'false'
                  ].indexOf(value);
                  return idx !== -1 ? idx : 2;
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          tags:
            - tag: component
              value: storage
          triggers:
            - uuid: 28627af63fe64e79b08ad752dee5205e
              expression: 'last(/VMware Guest/vmware.vm.consolidationneeded[{$VMWARE.URL},{$VMWARE.VM.UUID}])=0'
              name: 'VMware Guest: Snapshot consolidation needed'
              priority: AVERAGE
              description: 'Snapshot consolidation needed.'
              manual_close: 'YES'
              dependencies:
                - name: 'VMware Guest: Hypervisor is in the maintenance mode'
                  expression: 'last(/VMware Guest/vmware.vm.hv.maintenance[{$VMWARE.URL},{$VMWARE.VM.UUID}])=1 and {$VMWARE.HYPERVISOR.MAINTENANCE}=1'
              tags:
                - tag: scope
                  value: availability
        - uuid: 31389342688f4b0696a49431923a528f
          name: 'CPU latency in percent'
          type: SIMPLE
          key: 'vmware.vm.cpu.latency[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          value_type: FLOAT
          units: '%'
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Percentage of time the VM is unable to run because it is contending for access to the physical CPU(s).'
          tags:
            - tag: component
              value: cpu
        - uuid: bbfb146e74144160b2e47c0f2cdc6c20
          name: 'Number of virtual CPUs'
          type: SIMPLE
          key: 'vmware.vm.cpu.num[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          delay: 1h
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Number of virtual CPUs assigned to the guest.'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          tags:
            - tag: component
              value: cpu
        - uuid: f4d72109b7ee4e0bb65aab1de85b6b05
          name: 'CPU readiness latency in percent'
          type: SIMPLE
          key: 'vmware.vm.cpu.readiness[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          value_type: FLOAT
          units: '%'
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Percentage of time that the virtual machine was ready, but was unable to get scheduled to run on the physical CPU.'
          tags:
            - tag: component
              value: cpu
        - uuid: ff0a31df94784cfbbf10deca55f76145
          name: 'CPU ready'
          type: SIMPLE
          key: 'vmware.vm.cpu.ready[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          units: ms
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Time that the VM was ready, but unable to get scheduled to run on the physical CPU during the last measurement interval (VMware vCenter/ESXi Server performance counter sampling interval - 20 seconds).'
          tags:
            - tag: component
              value: cpu
        - uuid: 50de05f27f33425cb207a3fdece7ecb1
          name: 'CPU swap-in latency in percent'
          type: SIMPLE
          key: 'vmware.vm.cpu.swapwait[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          units: '%'
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Percentage of CPU time spent waiting for a swap-in.'
          tags:
            - tag: component
              value: cpu
        - uuid: 50606be978814b51b4bae54340965cdc
          name: 'CPU usage in percent'
          type: SIMPLE
          key: 'vmware.vm.cpu.usage.perf[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          value_type: FLOAT
          units: '%'
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'CPU usage as a percentage during the interval.'
          tags:
            - tag: component
              value: cpu
        - uuid: ea416ff054cc4031ac6b5cf446156540
          name: 'CPU usage'
          type: SIMPLE
          key: 'vmware.vm.cpu.usage[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          units: Hz
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Current upper-bound on CPU usage. The upper-bound is based on the host the VM is current running on, as well as limits configured on the VM itself or any parent resource pool. Valid while the VM is running.'
          tags:
            - tag: component
              value: cpu
        - uuid: 3e70b5d443b942db974b5f92a7acce19
          name: 'Datacenter name'
          type: SIMPLE
          key: 'vmware.vm.datacenter.name[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          delay: 1h
          value_type: CHAR
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Datacenter name of the guest VM.'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          tags:
            - tag: component
              value: datacenter
        - uuid: e645130999db470fbbf14a8055c95b23
          name: 'Guest memory swapped'
          type: SIMPLE
          key: 'vmware.vm.guest.memory.size.swapped[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          units: B
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Amount of guest physical memory that is swapped out to the swap space.'
          tags:
            - tag: component
              value: memory
        - uuid: 521a0396514845e3bc5d3dc54ec3d940
          name: 'Uptime of guest OS'
          type: SIMPLE
          key: 'vmware.vm.guest.osuptime[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          units: uptime
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Total time elapsed since the last operating system boot-up (in seconds).'
          tags:
            - tag: component
              value: system
        - uuid: b794d9df3e764df8b04239d5779269cd
          name: 'Hypervisor maintenance mode'
          type: SIMPLE
          key: 'vmware.vm.hv.maintenance[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: |
            Hypervisor maintenance mode. One of the following:
            - Normal mode;
            - Maintenance mode.
          valuemap:
            name: 'VMware Hypervisor maintenance mode'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 05c2982de3f94647808a523a91af554c
              expression: 'last(/VMware Guest/vmware.vm.hv.maintenance[{$VMWARE.URL},{$VMWARE.VM.UUID}])=1 and {$VMWARE.HYPERVISOR.MAINTENANCE}=1'
              name: 'VMware Guest: Hypervisor is in the maintenance mode'
              event_name: 'VMware Guest: Hypervisor is in the maintenance mode'
              priority: INFO
              description: 'Hypervisor is in the maintenance mode. All other problem on the host will be suppressed.'
              tags:
                - tag: scope
                  value: notice
        - uuid: fedec469a1d040ae971e0013102e1e7c
          name: 'Hypervisor name'
          type: SIMPLE
          key: 'vmware.vm.hv.name[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          delay: 1h
          value_type: CHAR
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Hypervisor name of the guest VM.'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          tags:
            - tag: component
              value: hypervisor
        - uuid: fbe7477fd85a4ee39a9226b2c6995446
          name: 'Ballooned memory'
          type: SIMPLE
          key: 'vmware.vm.memory.size.ballooned[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          units: B
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'The amount of guest physical memory that is currently reclaimed through the balloon driver.'
          tags:
            - tag: component
              value: memory
        - uuid: 9e7b9360e4d84e9397b5f0a7ab074726
          name: 'Compressed memory'
          type: SIMPLE
          key: 'vmware.vm.memory.size.compressed[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          units: B
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'The amount of memory currently in the compression cache for this VM.'
          tags:
            - tag: component
              value: memory
        - uuid: 04a40f805fed4ddfa1590274a996a019
          name: 'Host memory consumed'
          type: SIMPLE
          key: 'vmware.vm.memory.size.consumed[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          units: B
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Amount of host physical memory consumed for backing up guest physical memory pages.'
          tags:
            - tag: component
              value: memory
        - uuid: 6563409185804ed89b49dfde92edfa10
          name: 'Private memory'
          type: SIMPLE
          key: 'vmware.vm.memory.size.private[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          units: B
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Amount of memory backed by host memory and not being shared.'
          tags:
            - tag: component
              value: memory
        - uuid: c6a539ee57bf48f78342358c391c65ea
          name: 'Shared memory'
          type: SIMPLE
          key: 'vmware.vm.memory.size.shared[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          units: B
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'The amount of guest physical memory shared through transparent page sharing.'
          tags:
            - tag: component
              value: memory
        - uuid: b064f0e0a53f4f6588827100becb4335
          name: 'Swapped memory'
          type: SIMPLE
          key: 'vmware.vm.memory.size.swapped[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          units: B
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'The amount of guest physical memory swapped out to the VM''s swap device by ESX.'
          tags:
            - tag: component
              value: memory
        - uuid: e960399726a240de9ecc12eff65415ae
          name: 'Guest memory usage'
          type: SIMPLE
          key: 'vmware.vm.memory.size.usage.guest[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          units: B
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'The amount of guest physical memory that is being used by the VM.'
          tags:
            - tag: component
              value: memory
        - uuid: 6fcbe4e95fce445aa417b9738004391f
          name: 'Host memory usage'
          type: SIMPLE
          key: 'vmware.vm.memory.size.usage.host[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          units: B
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'The amount of host physical memory allocated to the VM, accounting for the amount saved from memory sharing with other VMs.'
          tags:
            - tag: component
              value: memory
        - uuid: 9533bc39366443fe8a3808190801441a
          name: 'Memory size'
          type: SIMPLE
          key: 'vmware.vm.memory.size[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          delay: 1h
          units: B
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Total size of configured memory.'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          tags:
            - tag: component
              value: memory
        - uuid: e82daa73e03e43b9838d9e414d710e38
          name: 'Host memory usage in percent'
          type: SIMPLE
          key: 'vmware.vm.memory.usage[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          value_type: FLOAT
          units: '%'
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Percentage of host physical memory that has been consumed.'
          tags:
            - tag: component
              value: memory
        - uuid: 0943ff346c9d4cc69fc773843066c473
          name: 'Power state'
          type: SIMPLE
          key: 'vmware.vm.powerstate[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: |
            The current power state of the VM. One of the following:
            - Powered off;
            - Powered on;
            - Suspended.
          valuemap:
            name: 'VMware VirtualMachinePowerState'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
          tags:
            - tag: component
              value: power
        - uuid: de013bcc700f4878ab80aa3fdd87cc8c
          name: 'Snapshot count'
          type: DEPENDENT
          key: vmware.vm.snapshot.count
          description: 'Snapshot count of the guest VM.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.count
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: 'vmware.vm.snapshot.get[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          tags:
            - tag: component
              value: storage
        - uuid: 550350d76aa346c49ef828418ebc53be
          name: 'Get snapshots'
          type: SIMPLE
          key: 'vmware.vm.snapshot.get[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          delay: 1h
          history: '0'
          value_type: TEXT
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Snapshots of the guest VM.'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          tags:
            - tag: component
              value: raw
        - uuid: da2d382ba9554661ba476e1f3d5294b3
          name: 'Snapshot latest date'
          type: DEPENDENT
          key: vmware.vm.snapshot.latestdate
          value_type: CHAR
          description: 'Latest snapshot date of the guest VM.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.latestdate
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: 'vmware.vm.snapshot.get[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          tags:
            - tag: component
              value: storage
        - uuid: 2e68d5709d4f46b49b62d37a890e4193
          name: 'VM state'
          type: SIMPLE
          key: 'vmware.vm.state[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: |
            VMware virtual machine state. One of the following:
            - Not running;
            - Resetting;
            - Running;
            - Shutting down;
            - Standby;
            - Unknown.
          valuemap:
            name: 'VMware Virtual Machine state'
          preprocessing:
            - type: JAVASCRIPT
              parameters:
                - |
                  const idx = [
                  	'notRunning',
                  	'resetting',
                  	'running',
                  	'shuttingDown',
                  	'standby',
                  	'unknown'
                  ].indexOf(value);
                  return idx !== -1 ? idx : 5;
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
          tags:
            - tag: component
              value: health
            - tag: component
              value: system
          triggers:
            - uuid: 6ebb2a2de81e4bacbb32d1b767c3cb04
              expression: 'last(/VMware Guest/vmware.vm.state[{$VMWARE.URL},{$VMWARE.VM.UUID}]) <> 2'
              name: 'VMware Guest: VM is not running'
              opdata: 'Current state: {ITEM.LASTVALUE1}'
              priority: AVERAGE
              description: 'VMware virtual machine is not running.'
              dependencies:
                - name: 'VMware Guest: Hypervisor is in the maintenance mode'
                  expression: 'last(/VMware Guest/vmware.vm.hv.maintenance[{$VMWARE.URL},{$VMWARE.VM.UUID}])=1 and {$VMWARE.HYPERVISOR.MAINTENANCE}=1'
              tags:
                - tag: scope
                  value: notice
        - uuid: 13173517c99e4a87aa6750392d14b255
          name: 'Committed storage space'
          type: SIMPLE
          key: 'vmware.vm.storage.committed[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          units: B
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Total storage space, in bytes, committed to this VM across all datastores.'
          tags:
            - tag: component
              value: storage
        - uuid: 8183cf2c54774d7eb544f645d5c26b8c
          name: 'Uncommitted storage space'
          type: SIMPLE
          key: 'vmware.vm.storage.uncommitted[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          units: B
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Additional storage space, in bytes, potentially used by this VM on all datastores.'
          tags:
            - tag: component
              value: storage
        - uuid: 35aa9ee1743e4c1787c426da20f48097
          name: 'Unshared storage space'
          type: SIMPLE
          key: 'vmware.vm.storage.unshared[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          units: B
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Total storage space, in bytes, occupied by the VM across all datastores that is not shared with any other VM.'
          tags:
            - tag: component
              value: storage
        - uuid: 6089b7822620423aa2b2e66066d33217
          name: 'VMware Tools status'
          type: SIMPLE
          key: 'vmware.vm.tools[{$VMWARE.URL},{$VMWARE.VM.UUID},status]'
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: |
            Monitoring of VMware Tools. One of the following:
            - Guest tools executing scripts: VMware Tools is starting.
            - Guest tools not running: VMware Tools is not running.
            - Guest tools running: VMware Tools is running.
          valuemap:
            name: 'VMware Tools status'
          preprocessing:
            - type: JAVASCRIPT
              parameters:
                - |
                  const idx = [
                  	'guestToolsExecutingScripts',
                  	'guestToolsNotRunning',
                  	'guestToolsRunning'
                  ].indexOf(value);
                  return idx !== -1 ? idx : 10;
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 132d6e490fea42e390de64ce389ad538
              expression: 'last(/VMware Guest/vmware.vm.tools[{$VMWARE.URL},{$VMWARE.VM.UUID},status]) = 1'
              name: 'VMware Guest: VMware Tools is not running'
              priority: WARNING
              description: 'VMware Tools is not running on the VM.'
              dependencies:
                - name: 'VMware Guest: Hypervisor is in the maintenance mode'
                  expression: 'last(/VMware Guest/vmware.vm.hv.maintenance[{$VMWARE.URL},{$VMWARE.VM.UUID}])=1 and {$VMWARE.HYPERVISOR.MAINTENANCE}=1'
                - name: 'VMware Guest: VM is not running'
                  expression: 'last(/VMware Guest/vmware.vm.state[{$VMWARE.URL},{$VMWARE.VM.UUID}]) <> 2'
              tags:
                - tag: scope
                  value: notice
        - uuid: 3870a0d8bfd1474db6e096a1a9a246b3
          name: 'VMware Tools version'
          type: SIMPLE
          key: 'vmware.vm.tools[{$VMWARE.URL},{$VMWARE.VM.UUID},version]'
          delay: 1h
          value_type: CHAR
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Monitoring of the VMware Tools version.'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 12h
          tags:
            - tag: component
              value: system
        - uuid: 4c3b010d7ea74da6b0dc1dd4e625bbb0
          name: Uptime
          type: SIMPLE
          key: 'vmware.vm.uptime[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          units: uptime
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'System uptime.'
          tags:
            - tag: component
              value: system
      discovery_rules:
        - uuid: 914634668bab4266bd641ee224dbc1e4
          name: 'Network device discovery'
          type: SIMPLE
          key: 'vmware.vm.net.if.discovery[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          delay: 1h
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Discovery of all network devices.'
          item_prototypes:
            - uuid: 1a7452a0061b45b1b1904e3ff64cf49f
              name: 'Number of bytes received on interface [{#IFBACKINGDEVICE}]/[{#IFDESC}]'
              type: SIMPLE
              key: 'vmware.vm.net.if.in[{$VMWARE.URL},{$VMWARE.VM.UUID},{#IFNAME},bps]'
              units: Bps
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'VMware virtual machine network interface input statistics (bytes per second).'
              tags:
                - tag: component
                  value: interface
                - tag: interface
                  value: '{#IFDESC}'
            - uuid: 863c3aee5d9248d48adbf86832fa6c8e
              name: 'Number of packets received on interface [{#IFBACKINGDEVICE}]/[{#IFDESC}]'
              type: SIMPLE
              key: 'vmware.vm.net.if.in[{$VMWARE.URL},{$VMWARE.VM.UUID},{#IFNAME},pps]'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'VMware virtual machine network interface input statistics (packets per second).'
              tags:
                - tag: component
                  value: interface
                - tag: interface
                  value: '{#IFDESC}'
            - uuid: 0993e42664a14cd7936351c55b1d64a4
              name: 'Number of bytes transmitted on interface [{#IFBACKINGDEVICE}]/[{#IFDESC}]'
              type: SIMPLE
              key: 'vmware.vm.net.if.out[{$VMWARE.URL},{$VMWARE.VM.UUID},{#IFNAME},bps]'
              units: Bps
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'VMware virtual machine network interface output statistics (bytes per second).'
              tags:
                - tag: component
                  value: interface
                - tag: interface
                  value: '{#IFDESC}'
            - uuid: 144a2ed3f76e49af92462e0fea275ede
              name: 'Number of packets transmitted on interface [{#IFBACKINGDEVICE}]/[{#IFDESC}]'
              type: SIMPLE
              key: 'vmware.vm.net.if.out[{$VMWARE.URL},{$VMWARE.VM.UUID},{#IFNAME},pps]'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'VMware virtual machine network interface output statistics (packets per second).'
              tags:
                - tag: component
                  value: interface
                - tag: interface
                  value: '{#IFDESC}'
            - uuid: 9c3cd13576cc4c0a8972fa188f911e96
              name: 'Network utilization on interface [{#IFBACKINGDEVICE}]/[{#IFDESC}]'
              type: SIMPLE
              key: 'vmware.vm.net.if.usage[{$VMWARE.URL},{$VMWARE.VM.UUID},{#IFNAME}]'
              units: Bps
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'VMware virtual machine network utilization (combined transmit and receive rates) during the interval.'
              tags:
                - tag: component
                  value: interface
                - tag: interface
                  value: '{#IFDESC}'
        - uuid: b1543bdfb5a342d7ad694c87248fe173
          name: 'Disk device discovery'
          type: SIMPLE
          key: 'vmware.vm.vfs.dev.discovery[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          delay: 1h
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Discovery of all disk devices.'
          item_prototypes:
            - uuid: a4886b1072314819aaf21183949c94bb
              name: 'Average number of outstanding read requests to the disk [{#DISKDESC}]'
              type: SIMPLE
              key: 'vmware.vm.storage.readoio[{$VMWARE.URL},{$VMWARE.VM.UUID},{#DISKNAME}]'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'Average number of outstanding read requests to the virtual disk during the collection interval.'
              tags:
                - tag: component
                  value: disk
                - tag: disk
                  value: '{#DISKDESC}'
            - uuid: 172e4882d39f49d486ab5590163fdd4b
              name: 'Average read latency from the disk [{#DISKDESC}]'
              type: SIMPLE
              key: 'vmware.vm.storage.totalreadlatency[{$VMWARE.URL},{$VMWARE.VM.UUID},{#DISKNAME}]'
              units: '!ms'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'The average time a read from the virtual disk takes.'
              tags:
                - tag: component
                  value: disk
                - tag: disk
                  value: '{#DISKDESC}'
            - uuid: 4fe54828be084b15bb92507106756a5f
              name: 'Average write latency to the disk [{#DISKDESC}]'
              type: SIMPLE
              key: 'vmware.vm.storage.totalwritelatency[{$VMWARE.URL},{$VMWARE.VM.UUID},{#DISKNAME}]'
              units: '!ms'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'The average time a write to the virtual disk takes.'
              tags:
                - tag: component
                  value: disk
                - tag: disk
                  value: '{#DISKDESC}'
            - uuid: a74614af101c404eb7ebec10319dca05
              name: 'Average number of outstanding write requests to the disk [{#DISKDESC}]'
              type: SIMPLE
              key: 'vmware.vm.storage.writeoio[{$VMWARE.URL},{$VMWARE.VM.UUID},{#DISKNAME}]'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'Average number of outstanding write requests to the virtual disk during the collection interval.'
              tags:
                - tag: component
                  value: disk
                - tag: disk
                  value: '{#DISKDESC}'
            - uuid: bd151efc8a0b41e9b64cbf21303fc659
              name: 'Average number of bytes read from the disk [{#DISKDESC}]'
              type: SIMPLE
              key: 'vmware.vm.vfs.dev.read[{$VMWARE.URL},{$VMWARE.VM.UUID},{#DISKNAME},bps]'
              units: Bps
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'VMware virtual machine disk device read statistics (bytes per second).'
              tags:
                - tag: component
                  value: disk
                - tag: disk
                  value: '{#DISKDESC}'
            - uuid: e6248013150d4f23a0774f6cc80e8df3
              name: 'Average number of reads from the disk [{#DISKDESC}]'
              type: SIMPLE
              key: 'vmware.vm.vfs.dev.read[{$VMWARE.URL},{$VMWARE.VM.UUID},{#DISKNAME},ops]'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'VMware virtual machine disk device read statistics (operations per second).'
              tags:
                - tag: component
                  value: disk
                - tag: disk
                  value: '{#DISKDESC}'
            - uuid: 7ea68380b855460b8e51281223659661
              name: 'Average number of bytes written to the disk [{#DISKDESC}]'
              type: SIMPLE
              key: 'vmware.vm.vfs.dev.write[{$VMWARE.URL},{$VMWARE.VM.UUID},{#DISKNAME},bps]'
              units: Bps
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'VMware virtual machine disk device write statistics (bytes per second).'
              tags:
                - tag: component
                  value: disk
                - tag: disk
                  value: '{#DISKDESC}'
            - uuid: 8344a1066f5c4ef49894d2d18fac2339
              name: 'Average number of writes to the disk [{#DISKDESC}]'
              type: SIMPLE
              key: 'vmware.vm.vfs.dev.write[{$VMWARE.URL},{$VMWARE.VM.UUID},{#DISKNAME},ops]'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'VMware virtual machine disk device write statistics (operations per second).'
              tags:
                - tag: component
                  value: disk
                - tag: disk
                  value: '{#DISKDESC}'
        - uuid: 44ff9ef164dc4d20acf06b3368d64456
          name: 'Mounted filesystem discovery'
          type: SIMPLE
          key: 'vmware.vm.vfs.fs.discovery[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
          delay: 1h
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Discovery of all guest file systems.'
          item_prototypes:
            - uuid: 622e96310f9d4f54b4ed82f655fa153b
              name: 'Free disk space on [{#FSNAME}]'
              type: SIMPLE
              key: 'vmware.vm.vfs.fs.size[{$VMWARE.URL},{$VMWARE.VM.UUID},{#FSNAME},free]'
              units: B
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'VMware virtual machine file system statistics (bytes).'
              tags:
                - tag: component
                  value: filesystem
                - tag: filesystem
                  value: '{#FSNAME}'
            - uuid: 3103537bb1d24633a064d173b3b530f2
              name: 'Free disk space on [{#FSNAME}] (percentage)'
              type: SIMPLE
              key: 'vmware.vm.vfs.fs.size[{$VMWARE.URL},{$VMWARE.VM.UUID},{#FSNAME},pfree]'
              value_type: FLOAT
              units: '%'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'VMware virtual machine file system statistics (percentage).'
              tags:
                - tag: component
                  value: filesystem
                - tag: filesystem
                  value: '{#FSNAME}'
              trigger_prototypes:
                - uuid: 19c60e68a55d4910a278b6242ead7686
                  expression: 'max(/VMware Guest/vmware.vm.vfs.fs.size[{$VMWARE.URL},{$VMWARE.VM.UUID},{#FSNAME},pfree],5m)<{$VMWARE.VM.FS.PFREE.MIN.CRIT:"{#FSNAME}"} and {$VMWARE.VM.FS.TRIGGER.USED:"{#FSNAME}"}=1'
                  name: 'VMware Guest: [{#FSNAME}]: Disk space is critically low'
                  event_name: 'VMware Guest: [{#FSNAME}]: Disk space is critically low (below {$VMWARE.VM.FS.PFREE.MIN.CRIT:"{#FSNAME}"}% for 5m)'
                  opdata: 'Space free: {ITEM.LASTVALUE}'
                  priority: AVERAGE
                  description: 'The disk free space on [{#FSNAME}] has been less than `{$VMWARE.VM.FS.PFREE.MIN.CRIT:"{#FSNAME}"}`% for 5m.'
                  manual_close: 'YES'
                  dependencies:
                    - name: 'VMware Guest: Hypervisor is in the maintenance mode'
                      expression: 'last(/VMware Guest/vmware.vm.hv.maintenance[{$VMWARE.URL},{$VMWARE.VM.UUID}])=1 and {$VMWARE.HYPERVISOR.MAINTENANCE}=1'
                  tags:
                    - tag: scope
                      value: capacity
                - uuid: cc995d4c595d46ee80954fd4bb3e0b1b
                  expression: 'max(/VMware Guest/vmware.vm.vfs.fs.size[{$VMWARE.URL},{$VMWARE.VM.UUID},{#FSNAME},pfree],5m)<{$VMWARE.VM.FS.PFREE.MIN.WARN:"{#FSNAME}"} and {$VMWARE.VM.FS.TRIGGER.USED:"{#FSNAME}"}=1'
                  name: 'VMware Guest: [{#FSNAME}]: Disk space is low'
                  event_name: 'VMware Guest: [{#FSNAME}]: Disk space is low (below {$VMWARE.VM.FS.PFREE.MIN.WARN:"{#FSNAME}"}% for 5m)'
                  opdata: 'Space free: {ITEM.LASTVALUE}'
                  priority: WARNING
                  description: 'The disk free space on [{#FSNAME}] has been less than `{$VMWARE.VM.FS.PFREE.MIN.WARN:"{#FSNAME}"}`% for 5m.'
                  manual_close: 'YES'
                  dependencies:
                    - name: 'VMware Guest: Hypervisor is in the maintenance mode'
                      expression: 'last(/VMware Guest/vmware.vm.hv.maintenance[{$VMWARE.URL},{$VMWARE.VM.UUID}])=1 and {$VMWARE.HYPERVISOR.MAINTENANCE}=1'
                    - name: 'VMware Guest: [{#FSNAME}]: Disk space is critically low'
                      expression: 'max(/VMware Guest/vmware.vm.vfs.fs.size[{$VMWARE.URL},{$VMWARE.VM.UUID},{#FSNAME},pfree],5m)<{$VMWARE.VM.FS.PFREE.MIN.CRIT:"{#FSNAME}"} and {$VMWARE.VM.FS.TRIGGER.USED:"{#FSNAME}"}=1'
                  tags:
                    - tag: scope
                      value: capacity
            - uuid: 08d05eac03994b56867ec302a346735c
              name: 'Total disk space on [{#FSNAME}]'
              type: SIMPLE
              key: 'vmware.vm.vfs.fs.size[{$VMWARE.URL},{$VMWARE.VM.UUID},{#FSNAME},total]'
              delay: 1h
              units: B
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'VMware virtual machine total disk space (bytes).'
              preprocessing:
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              tags:
                - tag: component
                  value: filesystem
                - tag: filesystem
                  value: '{#FSNAME}'
            - uuid: 09bb15da42464d8295d5e94b1d42cc87
              name: 'Used disk space on [{#FSNAME}]'
              type: SIMPLE
              key: 'vmware.vm.vfs.fs.size[{$VMWARE.URL},{$VMWARE.VM.UUID},{#FSNAME},used]'
              units: B
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'VMware virtual machine used disk space (bytes).'
              tags:
                - tag: component
                  value: filesystem
                - tag: filesystem
                  value: '{#FSNAME}'
      tags:
        - tag: class
          value: software
        - tag: subclass
          value: virtualization
        - tag: target
          value: vmware
        - tag: target
          value: vmware-guest
      macros:
        - macro: '{$VMWARE.HYPERVISOR.MAINTENANCE}'
          value: '1'
          description: 'If the hypervisor is in maintenance mode, all other problems on the VM will be suppressed automatically. Set to "1"/"0" to enable or disable this feature.'
        - macro: '{$VMWARE.PASSWORD}'
          type: SECRET_TEXT
          description: 'VMware service `{$USERNAME}` user password.'
        - macro: '{$VMWARE.URL}'
          description: 'VMware service (vCenter or ESX hypervisor) SDK URL (https://servername/sdk).'
        - macro: '{$VMWARE.USERNAME}'
          description: 'VMware service user name.'
        - macro: '{$VMWARE.VM.FS.PFREE.MIN.CRIT}'
          value: '10'
          description: 'VMware guest free space threshold for the critical trigger.'
        - macro: '{$VMWARE.VM.FS.PFREE.MIN.WARN}'
          value: '20'
          description: 'VMware guest free space threshold for the warning trigger.'
        - macro: '{$VMWARE.VM.FS.TRIGGER.USED}'
          value: '0'
          description: 'VMware guest used free space trigger. Set to "1"/"0" to enable or disable the trigger.'
      dashboards:
        - uuid: ea7f45fa45e4429abb2fd3a675765483
          name: 'Guest VM overview'
          pages:
            - name: 'VMware: Guest VM Overview'
              widgets:
                - type: gauge
                  name: 'CPU utilization'
                  width: '21'
                  height: '4'
                  hide_header: 'YES'
                  fields:
                    - type: STRING
                      name: description
                      value: 'CPU usage'
                    - type: INTEGER
                      name: desc_size
                      value: '10'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.cpu.usage.perf[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: scale_size
                      value: '10'
                    - type: STRING
                      name: thresholds.0.color
                      value: 0EC9AC
                    - type: STRING
                      name: thresholds.0.threshold
                      value: '0'
                    - type: STRING
                      name: thresholds.1.color
                      value: FFD54F
                    - type: STRING
                      name: thresholds.1.threshold
                      value: '70'
                    - type: STRING
                      name: thresholds.2.color
                      value: FF465C
                    - type: STRING
                      name: thresholds.2.threshold
                      value: '90'
                    - type: INTEGER
                      name: th_show_arc
                      value: '1'
                    - type: INTEGER
                      name: th_show_labels
                      value: '1'
                    - type: STRING
                      name: units
                      value: '%'
                - type: svggraph
                  name: 'CPU and memory usage in percents'
                  'y': '4'
                  width: '42'
                  height: '4'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 4FC3F7
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.0.fill
                      value: '5'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.cpu.usage.perf[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: ds.0.width
                      value: '3'
                    - type: STRING
                      name: ds.1.color.0
                      value: FFAB91
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.1.fill
                      value: '5'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.memory.usage[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: ds.1.width
                      value: '2'
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_columns
                      value: '1'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAAB
                - type: item
                  name: 'Number of virtual CPUs'
                  'y': '8'
                  width: '15'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.cpu.num[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: item
                  name: 'Committed storage space'
                  'y': '10'
                  width: '15'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: decimal_size
                      value: '45'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.storage.committed[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: units_bold
                      value: '0'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: item
                  name: 'Memory size'
                  x: '15'
                  'y': '8'
                  width: '15'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: decimal_size
                      value: '45'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.memory.size[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: units_bold
                      value: '0'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: item
                  name: 'Uncommitted storage space'
                  x: '15'
                  'y': '10'
                  width: '15'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: decimal_size
                      value: '45'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.storage.uncommitted[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: units_bold
                      value: '0'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: gauge
                  name: 'Host memory usage'
                  x: '21'
                  width: '21'
                  height: '4'
                  hide_header: 'YES'
                  fields:
                    - type: STRING
                      name: description
                      value: 'Host memory usage'
                    - type: INTEGER
                      name: desc_size
                      value: '10'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.memory.usage[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: scale_size
                      value: '10'
                    - type: STRING
                      name: thresholds.0.color
                      value: 0EC9AC
                    - type: STRING
                      name: thresholds.0.threshold
                      value: '0'
                    - type: STRING
                      name: thresholds.1.color
                      value: FFD54F
                    - type: STRING
                      name: thresholds.1.threshold
                      value: '70'
                    - type: STRING
                      name: thresholds.2.color
                      value: FF465C
                    - type: STRING
                      name: thresholds.2.threshold
                      value: '90'
                    - type: INTEGER
                      name: th_show_arc
                      value: '1'
                    - type: INTEGER
                      name: th_show_labels
                      value: '1'
                    - type: STRING
                      name: units
                      value: '%'
                - type: item
                  name: 'VMware Tools version'
                  x: '30'
                  'y': '8'
                  width: '12'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.tools[{$VMWARE.URL},{$VMWARE.VM.UUID},version]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: item
                  name: Uptime
                  x: '30'
                  'y': '10'
                  width: '12'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.uptime[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: item
                  name: 'VM state'
                  x: '42'
                  width: '30'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.state[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: STRING
                      name: thresholds.0.color
                      value: FFBF00
                    - type: STRING
                      name: thresholds.0.threshold
                      value: '0'
                    - type: STRING
                      name: thresholds.1.color
                      value: FFBF00
                    - type: STRING
                      name: thresholds.1.threshold
                      value: '1'
                    - type: STRING
                      name: thresholds.2.color
                      value: 32CD32
                    - type: STRING
                      name: thresholds.2.threshold
                      value: '2'
                    - type: STRING
                      name: thresholds.3.color
                      value: FFECB3
                    - type: STRING
                      name: thresholds.3.threshold
                      value: '3'
                    - type: STRING
                      name: thresholds.4.color
                      value: FFECB3
                    - type: STRING
                      name: thresholds.4.threshold
                      value: '4'
                    - type: STRING
                      name: thresholds.5.color
                      value: D2D2D2
                    - type: STRING
                      name: thresholds.5.threshold
                      value: '5'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                    - type: INTEGER
                      name: value_size
                      value: '35'
                - type: item
                  name: 'VM Tools status'
                  x: '42'
                  'y': '2'
                  width: '30'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.tools[{$VMWARE.URL},{$VMWARE.VM.UUID},status]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: STRING
                      name: thresholds.0.color
                      value: FFBF00
                    - type: STRING
                      name: thresholds.0.threshold
                      value: '0'
                    - type: STRING
                      name: thresholds.1.color
                      value: FFBF00
                    - type: STRING
                      name: thresholds.1.threshold
                      value: '1'
                    - type: STRING
                      name: thresholds.2.color
                      value: 32CD32
                    - type: STRING
                      name: thresholds.2.threshold
                      value: '2'
                    - type: STRING
                      name: thresholds.3.color
                      value: D2D2D2
                    - type: STRING
                      name: thresholds.3.threshold
                      value: '10'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                    - type: INTEGER
                      name: value_size
                      value: '35'
                - type: item
                  name: 'Cluster name'
                  x: '42'
                  'y': '4'
                  width: '30'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.cluster.name[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: item
                  name: 'Datacenter name'
                  x: '42'
                  'y': '6'
                  width: '30'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.datacenter.name[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: item
                  name: 'Hypervisor name'
                  x: '42'
                  'y': '8'
                  width: '30'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.hv.name[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: item
                  name: 'Snapshot count'
                  x: '42'
                  'y': '10'
                  width: '12'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: vmware.vm.snapshot.count
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: item
                  name: 'Snapshot latest date'
                  x: '54'
                  'y': '10'
                  width: '18'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: vmware.vm.snapshot.latestdate
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                    - type: INTEGER
                      name: value_size
                      value: '30'
            - name: 'VMware: CPU'
              widgets:
                - type: svggraph
                  name: 'CPU usage'
                  width: '51'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 0288D1
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.0.fill
                      value: '4'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.cpu.usage.perf[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: ds.0.transparency
                      value: '6'
                    - type: INTEGER
                      name: ds.0.width
                      value: '2'
                    - type: INTEGER
                      name: legend_columns
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAAD
                - type: svggraph
                  name: 'CPU latency'
                  'y': '6'
                  width: '51'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 00BFFF
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.cpu.latency[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: ds.0.transparency
                      value: '6'
                    - type: STRING
                      name: ds.1.color.0
                      value: CE93D8
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.cpu.readiness[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: ds.1.transparency
                      value: '6'
                    - type: STRING
                      name: ds.2.color.0
                      value: FF4000
                    - type: INTEGER
                      name: ds.2.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.2.itemids.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.cpu.swapwait[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: ds.2.transparency
                      value: '6'
                    - type: INTEGER
                      name: legend_columns
                      value: '1'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAAE
                - type: item
                  name: 'Number of virtual CPUs'
                  x: '51'
                  width: '21'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.cpu.num[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: item
                  name: 'CPU usage'
                  x: '51'
                  'y': '2'
                  width: '21'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: decimal_size
                      value: '45'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.cpu.usage[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: units_bold
                      value: '0'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: item
                  name: 'CPU ready'
                  x: '51'
                  'y': '4'
                  width: '21'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: decimal_size
                      value: '45'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.cpu.ready[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: units_bold
                      value: '0'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: item
                  name: 'CPU latency in percents'
                  x: '51'
                  'y': '6'
                  width: '21'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: decimal_size
                      value: '45'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.cpu.latency[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: units_bold
                      value: '0'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: item
                  name: 'CPU readiness latency in percent'
                  x: '51'
                  'y': '8'
                  width: '21'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: decimal_size
                      value: '45'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.cpu.readiness[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: units_bold
                      value: '0'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: item
                  name: 'CPU readiness latency in percent'
                  x: '51'
                  'y': '10'
                  width: '21'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: decimal_size
                      value: '45'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.cpu.swapwait[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: units_bold
                      value: '0'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
            - name: 'VMware: Memory'
              widgets:
                - type: svggraph
                  name: 'Host memory usage in percent'
                  width: '51'
                  height: '4'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: EF9A9A
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.0.fill
                      value: '4'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.memory.usage[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: ds.0.transparency
                      value: '6'
                    - type: INTEGER
                      name: ds.0.width
                      value: '2'
                    - type: INTEGER
                      name: legend_columns
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAAF
                - type: svggraph
                  name: 'Host memory usage'
                  'y': '4'
                  width: '51'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: F06292
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.memory.size.usage.guest[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: ds.0.transparency
                      value: '3'
                    - type: STRING
                      name: ds.1.color.0
                      value: BF00FF
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.memory.size.consumed[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: ds.1.transparency
                      value: '3'
                    - type: STRING
                      name: ds.2.color.0
                      value: 90CAF9
                    - type: INTEGER
                      name: ds.2.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.2.itemids.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.memory.size.usage.host[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: ds.2.transparency
                      value: '3'
                    - type: INTEGER
                      name: legend_columns
                      value: '1'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAAG
                - type: item
                  name: 'Guest memory swapped'
                  'y': '10'
                  width: '12'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: decimal_size
                      value: '45'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.guest.memory.size.swapped[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: units_bold
                      value: '0'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: item
                  name: 'Swapped memory'
                  x: '12'
                  'y': '10'
                  width: '12'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: decimal_size
                      value: '45'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.memory.size.swapped[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: units_bold
                      value: '0'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: item
                  name: 'Private memory'
                  x: '24'
                  'y': '10'
                  width: '12'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: decimal_size
                      value: '45'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.memory.size.private[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: units_bold
                      value: '0'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: item
                  name: 'Shared memory'
                  x: '36'
                  'y': '10'
                  width: '12'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: decimal_size
                      value: '45'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.memory.size.shared[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: units_bold
                      value: '0'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: item
                  name: 'Ballooned memory'
                  x: '48'
                  'y': '10'
                  width: '12'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: decimal_size
                      value: '45'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.memory.size.ballooned[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: units_bold
                      value: '0'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: item
                  name: 'Memory size'
                  x: '51'
                  width: '21'
                  height: '4'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: decimal_size
                      value: '25'
                    - type: INTEGER
                      name: desc_size
                      value: '7'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.memory.size[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: units_bold
                      value: '0'
                    - type: INTEGER
                      name: units_size
                      value: '20'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                    - type: INTEGER
                      name: value_size
                      value: '25'
                - type: item
                  name: 'Guest memory usage'
                  x: '51'
                  'y': '4'
                  width: '21'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: decimal_size
                      value: '45'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.memory.size.usage.guest[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: units_bold
                      value: '0'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: item
                  name: 'Host memory consumed'
                  x: '51'
                  'y': '6'
                  width: '21'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: decimal_size
                      value: '45'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.memory.size.consumed[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: units_bold
                      value: '0'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: item
                  name: 'Host memory usage'
                  x: '51'
                  'y': '8'
                  width: '21'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: decimal_size
                      value: '45'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.memory.size.usage.host[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: units_bold
                      value: '0'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: item
                  name: 'Compressed memory'
                  x: '60'
                  'y': '10'
                  width: '12'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: decimal_size
                      value: '45'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.memory.size.compressed[{$VMWARE.URL},{$VMWARE.VM.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: units_bold
                      value: '0'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
            - name: 'VMware: Storage'
              widgets:
                - type: graphprototype
                  name: 'Average number of bytes read from the disk'
                  width: '36'
                  height: '6'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: ITEM_PROTOTYPE
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.vfs.dev.read[{$VMWARE.URL},{$VMWARE.VM.UUID},{#DISKNAME},bps]'
                    - type: STRING
                      name: reference
                      value: AAAAH
                    - type: INTEGER
                      name: source_type
                      value: '3'
                - type: graphprototype
                  name: 'Average read latency to the disk'
                  'y': '6'
                  width: '36'
                  height: '6'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: ITEM_PROTOTYPE
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.storage.totalreadlatency[{$VMWARE.URL},{$VMWARE.VM.UUID},{#DISKNAME}]'
                    - type: STRING
                      name: reference
                      value: AAAAJ
                    - type: INTEGER
                      name: source_type
                      value: '3'
                - type: graphprototype
                  name: 'Average number of bytes written to the disk'
                  x: '36'
                  width: '36'
                  height: '6'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: ITEM_PROTOTYPE
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.vfs.dev.write[{$VMWARE.URL},{$VMWARE.VM.UUID},{#DISKNAME},bps]'
                    - type: STRING
                      name: reference
                      value: AAAAK
                    - type: INTEGER
                      name: source_type
                      value: '3'
                - type: graphprototype
                  name: 'Average write latency to the disk'
                  x: '36'
                  'y': '6'
                  width: '36'
                  height: '6'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: ITEM_PROTOTYPE
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.storage.totalwritelatency[{$VMWARE.URL},{$VMWARE.VM.UUID},{#DISKNAME}]'
                    - type: STRING
                      name: reference
                      value: AAAAL
                    - type: INTEGER
                      name: source_type
                      value: '3'
            - name: 'VMware: Filesystem'
              widgets:
                - type: honeycomb
                  name: 'Total disk space'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: bg_color
                      value: 81D4FA
                    - type: STRING
                      name: items.0
                      value: 'Total disk space on*'
                    - type: STRING
                      name: primary_label
                      value: '{{ITEM.NAME}.regsub("space on.\[(.*)\]", \1)}'
                    - type: INTEGER
                      name: primary_label_size_type
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAAM
                - type: graphprototype
                  name: 'Free disk space'
                  'y': '6'
                  width: '36'
                  height: '6'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: ITEM_PROTOTYPE
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.vfs.fs.size[{$VMWARE.URL},{$VMWARE.VM.UUID},{#FSNAME},free]'
                    - type: STRING
                      name: reference
                      value: AAAAN
                    - type: INTEGER
                      name: source_type
                      value: '3'
                - type: honeycomb
                  name: 'Free disk space'
                  x: '36'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: items.0
                      value: 'Free disk space on*(percentage)'
                    - type: STRING
                      name: primary_label
                      value: '{{ITEM.NAME}.regsub("space on.\[(.*)\]", \1)}'
                    - type: INTEGER
                      name: primary_label_size_type
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAAO
                    - type: STRING
                      name: thresholds.0.color
                      value: FF465C
                    - type: STRING
                      name: thresholds.0.threshold
                      value: '10'
                    - type: STRING
                      name: thresholds.1.color
                      value: FFD54F
                    - type: STRING
                      name: thresholds.1.threshold
                      value: '20'
                    - type: STRING
                      name: thresholds.2.color
                      value: 0EC9AC
                    - type: STRING
                      name: thresholds.2.threshold
                      value: '30'
                - type: graphprototype
                  name: 'Free disk space (percentage)'
                  x: '36'
                  'y': '6'
                  width: '36'
                  height: '6'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: ITEM_PROTOTYPE
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.vfs.fs.size[{$VMWARE.URL},{$VMWARE.VM.UUID},{#FSNAME},pfree]'
                    - type: STRING
                      name: reference
                      value: AAAAP
                    - type: INTEGER
                      name: source_type
                      value: '3'
            - name: 'VMware: Network'
              widgets:
                - type: graphprototype
                  name: 'Network utilization on interface'
                  width: '72'
                  height: '4'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: ITEM_PROTOTYPE
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.net.if.usage[{$VMWARE.URL},{$VMWARE.VM.UUID},{#IFNAME}]'
                    - type: STRING
                      name: reference
                      value: AAAAQ
                    - type: INTEGER
                      name: source_type
                      value: '3'
                - type: graphprototype
                  name: 'Number of bytes received on interface'
                  'y': '4'
                  width: '36'
                  height: '4'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: ITEM_PROTOTYPE
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.net.if.in[{$VMWARE.URL},{$VMWARE.VM.UUID},{#IFNAME},bps]'
                    - type: STRING
                      name: reference
                      value: AAAAR
                    - type: INTEGER
                      name: source_type
                      value: '3'
                - type: graphprototype
                  name: 'Number of packets received on interface'
                  'y': '8'
                  width: '36'
                  height: '4'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: ITEM_PROTOTYPE
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.net.if.in[{$VMWARE.URL},{$VMWARE.VM.UUID},{#IFNAME},pps]'
                    - type: STRING
                      name: reference
                      value: AAAAS
                    - type: INTEGER
                      name: source_type
                      value: '3'
                - type: graphprototype
                  name: 'Number of bytes transmitted on interface'
                  x: '36'
                  'y': '4'
                  width: '36'
                  height: '4'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: ITEM_PROTOTYPE
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.net.if.out[{$VMWARE.URL},{$VMWARE.VM.UUID},{#IFNAME},bps]'
                    - type: STRING
                      name: reference
                      value: AAAAT
                    - type: INTEGER
                      name: source_type
                      value: '3'
                - type: graphprototype
                  name: 'Number of packets transmitted on interface'
                  x: '36'
                  'y': '8'
                  width: '36'
                  height: '4'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: ITEM_PROTOTYPE
                      name: itemid.0
                      value:
                        host: 'VMware Guest'
                        key: 'vmware.vm.net.if.out[{$VMWARE.URL},{$VMWARE.VM.UUID},{#IFNAME},pps]'
                    - type: STRING
                      name: reference
                      value: AAAAU
                    - type: INTEGER
                      name: source_type
                      value: '3'
      valuemaps:
        - uuid: be14ef9303f040859e6edbb13d9b64c5
          name: 'VMware Consolidation'
          mappings:
            - value: '0'
              newvalue: 'True'
            - value: '1'
              newvalue: 'False'
            - value: '2'
              newvalue: Unknown
        - uuid: 815e082c2a804884bb25da4aaee18934
          name: 'VMware Hypervisor maintenance mode'
          mappings:
            - value: '0'
              newvalue: 'Normal mode'
            - value: '1'
              newvalue: 'Maintenance mode'
        - uuid: 64586743ecc74b5a8b7b849cd4521f48
          name: 'VMware Tools status'
          mappings:
            - value: '0'
              newvalue: 'Guest tools is executing scripts'
            - value: '1'
              newvalue: 'Guest tools is not running'
            - value: '2'
              newvalue: 'Guest tools is running'
            - value: '10'
              newvalue: Unknown
        - uuid: 78f08f5c5c0047b999a2e8daa96cf8b7
          name: 'VMware VirtualMachinePowerState'
          mappings:
            - value: '0'
              newvalue: 'Powered off'
            - value: '1'
              newvalue: 'Powered on'
            - value: '2'
              newvalue: Suspended
        - uuid: 68d712e1c43c4e2d84619c9fcb965919
          name: 'VMware Virtual Machine state'
          mappings:
            - value: '0'
              newvalue: 'Not running'
            - value: '1'
              newvalue: Resetting
            - value: '2'
              newvalue: Running
            - value: '3'
              newvalue: 'Shutting down'
            - value: '4'
              newvalue: Standby
            - value: '5'
              newvalue: Unknown
    - uuid: 5899b2f0aced4085b5ac25d0461b3425
      template: 'VMware Hypervisor'
      name: 'VMware Hypervisor'
      description: |
        You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/
        
        This template can be used in discovery as well as manually linked to a host. To use this template as manually linked to a host, attach it to the host and set manually the value of '{$VMWARE.HV.UUID}' macro.
        
        Note: To create custom performance counter see documentation: https://www.zabbix.com/documentation/7.4/manual/vm_monitoring/vmware_keys#footnotes
        
        Note: To get all supported counters and generate path for custom performance counter see documentation: https://www.zabbix.com/documentation/7.4/manual/appendix/items/perf_counters
        
        Generated by official Zabbix template tool "Templator"
      wizard_ready: 'YES'
      readme: |
        ## Overview
        
        This template is designed for the effortless deployment of VMware ESX hypervisor monitoring and doesn't require any external scripts.
        
        This template can be used in discovery as well as manually linked to a host.
        
        For additional information, please see [Zabbix documentation on VM monitoring](https://www.zabbix.com/documentation/7.4/manual/vm_monitoring).
        
        To use this template as manually linked to a host, attach it to the host and manually set the `Hypervisor UUID` host wizard configuration field.
        
        ## Setup
        
        To use this template as manually linked to a host:
          1. Compile Zabbix server with the required options (`--with-libxml2` and `--with-libcurl`)
          2. Set the `StartVMwareCollectors` option in the Zabbix server configuration file to "1" or more
          3. Set the host wizard configuration fields required for VMware authentication: `VMware URL`, `VMware username` and `VMware password`
          4. To get the hypervisor UUID, enable access to the hypervisor via SSH and log in via SSH using a valid login and password.
          5. Run the following command and specify the UUID in the `Hypervisor UUID` host wizard configuration field:
          ```text
          vim-cmd hostsvc/hostsummary | grep uuid
          ```
        
        Note: To enable discovery of hardware sensors of VMware hypervisors, set the host wizard configuration field `Monitoring of hardware sensors` to the selected state.
      vendor:
        name: Zabbix
        version: 7.4-2
      groups:
        - name: Templates/Applications
      items:
        - uuid: 3010cb082f23478b858912f944347530
          name: 'Hypervisor ping'
          type: SIMPLE
          key: 'icmpping[]'
          description: |
            Checks if the hypervisor is running and accepting ICMP pings. One of the following:
            - Down;
            - Up.
          valuemap:
            name: 'Service state'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 10m
          tags:
            - tag: component
              value: application
            - tag: component
              value: health
          triggers:
            - uuid: ab84a61566a5402db59efd40d20714a5
              expression: 'last(/VMware Hypervisor/icmpping[])=0'
              name: 'VMware Hypervisor: Hypervisor is down'
              priority: AVERAGE
              description: 'The service is unavailable or is not accepting ICMP pings.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: availability
        - uuid: af4d0877fda84753816c817ad76162f1
          name: 'Cluster name'
          type: SIMPLE
          key: 'vmware.hv.cluster.name[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          delay: 1h
          value_type: CHAR
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Cluster name of the guest VM.'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          tags:
            - tag: component
              value: cluster
        - uuid: 0e9fd4e6d6e446f08afe7b4b9431bc62
          name: 'Connection state'
          type: SIMPLE
          key: 'vmware.hv.connectionstate[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: |
            VMware hypervisor connection state. One of the following:
            - Connected;
            - Disconnected;
            - Not responding.
          valuemap:
            name: 'VMware Connection state'
          preprocessing:
            - type: JAVASCRIPT
              parameters:
                - |
                  const idx = [
                  	'connected',
                  	'disconnected',
                  	'notResponding'
                  ].indexOf(value);
                  return idx !== -1 ? idx : 3;
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
          tags:
            - tag: component
              value: availability
        - uuid: c4ebd62118464e7a8d1945f80d70f8ae
          name: 'CPU usage in percent'
          type: SIMPLE
          key: 'vmware.hv.cpu.usage.perf[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          value_type: FLOAT
          units: '%'
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'CPU usage as a percentage during the interval.'
          tags:
            - tag: component
              value: cpu
        - uuid: 1bff6fbd300d4455a787a273d957bba3
          name: 'CPU usage'
          type: SIMPLE
          key: 'vmware.hv.cpu.usage[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          units: Hz
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Aggregated CPU usage across all cores on the host in Hz. This is only available if the host is connected.'
          tags:
            - tag: component
              value: cpu
        - uuid: aad168c33cd14f76aa14ab5ca26498ec
          name: 'CPU utilization'
          type: SIMPLE
          key: 'vmware.hv.cpu.utilization[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          value_type: FLOAT
          units: '%'
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'CPU utilization as a percentage during the interval depends on power management or hyper-threading.'
          tags:
            - tag: component
              value: cpu
        - uuid: e4d27d7f9b9048d4ae6c60cbdd6c0091
          name: 'Datacenter name'
          type: SIMPLE
          key: 'vmware.hv.datacenter.name[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          delay: 1h
          value_type: CHAR
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Datacenter name of the hypervisor.'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          tags:
            - tag: component
              value: datacenter
        - uuid: 5c29837f75f04d7f9a5786691b3dd991
          name: 'Full name'
          type: SIMPLE
          key: 'vmware.hv.fullname[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          delay: 1h
          value_type: CHAR
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'The complete product name, including the version information.'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          tags:
            - tag: component
              value: system
        - uuid: ad0053d57b834e6a9776c08e1c455d55
          name: 'CPU frequency'
          type: SIMPLE
          key: 'vmware.hv.hw.cpu.freq[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          delay: 1h
          units: Hz
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'The speed of the CPU cores. This is an average value if there are multiple speeds. The product of CPU frequency and the number of cores is approximately equal to the sum of the MHz for all the individual cores on the host.'
          tags:
            - tag: component
              value: cpu
        - uuid: 3f0c35fcef9e4699ac5a1c51d80f8da4
          name: 'CPU model'
          type: SIMPLE
          key: 'vmware.hv.hw.cpu.model[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          delay: 1h
          value_type: CHAR
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'The CPU model.'
          tags:
            - tag: component
              value: cpu
        - uuid: c99a5bf2e3904f97b3d361ca20af7883
          name: 'CPU cores'
          type: SIMPLE
          key: 'vmware.hv.hw.cpu.num[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          delay: 1h
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Number of physical CPU cores on the host. Physical CPU cores are the processors contained by a CPU package.'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          tags:
            - tag: component
              value: cpu
        - uuid: 89cb0a4809e7454a862f398a0e9d6bed
          name: 'CPU threads'
          type: SIMPLE
          key: 'vmware.hv.hw.cpu.threads[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          delay: 1h
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Number of physical CPU threads on the host.'
          tags:
            - tag: component
              value: cpu
        - uuid: ce89c38e6e5d4338a30ee150be1b2b67
          name: 'Total memory'
          type: SIMPLE
          key: 'vmware.hv.hw.memory[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          delay: 1h
          units: B
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'The physical memory size.'
          tags:
            - tag: component
              value: memory
        - uuid: 7ed7ac26da384bcda976badf24ebbec1
          name: Model
          type: SIMPLE
          key: 'vmware.hv.hw.model[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          delay: 1h
          value_type: CHAR
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'The system model identification.'
          tags:
            - tag: component
              value: system
        - uuid: 6c4aab55b3e640779a25ac90b9ca2a43
          name: 'Bios UUID'
          type: SIMPLE
          key: 'vmware.hv.hw.uuid[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          delay: 1h
          value_type: CHAR
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'The hardware BIOS identification.'
          tags:
            - tag: component
              value: system
        - uuid: aec06090d16d4bdd8ed3494b448f19d8
          name: Vendor
          type: SIMPLE
          key: 'vmware.hv.hw.vendor[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          delay: 1h
          value_type: CHAR
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'The hardware vendor identification.'
          tags:
            - tag: component
              value: system
        - uuid: 21020a79436a49c38caf8941f6b68da3
          name: 'Ballooned memory'
          type: SIMPLE
          key: 'vmware.hv.memory.size.ballooned[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          units: B
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'The amount of guest physical memory that is currently reclaimed through the balloon driver. Sum of all guest VMs.'
          tags:
            - tag: component
              value: memory
        - uuid: 93d680d6886d446badbbe995ddd9ba9c
          name: 'Used memory'
          type: SIMPLE
          key: 'vmware.hv.memory.used[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          units: B
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Physical memory usage on the host.'
          tags:
            - tag: component
              value: memory
        - uuid: 33f78ab6ee6c4e7585a83a60cdecab6f
          name: 'Number of bytes received'
          type: SIMPLE
          key: 'vmware.hv.network.in[{$VMWARE.URL},{$VMWARE.HV.UUID},bps]'
          units: Bps
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'VMware hypervisor network input statistics (bytes per second).'
          tags:
            - tag: component
              value: network
        - uuid: 8f935e9718294cd4a67d02f4723a1713
          name: 'Number of broadcasts received'
          type: SIMPLE
          key: 'vmware.hv.network.in[{$VMWARE.URL},{$VMWARE.HV.UUID},broadcast]'
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'VMware hypervisor network input statistics (broadcasts).'
          tags:
            - tag: component
              value: network
        - uuid: 720c58685828440bacda845bfd848d6a
          name: 'Number of dropped received packets'
          type: SIMPLE
          key: 'vmware.hv.network.in[{$VMWARE.URL},{$VMWARE.HV.UUID},dropped]'
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'VMware hypervisor network input statistics (packets dropped).'
          tags:
            - tag: component
              value: network
        - uuid: 0084eb8fd76241b8938bb1dad5a3f160
          name: 'Number of errors received'
          type: SIMPLE
          key: 'vmware.hv.network.in[{$VMWARE.URL},{$VMWARE.HV.UUID},errors]'
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'VMware hypervisor network input statistics (errors).'
          tags:
            - tag: component
              value: network
        - uuid: b013afcba08b47f4a5b590a59f464a58
          name: 'Number of bytes transmitted'
          type: SIMPLE
          key: 'vmware.hv.network.out[{$VMWARE.URL},{$VMWARE.HV.UUID},bps]'
          units: Bps
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'VMware hypervisor network output statistics (bytes per second).'
          tags:
            - tag: component
              value: network
        - uuid: 16496c407daa43b9863c05416b294992
          name: 'Number of broadcasts transmitted'
          type: SIMPLE
          key: 'vmware.hv.network.out[{$VMWARE.URL},{$VMWARE.HV.UUID},broadcast]'
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'VMware hypervisor network output statistics (broadcasts).'
          tags:
            - tag: component
              value: network
        - uuid: f001256bbfc34cc0898c5eaef422973e
          name: 'Number of dropped transmitted packets'
          type: SIMPLE
          key: 'vmware.hv.network.out[{$VMWARE.URL},{$VMWARE.HV.UUID},dropped]'
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'VMware hypervisor network output statistics (packets dropped).'
          tags:
            - tag: component
              value: network
        - uuid: 5f549d8708f24160b04a4a74db29042a
          name: 'Number of errors transmitted'
          type: SIMPLE
          key: 'vmware.hv.network.out[{$VMWARE.URL},{$VMWARE.HV.UUID},errors]'
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'VMware hypervisor network output statistics (errors).'
          tags:
            - tag: component
              value: network
        - uuid: e4116d7c7e234c5ebd5784f42ade1f2e
          name: 'Power usage maximum allowed'
          type: SIMPLE
          key: 'vmware.hv.power[{$VMWARE.URL},{$VMWARE.HV.UUID},max]'
          units: '!W'
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Maximum allowed power usage.'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 6h
          tags:
            - tag: component
              value: power
        - uuid: 179a981cf30f4f77869e3b50dc2bc333
          name: 'Power usage'
          type: SIMPLE
          key: 'vmware.hv.power[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          units: '!W'
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Current power usage.'
          tags:
            - tag: component
              value: power
        - uuid: 3c9d6ffb53624758ad888bf70f69218c
          name: 'Get sensors'
          type: SIMPLE
          key: 'vmware.hv.sensors.get[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          history: '0'
          value_type: TEXT
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Master item for sensor data.'
          tags:
            - tag: component
              value: raw
        - uuid: 0cec294521314c5482233b5b96e90c8d
          name: 'Overall status'
          type: SIMPLE
          key: 'vmware.hv.status[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: |
            The overall alarm status of the host. One of the following:
            - Gray: Unknown;
            - Green: OK;
            - Yellow: It might have a problem;
            - Red: It has a problem.
          valuemap:
            name: 'VMware status'
          tags:
            - tag: component
              value: health
          triggers:
            - uuid: 378511e0f1794874a68aef1b43561ee5
              expression: 'last(/VMware Hypervisor/vmware.hv.status[{$VMWARE.URL},{$VMWARE.HV.UUID}])=3'
              name: 'VMware Hypervisor: The {$VMWARE.HV.UUID} health is Red'
              priority: HIGH
              description: 'One or more components in the appliance might be in an unusable status and the appliance might soon become unresponsive. Security patches might be available.'
              tags:
                - tag: scope
                  value: availability
                - tag: scope
                  value: performance
            - uuid: ef6ca4d7033c4c8cb963eb7d493b3c7b
              expression: 'last(/VMware Hypervisor/vmware.hv.status[{$VMWARE.URL},{$VMWARE.HV.UUID}])=2'
              name: 'VMware Hypervisor: The {$VMWARE.HV.UUID} health is Yellow'
              priority: AVERAGE
              description: 'One or more components in the appliance might soon become overloaded.'
              dependencies:
                - name: 'VMware Hypervisor: The {$VMWARE.HV.UUID} health is Red'
                  expression: 'last(/VMware Hypervisor/vmware.hv.status[{$VMWARE.URL},{$VMWARE.HV.UUID}])=3'
              tags:
                - tag: scope
                  value: availability
                - tag: scope
                  value: performance
        - uuid: ecad96137494476293b57a0440de3f65
          name: Uptime
          type: SIMPLE
          key: 'vmware.hv.uptime[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          units: uptime
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'System uptime.'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 01d316b0a8cf4998b344f0c4ef1daa32
              expression: 'last(/VMware Hypervisor/vmware.hv.uptime[{$VMWARE.URL},{$VMWARE.HV.UUID}])<10m'
              name: 'VMware Hypervisor: Hypervisor has been restarted'
              event_name: 'VMware Hypervisor: Hypervisor has been restarted (uptime < 10m)'
              priority: WARNING
              description: 'Uptime is less than 10 minutes.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: 222ad20887cf479b8e81a4c338078d17
          name: Version
          type: SIMPLE
          key: 'vmware.hv.version[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          delay: 1h
          value_type: CHAR
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Dot-separated version string.'
          tags:
            - tag: component
              value: system
        - uuid: 2045df572e864834bd4bd97046353f4e
          name: 'Number of guest VMs'
          type: SIMPLE
          key: 'vmware.hv.vm.num[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          delay: 1h
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Number of guest virtual machines.'
          tags:
            - tag: component
              value: system
      discovery_rules:
        - uuid: fb7774df87994355baff7402d9fabcc2
          name: 'Datastore discovery'
          type: SIMPLE
          key: 'vmware.hv.datastore.discovery[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          delay: 1h
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Discovery of VMware datastores.'
          item_prototypes:
            - uuid: 65e6c165c3674953b2845d4101a9a6bf
              name: 'Multipath count for datastore [{#DATASTORE}]'
              type: SIMPLE
              key: 'vmware.hv.datastore.multipath[{$VMWARE.URL},{$VMWARE.HV.UUID},{#DATASTORE.UUID}]'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'Number of available datastore paths.'
              tags:
                - tag: component
                  value: datastore
                - tag: datastore
                  value: '{#DATASTORE}'
                - tag: type
                  value: '{#DATASTORE.TYPE}'
              trigger_prototypes:
                - uuid: 8f1de4827ba446ef902ca5fa44109c6d
                  expression: 'last(/VMware Hypervisor/vmware.hv.datastore.multipath[{$VMWARE.URL},{$VMWARE.HV.UUID},{#DATASTORE.UUID}],#1)<>last(/VMware Hypervisor/vmware.hv.datastore.multipath[{$VMWARE.URL},{$VMWARE.HV.UUID},{#DATASTORE.UUID}],#2) and last(/VMware Hypervisor/vmware.hv.datastore.multipath[{$VMWARE.URL},{$VMWARE.HV.UUID},{#DATASTORE.UUID}])<{#MULTIPATH.COUNT}'
                  name: 'VMware Hypervisor: The multipath count has been changed'
                  event_name: 'VMware Hypervisor: The multipath count for datastore [{#DATASTORE}] has been changed'
                  opdata: 'Current: {ITEM.LASTVALUE}, Registered: {#MULTIPATH.COUNT}'
                  priority: AVERAGE
                  description: 'The number of available datastore paths is less than registered (`{#MULTIPATH.COUNT}`).'
                  manual_close: 'YES'
                  tags:
                    - tag: scope
                      value: notice
            - uuid: 259d1ff4bde143248f7ee2f7f880cb62
              name: 'Average read latency of the datastore [{#DATASTORE}]'
              type: SIMPLE
              key: 'vmware.hv.datastore.read[{$VMWARE.URL},{$VMWARE.HV.UUID},{#DATASTORE.UUID},latency]'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'Average amount of time for a read operation from the datastore (milliseconds).'
              tags:
                - tag: component
                  value: datastore
                - tag: datastore
                  value: '{#DATASTORE}'
                - tag: type
                  value: '{#DATASTORE.TYPE}'
            - uuid: 1d7761e9ad0c48c1a3f6b1b48290c16b
              name: 'Average read IOPS of the datastore [{#DATASTORE}]'
              type: SIMPLE
              key: 'vmware.hv.datastore.read[{$VMWARE.URL},{$VMWARE.HV.UUID},{#DATASTORE.UUID},rps]'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'Average IOPS for a read operation from the datastore.'
              tags:
                - tag: component
                  value: datastore
                - tag: datastore
                  value: '{#DATASTORE}'
                - tag: type
                  value: '{#DATASTORE.TYPE}'
            - uuid: f36245398cc4460a9cb4ec741612693b
              name: 'Free space on datastore [{#DATASTORE}] (percentage)'
              type: SIMPLE
              key: 'vmware.hv.datastore.size[{$VMWARE.URL},{$VMWARE.HV.UUID},{#DATASTORE.UUID},pfree]'
              delay: 5m
              value_type: FLOAT
              units: '%'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'VMware datastore free space (percentage from the total).'
              tags:
                - tag: component
                  value: datastore
                - tag: datastore
                  value: '{#DATASTORE}'
                - tag: type
                  value: '{#DATASTORE.TYPE}'
              trigger_prototypes:
                - uuid: 79c83ed72685487a9ef139c42eea1106
                  expression: 'last(/VMware Hypervisor/vmware.hv.datastore.size[{$VMWARE.URL},{$VMWARE.HV.UUID},{#DATASTORE.UUID},pfree])<{$VMWARE.HV.DATASTORE.SPACE.CRIT}'
                  name: 'VMware Hypervisor: [{#DATASTORE}]: Free space is critically low'
                  event_name: 'VMware Hypervisor: Datastore free space is critically low ([{#DATASTORE}] free space < {$VMWARE.HV.DATASTORE.SPACE.CRIT}%)'
                  priority: HIGH
                  description: 'Datastore free space has fallen below the critical threshold.'
                  tags:
                    - tag: scope
                      value: capacity
                - uuid: 5bc64ee899444a01a5bc315290256cdf
                  expression: 'last(/VMware Hypervisor/vmware.hv.datastore.size[{$VMWARE.URL},{$VMWARE.HV.UUID},{#DATASTORE.UUID},pfree])<{$VMWARE.HV.DATASTORE.SPACE.WARN}'
                  name: 'VMware Hypervisor: [{#DATASTORE}]: Free space is low'
                  event_name: 'VMware Hypervisor: Datastore free space is low ([{#DATASTORE}] free space < {$VMWARE.HV.DATASTORE.SPACE.WARN}%)'
                  priority: WARNING
                  description: 'Datastore free space has fallen below the warning threshold.'
                  dependencies:
                    - name: 'VMware Hypervisor: [{#DATASTORE}]: Free space is critically low'
                      expression: 'last(/VMware Hypervisor/vmware.hv.datastore.size[{$VMWARE.URL},{$VMWARE.HV.UUID},{#DATASTORE.UUID},pfree])<{$VMWARE.HV.DATASTORE.SPACE.CRIT}'
                  tags:
                    - tag: scope
                      value: capacity
            - uuid: cc83e8f5ec08483db75482706bf01aba
              name: 'Total size of datastore [{#DATASTORE}]'
              type: SIMPLE
              key: 'vmware.hv.datastore.size[{$VMWARE.URL},{$VMWARE.HV.UUID},{#DATASTORE.UUID}]'
              delay: 5m
              units: B
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'VMware datastore space in bytes.'
              preprocessing:
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              tags:
                - tag: component
                  value: datastore
                - tag: datastore
                  value: '{#DATASTORE}'
                - tag: type
                  value: '{#DATASTORE.TYPE}'
            - uuid: 9db980d8f5f44af5ad11a5949d80031d
              name: 'Average write latency of the datastore [{#DATASTORE}]'
              type: SIMPLE
              key: 'vmware.hv.datastore.write[{$VMWARE.URL},{$VMWARE.HV.UUID},{#DATASTORE.UUID},latency]'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'Average amount of time for a write operation to the datastore (milliseconds).'
              tags:
                - tag: component
                  value: datastore
                - tag: datastore
                  value: '{#DATASTORE}'
                - tag: type
                  value: '{#DATASTORE.TYPE}'
            - uuid: 4514c4ccf00142e48b243f69dee0b533
              name: 'Average write IOPS of the datastore [{#DATASTORE}]'
              type: SIMPLE
              key: 'vmware.hv.datastore.write[{$VMWARE.URL},{$VMWARE.HV.UUID},{#DATASTORE.UUID},rps]'
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'Average IOPS for a write operation to the datastore (milliseconds).'
              tags:
                - tag: component
                  value: datastore
                - tag: datastore
                  value: '{#DATASTORE}'
                - tag: type
                  value: '{#DATASTORE.TYPE}'
          overrides:
            - name: 'Disable IO perfCounter'
              step: '1'
              filter:
                conditions:
                  - macro: '{#DATASTORE.TYPE}'
                    value: vsan|nfs
              operations:
                - operator: LIKE
                  value: Average
                  discover: NO_DISCOVER
            - name: 'Disable Multipath perfCounter'
              step: '2'
              filter:
                conditions:
                  - macro: '{#DATASTORE.TYPE}'
                    value: vsan
              operations:
                - operator: LIKE
                  value: 'Multipath count for datastore'
                  discover: NO_DISCOVER
        - uuid: deb31adf69634837839e2d8f87167f28
          name: 'Healthcheck discovery'
          type: DEPENDENT
          key: vmware.hv.healthcheck.discovery
          description: 'VMware Rollup Health State sensor discovery.'
          item_prototypes:
            - uuid: fabb7524dd454daa942266e5565ce40e
              name: 'Health state rollup'
              type: DEPENDENT
              key: 'vmware.hv.sensor.health.state[{#SINGLETON}]'
              description: |
                The host's Rollup Health State sensor value. One of the following:
                - Gray: Unknown;
                - Green: OK;
                - Yellow: It might have a problem;
                - Red: It has a problem.
              valuemap:
                name: 'VMware status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$..HostNumericSensorInfo[?(@.name=="VMware Rollup Health State")].healthState.label.first()'
                - type: JAVASCRIPT
                  parameters:
                    - |
                      const idx = [
                      	'gray',
                      	'green',
                      	'yellow',
                      	'red'
                      ].indexOf(value.toLowerCase());
                      return idx !== -1 ? idx : 0;
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'vmware.hv.sensors.get[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
              tags:
                - tag: component
                  value: health
              trigger_prototypes:
                - uuid: 9f2a65161946436986aacf6c9a637673
                  expression: 'last(/VMware Hypervisor/vmware.hv.sensor.health.state[{#SINGLETON}])=3'
                  name: 'VMware Hypervisor: The {$VMWARE.HV.UUID} health is Red'
                  priority: HIGH
                  description: 'One or more components in the appliance might be in an unusable status and the appliance might soon become unresponsive. Security patches might be available.'
                  dependencies:
                    - name: 'VMware Hypervisor: The {$VMWARE.HV.UUID} health is Red'
                      expression: 'last(/VMware Hypervisor/vmware.hv.status[{$VMWARE.URL},{$VMWARE.HV.UUID}])=3'
                  tags:
                    - tag: scope
                      value: availability
                    - tag: scope
                      value: performance
                - uuid: dc4f84eb8d2143bb80999fbc58f38928
                  expression: 'last(/VMware Hypervisor/vmware.hv.sensor.health.state[{#SINGLETON}])=2'
                  name: 'VMware Hypervisor: The {$VMWARE.HV.UUID} health is Yellow'
                  priority: AVERAGE
                  description: 'One or more components in the appliance might soon become overloaded.'
                  dependencies:
                    - name: 'VMware Hypervisor: The {$VMWARE.HV.UUID} health is Red'
                      expression: 'last(/VMware Hypervisor/vmware.hv.sensor.health.state[{#SINGLETON}])=3'
                    - name: 'VMware Hypervisor: The {$VMWARE.HV.UUID} health is Red'
                      expression: 'last(/VMware Hypervisor/vmware.hv.status[{$VMWARE.URL},{$VMWARE.HV.UUID}])=3'
                    - name: 'VMware Hypervisor: The {$VMWARE.HV.UUID} health is Yellow'
                      expression: 'last(/VMware Hypervisor/vmware.hv.status[{$VMWARE.URL},{$VMWARE.HV.UUID}])=2'
                  tags:
                    - tag: scope
                      value: availability
                    - tag: scope
                      value: performance
          master_item:
            key: 'vmware.hv.sensors.get[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$..HostNumericSensorInfo[?(@.name=="VMware Rollup Health State")]'
              error_handler: CUSTOM_VALUE
              error_handler_params: '[]'
            - type: JAVASCRIPT
              parameters:
                - 'return JSON.stringify(value != "[]" ? [{''{#SINGLETON}'': ''''}] : []);'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 6h
        - uuid: cabe1fbdd4e04ef396afaa5dfd1a3423
          name: 'Network interface discovery'
          type: SIMPLE
          key: 'vmware.hv.net.if.discovery[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          delay: 1h
          username: '{$VMWARE.USERNAME}'
          password: '{$VMWARE.PASSWORD}'
          description: 'Discovery of VMware hypervisor network interfaces.'
          item_prototypes:
            - uuid: 706acba4535e4135b824d53763868a5f
              name: '[{#IFNAME}] network interface speed'
              type: SIMPLE
              key: 'vmware.hv.network.linkspeed[{$VMWARE.URL},{$VMWARE.HV.UUID},{#IFNAME}]'
              units: bps
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'VMware hypervisor network interface speed.'
              preprocessing:
                - type: MULTIPLIER
                  parameters:
                    - '1000000'
              tags:
                - tag: component
                  value: network
                - tag: interface
                  value: '{#IFNAME}'
        - uuid: ace5c21254804024a6571a5d030383a0
          name: 'Sensor discovery'
          type: DEPENDENT
          key: vmware.hv.sensors.discovery
          filter:
            evaltype: AND
            conditions:
              - macro: '{#NAME}'
                value: '{$VMWARE.HV.SENSOR.DISCOVERY.NAME.MATCHES}'
              - macro: '{#NAME}'
                value: 'VMware Rollup Health State'
                operator: NOT_MATCHES_REGEX
              - macro: '{#NAME}'
                value: '{$VMWARE.HV.SENSOR.DISCOVERY.NAME.NOT_MATCHES}'
                operator: NOT_MATCHES_REGEX
          description: 'VMware hardware sensor discovery. The data is retrieved from numeric sensor probes and provides information about the health of the physical system.'
          item_prototypes:
            - uuid: d9a7725ccb0647069b331c5e3e51aeaf
              name: 'Sensor [{#NAME}] health state'
              type: DEPENDENT
              key: 'vmware.hv.sensor.state["{#NAME}"]'
              description: |
                VMware hardware sensor health state. One of the following:
                - Gray: Unknown;
                - Green: OK;
                - Yellow: It might have a problem;
                - Red: It has a problem.
              valuemap:
                name: 'VMware status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$..HostNumericSensorInfo[?(@.name=="{#NAME}")].healthState.label.first()'
                - type: JAVASCRIPT
                  parameters:
                    - |
                      const idx = [
                      	'gray',
                      	'green',
                      	'yellow',
                      	'red'
                      ].indexOf(value.toLowerCase());
                      return idx !== -1 ? idx : 0;
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 6h
              master_item:
                key: 'vmware.hv.sensors.get[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
              tags:
                - tag: component
                  value: health
                - tag: component
                  value: sensor
                - tag: type
                  value: '{#TYPE}'
              trigger_prototypes:
                - uuid: f591aa480fb94996be8225176bc9c95c
                  expression: 'last(/VMware Hypervisor/vmware.hv.sensor.state["{#NAME}"])=3'
                  name: 'VMware Hypervisor: Sensor [{#NAME}] health state is Red'
                  priority: HIGH
                  description: 'One or more components in the appliance might be in an unusable status and the appliance might soon become unresponsive.'
                  dependencies:
                    - name: 'VMware Hypervisor: The {$VMWARE.HV.UUID} health is Red'
                      expression: 'last(/VMware Hypervisor/vmware.hv.status[{$VMWARE.URL},{$VMWARE.HV.UUID}])=3'
                  tags:
                    - tag: scope
                      value: availability
                    - tag: scope
                      value: performance
                - uuid: c49e1b853f07417abb3812fd03da0bc3
                  expression: 'last(/VMware Hypervisor/vmware.hv.sensor.state["{#NAME}"])=2'
                  name: 'VMware Hypervisor: Sensor [{#NAME}] health state is Yellow'
                  priority: AVERAGE
                  description: 'One or more components in the appliance might soon become overloaded.'
                  dependencies:
                    - name: 'VMware Hypervisor: Sensor [{#NAME}] health state is Red'
                      expression: 'last(/VMware Hypervisor/vmware.hv.sensor.state["{#NAME}"])=3'
                    - name: 'VMware Hypervisor: The {$VMWARE.HV.UUID} health is Red'
                      expression: 'last(/VMware Hypervisor/vmware.hv.status[{$VMWARE.URL},{$VMWARE.HV.UUID}])=3'
                    - name: 'VMware Hypervisor: The {$VMWARE.HV.UUID} health is Yellow'
                      expression: 'last(/VMware Hypervisor/vmware.hv.status[{$VMWARE.URL},{$VMWARE.HV.UUID}])=2'
                  tags:
                    - tag: scope
                      value: availability
                    - tag: scope
                      value: performance
          master_item:
            key: 'vmware.hv.sensors.get[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          preprocessing:
            - type: JAVASCRIPT
              parameters:
                - |
                  var result = [],
                  	sensors = JSON.parse(value)['val']['HostNumericSensorInfo'],
                  	discovery_flag = '{$VMWARE.HV.SENSOR.DISCOVERY}'.toLowerCase().trim();
                  
                  if (!(discovery_flag == 'true' || discovery_flag == 'false')) {
                  	throw 'Incorrect value of macro "{$' + 'VMWARE.HV.SENSOR.DISCOVERY}". Can be used only "true" or "false". Actual value: ' + discovery_flag;
                  }
                  
                  if (discovery_flag !== 'true' || typeof sensors === "undefined") {
                  	return JSON.stringify([]);
                  }
                  
                  sensors.forEach(function(sensor) {
                  	result.push({"{#NAME}": sensor['name'], "{#TYPE}": sensor['sensorType'].toLowerCase()});
                  })
                  
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 6h
        - uuid: 7f7ed06754fb4c59ac2d893b85169981
          name: 'Serial number discovery'
          type: DEPENDENT
          key: vmware.hv.serial.number.discovery
          description: 'VMware hypervisor serial number discovery. This item works only with VMware hypervisor versions above 6.7.'
          item_prototypes:
            - uuid: fcd12a13f97848b78b610e86a24417b2
              name: 'Serial number'
              type: SIMPLE
              key: 'vmware.hv.hw.serialnumber[{$VMWARE.URL},{#VMWARE.HV.UUID}]'
              delay: 1h
              value_type: CHAR
              username: '{$VMWARE.USERNAME}'
              password: '{$VMWARE.PASSWORD}'
              description: 'VMware hypervisor serial number.'
              preprocessing:
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              tags:
                - tag: component
                  value: system
          master_item:
            key: 'vmware.hv.version[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
          preprocessing:
            - type: JAVASCRIPT
              parameters:
                - |
                  function isGtOrEqVersion(first_version, second_version) {
                  	var first = first_version.split('.').map(Number),
                  	second = second_version.split('.').map(Number);
                  
                  	if (first.length > second.length) {
                  		const max_componens_length = first.length
                  	}
                  	else {
                  		const max_componens_length = second.length
                  	}
                  
                  	var num_components = first.length;
                  	while (num_components < max_componens_length) {
                  		first.push(0);
                  		num_components = num_components +1;
                  	}
                  
                  	var num_components = second.length;
                  	while (num_components < max_componens_length) {
                  		second.push(0);
                  		num_components = num_components +1;
                  	}
                  
                  	if (first[0] > second[0] ||
                  		(first[0] === second[0] && first[1] > second[1]) ||
                  		(first[0] === second[0] && first[1] === second[1] && first[2] >= second[2])) {
                  		
                  		return true;
                  	}
                  
                  	return false;
                  }
                  
                  try {
                  	const vmware_version = value;
                  	const hypervisor_uuid = '{$VMWARE.HV.UUID}';
                  
                  	if (isGtOrEqVersion(vmware_version, '6.7.0')) {
                  		return JSON.stringify([{'{#VMWARE.HV.UUID}': hypervisor_uuid}]);
                  	}
                  
                  	return JSON.stringify([]);
                  }
                  catch (error) {
                  	Zabbix.log(3, '[ VMware Serial Number Discovery ] ERROR: ' + error);
                  	throw 'Failed to process data:' + error;
                  }
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 6h
      tags:
        - tag: class
          value: software
        - tag: subclass
          value: virtualization
        - tag: target
          value: vmware
        - tag: target
          value: vmware-hypervisor
      macros:
        - macro: '{$VMWARE.HV.DATASTORE.SPACE.CRIT}'
          value: '10'
          description: 'The critical threshold of the datastore free space.'
          config:
            type: TEXT
            priority: '6'
            section_name: Thresholds
            label: 'Critical datastore free space threshold'
            description: 'Critical threshold of the datastore free space. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$VMWARE.HV.DATASTORE.SPACE.WARN}'
          value: '20'
          description: 'The warning threshold of the datastore free space.'
          config:
            type: TEXT
            priority: '5'
            section_name: Thresholds
            label: 'Warning datastore free space threshold'
            description: 'Warning threshold of the datastore free space. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$VMWARE.HV.SENSOR.DISCOVERY}'
          value: 'false'
          description: 'Set "true"/"false" to enable or disable the monitoring of hardware sensors.'
          config:
            type: CHECKBOX
            priority: '7'
            section_name: Filters
            label: 'Monitoring of hardware sensors'
            description: 'Whether it is necessary to monitor of hardware sensors.'
            options:
              - checked: 'true'
                unchecked: 'false'
        - macro: '{$VMWARE.HV.SENSOR.DISCOVERY.NAME.MATCHES}'
          value: '.*'
          description: 'Sets the regex string of hardware sensor names to be allowed in discovery.'
          config:
            type: TEXT
            priority: '8'
            section_name: Filters
            label: 'Include hardware sensors filter'
            description: 'Regex string to include hardware sensors by sensors name.'
        - macro: '{$VMWARE.HV.SENSOR.DISCOVERY.NAME.NOT_MATCHES}'
          value: CHANGE_IF_NEEDED
          description: 'Sets the regex string of hardware sensor names to be ignored in discovery.'
          config:
            type: TEXT
            priority: '9'
            section_name: Filters
            label: 'Exclude hardware sensors filter'
            description: 'Regex string to exclude hardware sensors by sensors name.'
        - macro: '{$VMWARE.HV.UUID}'
          description: 'UUID of hypervisor.'
          config:
            type: TEXT
            priority: '4'
            label: 'Hypervisor UUID'
            description: 'UUID of hypervisor.'
            required: 'YES'
        - macro: '{$VMWARE.PASSWORD}'
          type: SECRET_TEXT
          description: 'VMware service `{$USERNAME}` user password.'
          config:
            type: TEXT
            priority: '3'
            label: 'VMware password'
            required: 'YES'
        - macro: '{$VMWARE.URL}'
          description: 'VMware service (vCenter or ESX hypervisor) SDK URL (https://servername/sdk).'
          config:
            type: TEXT
            priority: '1'
            label: 'VMware URL'
            description: 'URL for vCenter or ESX hypervisor (https://servername/sdk).'
            required: 'YES'
        - macro: '{$VMWARE.USERNAME}'
          description: 'VMware service user name.'
          config:
            type: TEXT
            priority: '2'
            label: 'VMware username'
            required: 'YES'
      dashboards:
        - uuid: 1d1da8e6d38a4ea5a99d39cc31a8c435
          name: 'Hypervisor overview'
          pages:
            - name: 'VMware: Hypervisor Overview'
              widgets:
                - type: gauge
                  name: 'CPU utilization'
                  width: '18'
                  height: '4'
                  hide_header: 'YES'
                  fields:
                    - type: STRING
                      name: description
                      value: 'CPU utilization'
                    - type: INTEGER
                      name: desc_size
                      value: '10'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.cpu.utilization[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
                    - type: INTEGER
                      name: scale_size
                      value: '10'
                    - type: STRING
                      name: thresholds.0.color
                      value: 0EC9AC
                    - type: STRING
                      name: thresholds.0.threshold
                      value: '0'
                    - type: STRING
                      name: thresholds.1.color
                      value: FFD54F
                    - type: STRING
                      name: thresholds.1.threshold
                      value: '70'
                    - type: STRING
                      name: thresholds.2.color
                      value: FF465C
                    - type: STRING
                      name: thresholds.2.threshold
                      value: '90'
                    - type: INTEGER
                      name: th_show_arc
                      value: '1'
                    - type: INTEGER
                      name: th_show_labels
                      value: '1'
                    - type: STRING
                      name: units
                      value: '%'
                - type: item
                  name: 'Cluster name'
                  'y': '4'
                  width: '18'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.cluster.name[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                    - type: INTEGER
                      name: value_size
                      value: '35'
                - type: svggraph
                  name: 'Used memory'
                  'y': '6'
                  width: '51'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: FF465C
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.0.fill
                      value: '5'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.memory.used[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
                    - type: INTEGER
                      name: legend_columns
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAAB
                - type: item
                  name: 'Hypervisor ping'
                  x: '18'
                  width: '12'
                  height: '4'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: desc_size
                      value: '7'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'icmpping[]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: STRING
                      name: thresholds.0.color
                      value: F44336
                    - type: STRING
                      name: thresholds.0.threshold
                      value: '0'
                    - type: STRING
                      name: thresholds.1.color
                      value: 32CD32
                    - type: STRING
                      name: thresholds.1.threshold
                      value: '1'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                    - type: INTEGER
                      name: value_size
                      value: '25'
                - type: item
                  name: 'Datacenter name'
                  x: '18'
                  'y': '4'
                  width: '18'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.datacenter.name[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                    - type: INTEGER
                      name: value_size
                      value: '35'
                - type: item
                  name: 'Overall status'
                  x: '30'
                  width: '18'
                  height: '4'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: desc_size
                      value: '7'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.status[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: STRING
                      name: thresholds.0.color
                      value: D2D2D2
                    - type: STRING
                      name: thresholds.0.threshold
                      value: '0'
                    - type: STRING
                      name: thresholds.1.color
                      value: 32CD32
                    - type: STRING
                      name: thresholds.1.threshold
                      value: '1'
                    - type: STRING
                      name: thresholds.2.color
                      value: FFF176
                    - type: STRING
                      name: thresholds.2.threshold
                      value: '2'
                    - type: STRING
                      name: thresholds.3.color
                      value: F44336
                    - type: STRING
                      name: thresholds.3.threshold
                      value: '3'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                    - type: INTEGER
                      name: value_size
                      value: '25'
                - type: item
                  name: 'Full name'
                  x: '36'
                  'y': '4'
                  width: '18'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.fullname[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                    - type: INTEGER
                      name: value_size
                      value: '35'
                - type: item
                  name: 'Connection state'
                  x: '48'
                  width: '24'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.connectionstate[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: STRING
                      name: thresholds.0.color
                      value: 32CD32
                    - type: STRING
                      name: thresholds.0.threshold
                      value: '0'
                    - type: STRING
                      name: thresholds.1.color
                      value: F44336
                    - type: STRING
                      name: thresholds.1.threshold
                      value: '1'
                    - type: STRING
                      name: thresholds.2.color
                      value: FFDAB9
                    - type: STRING
                      name: thresholds.2.threshold
                      value: '2'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                    - type: INTEGER
                      name: value_size
                      value: '25'
                - type: item
                  name: Uptime
                  x: '48'
                  'y': '2'
                  width: '12'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.uptime[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: item
                  name: 'Total memory'
                  x: '51'
                  'y': '6'
                  width: '21'
                  height: '3'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: desc_size
                      value: '10'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.hw.memory[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: units_bold
                      value: '0'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                    - type: INTEGER
                      name: value_size
                      value: '35'
                - type: item
                  name: 'Used memory'
                  x: '51'
                  'y': '9'
                  width: '21'
                  height: '3'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: desc_size
                      value: '10'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.memory.used[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: units_bold
                      value: '0'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                    - type: INTEGER
                      name: value_size
                      value: '35'
                - type: item
                  name: Version
                  x: '54'
                  'y': '4'
                  width: '18'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.version[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                    - type: INTEGER
                      name: value_size
                      value: '35'
                - type: item
                  name: 'Number of guest VMs'
                  x: '60'
                  'y': '2'
                  width: '12'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.vm.num[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
            - name: 'VMware: CPU'
              widgets:
                - type: item
                  name: 'CPU cores'
                  width: '15'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.hw.cpu.num[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: svggraph
                  name: 'CPU utilization'
                  'y': '2'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 00BFFF
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.0.fill
                      value: '5'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.cpu.utilization[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
                    - type: INTEGER
                      name: legend_columns
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAAC
                - type: svggraph
                  name: 'CPU usage'
                  'y': '7'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 00BFFF
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.0.fill
                      value: '5'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.cpu.usage[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
                    - type: INTEGER
                      name: legend_columns
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAAI
                - type: item
                  name: 'CPU threads'
                  x: '15'
                  width: '15'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.hw.cpu.threads[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: item
                  name: 'CPU frequency'
                  x: '30'
                  width: '15'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: decimal_size
                      value: '45'
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.hw.cpu.freq[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: units_bold
                      value: '0'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                - type: item
                  name: 'CPU model'
                  x: '45'
                  width: '27'
                  hide_header: 'YES'
                  fields:
                    - type: INTEGER
                      name: desc_v_pos
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.hw.cpu.model[{$VMWARE.URL},{$VMWARE.HV.UUID}]'
                    - type: INTEGER
                      name: show.0
                      value: '1'
                    - type: INTEGER
                      name: show.1
                      value: '2'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: value_bold
                      value: '0'
                    - type: INTEGER
                      name: value_size
                      value: '35'
            - name: 'VMware: Network'
              widgets:
                - type: svggraph
                  name: 'Number of broadcast'
                  width: '36'
                  height: '4'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 00BFFF
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.0.fill
                      value: '5'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.network.in[{$VMWARE.URL},{$VMWARE.HV.UUID},broadcast]'
                    - type: STRING
                      name: ds.1.color.0
                      value: FF465C
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.1.fill
                      value: '5'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.network.out[{$VMWARE.URL},{$VMWARE.HV.UUID},broadcast]'
                    - type: INTEGER
                      name: legend_columns
                      value: '1'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAAD
                - type: svggraph
                  name: 'Number of bytes'
                  'y': '4'
                  width: '36'
                  height: '4'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 00BFFF
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.0.fill
                      value: '5'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.network.in[{$VMWARE.URL},{$VMWARE.HV.UUID},bps]'
                    - type: STRING
                      name: ds.1.color.0
                      value: FF465C
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.1.fill
                      value: '5'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.network.out[{$VMWARE.URL},{$VMWARE.HV.UUID},bps]'
                    - type: INTEGER
                      name: legend_columns
                      value: '1'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAAE
                - type: graphprototype
                  name: 'Network interface speed'
                  'y': '8'
                  width: '72'
                  height: '4'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: ITEM_PROTOTYPE
                      name: itemid.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.network.linkspeed[{$VMWARE.URL},{$VMWARE.HV.UUID},{#IFNAME}]'
                    - type: STRING
                      name: reference
                      value: AAAAF
                    - type: INTEGER
                      name: source_type
                      value: '3'
                - type: svggraph
                  name: 'Number of dropped'
                  x: '36'
                  width: '36'
                  height: '4'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 00BFFF
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.0.fill
                      value: '5'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.network.in[{$VMWARE.URL},{$VMWARE.HV.UUID},dropped]'
                    - type: STRING
                      name: ds.1.color.0
                      value: FF465C
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.1.fill
                      value: '5'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.network.out[{$VMWARE.URL},{$VMWARE.HV.UUID},dropped]'
                    - type: INTEGER
                      name: legend_columns
                      value: '1'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAAG
                - type: svggraph
                  name: 'Number of errors'
                  x: '36'
                  'y': '4'
                  width: '36'
                  height: '4'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 00BFFF
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.0.fill
                      value: '5'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.network.in[{$VMWARE.URL},{$VMWARE.HV.UUID},errors]'
                    - type: STRING
                      name: ds.1.color.0
                      value: FF465C
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.1.fill
                      value: '5'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.network.out[{$VMWARE.URL},{$VMWARE.HV.UUID},errors]'
                    - type: INTEGER
                      name: legend_columns
                      value: '1'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAAH
            - name: 'VMware: Datastore'
              widgets:
                - type: honeycomb
                  name: 'Total size of datastore'
                  width: '24'
                  height: '4'
                  fields:
                    - type: STRING
                      name: bg_color
                      value: 81D4FA
                    - type: STRING
                      name: items.0
                      value: 'Total size of datastore*'
                    - type: STRING
                      name: primary_label
                      value: '{{ITEM.NAME}.regsub("datastore.\[(.*)\]", \1)}'
                    - type: INTEGER
                      name: primary_label_size_type
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAAJ
                - type: graphprototype
                  name: 'Average read IOps of the datastore'
                  'y': '4'
                  width: '36'
                  height: '4'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: ITEM_PROTOTYPE
                      name: itemid.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.datastore.read[{$VMWARE.URL},{$VMWARE.HV.UUID},{#DATASTORE.UUID},rps]'
                    - type: STRING
                      name: reference
                      value: AAAAK
                    - type: INTEGER
                      name: source_type
                      value: '3'
                - type: graphprototype
                  name: 'Average read latency of the datastore'
                  'y': '8'
                  width: '36'
                  height: '4'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: ITEM_PROTOTYPE
                      name: itemid.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.datastore.read[{$VMWARE.URL},{$VMWARE.HV.UUID},{#DATASTORE.UUID},latency]'
                    - type: STRING
                      name: reference
                      value: AAAAP
                    - type: INTEGER
                      name: source_type
                      value: '3'
                - type: honeycomb
                  name: 'Free space on datastore'
                  x: '24'
                  width: '24'
                  height: '4'
                  fields:
                    - type: STRING
                      name: items.0
                      value: 'Free space on datastore*'
                    - type: STRING
                      name: primary_label
                      value: '{{ITEM.NAME}.regsub("datastore.\[(.*)\]", \1)}'
                    - type: INTEGER
                      name: primary_label_size_type
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAAL
                    - type: STRING
                      name: thresholds.0.color
                      value: FF465C
                    - type: STRING
                      name: thresholds.0.threshold
                      value: '10'
                    - type: STRING
                      name: thresholds.1.color
                      value: FFD54F
                    - type: STRING
                      name: thresholds.1.threshold
                      value: '20'
                    - type: STRING
                      name: thresholds.2.color
                      value: 0EC9AC
                    - type: STRING
                      name: thresholds.2.threshold
                      value: '30'
                - type: graphprototype
                  name: 'Average write IOps of the datastore'
                  x: '36'
                  'y': '4'
                  width: '36'
                  height: '4'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: ITEM_PROTOTYPE
                      name: itemid.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.datastore.write[{$VMWARE.URL},{$VMWARE.HV.UUID},{#DATASTORE.UUID},rps]'
                    - type: STRING
                      name: reference
                      value: AAAAM
                    - type: INTEGER
                      name: source_type
                      value: '3'
                - type: graphprototype
                  name: 'Average write latency of the datastore'
                  x: '36'
                  'y': '8'
                  width: '36'
                  height: '4'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: ITEM_PROTOTYPE
                      name: itemid.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.datastore.write[{$VMWARE.URL},{$VMWARE.HV.UUID},{#DATASTORE.UUID},latency]'
                    - type: STRING
                      name: reference
                      value: AAAAN
                    - type: INTEGER
                      name: source_type
                      value: '3'
                - type: graphprototype
                  name: 'Free space on datastore'
                  x: '48'
                  width: '24'
                  height: '4'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: ITEM_PROTOTYPE
                      name: itemid.0
                      value:
                        host: 'VMware Hypervisor'
                        key: 'vmware.hv.datastore.size[{$VMWARE.URL},{$VMWARE.HV.UUID},{#DATASTORE.UUID},pfree]'
                    - type: STRING
                      name: reference
                      value: AAAAO
                    - type: INTEGER
                      name: source_type
                      value: '3'
      valuemaps:
        - uuid: 25d04e2838af4fcca9ddd21df6781497
          name: 'Service state'
          mappings:
            - value: '0'
              newvalue: Down
            - value: '1'
              newvalue: Up
        - uuid: 66bedf62dffd4402a037a6ef0f93f228
          name: 'VMware Connection state'
          mappings:
            - value: '0'
              newvalue: Connected
            - value: '1'
              newvalue: Disconnected
            - value: '2'
              newvalue: 'Not responding'
            - value: '3'
              newvalue: Unknown
        - uuid: 2b324fd8d7624874a3a81449b62c2cd6
          name: 'VMware status'
          mappings:
            - value: '0'
              newvalue: Gray
            - value: '1'
              newvalue: Green
            - value: '2'
              newvalue: Yellow
            - value: '3'
              newvalue: Red
    - uuid: dd114bf0fb2f46bc84840f1bb24e2b23
      template: 'Zabbix proxy health'
      name: 'Zabbix proxy health'
      description: |
        This template is designed to monitor internal Zabbix metrics on the local Zabbix proxy.
        
        Link this template to the local Zabbix proxy host.
        
        Generated by official Zabbix template tool "Templator"
      wizard_ready: 'YES'
      readme: |
        ## Overview
        
        This template is designed to monitor internal Zabbix metrics on the local Zabbix proxy.
        
        ## Setup
        
        Link this template to the local Zabbix proxy host.
      vendor:
        name: Zabbix
        version: 7.4-3
      groups:
        - name: Templates/Applications
      items:
        - uuid: ca8a1cafec6e44a4b31f9ec5a6ed00cb
          name: 'Discovery queue'
          type: INTERNAL
          key: 'zabbix[discovery_queue]'
          description: 'The count of values enqueued in the discovery queue.'
          tags:
            - tag: component
              value: system
        - uuid: 0230306272c24858b49243ef1c61e2ec
          name: 'Preprocessing queue'
          type: INTERNAL
          key: 'zabbix[preprocessing_queue]'
          description: 'The number of values enqueued in the preprocessing queue.'
          tags:
            - tag: component
              value: system
        - uuid: 998df832cf58436ea7707331338d5f3b
          name: 'Utilization of agent poller data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,agent poller,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the agent poller processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 5abbe55bf614492d982e4af0f11b01e2
              expression: 'avg(/Zabbix proxy health/zabbix[process,agent poller,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"agent poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,agent poller,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"agent poller"}'
              name: 'Zabbix proxy: Utilization of agent poller processes is high'
              event_name: 'Zabbix proxy: Utilization of agent poller processes over {$ZABBIX.PROXY.UTIL.MAX:"agent poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the agent poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 5131f979c17a4346a95f8ba77e7133a4
          name: 'Utilization of availability manager internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,availability manager,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the availability manager processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 5a8375a8eee642f2940ed813ee062336
              expression: 'avg(/Zabbix proxy health/zabbix[process,availability manager,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"availability manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,availability manager,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"availability manager"}'
              name: 'Zabbix proxy: Utilization of availability manager processes is high'
              event_name: 'Zabbix proxy: Utilization of availability manager processes over {$ZABBIX.PROXY.UTIL.MAX:"availability manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the availability manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 3ec67d79691b432c8a357fedfec77e6d
          name: 'Utilization of browser poller data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,browser poller,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the browser poller processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 5cdced4b0c064f62802c360fa84408db
              expression: 'avg(/Zabbix proxy health/zabbix[process,browser poller,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"browser poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,browser poller,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"browser poller"}'
              name: 'Zabbix proxy: Utilization of browser poller processes is high'
              event_name: 'Zabbix proxy: Utilization of browser poller processes over {$ZABBIX.PROXY.UTIL.MAX:"browser poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the browser poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 3d1bfa64a447427da0b463c3617b212e
          name: 'Utilization of configuration syncer internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,configuration syncer,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the configuration syncer processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 27eb861e2e6f43f69f17b8ba65bfedcc
              expression: 'avg(/Zabbix proxy health/zabbix[process,configuration syncer,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"configuration syncer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,configuration syncer,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"configuration syncer"}'
              name: 'Zabbix proxy: Utilization of configuration syncer processes is high'
              event_name: 'Zabbix proxy: Utilization of configuration syncer processes over {$ZABBIX.PROXY.UTIL.MAX:"configuration syncer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the configuration syncer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 69eefd6aba164d71b0a2b8d2df06e9a3
          name: 'Utilization of data sender internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,data sender,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the data sender processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: e8fd57784b9e4289aa4515cfa7c6c4ad
              expression: 'avg(/Zabbix proxy health/zabbix[process,data sender,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"data sender"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,data sender,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"data sender"}'
              name: 'Zabbix proxy: Utilization of data sender processes is high'
              event_name: 'Zabbix proxy: Utilization of data sender processes over {$ZABBIX.PROXY.UTIL.MAX:"data sender"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the data sender, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 930bf9db6c754a17ab5026961d6369ba
          name: 'Utilization of discovery manager internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,discovery manager,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the discovery manager processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: e1dd2821756d489cb5443c924e57c356
              expression: 'avg(/Zabbix proxy health/zabbix[process,discovery manager,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"discovery manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,discovery manager,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"discovery manager"}'
              name: 'Zabbix proxy: Utilization of discovery manager processes is high'
              event_name: 'Zabbix proxy: Utilization of discovery manager processes over {$ZABBIX.PROXY.UTIL.MAX:"discovery manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the discovery manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: eeee7e927a854b61b166a13b8eb98f28
          name: 'Utilization of discovery worker internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,discovery worker,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the discovery worker processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: ff023c3fce664dff9fdcb3f8724f4832
              expression: 'avg(/Zabbix proxy health/zabbix[process,discovery worker,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"discovery worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,discovery worker,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"discovery worker"}'
              name: 'Zabbix proxy: Utilization of discovery worker processes is high'
              event_name: 'Zabbix proxy: Utilization of discovery worker processes over {$ZABBIX.PROXY.UTIL.MAX:"discovery worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the discovery worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 7dde8cd03e5043a2bd484f7213a5f112
          name: 'Utilization of history syncer internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,history syncer,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the history syncer processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 52fb303ec9164aa28821117f3a559fe3
              expression: 'avg(/Zabbix proxy health/zabbix[process,history syncer,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"history syncer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,history syncer,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"history syncer"}'
              name: 'Zabbix proxy: Utilization of history syncer processes is high'
              event_name: 'Zabbix proxy: Utilization of history syncer processes over {$ZABBIX.PROXY.UTIL.MAX:"history syncer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the history syncer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 31f0355f4d7c4de6b0d6f206d1ca9fa3
          name: 'Utilization of housekeeper internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,housekeeper,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the housekeeper processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: b6cbede80a4847ed94a0ba818b7ca261
              expression: 'avg(/Zabbix proxy health/zabbix[process,housekeeper,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"housekeeper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,housekeeper,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"housekeeper"}'
              name: 'Zabbix proxy: Utilization of housekeeper processes is high'
              event_name: 'Zabbix proxy: Utilization of housekeeper processes over {$ZABBIX.PROXY.UTIL.MAX:"housekeeper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the housekeeper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 584c5ee90cff40e2befc38061ce8e7e7
          name: 'Utilization of http agent poller data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,http agent poller,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the http agent poller processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: a5d7a54efea843c495795d14bbff166b
              expression: 'avg(/Zabbix proxy health/zabbix[process,http agent poller,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"http agent poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,http agent poller,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"http agent poller"}'
              name: 'Zabbix proxy: Utilization of http agent poller processes is high'
              event_name: 'Zabbix proxy: Utilization of http agent poller processes over {$ZABBIX.PROXY.UTIL.MAX:"http agent poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the http agent poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 782b11dbe3ce47e3b9098c43d83057ad
          name: 'Utilization of http poller data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,http poller,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the http poller processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: e93e5a3dd27f4d378bbfe2c8e5b009e7
              expression: 'avg(/Zabbix proxy health/zabbix[process,http poller,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"http poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,http poller,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"http poller"}'
              name: 'Zabbix proxy: Utilization of http poller processes is high'
              event_name: 'Zabbix proxy: Utilization of http poller processes over {$ZABBIX.PROXY.UTIL.MAX:"http poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the http poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 9b899ab317b447d1a82d1136e0a2ff6f
          name: 'Utilization of icmp pinger data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,icmp pinger,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the icmp pinger processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: d514f4a08bcd4fe2b696015a74ffafcf
              expression: 'avg(/Zabbix proxy health/zabbix[process,icmp pinger,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"icmp pinger"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,icmp pinger,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"icmp pinger"}'
              name: 'Zabbix proxy: Utilization of icmp pinger processes is high'
              event_name: 'Zabbix proxy: Utilization of icmp pinger processes over {$ZABBIX.PROXY.UTIL.MAX:"icmp pinger"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the icmp pinger, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: a1278ad64af9401a834cd09b0c2f5766
          name: 'Utilization of internal poller data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,internal poller,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the internal poller processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 3bc0e6ab1a9e470682d049840df4ce5a
              expression: 'avg(/Zabbix proxy health/zabbix[process,internal poller,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"internal poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,internal poller,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"internal poller"}'
              name: 'Zabbix proxy: Utilization of internal poller processes is high'
              event_name: 'Zabbix proxy: Utilization of internal poller processes over {$ZABBIX.PROXY.UTIL.MAX:"internal poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the internal poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 52b3123dfef94d8bba1b1a13314a9d4f
          name: 'Utilization of ipmi manager internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,ipmi manager,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the ipmi manager processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 751e3000367f42d9af0d4418f3472a91
              expression: 'avg(/Zabbix proxy health/zabbix[process,ipmi manager,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"ipmi manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,ipmi manager,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"ipmi manager"}'
              name: 'Zabbix proxy: Utilization of ipmi manager processes is high'
              event_name: 'Zabbix proxy: Utilization of ipmi manager processes over {$ZABBIX.PROXY.UTIL.MAX:"ipmi manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the ipmi manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 7cfb2f1504dd4b0aaac804b132d49bc5
          name: 'Utilization of ipmi poller data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,ipmi poller,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the ipmi poller processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 99ce9f0ed6204860b7b943e9e3a5fbc0
              expression: 'avg(/Zabbix proxy health/zabbix[process,ipmi poller,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"ipmi poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,ipmi poller,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"ipmi poller"}'
              name: 'Zabbix proxy: Utilization of ipmi poller processes is high'
              event_name: 'Zabbix proxy: Utilization of ipmi poller processes over {$ZABBIX.PROXY.UTIL.MAX:"ipmi poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the ipmi poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 02214c0c38394bef8d648369584ae30b
          name: 'Utilization of java poller data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,java poller,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the java poller processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 5b8cc59c21b145739e346479124c48f5
              expression: 'avg(/Zabbix proxy health/zabbix[process,java poller,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"java poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,java poller,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"java poller"}'
              name: 'Zabbix proxy: Utilization of java poller processes is high'
              event_name: 'Zabbix proxy: Utilization of java poller processes over {$ZABBIX.PROXY.UTIL.MAX:"java poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the java poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 06bdbdcfdbc04c24ad387b256e430801
          name: 'Utilization of ODBC poller data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,odbc poller,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the ODBC poller processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 3177430235ac4eeaa23b8c39987989cc
              expression: 'avg(/Zabbix proxy health/zabbix[process,odbc poller,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"ODBC poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,odbc poller,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"ODBC poller"}'
              name: 'Zabbix proxy: Utilization of ODBC poller processes is high'
              event_name: 'Zabbix proxy: Utilization of ODBC poller processes over {$ZABBIX.PROXY.UTIL.MAX:"ODBC poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the ODBC poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 334398ad893e4146bc1b9370eef9df59
          name: 'Utilization of poller data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,poller,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the poller processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 3f93b378367e48f89abe304ccb624047
              expression: 'avg(/Zabbix proxy health/zabbix[process,poller,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,poller,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"poller"}'
              name: 'Zabbix proxy: Utilization of poller processes is high'
              event_name: 'Zabbix proxy: Utilization of poller processes over {$ZABBIX.PROXY.UTIL.MAX:"poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 20705fe12d4c40a4a27306b66ec9a69d
          name: 'Utilization of preprocessing manager internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,preprocessing manager,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the preprocessing manager processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 1ed29eb53708417a827adbdf4d8f145b
              expression: 'avg(/Zabbix proxy health/zabbix[process,preprocessing manager,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"preprocessing manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,preprocessing manager,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"preprocessing manager"}'
              name: 'Zabbix proxy: Utilization of preprocessing manager processes is high'
              event_name: 'Zabbix proxy: Utilization of preprocessing manager processes over {$ZABBIX.PROXY.UTIL.MAX:"preprocessing manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the preprocessing manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 9c7916375cf841fb8edaf383b93a0522
          name: 'Utilization of preprocessing worker internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,preprocessing worker,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the preprocessing worker processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 22831f081149400a86cb18930de0cc20
              expression: 'avg(/Zabbix proxy health/zabbix[process,preprocessing worker,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"preprocessing worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,preprocessing worker,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"preprocessing worker"}'
              name: 'Zabbix proxy: Utilization of preprocessing worker processes is high'
              event_name: 'Zabbix proxy: Utilization of preprocessing worker processes over {$ZABBIX.PROXY.UTIL.MAX:"preprocessing worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the preprocessing worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 1fd488bbb4af450cb2b5e8c81b739f29
          name: 'Utilization of self-monitoring internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,self-monitoring,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the self-monitoring processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: cc9569f75bd44b5cbce4a4c556cd2949
              expression: 'avg(/Zabbix proxy health/zabbix[process,self-monitoring,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"self-monitoring"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,self-monitoring,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"self-monitoring"}'
              name: 'Zabbix proxy: Utilization of self-monitoring processes is high'
              event_name: 'Zabbix proxy: Utilization of self-monitoring processes over {$ZABBIX.PROXY.UTIL.MAX:"self-monitoring"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the self-monitoring, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 96b04e9605e04b26a280bc62da92879b
          name: 'Utilization of snmp poller data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,snmp poller,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the snmp poller processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 811e08cb2382482db4054a4665e328d7
              expression: 'avg(/Zabbix proxy health/zabbix[process,snmp poller,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"snmp poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,snmp poller,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"snmp poller"}'
              name: 'Zabbix proxy: Utilization of snmp poller processes is high'
              event_name: 'Zabbix proxy: Utilization of snmp poller processes over {$ZABBIX.PROXY.UTIL.MAX:"snmp poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the snmp poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 77ab21500d734deea86938a1a90035e0
          name: 'Utilization of snmp trapper data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,snmp trapper,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the snmp trapper processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: bb0a46beffbc457faea9362d4325c676
              expression: 'avg(/Zabbix proxy health/zabbix[process,snmp trapper,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"snmp trapper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,snmp trapper,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"snmp trapper"}'
              name: 'Zabbix proxy: Utilization of snmp trapper processes is high'
              event_name: 'Zabbix proxy: Utilization of snmp trapper processes over {$ZABBIX.PROXY.UTIL.MAX:"snmp trapper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the snmp trapper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 94d1aa1bff2d499f9e29dd9cafd04b9e
          name: 'Utilization of task manager internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,task manager,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the task manager processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 9a42dad8cef04138944f3a1b8c797f4e
              expression: 'avg(/Zabbix proxy health/zabbix[process,task manager,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"task manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,task manager,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"task manager"}'
              name: 'Zabbix proxy: Utilization of task manager processes is high'
              event_name: 'Zabbix proxy: Utilization of task manager processes over {$ZABBIX.PROXY.UTIL.MAX:"task manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the task manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 8d99635291d14ae8a5ba7d794540bde2
          name: 'Utilization of trapper data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,trapper,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the trapper processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 95ad6d80dc9c4f46a4e255d13f1b01a3
              expression: 'avg(/Zabbix proxy health/zabbix[process,trapper,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"trapper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,trapper,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"trapper"}'
              name: 'Zabbix proxy: Utilization of trapper processes is high'
              event_name: 'Zabbix proxy: Utilization of trapper processes over {$ZABBIX.PROXY.UTIL.MAX:"trapper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the trapper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 7b0f5b75d4854b84a7e1f51975732e25
          name: 'Utilization of unreachable poller data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,unreachable poller,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the unreachable poller processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: a28abd3f43f843af9646a1f8b1ca056a
              expression: 'avg(/Zabbix proxy health/zabbix[process,unreachable poller,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"unreachable poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,unreachable poller,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"unreachable poller"}'
              name: 'Zabbix proxy: Utilization of unreachable poller processes is high'
              event_name: 'Zabbix proxy: Utilization of unreachable poller processes over {$ZABBIX.PROXY.UTIL.MAX:"unreachable poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the unreachable poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: a5a7076a175c400f866a4d873d12e1e4
          name: 'Utilization of vmware collector data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,vmware collector,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the vmware collector processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: a1051b5ac8334125a40cb36a95605284
              expression: 'avg(/Zabbix proxy health/zabbix[process,vmware collector,avg,busy],10m)>{$ZABBIX.PROXY.UTIL.MAX:"vmware collector"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health/zabbix[process,vmware collector,avg,busy],10m)<{$ZABBIX.PROXY.UTIL.MIN:"vmware collector"}'
              name: 'Zabbix proxy: Utilization of vmware collector processes is high'
              event_name: 'Zabbix proxy: Utilization of vmware collector processes over {$ZABBIX.PROXY.UTIL.MAX:"vmware collector"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the vmware collector, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: e60cdba498a94c19955696f40d5e1b32
          name: 'Proxy memory buffer, % used'
          type: INTERNAL
          key: 'zabbix[proxy_buffer,buffer,pused]'
          value_type: FLOAT
          units: '%'
          description: |
            Statistics and availability of Zabbix proxy memory buffer usage statistics. Percentage of used proxy memory buffer.
            Proxy memory buffer is used to store the new historical data and upload from it without accessing database.
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 9b6cb370c00f4ebda91cdf247adc4780
              expression: 'max(/Zabbix proxy health/zabbix[proxy_buffer,buffer,pused],10m)>{$ZABBIX.PROXY.UTIL.MAX:"proxy buffer"}'
              name: 'Zabbix proxy: Excessive proxy memory buffer usage'
              event_name: 'Zabbix proxy: More than {$ZABBIX.PROXY.UTIL.MAX:"proxy buffer"}% used in the proxy memory buffer'
              priority: AVERAGE
              description: 'Consider increasing ProxyMemoryBufferSize in the zabbix_proxy.conf configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 1f5fbc277a574ce7a418439695f124ca
          name: 'Proxy buffer, state changes'
          type: INTERNAL
          key: 'zabbix[proxy_buffer,state,changes]'
          description: 'The number of state changes between disk/memory buffer modes since proxy start.'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
          tags:
            - tag: component
              value: system
        - uuid: c970e56eda504a4d89b051439dda9787
          name: 'Proxy buffer, state'
          type: INTERNAL
          key: 'zabbix[proxy_buffer,state,current]'
          description: |
            The current working state of proxy buffer where the new data is being stored. Possible values:
            
              0 - disk (also returned when memory buffer is disabled);
              1 - memory.
          valuemap:
            name: 'Proxy buffer mode'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
          tags:
            - tag: component
              value: system
        - uuid: 3b66d42ec1fa4dc7a41750aacf6e68f3
          name: 'Values waiting to be sent'
          type: INTERNAL
          key: 'zabbix[proxy_history]'
          description: 'The number of values in the proxy history table waiting to be sent to the server.'
          tags:
            - tag: component
              value: system
        - uuid: 2fa1c8d8fcb94d4c83cf4e291420a690
          name: 'Queue over 10 minutes'
          type: INTERNAL
          key: 'zabbix[queue,10m]'
          description: 'The number of monitored items in the queue that are delayed by at least 10 minutes.'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: f28d8231e0f2486bb68963719359789c
              expression: 'min(/Zabbix proxy health/zabbix[queue,10m],10m)>100'
              name: 'Zabbix proxy: More than 100 items have been missing data for over 10 minutes'
              priority: WARNING
              description: 'Indicates potential issues with network connectivity, agent failures, or unresponsive monitored resources that require attention.'
              tags:
                - tag: scope
                  value: performance
        - uuid: cfbb623cca754fd49d4f606ab52f658d
          name: Queue
          type: INTERNAL
          key: 'zabbix[queue]'
          description: 'The number of monitored items in the queue that are delayed by at least 6 seconds.'
          tags:
            - tag: component
              value: system
        - uuid: 606d1d43812341db8260a233295a4a4e
          name: 'Configuration cache, % used'
          type: INTERNAL
          key: 'zabbix[rcache,buffer,pused]'
          value_type: FLOAT
          units: '%'
          description: 'The availability statistics of Zabbix configuration cache. The percentage of used data buffer.'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 98ae52367f69476dbeb9c50e5f28b429
              expression: 'max(/Zabbix proxy health/zabbix[rcache,buffer,pused],10m)>{$ZABBIX.PROXY.UTIL.MAX:"configuration cache"}'
              name: 'Zabbix proxy: Excessive configuration cache usage'
              event_name: 'Zabbix proxy: More than {$ZABBIX.PROXY.UTIL.MAX:"configuration cache"}% used in the configuration cache'
              priority: AVERAGE
              description: 'Consider increasing `CacheSize` in the `zabbix_proxy.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: ef820395239d4a108980fe53017a89fc
          name: 'Required VPS'
          type: INTERNAL
          key: 'zabbix[requiredperformance]'
          value_type: FLOAT
          units: '!vps'
          description: 'The required performance of a proxy (the number of values that need to be collected per second).'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 12h
          tags:
            - tag: component
              value: system
        - uuid: 7a5c163672d1422aa663c2606d1166e5
          name: 'Zabbix proxy check'
          type: INTERNAL
          key: 'zabbix[triggers]'
          trends: '0'
          description: 'Flag indicating whether it is a proxy or not.'
          valuemap:
            name: 'Zabbix proxy check'
          preprocessing:
            - type: CHECK_NOT_SUPPORTED
              parameters:
                - '-1'
              error_handler: CUSTOM_VALUE
              error_handler_params: '0'
            - type: IN_RANGE
              parameters:
                - ''
                - '0'
              error_handler: CUSTOM_VALUE
              error_handler_params: '1'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 714e140b408d4b219fbee840e800b841
              expression: 'last(/Zabbix proxy health/zabbix[triggers])=1'
              name: 'Zabbix proxy: Wrong template assigned'
              event_name: 'Zabbix proxy: Zabbix proxy template is assigned to Zabbix server'
              priority: DISASTER
              description: 'Check that the template has been selected correctly.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: ef920914bc00432ea4d4007d09e081df
          name: Uptime
          type: INTERNAL
          key: 'zabbix[uptime]'
          units: uptime
          description: 'Uptime of the Zabbix proxy process in seconds.'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: b505a16c50f64adb8c5528907925f798
              expression: 'last(/Zabbix proxy health/zabbix[uptime])<10m'
              name: 'Zabbix proxy: {HOST.NAME} has been restarted'
              event_name: 'Zabbix proxy: {HOST.NAME} has been restarted (uptime < 10m)'
              priority: INFO
              description: 'Uptime is less than 10 minutes.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: 4d38d6d107714c96ae2ed2af44fddb60
          name: Version
          type: INTERNAL
          key: 'zabbix[version]'
          value_type: CHAR
          description: 'The version of Zabbix proxy.'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: bf7eef07faf14fc4b2603ae952f001da
              expression: 'last(/Zabbix proxy health/zabbix[version],#1)<>last(/Zabbix proxy health/zabbix[version],#2) and length(last(/Zabbix proxy health/zabbix[version]))>0'
              name: 'Zabbix proxy: Version has changed'
              event_name: 'Zabbix proxy: Version has changed (new version: {ITEM.VALUE})'
              priority: INFO
              description: 'Zabbix proxy version has changed. Acknowledge to close the problem manually.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: fc7412c1a02240b7931d3511743a2662
          name: 'VMware cache, % used'
          type: INTERNAL
          key: 'zabbix[vmware,buffer,pused]'
          value_type: FLOAT
          units: '%'
          description: 'The availability statistics of Zabbix vmware cache. The percentage of used data buffer.'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 69707cc61b7d408f8683dae435183d4f
              expression: 'max(/Zabbix proxy health/zabbix[vmware,buffer,pused],10m)>{$ZABBIX.PROXY.UTIL.MAX:"vmware cache"}'
              name: 'Zabbix proxy: Excessive vmware cache usage'
              event_name: 'Zabbix proxy: More than {$ZABBIX.PROXY.UTIL.MAX:"vmware cache"}% used in the vmware cache'
              priority: AVERAGE
              description: 'Consider increasing `VMwareCacheSize` in the `zabbix_proxy.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: aec73d2a7e444702b352c75998bf636e
          name: 'History write cache, % used'
          type: INTERNAL
          key: 'zabbix[wcache,history,pused]'
          value_type: FLOAT
          units: '%'
          description: |
            The statistics and availability of Zabbix write cache. The percentage of used history buffer.
            The history cache is used to store item values. A high number indicates database performance problems.
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: dc5a87f6c62d47b08ddd4578aa5f293f
              expression: 'max(/Zabbix proxy health/zabbix[wcache,history,pused],10m)>{$ZABBIX.PROXY.UTIL.MAX:"history cache"}'
              name: 'Zabbix proxy: Excessive history cache usage'
              event_name: 'Zabbix proxy: More than {$ZABBIX.PROXY.UTIL.MAX:"history cache"}% used in the history cache'
              priority: AVERAGE
              description: 'Consider increasing `HistoryCacheSize` in the `zabbix_proxy.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 8c4c7802497d4de4988278edc29f8eb1
          name: 'History index cache, % used'
          type: INTERNAL
          key: 'zabbix[wcache,index,pused]'
          value_type: FLOAT
          units: '%'
          description: |
            The statistics and availability of Zabbix write cache. The percentage of used history index buffer.
            The history index cache is used to index values stored in the history cache.
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 92b94edb126d48af9e5e959357e2107b
              expression: 'max(/Zabbix proxy health/zabbix[wcache,index,pused],10m)>{$ZABBIX.PROXY.UTIL.MAX:"index cache"}'
              name: 'Zabbix proxy: Excessive history index cache usage'
              event_name: 'Zabbix proxy: More than {$ZABBIX.PROXY.UTIL.MAX:"index cache"}% used in the history index cache'
              priority: AVERAGE
              description: 'Consider increasing `HistoryIndexCacheSize` in the `zabbix_proxy.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: ba5efd0ed21d4ac39e1375788b7198de
          name: 'Number of processed numeric (float) values per second'
          type: INTERNAL
          key: 'zabbix[wcache,values,float]'
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed numeric (float) values.
          preprocessing:
            - type: CHANGE_PER_SECOND
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 47cdd6ef01734ec1ab15b0ab43d147ca
          name: 'Number of processed log values per second'
          type: INTERNAL
          key: 'zabbix[wcache,values,log]'
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed log values.
          preprocessing:
            - type: CHANGE_PER_SECOND
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 46574db1d70545f6af89e8607d22f5bb
          name: 'Number of processed not supported values per second'
          type: INTERNAL
          key: 'zabbix[wcache,values,not supported]'
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of times the item processing resulted in an item becoming unsupported or remaining in that state.
          preprocessing:
            - type: CHANGE_PER_SECOND
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 5f0c3ed0998e499aaa1e4a30726928fc
          name: 'Number of processed character values per second'
          type: INTERNAL
          key: 'zabbix[wcache,values,str]'
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed character values.
          preprocessing:
            - type: CHANGE_PER_SECOND
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 1c259b08b3ff445f9b2f24a02c07c5db
          name: 'Number of processed text values per second'
          type: INTERNAL
          key: 'zabbix[wcache,values,text]'
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed text values.
          preprocessing:
            - type: CHANGE_PER_SECOND
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 8e4b9641b173415c8608ee4863bcd547
          name: 'Number of processed numeric (unsigned) values per second'
          type: INTERNAL
          key: 'zabbix[wcache,values,uint]'
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed numeric (unsigned) values.
          preprocessing:
            - type: CHANGE_PER_SECOND
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 5229b786efc84f01bb31f2819c47d9f4
          name: 'Number of processed values per second'
          type: INTERNAL
          key: 'zabbix[wcache,values]'
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The total number of values processed by Zabbix server or Zabbix proxy, except unsupported items.
          preprocessing:
            - type: CHANGE_PER_SECOND
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
      tags:
        - tag: class
          value: software
        - tag: subclass
          value: logging
        - tag: subclass
          value: monitoring
        - tag: target
          value: proxy
        - tag: target
          value: zabbix
      macros:
        - macro: '{$ZABBIX.PROXY.UTIL.MAX}'
          value: '75'
          description: 'Default maximum threshold for percentage utilization triggers (use macro context for specification).'
          config:
            type: TEXT
            priority: '2'
            section_name: Thresholds
            label: 'Maximum process utilization percentage'
            description: 'Default maximum threshold for process utilization triggers. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$ZABBIX.PROXY.UTIL.MIN}'
          value: '65'
          description: 'Default minimum threshold for percentage utilization triggers (use macro context for specification).'
          config:
            type: TEXT
            priority: '1'
            section_name: Thresholds
            label: 'Minimum process utilization percentage'
            description: 'Default minimum threshold for process utilization triggers. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
      dashboards:
        - uuid: c12bdb602db645a292d0cbba39d58e9f
          name: 'Zabbix proxy health'
          auto_start: 'NO'
          pages:
            - name: Performance
              widgets:
                - type: svggraph
                  name: 'Cache usage, in %'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.1
                      value: e31a1c
                    - type: STRING
                      name: ds.0.color.2
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.3
                      value: b15928
                    - type: STRING
                      name: ds.0.color.4
                      value: a6cee3
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[rcache,buffer,pused]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[wcache,index,pused]'
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[wcache,history,pused]'
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[vmware,buffer,pused]'
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[proxy_buffer,buffer,pused]'
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACA
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Server performance'
                  'y': '6'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.1
                      value: e31a1c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[wcache,values]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[queue]'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACC
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Values processed'
                  'y': '11'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.2
                      value: e31a1c
                    - type: STRING
                      name: ds.0.color.3
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.4
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.5
                      value: b15928
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[wcache,values,uint]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[wcache,values,float]'
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[wcache,values,not supported]'
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[wcache,values,str]'
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[wcache,values,log]'
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[wcache,values,text]'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACD
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Values to send'
                  'y': '16'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: b15928
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[proxy_history]'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACE
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Internal queues'
                  x: '36'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: ffff99
                    - type: STRING
                      name: ds.0.color.1
                      value: 6a3d9a
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[preprocessing_queue]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[discovery_queue]'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACB
                    - type: INTEGER
                      name: show_problems
                      value: '1'
            - name: Processes
              widgets:
                - type: svggraph
                  name: 'Utilization: Discovery processes'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 7e57c2
                    - type: STRING
                      name: ds.0.color.1
                      value: 1f78b4
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,discovery manager,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,discovery worker,avg,busy]'
                    - type: INTEGER
                      name: ds.1.axisy
                      value: '1'
                    - type: STRING
                      name: ds.1.color.0
                      value: ff465c
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[discovery_queue]'
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABH
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Synchronous gathering processes'
                  'y': '6'
                  width: '72'
                  height: '7'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.2
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.3
                      value: b15928
                    - type: STRING
                      name: ds.0.color.4
                      value: 17becf
                    - type: STRING
                      name: ds.0.color.5
                      value: a6cee3
                    - type: STRING
                      name: ds.0.color.6
                      value: fb9a99
                    - type: STRING
                      name: ds.0.color.7
                      value: bcbd22
                    - type: STRING
                      name: ds.0.color.8
                      value: fdbf6f
                    - type: STRING
                      name: ds.0.color.9
                      value: e31a1c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,poller,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,internal poller,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,ipmi poller,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,ipmi manager,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,http poller,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,java poller,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.6
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,vmware collector,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.7
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,browser poller,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.8
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,odbc poller,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.9
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,icmp pinger,avg,busy]'
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABJ
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Asynchronous gathering processes'
                  'y': '13'
                  width: '72'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: bcbd22
                    - type: STRING
                      name: ds.0.color.2
                      value: 6a3d9a
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,agent poller,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,http agent poller,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,snmp poller,avg,busy]'
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABK
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Internal processes: Core'
                  'y': '19'
                  width: '72'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: e31a1c
                    - type: STRING
                      name: ds.0.color.2
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.3
                      value: b15928
                    - type: STRING
                      name: ds.0.color.4
                      value: a6cee3
                    - type: STRING
                      name: ds.0.color.5
                      value: fdbf6f
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,configuration syncer,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,history syncer,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,self-monitoring,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,task manager,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,data sender,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,housekeeper,avg,busy]'
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '6'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABL
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Gathering processes: Trappers'
                  'y': '25'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: cab2d6
                    - type: STRING
                      name: ds.0.color.1
                      value: fdbf6f
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,trapper,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,snmp trapper,avg,busy]'
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABM
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Data exchange with server'
                  'y': '30'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: cab2d6
                    - type: STRING
                      name: ds.0.color.1
                      value: '000080'
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,trapper,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,data sender,avg,busy]'
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABO
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Preprocessing processes'
                  x: '36'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: fdbf6f
                    - type: STRING
                      name: ds.0.color.1
                      value: 7e57c2
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,preprocessing manager,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,preprocessing worker,avg,busy]'
                    - type: INTEGER
                      name: ds.1.axisy
                      value: '1'
                    - type: STRING
                      name: ds.1.color.0
                      value: ff465c
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.1.fill
                      value: '2'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[preprocessing_queue]'
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABI
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Availability processes'
                  x: '36'
                  'y': '25'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.1
                      value: b15928
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,unreachable poller,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[process,availability manager,avg,busy]'
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABN
                    - type: INTEGER
                      name: show_problems
                      value: '1'
            - name: Statuses
              widgets:
                - type: item
                  name: 'Zabbix proxy version'
                  width: '18'
                  height: '3'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[version]'
                    - type: INTEGER
                      name: show.0
                      value: '2'
                    - type: INTEGER
                      name: show.1
                      value: '3'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: time_h_pos
                      value: '2'
                    - type: INTEGER
                      name: time_size
                      value: '9'
                    - type: INTEGER
                      name: time_v_pos
                      value: '2'
                    - type: INTEGER
                      name: value_size
                      value: '25'
                - type: item
                  name: Uptime
                  x: '18'
                  width: '18'
                  height: '3'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[uptime]'
                    - type: INTEGER
                      name: show.0
                      value: '2'
                    - type: INTEGER
                      name: show.1
                      value: '3'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: time_h_pos
                      value: '2'
                    - type: INTEGER
                      name: time_size
                      value: '9'
                    - type: INTEGER
                      name: time_v_pos
                      value: '2'
                    - type: INTEGER
                      name: value_size
                      value: '25'
                - type: item
                  name: 'Proxy buffer state'
                  x: '36'
                  width: '18'
                  height: '3'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'Zabbix proxy health'
                        key: 'zabbix[proxy_buffer,state,current]'
                    - type: INTEGER
                      name: show.0
                      value: '2'
                    - type: INTEGER
                      name: show.1
                      value: '3'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: time_h_pos
                      value: '2'
                    - type: INTEGER
                      name: time_size
                      value: '9'
                    - type: INTEGER
                      name: time_v_pos
                      value: '2'
                    - type: INTEGER
                      name: value_size
                      value: '25'
      valuemaps:
        - uuid: 10388a0c06864ac483377f4ad3a91854
          name: 'Proxy buffer mode'
          mappings:
            - value: '0'
              newvalue: Disk
            - value: '1'
              newvalue: Memory
        - uuid: f9f6987645b341b68ba5449c9b741459
          name: 'Zabbix proxy check'
          mappings:
            - value: '0'
              newvalue: 'True'
            - value: '1'
              newvalue: 'False'
    - uuid: 8cd15d3b39654eb7b7423e6b109037b2
      template: 'Zabbix proxy health by Zabbix agent'
      name: 'Zabbix proxy health by Zabbix agent'
      description: |
        This template is designed to monitor internal Zabbix metrics on the remote Zabbix proxy via the passive Zabbix agent.
        
        Specify the address of the remote Zabbix proxy by changing the {$ZABBIX.PROXY.ADDRESS} and {$ZABBIX.PROXY.PORT} macros. Don't forget to adjust the "StatsAllowedIP" parameter in the remote proxy's configuration file to allow the collection of statistics.
        
        Generated by official Zabbix template tool "Templator"
      wizard_ready: 'YES'
      readme: |
        ## Overview
        
        This template is designed to monitor internal Zabbix metrics on the remote Zabbix proxy via the passive Zabbix agent.
        
        ## Setup
        
        Specify the address of the remote Zabbix proxy as the values for the `Zabbix proxy Address` and `Zabbix proxy Port` configuration fields. Don't forget to adjust the `StatsAllowedIP` parameter in the remote proxy's configuration file to allow the collection of statistics.
      vendor:
        name: Zabbix
        version: 7.4-3
      groups:
        - name: Templates/Applications
      items:
        - uuid: 8846a48c4acc4224a4e773469c159968
          name: 'Discovery queue'
          type: DEPENDENT
          key: discovery_queue
          description: 'The count of values enqueued in the discovery queue.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.discovery_queue
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "discoverer" processes started. Please check "StartDiscoverers" parameter in the server configuration file.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: 7ace08ac0d134dbd8e38f0eed7832006
          name: 'Preprocessing queue'
          type: DEPENDENT
          key: preprocessing_queue
          description: 'The number of values enqueued in the preprocessing queue.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.preprocessing_queue
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: a312044e08a84606b1cff94b32b7869b
          name: 'Utilization of agent poller data collector processes, in %'
          type: DEPENDENT
          key: process.agent_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the agent poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''agent poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes agent poller not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 2bc7af614177457381d7dac14073b167
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.agent_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"agent poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.agent_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"agent poller"}'
              name: 'Zabbix proxy: Utilization of agent poller processes is high'
              event_name: 'Zabbix proxy: Utilization of agent poller processes over {$ZABBIX.PROXY.UTIL.MAX:"agent poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the agent poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 61d39ded8711431285a6fbc083d8caed
          name: 'Utilization of availability manager internal processes, in %'
          type: DEPENDENT
          key: process.availability_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the availability manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''availability manager''].busy.avg'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: b93bf2d4f9094eefa462588f4121f339
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.availability_manager.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"availability manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.availability_manager.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"availability manager"}'
              name: 'Zabbix proxy: Utilization of availability manager processes is high'
              event_name: 'Zabbix proxy: Utilization of availability manager processes over {$ZABBIX.PROXY.UTIL.MAX:"availability manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the availability manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 6e0797f6789c4185a10e308428137582
          name: 'Utilization of browser poller data collector processes, in %'
          type: DEPENDENT
          key: process.browser_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the browser poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''browser poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "browser poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: edc46311472f4d26a08989a1cc5fc4ad
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.browser_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"browser poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.browser_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"browser poller"}'
              name: 'Zabbix proxy: Utilization of browser poller processes is high'
              event_name: 'Zabbix proxy: Utilization of browser poller processes over {$ZABBIX.PROXY.UTIL.MAX:"browser poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the browser poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 0ee53f651442409990eb622b564a2775
          name: 'Utilization of configuration syncer internal processes, in %'
          type: DEPENDENT
          key: process.configuration_syncer.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the configuration syncer processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''configuration syncer''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes configuration syncer not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: fdbac62718014e8ba5b9663ecd2c87cf
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.configuration_syncer.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"configuration syncer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.configuration_syncer.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"configuration syncer"}'
              name: 'Zabbix proxy: Utilization of configuration syncer processes is high'
              event_name: 'Zabbix proxy: Utilization of configuration syncer processes over {$ZABBIX.PROXY.UTIL.MAX:"configuration syncer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the configuration syncer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 013e6f87c56c4a579458feeba5691be6
          name: 'Utilization of data sender internal processes, in %'
          type: DEPENDENT
          key: process.data_sender.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the data sender processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''data sender''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes data sender not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 638a37f1268d4545bd037b88eb0f46b5
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.data_sender.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"data sender"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.data_sender.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"data sender"}'
              name: 'Zabbix proxy: Utilization of data sender processes is high'
              event_name: 'Zabbix proxy: Utilization of data sender processes over {$ZABBIX.PROXY.UTIL.MAX:"data sender"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the data sender, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 2fafb029d58546c3a6deabd4038e76cd
          name: 'Utilization of discovery manager internal processes, in %'
          type: DEPENDENT
          key: process.discovery_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the discovery manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''discovery manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "discovery manager" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: e4a34e7e45964602a329c04bedf0be11
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.discovery_manager.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"discovery manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.discovery_manager.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"discovery manager"}'
              name: 'Zabbix proxy: Utilization of discovery manager processes is high'
              event_name: 'Zabbix proxy: Utilization of discovery manager processes over {$ZABBIX.PROXY.UTIL.MAX:"discovery manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the discovery manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: b244b8cb318546c19b83b0af3b0bb093
          name: 'Utilization of discovery worker internal processes, in %'
          type: DEPENDENT
          key: process.discovery_worker.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the discovery worker processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''discovery worker''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "discovery worker" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: afd226d5a01c444bbe7ec7cc8e890385
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.discovery_worker.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"discovery worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.discovery_worker.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"discovery worker"}'
              name: 'Zabbix proxy: Utilization of discovery worker processes is high'
              event_name: 'Zabbix proxy: Utilization of discovery worker processes over {$ZABBIX.PROXY.UTIL.MAX:"discovery worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the discovery worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 32359f807d68434d83ee667da762b1c8
          name: 'Utilization of history syncer internal processes, in %'
          type: DEPENDENT
          key: process.history_syncer.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the history syncer processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''history syncer''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes history syncer not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: edc13a63baa94f898c5b90cffd568725
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.history_syncer.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"history syncer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.history_syncer.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"history syncer"}'
              name: 'Zabbix proxy: Utilization of history syncer processes is high'
              event_name: 'Zabbix proxy: Utilization of history syncer processes over {$ZABBIX.PROXY.UTIL.MAX:"history syncer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the history syncer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 52bcf9b7c2ae4787887bbd650b10105a
          name: 'Utilization of housekeeper internal processes, in %'
          type: DEPENDENT
          key: process.housekeeper.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the housekeeper processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''housekeeper''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes housekeeper not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 6db57127f7b74e3293be2942442665a5
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.housekeeper.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"housekeeper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.housekeeper.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"housekeeper"}'
              name: 'Zabbix proxy: Utilization of housekeeper processes is high'
              event_name: 'Zabbix proxy: Utilization of housekeeper processes over {$ZABBIX.PROXY.UTIL.MAX:"housekeeper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the housekeeper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 5913d66abf674eb0a73f8e1821b41b5b
          name: 'Utilization of http agent poller data collector processes, in %'
          type: DEPENDENT
          key: process.http_agent_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the http agent poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''http agent poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes http agent poller not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 2e968911946b437da198218d0c9c53d7
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.http_agent_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"http agent poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.http_agent_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"http agent poller"}'
              name: 'Zabbix proxy: Utilization of http agent poller processes is high'
              event_name: 'Zabbix proxy: Utilization of http agent poller processes over {$ZABBIX.PROXY.UTIL.MAX:"http agent poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the http agent poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: d473cf000bd94347ac6326209e9b1cb6
          name: 'Utilization of http poller data collector processes, in %'
          type: DEPENDENT
          key: process.http_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the http poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''http poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes http poller not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: a968792590324fd88c887619859b6aaa
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.http_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"http poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.http_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"http poller"}'
              name: 'Zabbix proxy: Utilization of http poller processes is high'
              event_name: 'Zabbix proxy: Utilization of http poller processes over {$ZABBIX.PROXY.UTIL.MAX:"http poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the http poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: fb0cd69bbafd45068e1429ab891a89d9
          name: 'Utilization of icmp pinger data collector processes, in %'
          type: DEPENDENT
          key: process.icmp_pinger.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the icmp pinger processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''icmp pinger''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes icmp pinger not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 4accc46c86674786a09962d2ba865fad
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.icmp_pinger.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"icmp pinger"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.icmp_pinger.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"icmp pinger"}'
              name: 'Zabbix proxy: Utilization of icmp pinger processes is high'
              event_name: 'Zabbix proxy: Utilization of icmp pinger processes over {$ZABBIX.PROXY.UTIL.MAX:"icmp pinger"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the icmp pinger, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 91eb0701b6a54ccd955f67223b64e84c
          name: 'Utilization of internal poller data collector processes, in %'
          type: DEPENDENT
          key: process.internal_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the internal poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''internal poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "internal poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: eb18c6abd7244d1b9addd5c0c411eef4
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.internal_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"internal poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.internal_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"internal poller"}'
              name: 'Zabbix proxy: Utilization of internal poller processes is high'
              event_name: 'Zabbix proxy: Utilization of internal poller processes over {$ZABBIX.PROXY.UTIL.MAX:"internal poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the internal poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 6baa5907fc4747d2ba5b0095c12fbe9d
          name: 'Utilization of ipmi manager internal processes, in %'
          type: DEPENDENT
          key: process.ipmi_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the ipmi manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''ipmi manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes ipmi manager not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 8b7ba23a9571419985996aaa5545c093
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.ipmi_manager.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"ipmi manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.ipmi_manager.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"ipmi manager"}'
              name: 'Zabbix proxy: Utilization of ipmi manager processes is high'
              event_name: 'Zabbix proxy: Utilization of ipmi manager processes over {$ZABBIX.PROXY.UTIL.MAX:"ipmi manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the ipmi manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 842f2465e5614597be977fdb7b72ba63
          name: 'Utilization of ipmi poller data collector processes, in %'
          type: DEPENDENT
          key: process.ipmi_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the ipmi poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''ipmi poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes ipmi poller not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: f108f03ff3174bf0be5bab5f8dd3edd9
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.ipmi_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"ipmi poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.ipmi_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"ipmi poller"}'
              name: 'Zabbix proxy: Utilization of ipmi poller processes is high'
              event_name: 'Zabbix proxy: Utilization of ipmi poller processes over {$ZABBIX.PROXY.UTIL.MAX:"ipmi poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the ipmi poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 0a4560d7e2ca4c1a88997d2353fd624c
          name: 'Utilization of java poller data collector processes, in %'
          type: DEPENDENT
          key: process.java_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the java poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''java poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes java poller not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 6e21610d53534d17a46e82ba77d94839
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.java_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"java poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.java_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"java poller"}'
              name: 'Zabbix proxy: Utilization of java poller processes is high'
              event_name: 'Zabbix proxy: Utilization of java poller processes over {$ZABBIX.PROXY.UTIL.MAX:"java poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the java poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: a3d0a85f9e9b4c59b5d8165a8f390ff1
          name: 'Utilization of ODBC poller data collector processes, in %'
          type: DEPENDENT
          key: process.odbc_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the ODBC poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''odbc poller''].busy.avg'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: f792aff9eafc495e82717b11e15c61eb
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.odbc_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"ODBC poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.odbc_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"ODBC poller"}'
              name: 'Zabbix proxy: Utilization of ODBC poller processes is high'
              event_name: 'Zabbix proxy: Utilization of ODBC poller processes over {$ZABBIX.PROXY.UTIL.MAX:"ODBC poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the ODBC poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 459a5b2aba7e43638dd151d32b7b5244
          name: 'Utilization of poller data collector processes, in %'
          type: DEPENDENT
          key: process.poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes poller not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: b0e501fd7ee44bfb8e4b76b8ed3f7bcf
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"poller"}'
              name: 'Zabbix proxy: Utilization of poller processes is high'
              event_name: 'Zabbix proxy: Utilization of poller processes over {$ZABBIX.PROXY.UTIL.MAX:"poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 4378cc82528d46d8be81f99e0e7e7f23
          name: 'Utilization of preprocessing manager internal processes, in %'
          type: DEPENDENT
          key: process.preprocessing_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the preprocessing manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''preprocessing manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes preprocessing manager not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 16d99a3deb574313ac1c9d3514b2174e
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.preprocessing_manager.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"preprocessing manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.preprocessing_manager.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"preprocessing manager"}'
              name: 'Zabbix proxy: Utilization of preprocessing manager processes is high'
              event_name: 'Zabbix proxy: Utilization of preprocessing manager processes over {$ZABBIX.PROXY.UTIL.MAX:"preprocessing manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the preprocessing manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: a8700cc1c2f8486fa09a90f19bbd877e
          name: 'Utilization of preprocessing worker internal processes, in %'
          type: DEPENDENT
          key: process.preprocessing_worker.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the preprocessing worker processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''preprocessing worker''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes preprocessing worker not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 44b4036596a648249665be9bdaf99001
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.preprocessing_worker.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"preprocessing worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.preprocessing_worker.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"preprocessing worker"}'
              name: 'Zabbix proxy: Utilization of preprocessing worker processes is high'
              event_name: 'Zabbix proxy: Utilization of preprocessing worker processes over {$ZABBIX.PROXY.UTIL.MAX:"preprocessing worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the preprocessing worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 362cff08ec00461795dd514cf1757360
          name: 'Utilization of self-monitoring internal processes, in %'
          type: DEPENDENT
          key: process.self-monitoring.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the self-monitoring processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''self-monitoring''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes self-monitoring not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: bf4a1a0d24da4929afd8ef77cc8e0aee
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.self-monitoring.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"self-monitoring"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.self-monitoring.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"self-monitoring"}'
              name: 'Zabbix proxy: Utilization of self-monitoring processes is high'
              event_name: 'Zabbix proxy: Utilization of self-monitoring processes over {$ZABBIX.PROXY.UTIL.MAX:"self-monitoring"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the self-monitoring, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: a2dd22ed51df44ae86f86555dc3ba3c2
          name: 'Utilization of snmp poller data collector processes, in %'
          type: DEPENDENT
          key: process.snmp_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the snmp poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''snmp poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes snmp poller not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 3fab2971d5eb46d8953bc34af262eef7
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.snmp_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"snmp poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.snmp_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"snmp poller"}'
              name: 'Zabbix proxy: Utilization of snmp poller processes is high'
              event_name: 'Zabbix proxy: Utilization of snmp poller processes over {$ZABBIX.PROXY.UTIL.MAX:"snmp poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the snmp poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 48204005c3ec441e990e132caa4968a0
          name: 'Utilization of snmp trapper data collector processes, in %'
          type: DEPENDENT
          key: process.snmp_trapper.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the snmp trapper processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''snmp trapper''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes snmp trapper not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: c67d6cf7bb414ba5bf5e295323ceca3e
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.snmp_trapper.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"snmp trapper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.snmp_trapper.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"snmp trapper"}'
              name: 'Zabbix proxy: Utilization of snmp trapper processes is high'
              event_name: 'Zabbix proxy: Utilization of snmp trapper processes over {$ZABBIX.PROXY.UTIL.MAX:"snmp trapper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the snmp trapper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 919f3c24e8bf4099aabd25a843613f35
          name: 'Utilization of task manager internal processes, in %'
          type: DEPENDENT
          key: process.task_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the task manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''task manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes task manager not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: fbba9326edf24178b4ef43de4c545fcc
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.task_manager.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"task manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.task_manager.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"task manager"}'
              name: 'Zabbix proxy: Utilization of task manager processes is high'
              event_name: 'Zabbix proxy: Utilization of task manager processes over {$ZABBIX.PROXY.UTIL.MAX:"task manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the task manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: a5ef0fec5c864de98519e340d2d182bb
          name: 'Utilization of trapper data collector processes, in %'
          type: DEPENDENT
          key: process.trapper.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the trapper processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''trapper''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes trapper not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 7ab1c8f1b661480da56f12d7e9df525d
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.trapper.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"trapper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.trapper.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"trapper"}'
              name: 'Zabbix proxy: Utilization of trapper processes is high'
              event_name: 'Zabbix proxy: Utilization of trapper processes over {$ZABBIX.PROXY.UTIL.MAX:"trapper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the trapper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 2455887b313847d39d318078b29120e7
          name: 'Utilization of unreachable poller data collector processes, in %'
          type: DEPENDENT
          key: process.unreachable_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the unreachable poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''unreachable poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes unreachable poller not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 0dd4fe44dd7c45a589b95af7410e44e1
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.unreachable_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"unreachable poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.unreachable_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"unreachable poller"}'
              name: 'Zabbix proxy: Utilization of unreachable poller processes is high'
              event_name: 'Zabbix proxy: Utilization of unreachable poller processes over {$ZABBIX.PROXY.UTIL.MAX:"unreachable poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the unreachable poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 2bea24eb5d8d42b48049e340ea385aad
          name: 'Utilization of vmware collector data collector processes, in %'
          type: DEPENDENT
          key: process.vmware_collector.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the vmware collector processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''vmware collector''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes vmware collector not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: e4c5051b01aa4c3bbad9237e7c593308
              expression: 'avg(/Zabbix proxy health by Zabbix agent/process.vmware_collector.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"vmware collector"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent/process.vmware_collector.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"vmware collector"}'
              name: 'Zabbix proxy: Utilization of vmware collector processes is high'
              event_name: 'Zabbix proxy: Utilization of vmware collector processes over {$ZABBIX.PROXY.UTIL.MAX:"vmware collector"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the vmware collector, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: c98b4b21c1744546898dbb8b1dfead42
          name: 'Proxy memory buffer, % used'
          type: DEPENDENT
          key: proxy_buffer.buffer.pused
          value_type: FLOAT
          units: '%'
          description: |
            Statistics and availability of Zabbix proxy memory buffer usage statistics. Percentage of used proxy memory buffer.
            Proxy memory buffer is used to store the new historical data and upload from it without accessing database.
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.wcache.[''proxy buffer''].memory.pused'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Proxy memory buffer is disabled.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: c784f7f231c34461a63d0a5cb2ce4a45
              expression: 'max(/Zabbix proxy health by Zabbix agent/proxy_buffer.buffer.pused,10m)>{$ZABBIX.PROXY.UTIL.MAX:"proxy buffer"}'
              name: 'Zabbix proxy: Excessive proxy memory buffer usage'
              event_name: 'Zabbix proxy: More than {$ZABBIX.PROXY.UTIL.MAX:"proxy buffer"}% used in the proxy memory buffer'
              priority: AVERAGE
              description: 'Consider increasing ProxyMemoryBufferSize in the zabbix_proxy.conf configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 0f120fc684234c9a9ee5a9f6666f3413
          name: 'Proxy buffer, state changes'
          type: DEPENDENT
          key: proxy_buffer.state.changes
          description: 'The number of state changes between disk/memory buffer modes since proxy start.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.wcache.[''proxy buffer''].[''state change'']'
              error_handler: CUSTOM_VALUE
              error_handler_params: '0'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: 38bfb3b653914ca2add4bc219d50dc32
          name: 'Proxy buffer, state'
          type: DEPENDENT
          key: proxy_buffer.state.current
          description: |
            The current working state of proxy buffer where the new data is being stored. Possible values:
            
              0 - disk (also returned when memory buffer is disabled);
              1 - memory.
          valuemap:
            name: 'Proxy buffer mode'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.wcache.[''proxy buffer''].state'
              error_handler: CUSTOM_VALUE
              error_handler_params: '0'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: 562d546ed5e8413b8c756b3b47a4f720
          name: 'Zabbix proxy check'
          type: DEPENDENT
          key: proxy_check
          trends: '0'
          description: 'Flag indicating whether it is a proxy or not.'
          valuemap:
            name: 'Zabbix proxy check'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.triggers
              error_handler: CUSTOM_VALUE
              error_handler_params: '0'
            - type: IN_RANGE
              parameters:
                - ''
                - '0'
              error_handler: CUSTOM_VALUE
              error_handler_params: '1'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 315fc2009a02420cbe059ac199171d6d
              expression: 'last(/Zabbix proxy health by Zabbix agent/proxy_check)=1'
              name: 'Zabbix proxy: Wrong template assigned'
              event_name: 'Zabbix proxy: Zabbix proxy template is assigned to Zabbix server'
              priority: DISASTER
              description: 'Check that the template has been selected correctly.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: 06aa2a793fa3415281aefdf937e5ddee
          name: 'Configuration cache, % used'
          type: DEPENDENT
          key: rcache.buffer.pused
          value_type: FLOAT
          units: '%'
          description: 'The availability statistics of Zabbix configuration cache. The percentage of used data buffer.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.rcache.pused
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 523f092b9f8b41f9b652eeb7fdafe40c
              expression: 'max(/Zabbix proxy health by Zabbix agent/rcache.buffer.pused,10m)>{$ZABBIX.PROXY.UTIL.MAX:"configuration cache"}'
              name: 'Zabbix proxy: Excessive configuration cache usage'
              event_name: 'Zabbix proxy: More than {$ZABBIX.PROXY.UTIL.MAX:"configuration cache"}% used in the configuration cache'
              priority: AVERAGE
              description: 'Consider increasing `CacheSize` in the `zabbix_proxy.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
            - uuid: 013a980007284540964d72be2de27a0d
              expression: 'nodata(/Zabbix proxy health by Zabbix agent/rcache.buffer.pused,{$ZABBIX.PROXY.NODATA_TIMEOUT})=1'
              name: 'Zabbix proxy: Failed to fetch stats data'
              event_name: 'Zabbix proxy: Failed to fetch stats data (or no data for {$ZABBIX.PROXY.NODATA_TIMEOUT})'
              priority: WARNING
              description: 'Zabbix has not received statistics data for `{$ZABBIX.PROXY.NODATA_TIMEOUT}`.'
              tags:
                - tag: scope
                  value: availability
        - uuid: b2446bae74174e25b0cca1f32aef8553
          name: 'Required VPS'
          type: DEPENDENT
          key: requiredperformance
          value_type: FLOAT
          units: '!vps'
          description: 'The required performance of a proxy (the number of values that need to be collected per second).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.requiredperformance
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 12h
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: 1c36d8e963a64ee1aa93a1a9568370a3
          name: Uptime
          type: DEPENDENT
          key: uptime
          units: uptime
          description: 'Uptime of the Zabbix proxy process in seconds.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.uptime
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 187bc575a0a14bbc84ad86225ddbcb61
              expression: 'last(/Zabbix proxy health by Zabbix agent/uptime)<10m'
              name: 'Zabbix proxy: {HOST.NAME} has been restarted'
              event_name: 'Zabbix proxy: {HOST.NAME} has been restarted (uptime < 10m)'
              priority: INFO
              description: 'Uptime is less than 10 minutes.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: fe584f47643f4ae8be825c00854719ad
          name: Version
          type: DEPENDENT
          key: version
          value_type: CHAR
          description: 'The version of Zabbix proxy.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.version
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 0a95e8c307074bc4ba9f55d9f172ff0a
              expression: 'last(/Zabbix proxy health by Zabbix agent/version,#1)<>last(/Zabbix proxy health by Zabbix agent/version,#2) and length(last(/Zabbix proxy health by Zabbix agent/version))>0'
              name: 'Zabbix proxy: Version has changed'
              event_name: 'Zabbix proxy: Version has changed (new version: {ITEM.VALUE})'
              priority: INFO
              description: 'Zabbix proxy version has changed. Acknowledge to close the problem manually.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: c41ad12215a94aca827b31c427f8f2e1
          name: 'VMware cache, % used'
          type: DEPENDENT
          key: vmware.buffer.pused
          value_type: FLOAT
          units: '%'
          description: 'The availability statistics of Zabbix vmware cache. The percentage of used data buffer.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.vmware.pused
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No vmware collector processes started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 04c4161b994046fe9d657da0a5a1c3db
              expression: 'max(/Zabbix proxy health by Zabbix agent/vmware.buffer.pused,10m)>{$ZABBIX.PROXY.UTIL.MAX:"vmware cache"}'
              name: 'Zabbix proxy: Excessive vmware cache usage'
              event_name: 'Zabbix proxy: More than {$ZABBIX.PROXY.UTIL.MAX:"vmware cache"}% used in the vmware cache'
              priority: AVERAGE
              description: 'Consider increasing `VMwareCacheSize` in the `zabbix_proxy.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 735347973ba04edd8f930ffafd81ee6d
          name: 'History write cache, % used'
          type: DEPENDENT
          key: wcache.history.pused
          value_type: FLOAT
          units: '%'
          description: |
            The statistics and availability of Zabbix write cache. The percentage of used history buffer.
            The history cache is used to store item values. A high number indicates database performance problems.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.history.pused
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 042eaacf59f74383b29c0a8130ae4b16
              expression: 'max(/Zabbix proxy health by Zabbix agent/wcache.history.pused,10m)>{$ZABBIX.PROXY.UTIL.MAX:"history cache"}'
              name: 'Zabbix proxy: Excessive history cache usage'
              event_name: 'Zabbix proxy: More than {$ZABBIX.PROXY.UTIL.MAX:"history cache"}% used in the history cache'
              priority: AVERAGE
              description: 'Consider increasing `HistoryCacheSize` in the `zabbix_proxy.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 248bb7f1ab5546ccaa0fdc529e746e04
          name: 'History index cache, % used'
          type: DEPENDENT
          key: wcache.index.pused
          value_type: FLOAT
          units: '%'
          description: |
            The statistics and availability of Zabbix write cache. The percentage of used history index buffer.
            The history index cache is used to index values stored in the history cache.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.index.pused
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: fa7be5e77ff04e728db5ee0369708dde
              expression: 'max(/Zabbix proxy health by Zabbix agent/wcache.index.pused,10m)>{$ZABBIX.PROXY.UTIL.MAX:"index cache"}'
              name: 'Zabbix proxy: Excessive history index cache usage'
              event_name: 'Zabbix proxy: More than {$ZABBIX.PROXY.UTIL.MAX:"index cache"}% used in the history index cache'
              priority: AVERAGE
              description: 'Consider increasing `HistoryIndexCacheSize` in the `zabbix_proxy.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 1006c5bf5fbc47c1a367f74d29e72257
          name: 'Number of processed values per second'
          type: DEPENDENT
          key: wcache.values
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The total number of values processed by Zabbix server or Zabbix proxy, except unsupported items.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.all
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 0117f333d91846fbb10d4941a258ec5b
          name: 'Number of processed numeric (float) values per second'
          type: DEPENDENT
          key: wcache.values.float
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed numeric (float) values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.float
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: fae6ad936ab94641a6e0446a5dbe2e3a
          name: 'Number of processed log values per second'
          type: DEPENDENT
          key: wcache.values.log
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed log values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.log
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 49e235b0e2514255bf395db06df1660a
          name: 'Number of processed not supported values per second'
          type: DEPENDENT
          key: wcache.values.not_supported
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of times the item processing resulted in an item becoming unsupported or remaining in that state.
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.wcache.values[''not supported'']'
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 505ac45e931b45959df5b78524fe7916
          name: 'Number of processed character values per second'
          type: DEPENDENT
          key: wcache.values.str
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed character values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.str
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 4e293845715644c199b295f3701c553e
          name: 'Number of processed text values per second'
          type: DEPENDENT
          key: wcache.values.text
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed text values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.text
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 53811a399df5460eae32ea7fbbd3ae3c
          name: 'Number of processed numeric (unsigned) values per second'
          type: DEPENDENT
          key: wcache.values.uint
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed numeric (unsigned) values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.uint
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: d4da5073f23d47c1adc55b30117bb1e0
          name: 'Queue over 10 minutes'
          key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT},queue,10m]'
          description: 'The number of monitored items in the queue that are delayed by at least 10 minutes.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.queue
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 73460db4082c4feaac254b6ed790045a
              expression: 'min(/Zabbix proxy health by Zabbix agent/zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT},queue,10m],10m)>100'
              name: 'Zabbix proxy: More than 100 items have been missing data for over 10 minutes'
              priority: WARNING
              description: 'Indicates potential issues with network connectivity, agent failures, or unresponsive monitored resources that require attention.'
              tags:
                - tag: scope
                  value: performance
        - uuid: b05149cb78b44bc08ccd72b58a34aded
          name: Queue
          key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT},queue]'
          description: 'The number of monitored items in the queue that are delayed by at least 6 seconds.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.queue
          tags:
            - tag: component
              value: system
        - uuid: 32495fbb4c6642378a5871323b11cb08
          name: 'Zabbix stats'
          key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          history: '0'
          value_type: TEXT
          description: 'The master item of Zabbix proxy statistics.'
          tags:
            - tag: component
              value: raw
      tags:
        - tag: class
          value: software
        - tag: subclass
          value: logging
        - tag: subclass
          value: monitoring
        - tag: target
          value: proxy
        - tag: target
          value: zabbix
      macros:
        - macro: '{$ZABBIX.PROXY.ADDRESS}'
          description: 'IP/DNS of the remote Zabbix proxy (default is 127.0.0.1).'
          config:
            type: TEXT
            priority: '1'
            label: 'Zabbix proxy Address'
            description: 'IP or DNS of the remote Zabbix proxy that should be monitored via the Zabbix agent.'
            required: 'YES'
        - macro: '{$ZABBIX.PROXY.NODATA_TIMEOUT}'
          value: 5m
          description: 'The time threshold after which statistics are considered unavailable. Used in trigger expressions.'
          config:
            type: TEXT
            priority: '5'
            section_name: Thresholds
            label: 'Time since the last statistic was received'
            description: 'Threshold value of time since the last statistic was received from the remote proxy.'
        - macro: '{$ZABBIX.PROXY.PORT}'
          description: 'Port of the remote Zabbix proxy (default is 10051).'
          config:
            type: TEXT
            priority: '2'
            label: 'Zabbix proxy Port'
            description: 'Port of the remote Zabbix proxy that should be monitored via the Zabbix agent. In the range from 1 to 65535 inclusive.'
            required: 'YES'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$ZABBIX.PROXY.UTIL.MAX}'
          value: '75'
          description: 'Default maximum threshold for percentage utilization triggers (use macro context for specification).'
          config:
            type: TEXT
            priority: '4'
            section_name: Thresholds
            label: 'Maximum process utilization percentage'
            description: 'Default maximum threshold for process utilization triggers. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$ZABBIX.PROXY.UTIL.MIN}'
          value: '65'
          description: 'Default minimum threshold for percentage utilization triggers (use macro context for specification).'
          config:
            type: TEXT
            priority: '3'
            section_name: Thresholds
            label: 'Minimum process utilization percentage'
            description: 'Default minimum threshold for process utilization triggers. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
      dashboards:
        - uuid: 707ef24a70ff433eb28a70cd0f78bf66
          name: 'Zabbix proxy health'
          auto_start: 'NO'
          pages:
            - name: Performance
              widgets:
                - type: svggraph
                  name: 'Cache usage, in %'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.1
                      value: e31a1c
                    - type: STRING
                      name: ds.0.color.2
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.3
                      value: b15928
                    - type: STRING
                      name: ds.0.color.4
                      value: a6cee3
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: rcache.buffer.pused
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: wcache.index.pused
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: wcache.history.pused
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: vmware.buffer.pused
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: proxy_buffer.buffer.pused
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACA
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Server performance'
                  'y': '6'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.1
                      value: e31a1c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: wcache.values
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT},queue]'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACC
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Values processed'
                  'y': '11'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.2
                      value: e31a1c
                    - type: STRING
                      name: ds.0.color.3
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.4
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.5
                      value: b15928
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: wcache.values.uint
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: wcache.values.float
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: wcache.values.not_supported
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: wcache.values.str
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: wcache.values.log
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: wcache.values.text
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACD
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Internal queues'
                  x: '36'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: ffff99
                    - type: STRING
                      name: ds.0.color.1
                      value: 6a3d9a
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: preprocessing_queue
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: discovery_queue
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACB
                    - type: INTEGER
                      name: show_problems
                      value: '1'
            - name: Processes
              widgets:
                - type: svggraph
                  name: 'Utilization: Discovery processes'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 7e57c2
                    - type: STRING
                      name: ds.0.color.1
                      value: 1f78b4
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.discovery_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.discovery_worker.avg.busy
                    - type: INTEGER
                      name: ds.1.axisy
                      value: '1'
                    - type: STRING
                      name: ds.1.color.0
                      value: ff465c
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: discovery_queue
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABH
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Synchronous gathering processes'
                  'y': '6'
                  width: '72'
                  height: '7'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.2
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.3
                      value: b15928
                    - type: STRING
                      name: ds.0.color.4
                      value: 17becf
                    - type: STRING
                      name: ds.0.color.5
                      value: a6cee3
                    - type: STRING
                      name: ds.0.color.6
                      value: fb9a99
                    - type: STRING
                      name: ds.0.color.7
                      value: bcbd22
                    - type: STRING
                      name: ds.0.color.8
                      value: fdbf6f
                    - type: STRING
                      name: ds.0.color.9
                      value: e31a1c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.internal_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.ipmi_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.ipmi_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.http_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.java_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.6
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.vmware_collector.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.7
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.browser_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.8
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.odbc_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.9
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.icmp_pinger.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABJ
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Asynchronous gathering processes'
                  'y': '13'
                  width: '72'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: bcbd22
                    - type: STRING
                      name: ds.0.color.2
                      value: 6a3d9a
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.agent_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.http_agent_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.snmp_poller.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABK
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Internal processes: Core'
                  'y': '19'
                  width: '72'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: e31a1c
                    - type: STRING
                      name: ds.0.color.2
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.3
                      value: b15928
                    - type: STRING
                      name: ds.0.color.4
                      value: a6cee3
                    - type: STRING
                      name: ds.0.color.5
                      value: fdbf6f
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.configuration_syncer.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.history_syncer.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.self-monitoring.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.task_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.data_sender.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.housekeeper.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '6'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABL
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Gathering processes: Trappers'
                  'y': '25'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: cab2d6
                    - type: STRING
                      name: ds.0.color.1
                      value: fdbf6f
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.trapper.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.snmp_trapper.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABM
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Data exchange with server'
                  'y': '30'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: cab2d6
                    - type: STRING
                      name: ds.0.color.1
                      value: '000080'
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.trapper.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.data_sender.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABO
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Preprocessing processes'
                  x: '36'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: fdbf6f
                    - type: STRING
                      name: ds.0.color.1
                      value: 7e57c2
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.preprocessing_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.preprocessing_worker.avg.busy
                    - type: INTEGER
                      name: ds.1.axisy
                      value: '1'
                    - type: STRING
                      name: ds.1.color.0
                      value: ff465c
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.1.fill
                      value: '2'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: preprocessing_queue
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABI
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Availability processes'
                  x: '36'
                  'y': '25'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.1
                      value: b15928
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.unreachable_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: process.availability_manager.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABN
                    - type: INTEGER
                      name: show_problems
                      value: '1'
            - name: Statuses
              widgets:
                - type: item
                  name: 'Zabbix proxy version'
                  width: '18'
                  height: '3'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: version
                    - type: INTEGER
                      name: show.0
                      value: '2'
                    - type: INTEGER
                      name: show.1
                      value: '3'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: time_h_pos
                      value: '2'
                    - type: INTEGER
                      name: time_size
                      value: '9'
                    - type: INTEGER
                      name: time_v_pos
                      value: '2'
                    - type: INTEGER
                      name: value_size
                      value: '25'
                - type: item
                  name: Uptime
                  x: '18'
                  width: '18'
                  height: '3'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: uptime
                    - type: INTEGER
                      name: show.0
                      value: '2'
                    - type: INTEGER
                      name: show.1
                      value: '3'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: time_h_pos
                      value: '2'
                    - type: INTEGER
                      name: time_size
                      value: '9'
                    - type: INTEGER
                      name: time_v_pos
                      value: '2'
                    - type: INTEGER
                      name: value_size
                      value: '25'
                - type: item
                  name: 'Proxy buffer state'
                  x: '36'
                  width: '18'
                  height: '3'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent'
                        key: proxy_buffer.state.current
                    - type: INTEGER
                      name: show.0
                      value: '2'
                    - type: INTEGER
                      name: show.1
                      value: '3'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: time_h_pos
                      value: '2'
                    - type: INTEGER
                      name: time_size
                      value: '9'
                    - type: INTEGER
                      name: time_v_pos
                      value: '2'
                    - type: INTEGER
                      name: value_size
                      value: '25'
      valuemaps:
        - uuid: 22c73bf5429d4e9baf358fe6c177a033
          name: 'Proxy buffer mode'
          mappings:
            - value: '0'
              newvalue: Disk
            - value: '1'
              newvalue: Memory
        - uuid: 942633fa91474837afc5ce050cb86cb4
          name: 'Zabbix proxy check'
          mappings:
            - value: '0'
              newvalue: 'True'
            - value: '1'
              newvalue: 'False'
    - uuid: 02aac022a62c48bba810d07bbaa712cc
      template: 'Zabbix proxy health by Zabbix agent active'
      name: 'Zabbix proxy health by Zabbix agent active'
      description: |
        This template is designed to monitor internal Zabbix metrics on the remote Zabbix proxy via the active Zabbix agent.
        
        Specify the address of the remote Zabbix proxy by changing the {$ZABBIX.PROXY.ADDRESS} and {$ZABBIX.PROXY.PORT} macros. Don't forget to adjust the "StatsAllowedIP" parameter in the remote proxy's configuration file to allow the collection of statistics.
        
        Generated by official Zabbix template tool "Templator"
      wizard_ready: 'YES'
      readme: |
        ## Overview
        
        This template is designed to monitor internal Zabbix metrics on the remote Zabbix proxy via the active Zabbix agent.
        
        ## Setup
        
        Specify the address of the remote Zabbix proxy as the values for the `Zabbix proxy Address` and `Zabbix proxy Port` configuration fields. Don't forget to adjust the `StatsAllowedIP` parameter in the remote proxy's configuration file to allow the collection of statistics.
      vendor:
        name: Zabbix
        version: 7.4-3
      groups:
        - name: Templates/Applications
      items:
        - uuid: 19639a8badd8427580ca4ef1a3f3e037
          name: 'Discovery queue'
          type: DEPENDENT
          key: discovery_queue
          description: 'The count of values enqueued in the discovery queue.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.discovery_queue
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "discoverer" processes started. Please check "StartDiscoverers" parameter in the server configuration file.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: b8bba41ac6fb47b987d4b50363b5682e
          name: 'Preprocessing queue'
          type: DEPENDENT
          key: preprocessing_queue
          description: 'The number of values enqueued in the preprocessing queue.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.preprocessing_queue
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: defab1c17e114e8d9a752579036b42dd
          name: 'Utilization of agent poller data collector processes, in %'
          type: DEPENDENT
          key: process.agent_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the agent poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''agent poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes agent poller not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 781f2b17fc384acebdcbb008a3f24bc1
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.agent_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"agent poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.agent_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"agent poller"}'
              name: 'Zabbix proxy: Utilization of agent poller processes is high'
              event_name: 'Zabbix proxy: Utilization of agent poller processes over {$ZABBIX.PROXY.UTIL.MAX:"agent poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the agent poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 5212844ce04048a08d7c88f9d914b4c6
          name: 'Utilization of availability manager internal processes, in %'
          type: DEPENDENT
          key: process.availability_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the availability manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''availability manager''].busy.avg'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 60c4627e26e24f5583b13ac51c652bb6
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.availability_manager.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"availability manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.availability_manager.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"availability manager"}'
              name: 'Zabbix proxy: Utilization of availability manager processes is high'
              event_name: 'Zabbix proxy: Utilization of availability manager processes over {$ZABBIX.PROXY.UTIL.MAX:"availability manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the availability manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: d54d7e00c2b547c891d56fd11791673c
          name: 'Utilization of browser poller data collector processes, in %'
          type: DEPENDENT
          key: process.browser_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the browser poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''browser poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "browser poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 9ceb9623900f4fd097c96be779088a1a
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.browser_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"browser poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.browser_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"browser poller"}'
              name: 'Zabbix proxy: Utilization of browser poller processes is high'
              event_name: 'Zabbix proxy: Utilization of browser poller processes over {$ZABBIX.PROXY.UTIL.MAX:"browser poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the browser poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: bc6b359fb245474ab52a2f07a4fd130b
          name: 'Utilization of configuration syncer internal processes, in %'
          type: DEPENDENT
          key: process.configuration_syncer.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the configuration syncer processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''configuration syncer''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes configuration syncer not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 4fc6ad715b6d4eea89c47e9a80cc1bd2
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.configuration_syncer.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"configuration syncer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.configuration_syncer.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"configuration syncer"}'
              name: 'Zabbix proxy: Utilization of configuration syncer processes is high'
              event_name: 'Zabbix proxy: Utilization of configuration syncer processes over {$ZABBIX.PROXY.UTIL.MAX:"configuration syncer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the configuration syncer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: d6dbae1eb33f4235807462e0043fe89c
          name: 'Utilization of data sender internal processes, in %'
          type: DEPENDENT
          key: process.data_sender.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the data sender processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''data sender''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes data sender not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 53a13b3f8ae746a5aa698c48beeb782f
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.data_sender.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"data sender"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.data_sender.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"data sender"}'
              name: 'Zabbix proxy: Utilization of data sender processes is high'
              event_name: 'Zabbix proxy: Utilization of data sender processes over {$ZABBIX.PROXY.UTIL.MAX:"data sender"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the data sender, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 02289431d3634e80931617d145759057
          name: 'Utilization of discovery manager internal processes, in %'
          type: DEPENDENT
          key: process.discovery_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the discovery manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''discovery manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "discovery manager" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: ac5583b00510498ea9f0cf75835dc8c9
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.discovery_manager.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"discovery manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.discovery_manager.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"discovery manager"}'
              name: 'Zabbix proxy: Utilization of discovery manager processes is high'
              event_name: 'Zabbix proxy: Utilization of discovery manager processes over {$ZABBIX.PROXY.UTIL.MAX:"discovery manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the discovery manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 67edf3a9ef824014be826ea4cc13d7ae
          name: 'Utilization of discovery worker internal processes, in %'
          type: DEPENDENT
          key: process.discovery_worker.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the discovery worker processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''discovery worker''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "discovery worker" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 2368cc40dca345dc81b4e06f6c652f5a
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.discovery_worker.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"discovery worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.discovery_worker.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"discovery worker"}'
              name: 'Zabbix proxy: Utilization of discovery worker processes is high'
              event_name: 'Zabbix proxy: Utilization of discovery worker processes over {$ZABBIX.PROXY.UTIL.MAX:"discovery worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the discovery worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: beaa4c6f193e4dfcbd1988319156a2c8
          name: 'Utilization of history syncer internal processes, in %'
          type: DEPENDENT
          key: process.history_syncer.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the history syncer processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''history syncer''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes history syncer not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: f56becd9ed784dcf9f97fa703269b46e
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.history_syncer.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"history syncer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.history_syncer.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"history syncer"}'
              name: 'Zabbix proxy: Utilization of history syncer processes is high'
              event_name: 'Zabbix proxy: Utilization of history syncer processes over {$ZABBIX.PROXY.UTIL.MAX:"history syncer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the history syncer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 00ea59e1231947a5b16312326906d3a8
          name: 'Utilization of housekeeper internal processes, in %'
          type: DEPENDENT
          key: process.housekeeper.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the housekeeper processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''housekeeper''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes housekeeper not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: f81451219df048ce92a35b9673548358
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.housekeeper.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"housekeeper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.housekeeper.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"housekeeper"}'
              name: 'Zabbix proxy: Utilization of housekeeper processes is high'
              event_name: 'Zabbix proxy: Utilization of housekeeper processes over {$ZABBIX.PROXY.UTIL.MAX:"housekeeper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the housekeeper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: fed4a2ec074748c5acc8d027156257ae
          name: 'Utilization of http agent poller data collector processes, in %'
          type: DEPENDENT
          key: process.http_agent_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the http agent poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''http agent poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes http agent poller not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: b0bd0d9770fc4276be324b97150c691c
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.http_agent_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"http agent poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.http_agent_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"http agent poller"}'
              name: 'Zabbix proxy: Utilization of http agent poller processes is high'
              event_name: 'Zabbix proxy: Utilization of http agent poller processes over {$ZABBIX.PROXY.UTIL.MAX:"http agent poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the http agent poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 92372873a1724cb9a02e0472d0662483
          name: 'Utilization of http poller data collector processes, in %'
          type: DEPENDENT
          key: process.http_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the http poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''http poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes http poller not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 43b21d9aff8441cba1c0db97e7b193e0
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.http_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"http poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.http_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"http poller"}'
              name: 'Zabbix proxy: Utilization of http poller processes is high'
              event_name: 'Zabbix proxy: Utilization of http poller processes over {$ZABBIX.PROXY.UTIL.MAX:"http poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the http poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 7f031eb8ecef40ba853054c471fe7b0a
          name: 'Utilization of icmp pinger data collector processes, in %'
          type: DEPENDENT
          key: process.icmp_pinger.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the icmp pinger processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''icmp pinger''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes icmp pinger not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 417d421e076342e5b38ab7a925dc7ee6
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.icmp_pinger.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"icmp pinger"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.icmp_pinger.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"icmp pinger"}'
              name: 'Zabbix proxy: Utilization of icmp pinger processes is high'
              event_name: 'Zabbix proxy: Utilization of icmp pinger processes over {$ZABBIX.PROXY.UTIL.MAX:"icmp pinger"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the icmp pinger, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 39209185bab1415a9a12b70be0e568f9
          name: 'Utilization of internal poller data collector processes, in %'
          type: DEPENDENT
          key: process.internal_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the internal poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''internal poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "internal poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 60dacadac60641789e7f8eb2a6441498
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.internal_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"internal poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.internal_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"internal poller"}'
              name: 'Zabbix proxy: Utilization of internal poller processes is high'
              event_name: 'Zabbix proxy: Utilization of internal poller processes over {$ZABBIX.PROXY.UTIL.MAX:"internal poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the internal poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 6b5f54fc00dc456e98c1669d49d84b59
          name: 'Utilization of ipmi manager internal processes, in %'
          type: DEPENDENT
          key: process.ipmi_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the ipmi manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''ipmi manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes ipmi manager not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 773bcda0a0d44428bd66f619df41a94d
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.ipmi_manager.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"ipmi manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.ipmi_manager.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"ipmi manager"}'
              name: 'Zabbix proxy: Utilization of ipmi manager processes is high'
              event_name: 'Zabbix proxy: Utilization of ipmi manager processes over {$ZABBIX.PROXY.UTIL.MAX:"ipmi manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the ipmi manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: aa601feb9b97499995b8abfe1a001029
          name: 'Utilization of ipmi poller data collector processes, in %'
          type: DEPENDENT
          key: process.ipmi_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the ipmi poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''ipmi poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes ipmi poller not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 520d3b11a75c42cd911ec3e8639c7325
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.ipmi_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"ipmi poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.ipmi_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"ipmi poller"}'
              name: 'Zabbix proxy: Utilization of ipmi poller processes is high'
              event_name: 'Zabbix proxy: Utilization of ipmi poller processes over {$ZABBIX.PROXY.UTIL.MAX:"ipmi poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the ipmi poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 081941c3f18743c2b62217b84e8421a1
          name: 'Utilization of java poller data collector processes, in %'
          type: DEPENDENT
          key: process.java_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the java poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''java poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes java poller not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 48c63db097c94a52a13cfea9d53a5d6e
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.java_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"java poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.java_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"java poller"}'
              name: 'Zabbix proxy: Utilization of java poller processes is high'
              event_name: 'Zabbix proxy: Utilization of java poller processes over {$ZABBIX.PROXY.UTIL.MAX:"java poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the java poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: af2a9d4b24084528bfe60204ca385fcd
          name: 'Utilization of ODBC poller data collector processes, in %'
          type: DEPENDENT
          key: process.odbc_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the ODBC poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''odbc poller''].busy.avg'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: d3d1b01114b14de1b5a432fb574713f1
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.odbc_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"ODBC poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.odbc_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"ODBC poller"}'
              name: 'Zabbix proxy: Utilization of ODBC poller processes is high'
              event_name: 'Zabbix proxy: Utilization of ODBC poller processes over {$ZABBIX.PROXY.UTIL.MAX:"ODBC poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the ODBC poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: ab3a54eb85d548e38dba2f6642372cb4
          name: 'Utilization of poller data collector processes, in %'
          type: DEPENDENT
          key: process.poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes poller not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 1d7cee57cd28400790ea8fea6901d0a9
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"poller"}'
              name: 'Zabbix proxy: Utilization of poller processes is high'
              event_name: 'Zabbix proxy: Utilization of poller processes over {$ZABBIX.PROXY.UTIL.MAX:"poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: afb08d2d0f33405980c319ac25a31224
          name: 'Utilization of preprocessing manager internal processes, in %'
          type: DEPENDENT
          key: process.preprocessing_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the preprocessing manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''preprocessing manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes preprocessing manager not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: a3692dec8449492b8c1c0fc0ffc38ba7
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.preprocessing_manager.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"preprocessing manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.preprocessing_manager.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"preprocessing manager"}'
              name: 'Zabbix proxy: Utilization of preprocessing manager processes is high'
              event_name: 'Zabbix proxy: Utilization of preprocessing manager processes over {$ZABBIX.PROXY.UTIL.MAX:"preprocessing manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the preprocessing manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 060a18c681c340ab8ba85b92ac73fff0
          name: 'Utilization of preprocessing worker internal processes, in %'
          type: DEPENDENT
          key: process.preprocessing_worker.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the preprocessing worker processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''preprocessing worker''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes preprocessing worker not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: cbdfa6eab86547a9bcc15308cb24ecec
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.preprocessing_worker.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"preprocessing worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.preprocessing_worker.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"preprocessing worker"}'
              name: 'Zabbix proxy: Utilization of preprocessing worker processes is high'
              event_name: 'Zabbix proxy: Utilization of preprocessing worker processes over {$ZABBIX.PROXY.UTIL.MAX:"preprocessing worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the preprocessing worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 1deace63f8e7490b86fb58161dd938b4
          name: 'Utilization of self-monitoring internal processes, in %'
          type: DEPENDENT
          key: process.self-monitoring.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the self-monitoring processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''self-monitoring''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes self-monitoring not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 8c731df045474ff78961106f51943a2d
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.self-monitoring.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"self-monitoring"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.self-monitoring.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"self-monitoring"}'
              name: 'Zabbix proxy: Utilization of self-monitoring processes is high'
              event_name: 'Zabbix proxy: Utilization of self-monitoring processes over {$ZABBIX.PROXY.UTIL.MAX:"self-monitoring"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the self-monitoring, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 09fcd6d6ff724ca7b73e3d460f858bd3
          name: 'Utilization of snmp poller data collector processes, in %'
          type: DEPENDENT
          key: process.snmp_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the snmp poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''snmp poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes snmp poller not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 37f76a103450441c91dc980877685fdf
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.snmp_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"snmp poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.snmp_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"snmp poller"}'
              name: 'Zabbix proxy: Utilization of snmp poller processes is high'
              event_name: 'Zabbix proxy: Utilization of snmp poller processes over {$ZABBIX.PROXY.UTIL.MAX:"snmp poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the snmp poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 456aec8079074dcbb20d547d90dcb8b9
          name: 'Utilization of snmp trapper data collector processes, in %'
          type: DEPENDENT
          key: process.snmp_trapper.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the snmp trapper processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''snmp trapper''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes snmp trapper not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 125f0015cbab441f8fb585273b1be59d
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.snmp_trapper.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"snmp trapper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.snmp_trapper.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"snmp trapper"}'
              name: 'Zabbix proxy: Utilization of snmp trapper processes is high'
              event_name: 'Zabbix proxy: Utilization of snmp trapper processes over {$ZABBIX.PROXY.UTIL.MAX:"snmp trapper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the snmp trapper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 452f67fd89764adfb638a9ea0a902063
          name: 'Utilization of task manager internal processes, in %'
          type: DEPENDENT
          key: process.task_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the task manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''task manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes task manager not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 639ce0f06fa4454784458426fedce080
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.task_manager.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"task manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.task_manager.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"task manager"}'
              name: 'Zabbix proxy: Utilization of task manager processes is high'
              event_name: 'Zabbix proxy: Utilization of task manager processes over {$ZABBIX.PROXY.UTIL.MAX:"task manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the task manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 155b770a61d1483c9fda1d1530c62080
          name: 'Utilization of trapper data collector processes, in %'
          type: DEPENDENT
          key: process.trapper.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the trapper processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''trapper''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes trapper not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: dd4185cd7ff646ccaee1d7c36eba58b4
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.trapper.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"trapper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.trapper.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"trapper"}'
              name: 'Zabbix proxy: Utilization of trapper processes is high'
              event_name: 'Zabbix proxy: Utilization of trapper processes over {$ZABBIX.PROXY.UTIL.MAX:"trapper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the trapper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 7eeed993f1874749849ac988a92835ba
          name: 'Utilization of unreachable poller data collector processes, in %'
          type: DEPENDENT
          key: process.unreachable_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the unreachable poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''unreachable poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes unreachable poller not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 353e0603f5454b92806bc27442e4675a
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.unreachable_poller.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"unreachable poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.unreachable_poller.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"unreachable poller"}'
              name: 'Zabbix proxy: Utilization of unreachable poller processes is high'
              event_name: 'Zabbix proxy: Utilization of unreachable poller processes over {$ZABBIX.PROXY.UTIL.MAX:"unreachable poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the unreachable poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: d38cebfe55ff45338051302e99b90454
          name: 'Utilization of vmware collector data collector processes, in %'
          type: DEPENDENT
          key: process.vmware_collector.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the vmware collector processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''vmware collector''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Processes vmware collector not started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 19212b4c55a5412a8358486ccec73867
              expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.vmware_collector.avg.busy,10m)>{$ZABBIX.PROXY.UTIL.MAX:"vmware collector"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix proxy health by Zabbix agent active/process.vmware_collector.avg.busy,10m)<{$ZABBIX.PROXY.UTIL.MIN:"vmware collector"}'
              name: 'Zabbix proxy: Utilization of vmware collector processes is high'
              event_name: 'Zabbix proxy: Utilization of vmware collector processes over {$ZABBIX.PROXY.UTIL.MAX:"vmware collector"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the vmware collector, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 1ec67a7436c84892ac8eba71461a5cb3
          name: 'Proxy memory buffer, % used'
          type: DEPENDENT
          key: proxy_buffer.buffer.pused
          value_type: FLOAT
          units: '%'
          description: |
            Statistics and availability of Zabbix proxy memory buffer usage statistics. Percentage of used proxy memory buffer.
            Proxy memory buffer is used to store the new historical data and upload from it without accessing database.
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.wcache.[''proxy buffer''].memory.pused'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Proxy memory buffer is disabled.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 58582605c4644fffaabca8e403ae7529
              expression: 'max(/Zabbix proxy health by Zabbix agent active/proxy_buffer.buffer.pused,10m)>{$ZABBIX.PROXY.UTIL.MAX:"proxy buffer"}'
              name: 'Zabbix proxy: Excessive proxy memory buffer usage'
              event_name: 'Zabbix proxy: More than {$ZABBIX.PROXY.UTIL.MAX:"proxy buffer"}% used in the proxy memory buffer'
              priority: AVERAGE
              description: 'Consider increasing ProxyMemoryBufferSize in the zabbix_proxy.conf configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 30b187882593400aa4bf703b83ac48e9
          name: 'Proxy buffer, state changes'
          type: DEPENDENT
          key: proxy_buffer.state.changes
          description: 'The number of state changes between disk/memory buffer modes since proxy start.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.wcache.[''proxy buffer''].[''state change'']'
              error_handler: CUSTOM_VALUE
              error_handler_params: '0'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: ecbad291c31f4a94988256d78671e7fe
          name: 'Proxy buffer, state'
          type: DEPENDENT
          key: proxy_buffer.state.current
          description: |
            The current working state of proxy buffer where the new data is being stored. Possible values:
            
              0 - disk (also returned when memory buffer is disabled);
              1 - memory.
          valuemap:
            name: 'Proxy buffer mode'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.wcache.[''proxy buffer''].state'
              error_handler: CUSTOM_VALUE
              error_handler_params: '0'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: 96e28e7707a546df86283808245a259b
          name: 'Zabbix proxy check'
          type: DEPENDENT
          key: proxy_check
          trends: '0'
          description: 'Flag indicating whether it is a proxy or not.'
          valuemap:
            name: 'Zabbix proxy check'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.triggers
              error_handler: CUSTOM_VALUE
              error_handler_params: '0'
            - type: IN_RANGE
              parameters:
                - ''
                - '0'
              error_handler: CUSTOM_VALUE
              error_handler_params: '1'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 90d305b0cf7246c19aedc74b4c566148
              expression: 'last(/Zabbix proxy health by Zabbix agent active/proxy_check)=1'
              name: 'Zabbix proxy: Wrong template assigned'
              event_name: 'Zabbix proxy: Zabbix proxy template is assigned to Zabbix server'
              priority: DISASTER
              description: 'Check that the template has been selected correctly.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: 91dd05ad3bef4c14a988bd2f759eff59
          name: 'Configuration cache, % used'
          type: DEPENDENT
          key: rcache.buffer.pused
          value_type: FLOAT
          units: '%'
          description: 'The availability statistics of Zabbix configuration cache. The percentage of used data buffer.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.rcache.pused
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 280ce16d51a04a2c98574da85639df8a
              expression: 'max(/Zabbix proxy health by Zabbix agent active/rcache.buffer.pused,10m)>{$ZABBIX.PROXY.UTIL.MAX:"configuration cache"}'
              name: 'Zabbix proxy: Excessive configuration cache usage'
              event_name: 'Zabbix proxy: More than {$ZABBIX.PROXY.UTIL.MAX:"configuration cache"}% used in the configuration cache'
              priority: AVERAGE
              description: 'Consider increasing `CacheSize` in the `zabbix_proxy.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
            - uuid: 78ee655520bb495097142ba6b4ac30ab
              expression: 'nodata(/Zabbix proxy health by Zabbix agent active/rcache.buffer.pused,{$ZABBIX.PROXY.NODATA_TIMEOUT})=1'
              name: 'Zabbix proxy: Failed to fetch stats data'
              event_name: 'Zabbix proxy: Failed to fetch stats data (or no data for {$ZABBIX.PROXY.NODATA_TIMEOUT})'
              priority: WARNING
              description: 'Zabbix has not received statistics data for `{$ZABBIX.PROXY.NODATA_TIMEOUT}`.'
              tags:
                - tag: scope
                  value: availability
        - uuid: ac3a8cf2873a44669454c1fdd03145b3
          name: 'Required VPS'
          type: DEPENDENT
          key: requiredperformance
          value_type: FLOAT
          units: '!vps'
          description: 'The required performance of a proxy (the number of values that need to be collected per second).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.requiredperformance
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 12h
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: bb60426c6fa1471e80f6214fbb66c66a
          name: Uptime
          type: DEPENDENT
          key: uptime
          units: uptime
          description: 'Uptime of the Zabbix proxy process in seconds.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.uptime
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: f31a41c673c541e89fa0d4792506316a
              expression: 'last(/Zabbix proxy health by Zabbix agent active/uptime)<10m'
              name: 'Zabbix proxy: {HOST.NAME} has been restarted'
              event_name: 'Zabbix proxy: {HOST.NAME} has been restarted (uptime < 10m)'
              priority: INFO
              description: 'Uptime is less than 10 minutes.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: 0642b827f604424daf5429cccee0a3b7
          name: Version
          type: DEPENDENT
          key: version
          value_type: CHAR
          description: 'The version of Zabbix proxy.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.version
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 2e0d640f83e14fd1940d195bbb133ed8
              expression: 'last(/Zabbix proxy health by Zabbix agent active/version,#1)<>last(/Zabbix proxy health by Zabbix agent active/version,#2) and length(last(/Zabbix proxy health by Zabbix agent active/version))>0'
              name: 'Zabbix proxy: Version has changed'
              event_name: 'Zabbix proxy: Version has changed (new version: {ITEM.VALUE})'
              priority: INFO
              description: 'Zabbix proxy version has changed. Acknowledge to close the problem manually.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: 6bb9f2511eb446558b5a75842a7e5018
          name: 'VMware cache, % used'
          type: DEPENDENT
          key: vmware.buffer.pused
          value_type: FLOAT
          units: '%'
          description: 'The availability statistics of Zabbix vmware cache. The percentage of used data buffer.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.vmware.pused
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No vmware collector processes started'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: a0ed7fac6d7c4b1ea5e66e476dfdc9d1
              expression: 'max(/Zabbix proxy health by Zabbix agent active/vmware.buffer.pused,10m)>{$ZABBIX.PROXY.UTIL.MAX:"vmware cache"}'
              name: 'Zabbix proxy: Excessive vmware cache usage'
              event_name: 'Zabbix proxy: More than {$ZABBIX.PROXY.UTIL.MAX:"vmware cache"}% used in the vmware cache'
              priority: AVERAGE
              description: 'Consider increasing `VMwareCacheSize` in the `zabbix_proxy.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: f08835beb38c4b58ab337cb87f3ae56c
          name: 'History write cache, % used'
          type: DEPENDENT
          key: wcache.history.pused
          value_type: FLOAT
          units: '%'
          description: |
            The statistics and availability of Zabbix write cache. The percentage of used history buffer.
            The history cache is used to store item values. A high number indicates database performance problems.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.history.pused
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: eba5460898154090bb57db9b6f80aefb
              expression: 'max(/Zabbix proxy health by Zabbix agent active/wcache.history.pused,10m)>{$ZABBIX.PROXY.UTIL.MAX:"history cache"}'
              name: 'Zabbix proxy: Excessive history cache usage'
              event_name: 'Zabbix proxy: More than {$ZABBIX.PROXY.UTIL.MAX:"history cache"}% used in the history cache'
              priority: AVERAGE
              description: 'Consider increasing `HistoryCacheSize` in the `zabbix_proxy.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 5e78de0022cf4c69a727001fbe5dafd1
          name: 'History index cache, % used'
          type: DEPENDENT
          key: wcache.index.pused
          value_type: FLOAT
          units: '%'
          description: |
            The statistics and availability of Zabbix write cache. The percentage of used history index buffer.
            The history index cache is used to index values stored in the history cache.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.index.pused
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 0ed6244bfe5f405face0941e87c9233a
              expression: 'max(/Zabbix proxy health by Zabbix agent active/wcache.index.pused,10m)>{$ZABBIX.PROXY.UTIL.MAX:"index cache"}'
              name: 'Zabbix proxy: Excessive history index cache usage'
              event_name: 'Zabbix proxy: More than {$ZABBIX.PROXY.UTIL.MAX:"index cache"}% used in the history index cache'
              priority: AVERAGE
              description: 'Consider increasing `HistoryIndexCacheSize` in the `zabbix_proxy.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 6579ae03a0b34806adb0fb996a96fec8
          name: 'Number of processed values per second'
          type: DEPENDENT
          key: wcache.values
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The total number of values processed by Zabbix server or Zabbix proxy, except unsupported items.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.all
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: b7cc386e51754e3f889e7023d25e6c9a
          name: 'Number of processed numeric (float) values per second'
          type: DEPENDENT
          key: wcache.values.float
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed numeric (float) values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.float
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 3a1e8466b5e84178938530c41e83afb7
          name: 'Number of processed log values per second'
          type: DEPENDENT
          key: wcache.values.log
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed log values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.log
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 30f6e1cf5d88497194233967cdae1e9c
          name: 'Number of processed not supported values per second'
          type: DEPENDENT
          key: wcache.values.not_supported
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of times the item processing resulted in an item becoming unsupported or remaining in that state.
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.wcache.values[''not supported'']'
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 26f80a634144408d96d489971307effc
          name: 'Number of processed character values per second'
          type: DEPENDENT
          key: wcache.values.str
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed character values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.str
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 0784afdd396d4697be033476b49cd779
          name: 'Number of processed text values per second'
          type: DEPENDENT
          key: wcache.values.text
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed text values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.text
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 0f00c626c85742858dfd658e5823cfbf
          name: 'Number of processed numeric (unsigned) values per second'
          type: DEPENDENT
          key: wcache.values.uint
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed numeric (unsigned) values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.uint
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 38016356b0c2422baeaaf83add1c07dd
          name: 'Queue over 10 minutes'
          type: ZABBIX_ACTIVE
          key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT},queue,10m]'
          description: 'The number of monitored items in the queue that are delayed by at least 10 minutes.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.queue
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 1bdab54e366e423aa9320baeec90f57b
              expression: 'min(/Zabbix proxy health by Zabbix agent active/zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT},queue,10m],10m)>100'
              name: 'Zabbix proxy: More than 100 items have been missing data for over 10 minutes'
              priority: WARNING
              description: 'Indicates potential issues with network connectivity, agent failures, or unresponsive monitored resources that require attention.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 35c77ed090df4bb58f29a50db9584325
          name: Queue
          type: ZABBIX_ACTIVE
          key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT},queue]'
          description: 'The number of monitored items in the queue that are delayed by at least 6 seconds.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.queue
          tags:
            - tag: component
              value: system
        - uuid: ca89ec32d7ac45aba86a319cdb4f3b0d
          name: 'Zabbix stats'
          type: ZABBIX_ACTIVE
          key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT}]'
          history: '0'
          value_type: TEXT
          description: 'The master item of Zabbix proxy statistics.'
          tags:
            - tag: component
              value: raw
      tags:
        - tag: class
          value: software
        - tag: subclass
          value: logging
        - tag: subclass
          value: monitoring
        - tag: target
          value: proxy
        - tag: target
          value: zabbix
      macros:
        - macro: '{$ZABBIX.PROXY.ADDRESS}'
          description: 'IP/DNS of the remote Zabbix proxy (default is 127.0.0.1).'
          config:
            type: TEXT
            priority: '1'
            label: 'Zabbix proxy Address'
            description: 'IP or DNS of the remote Zabbix proxy that should be monitored via the Zabbix agent.'
            required: 'YES'
        - macro: '{$ZABBIX.PROXY.NODATA_TIMEOUT}'
          value: 5m
          description: 'The time threshold after which statistics are considered unavailable. Used in trigger expressions.'
          config:
            type: TEXT
            priority: '5'
            section_name: Thresholds
            label: 'Time since the last statistic was received'
            description: 'Threshold value of time since the last statistic was received from the remote proxy.'
        - macro: '{$ZABBIX.PROXY.PORT}'
          description: 'Port of the remote Zabbix proxy (default is 10051).'
          config:
            type: TEXT
            priority: '2'
            label: 'Zabbix proxy Port'
            description: 'Port of the remote Zabbix proxy that should be monitored via the Zabbix agent. In the range from 1 to 65535 inclusive.'
            required: 'YES'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$ZABBIX.PROXY.UTIL.MAX}'
          value: '75'
          description: 'Default maximum threshold for percentage utilization triggers (use macro context for specification).'
          config:
            type: TEXT
            priority: '4'
            section_name: Thresholds
            label: 'Maximum process utilization percentage'
            description: 'Default maximum threshold for process utilization triggers. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$ZABBIX.PROXY.UTIL.MIN}'
          value: '65'
          description: 'Default minimum threshold for percentage utilization triggers (use macro context for specification).'
          config:
            type: TEXT
            priority: '3'
            section_name: Thresholds
            label: 'Minimum process utilization percentage'
            description: 'Default minimum threshold for process utilization triggers. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
      dashboards:
        - uuid: df9b385da30a4a049516fdfb75d7d958
          name: 'Zabbix proxy health'
          auto_start: 'NO'
          pages:
            - name: Performance
              widgets:
                - type: svggraph
                  name: 'Cache usage, in %'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.1
                      value: e31a1c
                    - type: STRING
                      name: ds.0.color.2
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.3
                      value: b15928
                    - type: STRING
                      name: ds.0.color.4
                      value: a6cee3
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: rcache.buffer.pused
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: wcache.index.pused
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: wcache.history.pused
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: vmware.buffer.pused
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: proxy_buffer.buffer.pused
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACA
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Server performance'
                  'y': '6'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.1
                      value: e31a1c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: wcache.values
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: 'zabbix.stats[{$ZABBIX.PROXY.ADDRESS},{$ZABBIX.PROXY.PORT},queue]'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACC
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Values processed'
                  'y': '11'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.2
                      value: e31a1c
                    - type: STRING
                      name: ds.0.color.3
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.4
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.5
                      value: b15928
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: wcache.values.uint
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: wcache.values.float
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: wcache.values.not_supported
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: wcache.values.str
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: wcache.values.log
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: wcache.values.text
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACD
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Internal queues'
                  x: '36'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: ffff99
                    - type: STRING
                      name: ds.0.color.1
                      value: 6a3d9a
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: preprocessing_queue
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: discovery_queue
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACB
                    - type: INTEGER
                      name: show_problems
                      value: '1'
            - name: Processes
              widgets:
                - type: svggraph
                  name: 'Utilization: Discovery processes'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 7e57c2
                    - type: STRING
                      name: ds.0.color.1
                      value: 1f78b4
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.discovery_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.discovery_worker.avg.busy
                    - type: INTEGER
                      name: ds.1.axisy
                      value: '1'
                    - type: STRING
                      name: ds.1.color.0
                      value: ff465c
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: discovery_queue
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABH
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Synchronous gathering processes'
                  'y': '6'
                  width: '72'
                  height: '7'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.2
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.3
                      value: b15928
                    - type: STRING
                      name: ds.0.color.4
                      value: 17becf
                    - type: STRING
                      name: ds.0.color.5
                      value: a6cee3
                    - type: STRING
                      name: ds.0.color.6
                      value: fb9a99
                    - type: STRING
                      name: ds.0.color.7
                      value: bcbd22
                    - type: STRING
                      name: ds.0.color.8
                      value: fdbf6f
                    - type: STRING
                      name: ds.0.color.9
                      value: e31a1c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.internal_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.ipmi_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.ipmi_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.http_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.java_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.6
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.vmware_collector.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.7
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.browser_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.8
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.odbc_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.9
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.icmp_pinger.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABJ
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Asynchronous gathering processes'
                  'y': '13'
                  width: '72'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: bcbd22
                    - type: STRING
                      name: ds.0.color.2
                      value: 6a3d9a
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.agent_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.http_agent_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.snmp_poller.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABK
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Internal processes: Core'
                  'y': '19'
                  width: '72'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: e31a1c
                    - type: STRING
                      name: ds.0.color.2
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.3
                      value: b15928
                    - type: STRING
                      name: ds.0.color.4
                      value: a6cee3
                    - type: STRING
                      name: ds.0.color.5
                      value: fdbf6f
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.configuration_syncer.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.history_syncer.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.self-monitoring.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.task_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.data_sender.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.housekeeper.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '6'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABL
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Gathering processes: Trappers'
                  'y': '25'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: cab2d6
                    - type: STRING
                      name: ds.0.color.1
                      value: fdbf6f
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.trapper.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.snmp_trapper.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABM
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Data exchange with server'
                  'y': '30'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: cab2d6
                    - type: STRING
                      name: ds.0.color.1
                      value: '000080'
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.trapper.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.data_sender.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABO
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Preprocessing processes'
                  x: '36'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: fdbf6f
                    - type: STRING
                      name: ds.0.color.1
                      value: 7e57c2
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.preprocessing_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.preprocessing_worker.avg.busy
                    - type: INTEGER
                      name: ds.1.axisy
                      value: '1'
                    - type: STRING
                      name: ds.1.color.0
                      value: ff465c
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.1.fill
                      value: '2'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: preprocessing_queue
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABI
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Availability processes'
                  x: '36'
                  'y': '25'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.1
                      value: b15928
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.unreachable_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: process.availability_manager.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABN
                    - type: INTEGER
                      name: show_problems
                      value: '1'
            - name: Statuses
              widgets:
                - type: item
                  name: 'Zabbix proxy version'
                  width: '18'
                  height: '3'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: version
                    - type: INTEGER
                      name: show.0
                      value: '2'
                    - type: INTEGER
                      name: show.1
                      value: '3'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: time_h_pos
                      value: '2'
                    - type: INTEGER
                      name: time_size
                      value: '9'
                    - type: INTEGER
                      name: time_v_pos
                      value: '2'
                    - type: INTEGER
                      name: value_size
                      value: '25'
                - type: item
                  name: Uptime
                  x: '18'
                  width: '18'
                  height: '3'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: uptime
                    - type: INTEGER
                      name: show.0
                      value: '2'
                    - type: INTEGER
                      name: show.1
                      value: '3'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: time_h_pos
                      value: '2'
                    - type: INTEGER
                      name: time_size
                      value: '9'
                    - type: INTEGER
                      name: time_v_pos
                      value: '2'
                    - type: INTEGER
                      name: value_size
                      value: '25'
                - type: item
                  name: 'Proxy buffer state'
                  x: '36'
                  width: '18'
                  height: '3'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'Zabbix proxy health by Zabbix agent active'
                        key: proxy_buffer.state.current
                    - type: INTEGER
                      name: show.0
                      value: '2'
                    - type: INTEGER
                      name: show.1
                      value: '3'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: time_h_pos
                      value: '2'
                    - type: INTEGER
                      name: time_size
                      value: '9'
                    - type: INTEGER
                      name: time_v_pos
                      value: '2'
                    - type: INTEGER
                      name: value_size
                      value: '25'
      valuemaps:
        - uuid: 550df0eb013b4103ad00dc3cc478189d
          name: 'Proxy buffer mode'
          mappings:
            - value: '0'
              newvalue: Disk
            - value: '1'
              newvalue: Memory
        - uuid: c5cae9ab19384c9f85fe31f7e22ab8c7
          name: 'Zabbix proxy check'
          mappings:
            - value: '0'
              newvalue: 'True'
            - value: '1'
              newvalue: 'False'
    - uuid: e2d2b4e4ac28483996cc11fe42823d57
      template: 'Zabbix server health'
      name: 'Zabbix server health'
      description: |
        This template is designed to monitor internal Zabbix metrics on the local Zabbix server.
        
        Link this template to the local Zabbix server host.
        
        Generated by official Zabbix template tool "Templator"
      wizard_ready: 'YES'
      readme: |
        ## Overview
        
        This template is designed to monitor internal Zabbix metrics on the local Zabbix server.
        
        ## Setup
        
        Link this template to the local Zabbix server host.
      vendor:
        name: Zabbix
        version: 7.4-5
      groups:
        - name: Templates/Applications
      items:
        - uuid: f9d60d6dcbe14cd4aaec08aec6ca1856
          name: 'Zabbix stats cluster'
          type: INTERNAL
          key: 'zabbix[cluster,discovery,nodes]'
          history: '0'
          value_type: TEXT
          description: 'The master item of Zabbix cluster statistics.'
          tags:
            - tag: component
              value: raw
        - uuid: 1a185ce77d4e4dd49be5b9ded51c1460
          name: 'Connector queue'
          type: INTERNAL
          key: 'zabbix[connector_queue]'
          description: 'The count of values enqueued in the connector queue.'
          tags:
            - tag: component
              value: system
        - uuid: 8e02b4a9afbb4ae994f2210aac8aab83
          name: 'Discovery queue'
          type: INTERNAL
          key: 'zabbix[discovery_queue]'
          description: 'The count of values enqueued in the discovery queue.'
          tags:
            - tag: component
              value: system
        - uuid: d596a84dece14aa59ca53e9f53b21edb
          name: 'LLD queue'
          type: INTERNAL
          key: 'zabbix[lld_queue]'
          description: 'The number of values enqueued in the low-level discovery processing queue.'
          tags:
            - tag: component
              value: system
        - uuid: 5d253eac13394305a85d6c01a4a0774e
          name: 'Zabbix preprocessing'
          type: INTERNAL
          key: 'zabbix[preprocessing]'
          history: '0'
          value_type: TEXT
          description: 'The master item of Zabbix server''s preprocessing statistics.'
          tags:
            - tag: component
              value: raw
        - uuid: 97485f6c9efb443caa54b44c15fdbfeb
          name: 'Preprocessing queue'
          type: DEPENDENT
          key: 'zabbix[preprocessing_queue]'
          description: 'The number of values enqueued in the preprocessing queue.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.queue
          master_item:
            key: 'zabbix[preprocessing]'
          tags:
            - tag: component
              value: system
        - uuid: 4476af46c9114bec80cbc555cd81ee69
          name: 'Preprocessing throughput'
          type: DEPENDENT
          key: 'zabbix[preprocessing_throughput]'
          value_type: FLOAT
          units: Bps
          description: 'Reflects the throughput of the preprocessing.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.queued.size
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix[preprocessing]'
          tags:
            - tag: component
              value: system
        - uuid: 47f983079b064558976fb3cf5d50d742
          name: 'Utilization of agent poller data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,agent poller,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the agent poller processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 01c490b526144241930b908b64c92c97
              expression: 'avg(/Zabbix server health/zabbix[process,agent poller,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"agent poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,agent poller,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"agent poller"}'
              name: 'Zabbix server: Utilization of agent poller processes is high'
              event_name: 'Zabbix server: Utilization of agent poller processes over {$ZABBIX.SERVER.UTIL.MAX:"agent poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the agent poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: cac7bb12993945fe848df86f7c4502ed
          name: 'Utilization of alerter internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,alerter,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the alerter processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 20963ffd33864196ab909b60d7acdc0a
              expression: 'avg(/Zabbix server health/zabbix[process,alerter,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"alerter"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,alerter,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"alerter"}'
              name: 'Zabbix server: Utilization of alerter processes is high'
              event_name: 'Zabbix server: Utilization of alerter processes over {$ZABBIX.SERVER.UTIL.MAX:"alerter"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the alerter, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: d098ea71dd22428a8a8a42cf299699b7
          name: 'Utilization of alert manager internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,alert manager,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the alert manager processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: c7f8ac54e4d3409788b8a456046ee461
              expression: 'avg(/Zabbix server health/zabbix[process,alert manager,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"alert manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,alert manager,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"alert manager"}'
              name: 'Zabbix server: Utilization of alert manager processes is high'
              event_name: 'Zabbix server: Utilization of alert manager processes over {$ZABBIX.SERVER.UTIL.MAX:"alert manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the alert manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: eea69b4541844ebbbbf634594c14a8f2
          name: 'Utilization of alert syncer internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,alert syncer,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the alert syncer processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: e2a487335f2748a6b26d867290c9cfe4
              expression: 'avg(/Zabbix server health/zabbix[process,alert syncer,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"alert syncer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,alert syncer,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"alert syncer"}'
              name: 'Zabbix server: Utilization of alert syncer processes is high'
              event_name: 'Zabbix server: Utilization of alert syncer processes over {$ZABBIX.SERVER.UTIL.MAX:"alert syncer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the alert syncer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 8677812221994919a46f6cbba16ad447
          name: 'Utilization of availability manager internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,availability manager,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the availability manager processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 048c947b3b0a440b80ad6ebfc1a43f10
              expression: 'avg(/Zabbix server health/zabbix[process,availability manager,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"availability manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,availability manager,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"availability manager"}'
              name: 'Zabbix server: Utilization of availability manager processes is high'
              event_name: 'Zabbix server: Utilization of availability manager processes over {$ZABBIX.SERVER.UTIL.MAX:"availability manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the availability manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: dd20332db0c64a63a82378c1e8b2685c
          name: 'Utilization of browser poller data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,browser poller,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the browser poller processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: c260a09bb64c438bb4d3b720ecf51bc6
              expression: 'avg(/Zabbix server health/zabbix[process,browser poller,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"browser poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,browser poller,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"browser poller"}'
              name: 'Zabbix server: Utilization of browser poller processes is high'
              event_name: 'Zabbix server: Utilization of browser poller processes over {$ZABBIX.SERVER.UTIL.MAX:"browser poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the browser poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 301e7fe93a024444b19766e665e9d156
          name: 'Utilization of configuration syncer internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,configuration syncer,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the configuration syncer processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 63d681dba0b94487886a1d9b3360d1d1
              expression: 'avg(/Zabbix server health/zabbix[process,configuration syncer,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"configuration syncer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,configuration syncer,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"configuration syncer"}'
              name: 'Zabbix server: Utilization of configuration syncer processes is high'
              event_name: 'Zabbix server: Utilization of configuration syncer processes over {$ZABBIX.SERVER.UTIL.MAX:"configuration syncer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the configuration syncer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: dfb04028770e4e3e8a154304b82284ba
          name: 'Utilization of configuration syncer worker internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,configuration syncer worker,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the configuration syncer worker processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: c5fe6915d3a34e13b7a2fd1326e3781a
              expression: 'avg(/Zabbix server health/zabbix[process,configuration syncer worker,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"configuration syncer worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,configuration syncer worker,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"configuration syncer worker"}'
              name: 'Zabbix server: Utilization of configuration syncer worker processes is high'
              event_name: 'Zabbix server: Utilization of configuration syncer worker processes over {$ZABBIX.SERVER.UTIL.MAX:"configuration syncer worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the configuration syncer worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 2fcfd911ae8647149bad91c883abf41d
          name: 'Utilization of connector manager internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,connector manager,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the connector manager processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 5d72f9b951144e6797e19315b3a2da2b
              expression: 'avg(/Zabbix server health/zabbix[process,connector manager,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"connector manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,connector manager,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"connector manager"}'
              name: 'Zabbix server: Utilization of connector manager processes is high'
              event_name: 'Zabbix server: Utilization of connector manager processes over {$ZABBIX.SERVER.UTIL.MAX:"connector manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the connector manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 1c8c3b3045384a39af8baa9e40f2b487
          name: 'Utilization of connector worker internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,connector worker,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the connector worker processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: c6322f7a90d847b5a630bc9c64ce3c1b
              expression: 'avg(/Zabbix server health/zabbix[process,connector worker,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"connector worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,connector worker,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"connector worker"}'
              name: 'Zabbix server: Utilization of connector worker processes is high'
              event_name: 'Zabbix server: Utilization of connector worker processes over {$ZABBIX.SERVER.UTIL.MAX:"connector worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the connector worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 0a06a1b172c14e068cfc4ecee1511ffc
          name: 'Utilization of discovery manager internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,discovery manager,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the discovery manager processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 5af0558db3264b43981aafa8969ce433
              expression: 'avg(/Zabbix server health/zabbix[process,discovery manager,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"discovery manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,discovery manager,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"discovery manager"}'
              name: 'Zabbix server: Utilization of discovery manager processes is high'
              event_name: 'Zabbix server: Utilization of discovery manager processes over {$ZABBIX.SERVER.UTIL.MAX:"discovery manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the discovery manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: a88bad7225d3417da697220615252226
          name: 'Utilization of discovery worker internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,discovery worker,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the discovery worker processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 8dc524466ce04c0e97b613305fee0153
              expression: 'avg(/Zabbix server health/zabbix[process,discovery worker,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"discovery worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,discovery worker,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"discovery worker"}'
              name: 'Zabbix server: Utilization of discovery worker processes is high'
              event_name: 'Zabbix server: Utilization of discovery worker processes over {$ZABBIX.SERVER.UTIL.MAX:"discovery worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the discovery worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: d12ce718fad34644b92d98cf2096e7df
          name: 'Utilization of escalator internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,escalator,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the escalator processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 9895b4318f50487d9c7f25abd48bb1a1
              expression: 'avg(/Zabbix server health/zabbix[process,escalator,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"escalator"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,escalator,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"escalator"}'
              name: 'Zabbix server: Utilization of escalator processes is high'
              event_name: 'Zabbix server: Utilization of escalator processes over {$ZABBIX.SERVER.UTIL.MAX:"escalator"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the escalator, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 8de74bea977141469cf2d594bc907968
          name: 'Utilization of history poller internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,history poller,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the history poller processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 9a76cde4aaea4e8eb48f725e9653037b
              expression: 'avg(/Zabbix server health/zabbix[process,history poller,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"history poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,history poller,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"history poller"}'
              name: 'Zabbix server: Utilization of history poller processes is high'
              event_name: 'Zabbix server: Utilization of history poller processes over {$ZABBIX.SERVER.UTIL.MAX:"history poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the history poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 4d92eb7b411345cfbd6e2ea2ff5c1788
          name: 'Utilization of history syncer internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,history syncer,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the history syncer processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: a99ffd43a05e40f7abee83aa8c6c3ce5
              expression: 'avg(/Zabbix server health/zabbix[process,history syncer,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"history syncer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,history syncer,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"history syncer"}'
              name: 'Zabbix server: Utilization of history syncer processes is high'
              event_name: 'Zabbix server: Utilization of history syncer processes over {$ZABBIX.SERVER.UTIL.MAX:"history syncer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the history syncer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 23f448b5acba472881857647ca1bb614
          name: 'Utilization of housekeeper internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,housekeeper,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the housekeeper processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: faa349f84dc043658fe51294ad87f766
              expression: 'avg(/Zabbix server health/zabbix[process,housekeeper,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"housekeeper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,housekeeper,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"housekeeper"}'
              name: 'Zabbix server: Utilization of housekeeper processes is high'
              event_name: 'Zabbix server: Utilization of housekeeper processes over {$ZABBIX.SERVER.UTIL.MAX:"housekeeper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the housekeeper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 71934ae835034df5b9ce97eeb859b96b
          name: 'Utilization of http agent poller data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,http agent poller,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the http agent poller processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 3ba6561155df4cebb1111a6f229c483a
              expression: 'avg(/Zabbix server health/zabbix[process,http agent poller,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"http agent poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,http agent poller,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"http agent poller"}'
              name: 'Zabbix server: Utilization of http agent poller processes is high'
              event_name: 'Zabbix server: Utilization of http agent poller processes over {$ZABBIX.SERVER.UTIL.MAX:"http agent poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the http agent poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 419e937c4a1d4fa09c4b50ca88cbe3e2
          name: 'Utilization of http poller data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,http poller,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the http poller processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: c296c1ecdba44bd5b826ab4a86bbc300
              expression: 'avg(/Zabbix server health/zabbix[process,http poller,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"http poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,http poller,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"http poller"}'
              name: 'Zabbix server: Utilization of http poller processes is high'
              event_name: 'Zabbix server: Utilization of http poller processes over {$ZABBIX.SERVER.UTIL.MAX:"http poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the http poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: d5d469d5eb2e4e0ca0afc89b603d4065
          name: 'Utilization of icmp pinger data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,icmp pinger,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the icmp pinger processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: d5c6ea5711594a9587ab8d7094f1f481
              expression: 'avg(/Zabbix server health/zabbix[process,icmp pinger,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"icmp pinger"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,icmp pinger,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"icmp pinger"}'
              name: 'Zabbix server: Utilization of icmp pinger processes is high'
              event_name: 'Zabbix server: Utilization of icmp pinger processes over {$ZABBIX.SERVER.UTIL.MAX:"icmp pinger"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the icmp pinger, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 912dd7b55d244aa9bbc3af17ba168b13
          name: 'Utilization of internal poller data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,internal poller,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the internal poller processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 9bf9a345764740b79eb7e36398992593
              expression: 'avg(/Zabbix server health/zabbix[process,internal poller,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"internal poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,internal poller,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"internal poller"}'
              name: 'Zabbix server: Utilization of internal poller processes is high'
              event_name: 'Zabbix server: Utilization of internal poller processes over {$ZABBIX.SERVER.UTIL.MAX:"internal poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the internal poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 24b6b466929347f0a8164c89ba5624fe
          name: 'Utilization of ipmi manager internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,ipmi manager,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the ipmi manager processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 9ce0c874e5924b308827e8be5a9bf0eb
              expression: 'avg(/Zabbix server health/zabbix[process,ipmi manager,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"ipmi manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,ipmi manager,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"ipmi manager"}'
              name: 'Zabbix server: Utilization of ipmi manager processes is high'
              event_name: 'Zabbix server: Utilization of ipmi manager processes over {$ZABBIX.SERVER.UTIL.MAX:"ipmi manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the ipmi manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: c11d415de9c64fd6911f82d49db140d3
          name: 'Utilization of ipmi poller data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,ipmi poller,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the ipmi poller processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 5a4f841292fd4bb5bec2e28340c9e4c2
              expression: 'avg(/Zabbix server health/zabbix[process,ipmi poller,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"ipmi poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,ipmi poller,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"ipmi poller"}'
              name: 'Zabbix server: Utilization of ipmi poller processes is high'
              event_name: 'Zabbix server: Utilization of ipmi poller processes over {$ZABBIX.SERVER.UTIL.MAX:"ipmi poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the ipmi poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: a8168691df3d43f1a1e106062f18ee06
          name: 'Utilization of java poller data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,java poller,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the java poller processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: d7705ba9c3f74554ac21c59c9a0dcc11
              expression: 'avg(/Zabbix server health/zabbix[process,java poller,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"java poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,java poller,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"java poller"}'
              name: 'Zabbix server: Utilization of java poller processes is high'
              event_name: 'Zabbix server: Utilization of java poller processes over {$ZABBIX.SERVER.UTIL.MAX:"java poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the java poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 5e0ffccdaa51459c90d4868e61b1c6a8
          name: 'Utilization of LLD manager internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,lld manager,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the LLD manager processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 39109dabd9454844996864834292c0c4
              expression: 'avg(/Zabbix server health/zabbix[process,lld manager,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"LLD manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,lld manager,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"LLD manager"}'
              name: 'Zabbix server: Utilization of LLD manager processes is high'
              event_name: 'Zabbix server: Utilization of LLD manager processes over {$ZABBIX.SERVER.UTIL.MAX:"LLD manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the LLD manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 0b7b36eea80448ac8d11f7f30fb355da
          name: 'Utilization of LLD worker internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,lld worker,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the LLD worker processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 8eca01d6e0e64f5795d3a5b5e4aa593d
              expression: 'avg(/Zabbix server health/zabbix[process,lld worker,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"LLD worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,lld worker,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"LLD worker"}'
              name: 'Zabbix server: Utilization of LLD worker processes is high'
              event_name: 'Zabbix server: Utilization of LLD worker processes over {$ZABBIX.SERVER.UTIL.MAX:"LLD worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the LLD worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: f8d593ff5690419f8679a5b8303f3a66
          name: 'Utilization of ODBC poller data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,odbc poller,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the ODBC poller processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: f536b921e9444c6eb0ac805ab9302af9
              expression: 'avg(/Zabbix server health/zabbix[process,odbc poller,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"ODBC poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,odbc poller,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"ODBC poller"}'
              name: 'Zabbix server: Utilization of ODBC poller processes is high'
              event_name: 'Zabbix server: Utilization of ODBC poller processes over {$ZABBIX.SERVER.UTIL.MAX:"ODBC poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the ODBC poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: cbec202e15be49de93dc0c5f58824ae3
          name: 'Utilization of poller data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,poller,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the poller processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: bb50da4052134ef1a478bface291b50a
              expression: 'avg(/Zabbix server health/zabbix[process,poller,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,poller,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"poller"}'
              name: 'Zabbix server: Utilization of poller processes is high'
              event_name: 'Zabbix server: Utilization of poller processes over {$ZABBIX.SERVER.UTIL.MAX:"poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: fc7999dd8d2d41a5a80eeb4b6c4c9b13
          name: 'Utilization of preprocessing manager internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,preprocessing manager,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the preprocessing manager processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 6e7a117afa7e41e2a783f8afc42434fa
              expression: 'avg(/Zabbix server health/zabbix[process,preprocessing manager,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"preprocessing manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,preprocessing manager,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"preprocessing manager"}'
              name: 'Zabbix server: Utilization of preprocessing manager processes is high'
              event_name: 'Zabbix server: Utilization of preprocessing manager processes over {$ZABBIX.SERVER.UTIL.MAX:"preprocessing manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the preprocessing manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 6af695693d41434a96c0c6a020580828
          name: 'Utilization of preprocessing worker internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,preprocessing worker,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the preprocessing worker processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: e2cbdcc8b4844943a67d1f51587e599c
              expression: 'avg(/Zabbix server health/zabbix[process,preprocessing worker,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"preprocessing worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,preprocessing worker,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"preprocessing worker"}'
              name: 'Zabbix server: Utilization of preprocessing worker processes is high'
              event_name: 'Zabbix server: Utilization of preprocessing worker processes over {$ZABBIX.SERVER.UTIL.MAX:"preprocessing worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the preprocessing worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 306334d48ce6427d93ca8fbe292b8a11
          name: 'Utilization of proxy group manager internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,proxy group manager,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the proxy group manager processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 67db7f858e0348feb7cfe26f2afa1bd6
              expression: 'avg(/Zabbix server health/zabbix[process,proxy group manager,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"proxy group manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,proxy group manager,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"proxy group manager"}'
              name: 'Zabbix server: Utilization of proxy group manager processes is high'
              event_name: 'Zabbix server: Utilization of proxy group manager processes over {$ZABBIX.SERVER.UTIL.MAX:"proxy group manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the proxy group manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: baf22e095078435d978a6c4374500db4
          name: 'Utilization of proxy poller data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,proxy poller,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the proxy poller processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 6a884c1fbf254637bb74b68571ee2ffa
              expression: 'avg(/Zabbix server health/zabbix[process,proxy poller,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"proxy poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,proxy poller,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"proxy poller"}'
              name: 'Zabbix server: Utilization of proxy poller processes is high'
              event_name: 'Zabbix server: Utilization of proxy poller processes over {$ZABBIX.SERVER.UTIL.MAX:"proxy poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the proxy poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 3db38f5d250741fd833aec23e09bc52e
          name: 'Utilization of report manager internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,report manager,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the report manager processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 82f774b4a47247f49db1ab0480a69eae
              expression: 'avg(/Zabbix server health/zabbix[process,report manager,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"report manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,report manager,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"report manager"}'
              name: 'Zabbix server: Utilization of report manager processes is high'
              event_name: 'Zabbix server: Utilization of report manager processes over {$ZABBIX.SERVER.UTIL.MAX:"report manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the report manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 9c74858428cb4578b8a9095140b64d52
          name: 'Utilization of report writer internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,report writer,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the report writer processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 03158d902b854b3495aa76042f361bea
              expression: 'avg(/Zabbix server health/zabbix[process,report writer,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"report writer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,report writer,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"report writer"}'
              name: 'Zabbix server: Utilization of report writer processes is high'
              event_name: 'Zabbix server: Utilization of report writer processes over {$ZABBIX.SERVER.UTIL.MAX:"report writer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the report writer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 6fc9c055d4894c19b3b1075db106d995
          name: 'Utilization of self-monitoring internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,self-monitoring,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the self-monitoring processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: bf730ed3313f45248f483289c704f5e9
              expression: 'avg(/Zabbix server health/zabbix[process,self-monitoring,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"self-monitoring"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,self-monitoring,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"self-monitoring"}'
              name: 'Zabbix server: Utilization of self-monitoring processes is high'
              event_name: 'Zabbix server: Utilization of self-monitoring processes over {$ZABBIX.SERVER.UTIL.MAX:"self-monitoring"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the self-monitoring, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 4f6c2b59437c4345b348d78b5d2242db
          name: 'Utilization of service manager internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,service manager,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the service manager processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: c4cdbce205e843d6b882503961a15376
              expression: 'avg(/Zabbix server health/zabbix[process,service manager,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"service manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,service manager,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"service manager"}'
              name: 'Zabbix server: Utilization of service manager processes is high'
              event_name: 'Zabbix server: Utilization of service manager processes over {$ZABBIX.SERVER.UTIL.MAX:"service manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the service manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: aa5db45e74834355a80566316017d6d4
          name: 'Utilization of snmp poller data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,snmp poller,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the snmp poller processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 3fab1765b54b4036a03ca1fb69763e81
              expression: 'avg(/Zabbix server health/zabbix[process,snmp poller,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"snmp poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,snmp poller,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"snmp poller"}'
              name: 'Zabbix server: Utilization of snmp poller processes is high'
              event_name: 'Zabbix server: Utilization of snmp poller processes over {$ZABBIX.SERVER.UTIL.MAX:"snmp poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the snmp poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: cb9a7c4f3373496da97f3e0b8c978366
          name: 'Utilization of snmp trapper data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,snmp trapper,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the snmp trapper processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 821611786e5e49bf941cbca370d6ed6b
              expression: 'avg(/Zabbix server health/zabbix[process,snmp trapper,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"snmp trapper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,snmp trapper,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"snmp trapper"}'
              name: 'Zabbix server: Utilization of snmp trapper processes is high'
              event_name: 'Zabbix server: Utilization of snmp trapper processes over {$ZABBIX.SERVER.UTIL.MAX:"snmp trapper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the snmp trapper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: caeb7ecc88cc4c14bb80f901284be9a5
          name: 'Utilization of task manager internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,task manager,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the task manager processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 37c1c6ec07474a8a95b06c3c28e4bf96
              expression: 'avg(/Zabbix server health/zabbix[process,task manager,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"task manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,task manager,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"task manager"}'
              name: 'Zabbix server: Utilization of task manager processes is high'
              event_name: 'Zabbix server: Utilization of task manager processes over {$ZABBIX.SERVER.UTIL.MAX:"task manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the task manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 3af0ec03af6542e18aaff505e3806089
          name: 'Utilization of timer internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,timer,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the timer processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 0c7715df608f4736a7077ff2f6098adc
              expression: 'avg(/Zabbix server health/zabbix[process,timer,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"timer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,timer,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"timer"}'
              name: 'Zabbix server: Utilization of timer processes is high'
              event_name: 'Zabbix server: Utilization of timer processes over {$ZABBIX.SERVER.UTIL.MAX:"timer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the timer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 0dd727eddfaf45a9a819a9d64c5b72c7
          name: 'Utilization of trapper data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,trapper,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the trapper processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 197c04bbf5204ce7ac80630f2948b6b0
              expression: 'avg(/Zabbix server health/zabbix[process,trapper,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"trapper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,trapper,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"trapper"}'
              name: 'Zabbix server: Utilization of trapper processes is high'
              event_name: 'Zabbix server: Utilization of trapper processes over {$ZABBIX.SERVER.UTIL.MAX:"trapper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the trapper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: ad2199d0152d4deb8259699ebd1f3da5
          name: 'Utilization of trigger housekeeper internal processes, in %'
          type: INTERNAL
          key: 'zabbix[process,trigger housekeeper,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the trigger housekeeper processes have been busy for the last minute.'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 5ffa02f393d34c49bcb9eed2b2b89704
              expression: 'avg(/Zabbix server health/zabbix[process,trigger housekeeper,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"trigger housekeeper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,trigger housekeeper,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"trigger housekeeper"}'
              name: 'Zabbix server: Utilization of trigger housekeeper processes is high'
              event_name: 'Zabbix server: Utilization of trigger housekeeper processes over {$ZABBIX.SERVER.UTIL.MAX:"trigger housekeeper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the trigger housekeeper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 4fd24bdb8935435e8617c9607b9c6ca1
          name: 'Utilization of unreachable poller data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,unreachable poller,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the unreachable poller processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: b0168864ef6849f185deb6ef22a056fa
              expression: 'avg(/Zabbix server health/zabbix[process,unreachable poller,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"unreachable poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,unreachable poller,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"unreachable poller"}'
              name: 'Zabbix server: Utilization of unreachable poller processes is high'
              event_name: 'Zabbix server: Utilization of unreachable poller processes over {$ZABBIX.SERVER.UTIL.MAX:"unreachable poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the unreachable poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: bad00e43cd064a0fb3a4b65b71bea926
          name: 'Utilization of vmware collector data collector processes, in %'
          type: INTERNAL
          key: 'zabbix[process,vmware collector,avg,busy]'
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the vmware collector processes have been busy for the last minute.'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 7e0881bb1b384deba18439ae098a7fbd
              expression: 'avg(/Zabbix server health/zabbix[process,vmware collector,avg,busy],10m)>{$ZABBIX.SERVER.UTIL.MAX:"vmware collector"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health/zabbix[process,vmware collector,avg,busy],10m)<{$ZABBIX.SERVER.UTIL.MIN:"vmware collector"}'
              name: 'Zabbix server: Utilization of vmware collector processes is high'
              event_name: 'Zabbix server: Utilization of vmware collector processes over {$ZABBIX.SERVER.UTIL.MAX:"vmware collector"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the vmware collector, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 6fb9d6a8d3f84c679e7af4b9ef437239
          name: 'Zabbix proxies stats'
          type: INTERNAL
          key: 'zabbix[proxy,discovery]'
          history: '0'
          value_type: TEXT
          description: 'The master item of Zabbix proxies'' statistics.'
          tags:
            - tag: component
              value: raw
        - uuid: efba7193b9aa48c385e98c9babfaa689
          name: 'Zabbix proxy groups stats'
          type: INTERNAL
          key: 'zabbix[proxy group,discovery]'
          history: '0'
          value_type: TEXT
          description: 'The master item of Zabbix proxy groups'' statistics.'
          tags:
            - tag: component
              value: raw
        - uuid: 2b2f695ed1ef4a7a871c80df9c911e90
          name: 'Queue over 10 minutes'
          type: INTERNAL
          key: 'zabbix[queue,10m]'
          description: 'The number of monitored items in the queue that are delayed by at least 10 minutes.'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 53883a57e663421ca5fa794067a267b4
              expression: 'min(/Zabbix server health/zabbix[queue,10m],10m)>100'
              name: 'Zabbix server: More than 100 items have been missing data for over 10 minutes'
              priority: WARNING
              description: 'Indicates potential issues with network connectivity, agent failures, or unresponsive monitored resources that require attention.'
              tags:
                - tag: scope
                  value: performance
        - uuid: aaf58555c0774e848f51a351b6ae8462
          name: Queue
          type: INTERNAL
          key: 'zabbix[queue]'
          description: 'The number of monitored items in the queue that are delayed by at least 6 seconds.'
          tags:
            - tag: component
              value: system
        - uuid: ac2aebc15b084d049538b12e9513c08d
          name: 'Configuration cache, % used'
          type: INTERNAL
          key: 'zabbix[rcache,buffer,pused]'
          value_type: FLOAT
          units: '%'
          description: 'The availability statistics of Zabbix configuration cache. The percentage of used data buffer.'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 088a0e0ac64442a29de4d86f11c87438
              expression: 'max(/Zabbix server health/zabbix[rcache,buffer,pused],10m)>{$ZABBIX.SERVER.UTIL.MAX:"configuration cache"}'
              name: 'Zabbix server: Excessive configuration cache usage'
              event_name: 'Zabbix server: More than {$ZABBIX.SERVER.UTIL.MAX:"configuration cache"}% used in the configuration cache'
              priority: AVERAGE
              description: 'Consider increasing `CacheSize` in the `zabbix_server.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: b14a5ba6c93f4d6c9dfd820640d34e9b
          name: 'Trend function cache, % of unique requests'
          type: INTERNAL
          key: 'zabbix[tcache,cache,pitems]'
          value_type: FLOAT
          units: '%'
          description: |
            The effectiveness statistics of the Zabbix trend function cache. The percentage of cached items calculated from the sum of the cached items plus requests.
            A low percentage most likely means that the cache size can be reduced.
          tags:
            - tag: component
              value: system
        - uuid: 6db1280cb0134e81af8e070ae2356e7b
          name: 'Trend function cache, % of misses'
          type: INTERNAL
          key: 'zabbix[tcache,cache,pmisses]'
          value_type: FLOAT
          units: '%'
          description: 'The effectiveness statistics of the Zabbix trend function cache. The percentage of cache misses.'
          tags:
            - tag: component
              value: system
        - uuid: 9a2d6f239ea642b9b231801db68638b5
          name: 'Zabbix server check'
          type: INTERNAL
          key: 'zabbix[triggers]'
          trends: '0'
          description: 'Flag indicating whether it is a server or not.'
          valuemap:
            name: 'Zabbix server check'
          preprocessing:
            - type: CHECK_NOT_SUPPORTED
              parameters:
                - '-1'
              error_handler: CUSTOM_VALUE
              error_handler_params: '0'
            - type: IN_RANGE
              parameters:
                - ''
                - '0'
              error_handler: CUSTOM_VALUE
              error_handler_params: '1'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 3b0969d950ac4f9e878d0f7d72d83af2
              expression: 'last(/Zabbix server health/zabbix[triggers])=0'
              name: 'Zabbix server: Wrong template assigned'
              event_name: 'Zabbix server: Zabbix server template is assigned to Zabbix proxy'
              priority: DISASTER
              description: 'Check that the template has been selected correctly.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: 559ca5966e404c948f99cabf7a9077e8
          name: 'Value cache, % used'
          type: INTERNAL
          key: 'zabbix[vcache,buffer,pused]'
          value_type: FLOAT
          units: '%'
          description: 'The availability statistics of Zabbix value cache. The percentage of used data buffer.'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: cdca16919f6648ebbe6119e7c23a98c7
              expression: 'max(/Zabbix server health/zabbix[vcache,buffer,pused],10m)>{$ZABBIX.SERVER.UTIL.MAX:"value cache"}'
              name: 'Zabbix server: Excessive value cache usage'
              event_name: 'Zabbix server: More than {$ZABBIX.SERVER.UTIL.MAX:"value cache"}% used in the value cache'
              priority: AVERAGE
              description: 'Consider increasing `ValueCacheSize` in the `zabbix_server.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 69b14487a9744dbb866f2e6ee131d0e5
          name: 'Value cache hits'
          type: INTERNAL
          key: 'zabbix[vcache,cache,hits]'
          value_type: FLOAT
          units: '!vps'
          description: 'The effectiveness statistics of Zabbix value cache. The number of cache hits (history values taken from the cache).'
          preprocessing:
            - type: CHANGE_PER_SECOND
          tags:
            - tag: component
              value: system
        - uuid: c78439859fd248cdb15e1eee37be2220
          name: 'Value cache misses'
          type: INTERNAL
          key: 'zabbix[vcache,cache,misses]'
          value_type: FLOAT
          units: '!vps'
          description: 'The effectiveness statistics of Zabbix value cache. The number of cache misses (history values taken from the database).'
          preprocessing:
            - type: CHANGE_PER_SECOND
          tags:
            - tag: component
              value: system
        - uuid: 07379df0114445b7b06818736f011ca6
          name: 'Value cache operating mode'
          type: INTERNAL
          key: 'zabbix[vcache,cache,mode]'
          units: '!vps'
          description: 'The operating mode of the value cache.'
          valuemap:
            name: 'Value cache operating mode'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: ee3db7e7bc104f1598ca36e735bce53f
              expression: 'last(/Zabbix server health/zabbix[vcache,cache,mode])=1'
              name: 'Zabbix server: Zabbix value cache working in low-memory mode'
              priority: HIGH
              description: 'Once low-memory mode has been switched on, the value cache will remain in this state for 24 hours, even if the problem that triggered this mode is resolved sooner.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 140cf84640564a60bcd107bebf9ac2e3
          name: Version
          type: INTERNAL
          key: 'zabbix[version]'
          value_type: CHAR
          description: 'The version of Zabbix server.'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 456403a2063c4e2298f9e3f60a7a3180
              expression: 'last(/Zabbix server health/zabbix[version],#1)<>last(/Zabbix server health/zabbix[version],#2) and length(last(/Zabbix server health/zabbix[version]))>0'
              name: 'Zabbix server: Version has changed'
              event_name: 'Zabbix server: Version has changed (new version: {ITEM.VALUE})'
              priority: INFO
              description: 'Zabbix server version has changed. Acknowledge to close the problem manually.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: d273413004094604ad247c0ff9695879
          name: 'VMware cache, % used'
          type: INTERNAL
          key: 'zabbix[vmware,buffer,pused]'
          value_type: FLOAT
          units: '%'
          description: 'The availability statistics of Zabbix vmware cache. The percentage of used data buffer.'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 2df2ed6520c44ee880f35912f869583e
              expression: 'max(/Zabbix server health/zabbix[vmware,buffer,pused],10m)>{$ZABBIX.SERVER.UTIL.MAX:"vmware cache"}'
              name: 'Zabbix server: Excessive vmware cache usage'
              event_name: 'Zabbix server: More than {$ZABBIX.SERVER.UTIL.MAX:"vmware cache"}% used in the vmware cache'
              priority: AVERAGE
              description: 'Consider increasing `VMwareCacheSize` in the `zabbix_server.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 0f61de4dcc1b469a94dd024e1b932936
          name: 'Number of values synchronized with the database per second'
          type: INTERNAL
          key: 'zabbix[vps,written]'
          value_type: FLOAT
          units: '!vps'
          description: 'Average quantity of values written to the database, recalculated once per minute.'
          preprocessing:
            - type: CHANGE_PER_SECOND
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 1ae8253bb4da434da3ea6bcb0352115d
          name: 'History write cache, % used'
          type: INTERNAL
          key: 'zabbix[wcache,history,pused]'
          value_type: FLOAT
          units: '%'
          description: |
            The statistics and availability of Zabbix write cache. The percentage of used history buffer.
            The history cache is used to store item values. A high number indicates database performance problems.
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 5d63483588964e49b1f870dfb770bf04
              expression: 'max(/Zabbix server health/zabbix[wcache,history,pused],10m)>{$ZABBIX.SERVER.UTIL.MAX:"history cache"}'
              name: 'Zabbix server: Excessive history cache usage'
              event_name: 'Zabbix server: More than {$ZABBIX.SERVER.UTIL.MAX:"history cache"}% used in the history cache'
              priority: AVERAGE
              description: 'Consider increasing `HistoryCacheSize` in the `zabbix_server.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 9fc7faf5455e4e78bdb1406f947bfa08
          name: 'History index cache, % used'
          type: INTERNAL
          key: 'zabbix[wcache,index,pused]'
          value_type: FLOAT
          units: '%'
          description: |
            The statistics and availability of Zabbix write cache. The percentage of used history index buffer.
            The history index cache is used to index values stored in the history cache.
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 24245fbc55b743319162dd1edb37c5a0
              expression: 'max(/Zabbix server health/zabbix[wcache,index,pused],10m)>{$ZABBIX.SERVER.UTIL.MAX:"index cache"}'
              name: 'Zabbix server: Excessive history index cache usage'
              event_name: 'Zabbix server: More than {$ZABBIX.SERVER.UTIL.MAX:"index cache"}% used in the history index cache'
              priority: AVERAGE
              description: 'Consider increasing `HistoryIndexCacheSize` in the `zabbix_server.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 5cca0fc9878d4e068467d5a3b8558ed5
          name: 'Trend write cache, % used'
          type: INTERNAL
          key: 'zabbix[wcache,trend,pused]'
          value_type: FLOAT
          units: '%'
          description: |
            The statistics and availability of Zabbix write cache. The percentage of used trend buffer.
            The trend cache stores the aggregate of all items that have received data for the current hour.
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 34426156de6b4690918117a23ccc1138
              expression: 'max(/Zabbix server health/zabbix[wcache,trend,pused],10m)>{$ZABBIX.SERVER.UTIL.MAX:"trend cache"}'
              name: 'Zabbix server: Excessive trends cache usage'
              event_name: 'Zabbix server: More than {$ZABBIX.SERVER.UTIL.MAX:"trend cache"}% used in the trends cache'
              priority: AVERAGE
              description: 'Consider increasing `TrendCacheSize` in the `zabbix_server.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: de63f78f36e74361b6c9993d12d8b7c8
          name: 'Number of processed numeric (float) values per second'
          type: INTERNAL
          key: 'zabbix[wcache,values,float]'
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed numeric (float) values.
          preprocessing:
            - type: CHANGE_PER_SECOND
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: dae76dc6c4ce4707be7cf9534efc0233
          name: 'Number of processed log values per second'
          type: INTERNAL
          key: 'zabbix[wcache,values,log]'
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed log values.
          preprocessing:
            - type: CHANGE_PER_SECOND
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: c99a99cf7e1e44918736ab860694d3a4
          name: 'Number of processed not supported values per second'
          type: INTERNAL
          key: 'zabbix[wcache,values,not supported]'
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of times the item processing resulted in an item becoming unsupported or remaining in that state.
          preprocessing:
            - type: CHANGE_PER_SECOND
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: b58fdd85cd6a48489d0b983ee8ebe97b
          name: 'Number of processed character values per second'
          type: INTERNAL
          key: 'zabbix[wcache,values,str]'
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed character values.
          preprocessing:
            - type: CHANGE_PER_SECOND
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 5397d6d4dedc44c29ff25b8fd5611003
          name: 'Number of processed text values per second'
          type: INTERNAL
          key: 'zabbix[wcache,values,text]'
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed text values.
          preprocessing:
            - type: CHANGE_PER_SECOND
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 47132a8565c943c0abbd4918d6af9339
          name: 'Number of processed numeric (unsigned) values per second'
          type: INTERNAL
          key: 'zabbix[wcache,values,uint]'
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed numeric (unsigned) values.
          preprocessing:
            - type: CHANGE_PER_SECOND
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: db364af6bcb24881850f3979933fccb0
          name: 'Number of processed values per second'
          type: INTERNAL
          key: 'zabbix[wcache,values]'
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The total number of values processed by Zabbix server or Zabbix proxy, except unsupported items.
          preprocessing:
            - type: CHANGE_PER_SECOND
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
      discovery_rules:
        - uuid: 32bf5c3b8f1f4d10b26806ae0d2adb25
          name: 'High availability cluster node discovery'
          type: DEPENDENT
          key: zabbix.nodes.discovery
          description: 'LLD rule with item and trigger prototypes for node discovery.'
          item_prototypes:
            - uuid: c5cb7ffbd314494cb1801ae804e9c76e
              name: 'Cluster node [{#NODE.NAME}]: Address'
              type: DEPENDENT
              key: 'zabbix.node.address[{#NODE.ID}]'
              value_type: CHAR
              description: 'The IPv4 address of a node.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.address
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.node.stats[{#NODE.ID}]'
              tags:
                - tag: component
                  value: cluster
                - tag: node-id
                  value: '{#NODE.ID}'
                - tag: node-name
                  value: '{#NODE.NAME}'
            - uuid: f444de7cdd7a4f3bb7f4b1f2e86e16d7
              name: 'Cluster node [{#NODE.NAME}]: Last access age'
              type: DEPENDENT
              key: 'zabbix.node.lastaccess.age[{#NODE.ID}]'
              units: uptime
              description: 'The time between the database''s `unix_timestamp()` and the last access time.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.lastaccess_age
              master_item:
                key: 'zabbix.node.stats[{#NODE.ID}]'
              tags:
                - tag: component
                  value: cluster
                - tag: node-id
                  value: '{#NODE.ID}'
                - tag: node-name
                  value: '{#NODE.NAME}'
            - uuid: 2e33f747803b45d7a9b94c171bf36f61
              name: 'Cluster node [{#NODE.NAME}]: Last access time'
              type: DEPENDENT
              key: 'zabbix.node.lastaccess.time[{#NODE.ID}]'
              units: unixtime
              description: 'Last access time.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.lastaccess
              master_item:
                key: 'zabbix.node.stats[{#NODE.ID}]'
              tags:
                - tag: component
                  value: cluster
                - tag: node-id
                  value: '{#NODE.ID}'
                - tag: node-name
                  value: '{#NODE.NAME}'
            - uuid: 4cf654a5bbb74ad69847b4ff15d0b623
              name: 'Cluster node [{#NODE.NAME}]: Stats'
              type: DEPENDENT
              key: 'zabbix.node.stats[{#NODE.ID}]'
              history: '0'
              value_type: TEXT
              description: 'Provides the statistics of a node.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[?(@.id=="{#NODE.ID}")].first()'
              master_item:
                key: 'zabbix[cluster,discovery,nodes]'
              tags:
                - tag: component
                  value: cluster
                - tag: component
                  value: raw
                - tag: node-id
                  value: '{#NODE.ID}'
                - tag: node-name
                  value: '{#NODE.NAME}'
            - uuid: 1e4de6a913764a22862c0265d329b592
              name: 'Cluster node [{#NODE.NAME}]: Status'
              type: DEPENDENT
              key: 'zabbix.node.status[{#NODE.ID}]'
              description: 'The status of a node.'
              valuemap:
                name: 'Cluster node status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.node.stats[{#NODE.ID}]'
              tags:
                - tag: component
                  value: cluster
                - tag: node-id
                  value: '{#NODE.ID}'
                - tag: node-name
                  value: '{#NODE.NAME}'
              trigger_prototypes:
                - uuid: 8d48978fb5724d19a950aa6eb8a3dd75
                  expression: 'last(/Zabbix server health/zabbix.node.status[{#NODE.ID}],#1)<>last(/Zabbix server health/zabbix.node.status[{#NODE.ID}],#2)'
                  name: 'Zabbix server: Cluster node [{#NODE.NAME}]: Status changed'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: INFO
                  description: 'The state of the node has changed. Acknowledge to close the problem manually.'
                  manual_close: 'YES'
                  tags:
                    - tag: scope
                      value: availability
          master_item:
            key: 'zabbix[cluster,discovery,nodes]'
          lld_macro_paths:
            - lld_macro: '{#NODE.ID}'
              path: $.id
            - lld_macro: '{#NODE.NAME}'
              path: $.name
          preprocessing:
            - type: JAVASCRIPT
              parameters:
                - |
                  var hacluster = JSON.parse(value);
                  
                  result = hacluster.map(function (hanode) {
                  	return {
                  		'id': hanode.id,
                  		'name': hanode.name
                  	};
                  });
                  
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
        - uuid: d6e3db2614914c1b977c7eb1b748bda6
          name: 'Zabbix proxy discovery'
          type: DEPENDENT
          key: zabbix.proxy.discovery
          description: 'LLD rule with item and trigger prototypes for proxy discovery.'
          item_prototypes:
            - uuid: 5cf1d8eae42740c88e2700ec619fc0e7
              name: 'Proxy [{#PROXY.NAME}]: Certificate'
              type: DEPENDENT
              key: 'zabbix.proxy.cert[{#PROXY.NAME}]'
              description: 'The encryption status for connections from a proxy.'
              valuemap:
                name: 'Service state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.cert
                - type: JAVASCRIPT
                  parameters:
                    - 'return value === ''false'' ? 0 : 1'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 38498bb9fc884b2082ff5ecf76cc401e
              name: 'Proxy [{#PROXY.NAME}]: Compatibility'
              type: DEPENDENT
              key: 'zabbix.proxy.compatibility[{#PROXY.NAME}]'
              description: |
                Version of proxy compared to Zabbix server version.
                
                Possible values:
                0 - Undefined;
                1 - Current version (proxy and server have the same major version);
                2 - Outdated version (proxy version is older than server version, but is partially supported);
                3 - Unsupported version (proxy version is older than server previous LTS release version or server major version is older than proxy major version).
              valuemap:
                name: Compatibility
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.compatibility
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
              trigger_prototypes:
                - uuid: d3b969b57fc74a2e96b8cf90f3159847
                  expression: 'last(/Zabbix server health/zabbix.proxy.compatibility[{#PROXY.NAME}],#1)=3'
                  name: 'Zabbix server: Proxy [{#PROXY.NAME}]: Zabbix proxy is not supported'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: HIGH
                  description: 'Zabbix proxy version is older than server previous LTS release version or server major version is older than proxy major version.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 519cd429ab184d9ba08a50968dc3e1e6
                  expression: 'last(/Zabbix server health/zabbix.proxy.compatibility[{#PROXY.NAME}],#1)=2'
                  name: 'Zabbix server: Proxy [{#PROXY.NAME}]: Zabbix proxy is outdated'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: WARNING
                  description: 'Zabbix proxy version is older than server version, but is partially supported. Only data collection and remote execution is available.'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: 5983273711b64a93bd30c7ba983f2b35
              name: 'Proxy [{#PROXY.NAME}]: Compression'
              type: DEPENDENT
              key: 'zabbix.proxy.compression[{#PROXY.NAME}]'
              description: 'The compression status of a proxy.'
              valuemap:
                name: 'Service state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.compression
                - type: JAVASCRIPT
                  parameters:
                    - 'return value === ''false'' ? 0 : 1'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 01c4a2f48dce46e0a931fc7ab906800d
              name: 'Proxy [{#PROXY.NAME}]: Host count'
              type: DEPENDENT
              key: 'zabbix.proxy.hosts[{#PROXY.NAME}]'
              description: 'The number of enabled hosts assigned to a proxy.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.hosts
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 187a005cd52c4ed69919b0356c1ccd39
              name: 'Proxy [{#PROXY.NAME}]: Item count'
              type: DEPENDENT
              key: 'zabbix.proxy.items[{#PROXY.NAME}]'
              description: 'The number of enabled items on enabled hosts assigned to a proxy.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.items
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: f8c915861df843bc9c95ec8034d66fb7
              name: 'Proxy [{#PROXY.NAME}]: Last seen, in seconds'
              type: DEPENDENT
              key: 'zabbix.proxy.last_seen[{#PROXY.NAME}]'
              value_type: FLOAT
              description: 'The time when a proxy was last seen by a server.'
              valuemap:
                name: 'Last seen'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.last_seen
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
              trigger_prototypes:
                - uuid: ee5eb0e4962b4bb59ac316a4110c86e3
                  expression: 'last(/Zabbix server health/zabbix.proxy.last_seen[{#PROXY.NAME}],#1)>{$ZABBIX.PROXY.LAST_SEEN.MAX}'
                  name: 'Zabbix server: Proxy [{#PROXY.NAME}]: Zabbix proxy last seen'
                  event_name: 'Zabbix server: Proxy [{#PROXY.NAME}]: Zabbix proxy last seen more than {$ZABBIX.PROXY.LAST_SEEN.MAX} seconds ago'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: WARNING
                  description: 'Zabbix proxy is not updating the configuration data.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 541732183fa747d6b7a05351172720bc
                  expression: 'last(/Zabbix server health/zabbix.proxy.last_seen[{#PROXY.NAME}],#1)=-1'
                  name: 'Zabbix server: Proxy [{#PROXY.NAME}]: Zabbix proxy never seen'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: WARNING
                  description: 'Zabbix proxy is not updating the configuration data.'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: 357461ce5cd24632a1359c8ab31e0422
              name: 'Proxy [{#PROXY.NAME}]: Mode'
              type: DEPENDENT
              key: 'zabbix.proxy.mode[{#PROXY.NAME}]'
              description: 'The mode of Zabbix proxy.'
              valuemap:
                name: 'Proxy mode'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.passive
                - type: JAVASCRIPT
                  parameters:
                    - 'return value === ''false'' ? 0 : 1'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: a68564ff50284903bdc38432638a653b
              name: 'Proxy [{#PROXY.NAME}]: PSK'
              type: DEPENDENT
              key: 'zabbix.proxy.psk[{#PROXY.NAME}]'
              description: 'The encryption status for connections from a proxy.'
              valuemap:
                name: 'Service state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.psk
                - type: JAVASCRIPT
                  parameters:
                    - 'return value === ''false'' ? 0 : 1'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 3e45db48df464b91a4951f13dd298cd5
              name: 'Proxy [{#PROXY.NAME}]: Required VPS'
              type: DEPENDENT
              key: 'zabbix.proxy.requiredperformance[{#PROXY.NAME}]'
              value_type: FLOAT
              units: '!vps'
              description: 'The required performance of a proxy (the number of values that need to be collected per second).'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.requiredperformance
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 76b3dc42b38b4f4a9d6979a64e8f6a4b
              name: 'Proxy [{#PROXY.NAME}]: Stats'
              type: DEPENDENT
              key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              history: '0'
              value_type: TEXT
              description: 'The statistics for the discovered proxy.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[?(@.name=="{#PROXY.NAME}")].first()'
              master_item:
                key: 'zabbix[proxy,discovery]'
              tags:
                - tag: component
                  value: proxy
                - tag: component
                  value: raw
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 8986a7d452c448de88dcb054541064e4
              name: 'Proxy [{#PROXY.NAME}]: Unencrypted'
              type: DEPENDENT
              key: 'zabbix.proxy.unencrypted[{#PROXY.NAME}]'
              description: 'The encryption status for connections from a proxy.'
              valuemap:
                name: 'Service state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.unencrypted
                - type: JAVASCRIPT
                  parameters:
                    - 'return value === ''false'' ? 0 : 1'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 22da7ee85c044e128ceb47225ce7aaba
              name: 'Proxy [{#PROXY.NAME}]: Version'
              type: DEPENDENT
              key: 'zabbix.proxy.version[{#PROXY.NAME}]'
              value_type: CHAR
              description: 'A version of Zabbix proxy.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.version
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
          master_item:
            key: 'zabbix[proxy,discovery]'
          lld_macro_paths:
            - lld_macro: '{#PROXY.GROUP}'
              path: $.proxy_group
            - lld_macro: '{#PROXY.NAME}'
              path: $.name
          preprocessing:
            - type: JAVASCRIPT
              parameters:
                - |
                  var proxies = JSON.parse(value);
                  
                  result = proxies.map(function (proxy) {
                  	return {
                  		'name': proxy.name,
                  		'proxy_group': proxy.proxy_group
                  	};
                  });
                  
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
          overrides:
            - name: 'Tag proxy-group if exists'
              step: '1'
              filter:
                conditions:
                  - macro: '{#PROXY.GROUP}'
                    operator: EXISTS
              operations:
                - operator: REGEXP
                  tags:
                    - tag: proxy-group
                      value: '{#PROXY.GROUP}'
        - uuid: 60eaeee3a90542aeae9762d36c804cce
          name: 'Zabbix proxy groups discovery'
          type: DEPENDENT
          key: zabbix.proxy.groups.discovery
          filter:
            evaltype: AND
            conditions:
              - macro: '{#PROXY.GROUP.NAME}'
                value: '{$PROXY.GROUP.DISCOVERY.NAME.MATCHES}'
              - macro: '{#PROXY.GROUP.NAME}'
                value: '{$PROXY.GROUP.DISCOVERY.NAME.NOT_MATCHES}'
                operator: NOT_MATCHES_REGEX
          description: 'LLD rule with item and trigger prototypes for proxy groups discovery.'
          item_prototypes:
            - uuid: f48cf3314ff6460596468e7e6b8525de
              name: 'Proxy group [{#PROXY.GROUP.NAME}]: Available proxies, in %'
              type: DEPENDENT
              key: 'zabbix.proxy.group.avail.proxies.percent[{#PROXY.GROUP.NAME}]'
              units: '%'
              description: 'Percentage of available proxies in the Zabbix proxy group.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.pavailable
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.group.stats[{#PROXY.GROUP.NAME}]'
              tags:
                - tag: component
                  value: proxy-group
                - tag: proxy-group-name
                  value: '{#PROXY.GROUP.NAME}'
              trigger_prototypes:
                - uuid: bbbaf1aaa1a64e57bad2ec53cc0e96f6
                  expression: 'max(/Zabbix server health/zabbix.proxy.group.avail.proxies.percent[{#PROXY.GROUP.NAME}],3m)<{$PROXY.GROUP.AVAIL.PERCENT.MIN}'
                  name: 'Zabbix server: Proxy group [{#PROXY.GROUP.NAME}]: Availability too low'
                  event_name: 'Zabbix server: Proxy group [{#PROXY.GROUP.NAME}]: Availability below {$PROXY.GROUP.AVAIL.PERCENT.MIN}%'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: WARNING
                  description: 'The availability of proxies in a proxy group is below {$PROXY.GROUP.AVAIL.PERCENT.MIN}% for at least 3 minutes.'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: 848a42e7022f4cfab65044e710859f80
              name: 'Proxy group [{#PROXY.GROUP.NAME}]: Available proxies'
              type: DEPENDENT
              key: 'zabbix.proxy.group.avail.proxies[{#PROXY.GROUP.NAME}]'
              description: 'Count of available proxies in the Zabbix proxy group.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.available
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.group.stats[{#PROXY.GROUP.NAME}]'
              tags:
                - tag: component
                  value: proxy-group
                - tag: proxy-group-name
                  value: '{#PROXY.GROUP.NAME}'
            - uuid: 7fa43a19cb4a448bbf7b1bc3ddf17594
              name: 'Proxy group [{#PROXY.GROUP.NAME}]: Failover period'
              type: DEPENDENT
              key: 'zabbix.proxy.group.failover[{#PROXY.GROUP.NAME}]'
              value_type: FLOAT
              units: s
              description: 'Failover period in the Zabbix proxy group.'
              valuemap:
                name: 'Proxy group invalid value'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.failover_delay
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.group.settings[{#PROXY.GROUP.NAME}]'
              tags:
                - tag: component
                  value: proxy-group
                - tag: proxy-group-name
                  value: '{#PROXY.GROUP.NAME}'
              trigger_prototypes:
                - uuid: 9d38306e2e1741eba5a910ccf380c484
                  expression: 'last(/Zabbix server health/zabbix.proxy.group.failover[{#PROXY.GROUP.NAME}],#1)=-1'
                  name: 'Zabbix server: Proxy group [{#PROXY.GROUP.NAME}]: Failover invalid value'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: WARNING
                  description: 'Proxy group failover has an invalid value.'
                  tags:
                    - tag: scope
                      value: notice
            - uuid: 150df878b45d4a259131f8bdf9e89fc1
              name: 'Proxy group [{#PROXY.GROUP.NAME}]: Minimum number of proxies'
              type: DEPENDENT
              key: 'zabbix.proxy.group.online.min[{#PROXY.GROUP.NAME}]'
              value_type: FLOAT
              description: 'Minimum number of proxies online in the Zabbix proxy group.'
              valuemap:
                name: 'Proxy group invalid value'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.min_online
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.group.settings[{#PROXY.GROUP.NAME}]'
              tags:
                - tag: component
                  value: proxy-group
                - tag: proxy-group-name
                  value: '{#PROXY.GROUP.NAME}'
              trigger_prototypes:
                - uuid: ba1aa13dc8204c76be4fa85a6411de4d
                  expression: 'last(/Zabbix server health/zabbix.proxy.group.online.min[{#PROXY.GROUP.NAME}],#1)=-1'
                  name: 'Zabbix server: Proxy group [{#PROXY.GROUP.NAME}]: Minimum number of proxies invalid value'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: WARNING
                  description: 'Proxy group minimum number of proxies has an invalid value.'
                  tags:
                    - tag: scope
                      value: notice
            - uuid: b493eccc24ea4343ae3caf0651d46b6c
              name: 'Proxy group [{#PROXY.GROUP.NAME}]: Settings'
              type: DEPENDENT
              key: 'zabbix.proxy.group.settings[{#PROXY.GROUP.NAME}]'
              history: '0'
              value_type: TEXT
              description: 'The settings for the discovered proxy group.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.data[?(@.name=="{#PROXY.GROUP.NAME}")].first()'
              master_item:
                key: 'zabbix[proxy group,discovery]'
              tags:
                - tag: component
                  value: proxy-group
                - tag: component
                  value: raw
                - tag: proxy-group-name
                  value: '{#PROXY.GROUP.NAME}'
            - uuid: 8a2d84926a4b4e9a810dfac576dd8451
              name: 'Proxy group [{#PROXY.GROUP.NAME}]: State'
              type: DEPENDENT
              key: 'zabbix.proxy.group.state[{#PROXY.GROUP.NAME}]'
              description: |
                State of the Zabbix proxy group.
                
                Possible values:
                0 - unknown;
                1 - offline;
                2 - recovering;
                3 - online;
                4 - degrading.
              valuemap:
                name: 'Proxy group state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.state
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.group.stats[{#PROXY.GROUP.NAME}]'
              tags:
                - tag: component
                  value: proxy-group
                - tag: proxy-group-name
                  value: '{#PROXY.GROUP.NAME}'
              trigger_prototypes:
                - uuid: 770cb8447a26472c9d825c874fccc030
                  expression: 'last(/Zabbix server health/zabbix.proxy.group.state[{#PROXY.GROUP.NAME}],#1)=4'
                  name: 'Zabbix server: Proxy group [{#PROXY.GROUP.NAME}]: Status "degrading"'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: AVERAGE
                  description: 'The state of the Zabbix proxy group is "degrading".'
                  dependencies:
                    - name: 'Zabbix server: Proxy group [{#PROXY.GROUP.NAME}]: Status "offline"'
                      expression: 'last(/Zabbix server health/zabbix.proxy.group.state[{#PROXY.GROUP.NAME}],#1)=1'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: ecd98a89c19045dea28c2c635f3b5db9
                  expression: 'last(/Zabbix server health/zabbix.proxy.group.state[{#PROXY.GROUP.NAME}],#1)=1'
                  name: 'Zabbix server: Proxy group [{#PROXY.GROUP.NAME}]: Status "offline"'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: HIGH
                  description: 'The state of the Zabbix proxy group is "offline".'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: e0c6041d678b46df8f633bda8ab24a1a
                  expression: 'last(/Zabbix server health/zabbix.proxy.group.state[{#PROXY.GROUP.NAME}],#1)<>last(/Zabbix server health/zabbix.proxy.group.state[{#PROXY.GROUP.NAME}],#2) and length(last(/Zabbix server health/zabbix.proxy.group.state[{#PROXY.GROUP.NAME}]))>0'
                  name: 'Zabbix server: Proxy group [{#PROXY.GROUP.NAME}]: Status changed'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: INFO
                  description: 'The state of the Zabbix proxy group has changed. Acknowledge to close the problem manually.'
                  manual_close: 'YES'
                  dependencies:
                    - name: 'Zabbix server: Proxy group [{#PROXY.GROUP.NAME}]: Status "degrading"'
                      expression: 'last(/Zabbix server health/zabbix.proxy.group.state[{#PROXY.GROUP.NAME}],#1)=4'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: aab08b95d317451089604077e6d8543c
              name: 'Proxy group [{#PROXY.GROUP.NAME}]: Stats'
              type: DEPENDENT
              key: 'zabbix.proxy.group.stats[{#PROXY.GROUP.NAME}]'
              history: '0'
              value_type: TEXT
              description: 'The statistics for the discovered proxy group.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.rtdata["{#PROXY.GROUP.NAME}"]'
              master_item:
                key: 'zabbix[proxy group,discovery]'
              tags:
                - tag: component
                  value: proxy-group
                - tag: component
                  value: raw
                - tag: proxy-group-name
                  value: '{#PROXY.GROUP.NAME}'
          master_item:
            key: 'zabbix[proxy group,discovery]'
          lld_macro_paths:
            - lld_macro: '{#PROXY.GROUP.NAME}'
              path: $.name
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
      tags:
        - tag: class
          value: software
        - tag: subclass
          value: logging
        - tag: subclass
          value: monitoring
        - tag: target
          value: server
        - tag: target
          value: zabbix
      macros:
        - macro: '{$PROXY.GROUP.AVAIL.PERCENT.MIN}'
          value: '75'
          description: 'Minimum threshold for the proxy group availability percentage triggers.'
          config:
            type: TEXT
            priority: '4'
            section_name: Thresholds
            label: 'Proxy group availability percentage'
            description: 'Threshold for the proxy group availability percentage triggers. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$PROXY.GROUP.DISCOVERY.NAME.MATCHES}'
          value: '.*'
          description: 'Filter to include discovered proxy groups by their name.'
          config:
            type: TEXT
            priority: '6'
            section_name: Filters
            label: 'Include proxy group name filter'
            description: 'Filter to include discovered proxy groups by their name.'
        - macro: '{$PROXY.GROUP.DISCOVERY.NAME.NOT_MATCHES}'
          value: CHANGE_IF_NEEDED
          description: 'Filter to exclude discovered proxy groups by their name.'
          config:
            type: TEXT
            priority: '7'
            section_name: Filters
            label: 'Exclude proxy group name filter'
            description: 'Filter to exclude discovered proxy groups by their name.'
        - macro: '{$ZABBIX.PROXY.LAST_SEEN.MAX}'
          value: '600'
          description: 'The maximum number of seconds that Zabbix proxy has not been seen.'
          config:
            type: TEXT
            priority: '5'
            section_name: Thresholds
            label: 'Seconds since the last Zabbix proxy seen'
            description: 'Threshold value of time since the last Zabbix proxy seen for triggers. No less than 0.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$ZABBIX.SERVER.UTIL.MAX}'
          value: '75'
          description: 'Default maximum threshold for percentage utilization triggers (use macro context for specification).'
          config:
            type: TEXT
            priority: '2'
            section_name: Thresholds
            label: 'Maximum process utilization percentage'
            description: 'Default maximum threshold for process utilization triggers. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$ZABBIX.SERVER.UTIL.MAX:"value cache"}'
          value: '95'
          description: 'Default minimum threshold for the value cache utilization trigger.'
          config:
            type: TEXT
            priority: '3'
            section_name: Thresholds
            label: 'Maximum value cache utilization percentage'
            description: 'Threshold for the value cache utilization trigger. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$ZABBIX.SERVER.UTIL.MIN}'
          value: '65'
          description: 'Default minimum threshold for percentage utilization triggers (use macro context for specification).'
          config:
            type: TEXT
            priority: '1'
            section_name: Thresholds
            label: 'Minimum process utilization percentage'
            description: 'Default minimum threshold for process utilization triggers. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
      dashboards:
        - uuid: 6815a90fb9b745fd8f1b1f47697893d6
          name: 'Zabbix server health'
          auto_start: 'NO'
          pages:
            - name: Performance
              widgets:
                - type: svggraph
                  name: 'Cache usage, in %'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.2
                      value: e31a1c
                    - type: STRING
                      name: ds.0.color.3
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.4
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.5
                      value: b15928
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[wcache,trend,pused]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[rcache,buffer,pused]'
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[wcache,index,pused]'
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[wcache,history,pused]'
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[vcache,buffer,pused]'
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[vmware,buffer,pused]'
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACA
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Server performance'
                  'y': '6'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.1
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.2
                      value: e31a1c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[wcache,values]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[vps,written]'
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[queue]'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACC
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Values processed'
                  'y': '11'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.2
                      value: e31a1c
                    - type: STRING
                      name: ds.0.color.3
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.4
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.5
                      value: b15928
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[wcache,values,uint]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[wcache,values,float]'
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[wcache,values,not supported]'
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[wcache,values,str]'
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[wcache,values,log]'
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[wcache,values,text]'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACD
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Value cache effectiveness'
                  'y': '16'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.1
                      value: e31a1c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[vcache,cache,hits]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[vcache,cache,misses]'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACE
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Internal queues'
                  x: '36'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: ffca58
                    - type: STRING
                      name: ds.0.color.1
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.2
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.3
                      value: d62728
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[preprocessing_queue]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[lld_queue]'
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[discovery_queue]'
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[connector_queue]'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACB
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Trend cache effectiveness, in %'
                  x: '36'
                  'y': '16'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: ffca58
                    - type: STRING
                      name: ds.0.color.1
                      value: e31a1c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[tcache,cache,pitems]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[tcache,cache,pmisses]'
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACF
                    - type: INTEGER
                      name: show_problems
                      value: '1'
            - name: Processes
              widgets:
                - type: svggraph
                  name: 'Utilization: LLD processes'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: ffca58
                    - type: STRING
                      name: ds.0.color.1
                      value: 7e57c2
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,lld manager,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,lld worker,avg,busy]'
                    - type: INTEGER
                      name: ds.1.axisy
                      value: '1'
                    - type: STRING
                      name: ds.1.color.0
                      value: ff465c
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.1.fill
                      value: '2'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[lld_queue]'
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABI
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Preprocessing processes'
                  'y': '6'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: ffca58
                    - type: STRING
                      name: ds.0.color.1
                      value: 7e57c2
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,preprocessing manager,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,preprocessing worker,avg,busy]'
                    - type: INTEGER
                      name: ds.1.axisy
                      value: '1'
                    - type: STRING
                      name: ds.1.color.0
                      value: ff465c
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.1.fill
                      value: '2'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[preprocessing_queue]'
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABK
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Synchronous gathering processes'
                  'y': '12'
                  width: '72'
                  height: '7'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.2
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.3
                      value: b15928
                    - type: STRING
                      name: ds.0.color.4
                      value: 17becf
                    - type: STRING
                      name: ds.0.color.5
                      value: a6cee3
                    - type: STRING
                      name: ds.0.color.6
                      value: fb9a99
                    - type: STRING
                      name: ds.0.color.7
                      value: bcbd22
                    - type: STRING
                      name: ds.0.color.8
                      value: ffca58
                    - type: STRING
                      name: ds.0.color.9
                      value: e31a1c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,poller,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,internal poller,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,ipmi poller,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,ipmi manager,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,http poller,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,java poller,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.6
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,vmware collector,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.7
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,browser poller,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.8
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,odbc poller,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.9
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,icmp pinger,avg,busy]'
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABM
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Asynchronous gathering processes'
                  'y': '19'
                  width: '72'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: bcbd22
                    - type: STRING
                      name: ds.0.color.2
                      value: 6a3d9a
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,agent poller,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,http agent poller,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,snmp poller,avg,busy]'
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABN
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Internal processes: Core'
                  'y': '25'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.2
                      value: e31a1c
                    - type: STRING
                      name: ds.0.color.3
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.4
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.5
                      value: b15928
                    - type: STRING
                      name: ds.0.color.6
                      value: a6cee3
                    - type: STRING
                      name: ds.0.color.7
                      value: ff465c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,configuration syncer,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,configuration syncer worker,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,history syncer,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,self-monitoring,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,service manager,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,task manager,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.6
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,timer,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.7
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,history poller,avg,busy]'
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '8'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABO
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Gathering processes: Trappers'
                  'y': '31'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: cab2d6
                    - type: STRING
                      name: ds.0.color.1
                      value: ffca58
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,trapper,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,snmp trapper,avg,busy]'
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABQ
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Alerting processes'
                  'y': '36'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 17becf
                    - type: STRING
                      name: ds.0.color.1
                      value: bcbd22
                    - type: STRING
                      name: ds.0.color.2
                      value: d62728
                    - type: STRING
                      name: ds.0.color.3
                      value: ff7f00
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,alert manager,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,alert syncer,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,alerter,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,escalator,avg,busy]'
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '4'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABS
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Proxy management and data exchange'
                  'y': '41'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: cab2d6
                    - type: STRING
                      name: ds.0.color.1
                      value: '000080'
                    - type: STRING
                      name: ds.0.color.2
                      value: '808000'
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,trapper,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,proxy poller,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,proxy group manager,avg,busy]'
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABU
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Preprocessing throughput'
                  'y': '46'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: '808000'
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[preprocessing_throughput]'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABV
                - type: svggraph
                  name: 'Utilization: Discovery processes'
                  x: '36'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 7e57c2
                    - type: STRING
                      name: ds.0.color.1
                      value: 1f78b4
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,discovery manager,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,discovery worker,avg,busy]'
                    - type: INTEGER
                      name: ds.1.axisy
                      value: '1'
                    - type: STRING
                      name: ds.1.color.0
                      value: ff465c
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[discovery_queue]'
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABJ
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Connector processes'
                  x: '36'
                  'y': '6'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: b2df8a
                    - type: STRING
                      name: ds.0.color.1
                      value: ffca58
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,connector manager,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,connector worker,avg,busy]'
                    - type: INTEGER
                      name: ds.1.axisy
                      value: '1'
                    - type: STRING
                      name: ds.1.color.0
                      value: ff465c
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[connector_queue]'
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABL
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Internal processes: Housekeeping'
                  x: '36'
                  'y': '25'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: ffca58
                    - type: STRING
                      name: ds.0.color.1
                      value: cab2d6
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,housekeeper,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,trigger housekeeper,avg,busy]'
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABP
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Availability processes'
                  x: '36'
                  'y': '31'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.1
                      value: b15928
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,unreachable poller,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,availability manager,avg,busy]'
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABR
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Reporting processes'
                  x: '36'
                  'y': '36'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: e377c2
                    - type: STRING
                      name: ds.0.color.1
                      value: ffdf00
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,report manager,avg,busy]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[process,report writer,avg,busy]'
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABT
                    - type: INTEGER
                      name: show_problems
                      value: '1'
            - name: Statuses
              widgets:
                - type: item
                  name: 'Zabbix server version'
                  width: '16'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'Zabbix server health'
                        key: 'zabbix[version]'
                    - type: INTEGER
                      name: show.0
                      value: '2'
                    - type: INTEGER
                      name: show.1
                      value: '3'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: time_h_pos
                      value: '2'
                    - type: INTEGER
                      name: time_size
                      value: '9'
                    - type: INTEGER
                      name: time_v_pos
                      value: '2'
                    - type: INTEGER
                      name: value_size
                      value: '25'
                - type: honeycomb
                  name: 'High availability: Node state'
                  x: '16'
                  width: '56'
                  height: '5'
                  fields:
                    - type: STRING
                      name: items.0
                      value: 'Cluster node [*]: Status'
                    - type: STRING
                      name: primary_label
                      value: '{{ITEM.NAME}.regsub("Cluster node \[(.*)]: Status","\1")}'
                    - type: STRING
                      name: reference
                      value: BAAAA
                    - type: INTEGER
                      name: secondary_label_decimal_places
                      value: '0'
                    - type: STRING
                      name: thresholds.0.color
                      value: b2df8a
                    - type: STRING
                      name: thresholds.0.threshold
                      value: '0'
                    - type: STRING
                      name: thresholds.1.color
                      value: '878787'
                    - type: STRING
                      name: thresholds.1.threshold
                      value: '1'
                    - type: STRING
                      name: thresholds.2.color
                      value: e31a1c
                    - type: STRING
                      name: thresholds.2.threshold
                      value: '2'
                    - type: STRING
                      name: thresholds.3.color
                      value: 33a02c
                    - type: STRING
                      name: thresholds.3.threshold
                      value: '3'
      valuemaps:
        - uuid: cee1681b12ff49b6b7d442a851e870b4
          name: 'Cluster node status'
          mappings:
            - value: '0'
              newvalue: Standby
            - value: '1'
              newvalue: Stopped
            - value: '2'
              newvalue: Unavailable
            - value: '3'
              newvalue: Active
        - uuid: b985f0f026be4889923f5d16393e5383
          name: Compatibility
          mappings:
            - value: '0'
              newvalue: Undefined
            - value: '1'
              newvalue: Current
            - value: '2'
              newvalue: Outdated
            - value: '3'
              newvalue: Unsupported
        - uuid: 3b60aa68965f47baba665e354e0e79de
          name: 'Last seen'
          mappings:
            - value: '-1'
              newvalue: Never
        - uuid: 8c23fc3b231b439a8eec4d0d60859c90
          name: 'Proxy group invalid value'
          mappings:
            - value: '-1'
              newvalue: 'Invalid value'
        - uuid: acd6475b06334535be452cd984a11f6b
          name: 'Proxy group state'
          mappings:
            - value: '0'
              newvalue: Unknown
            - value: '1'
              newvalue: Offline
            - value: '2'
              newvalue: Recovering
            - value: '3'
              newvalue: Online
            - value: '4'
              newvalue: Degrading
        - uuid: 7c52b5e2d2434edeba089e136a7eb845
          name: 'Proxy mode'
          mappings:
            - value: '0'
              newvalue: Active
            - value: '1'
              newvalue: Passive
        - uuid: 0d2da53a4e404248b9d156b5a7342002
          name: 'Service state'
          mappings:
            - value: '0'
              newvalue: 'Off'
            - value: '1'
              newvalue: 'On'
        - uuid: 97bbea700550483bbd8405b4dd9d8005
          name: 'Value cache operating mode'
          mappings:
            - value: '0'
              newvalue: Normal
            - value: '1'
              newvalue: 'Low memory'
        - uuid: 9b8fe61b528547f49598075e79fb6623
          name: 'Zabbix server check'
          mappings:
            - value: '0'
              newvalue: 'False'
            - value: '1'
              newvalue: 'True'
    - uuid: d31c888d12aa4bf68f280bc242501743
      template: 'Zabbix server health by Zabbix agent'
      name: 'Zabbix server health by Zabbix agent'
      description: |
        This template is designed to monitor Zabbix server metrics via the passive Zabbix agent.
        
        Specify the address of the remote Zabbix server by changing the {$ZABBIX.SERVER.ADDRESS} and {$ZABBIX.SERVER.PORT} macros. Don't forget to adjust the "StatsAllowedIP" parameter in the remote server's configuration file to allow the collection of statistics.
        
        Generated by official Zabbix template tool "Templator"
      wizard_ready: 'YES'
      readme: |
        ## Overview
        
        This template is designed to monitor Zabbix server metrics via the passive Zabbix agent.
        
        ## Setup
        
        Specify the address of the remote Zabbix server as the values for the `Zabbix server Address` and `Zabbix server Port` configuration fields. Don't forget to adjust the `StatsAllowedIP` parameter in the remote server's configuration file to allow the collection of statistics.
      vendor:
        name: Zabbix
        version: 7.4-5
      groups:
        - name: Templates/Applications
      items:
        - uuid: 67db1347c8774d22870995569f40a698
          name: 'Connector queue'
          type: DEPENDENT
          key: connector_queue
          description: 'The count of values enqueued in the connector queue.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.connector_queue
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "connector" processes started. Please check "StartConnectors" parameter in the server configuration file.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: 233d8a6776b743948a56b4cae17a189a
          name: 'Discovery queue'
          type: DEPENDENT
          key: discovery_queue
          description: 'The count of values enqueued in the discovery queue.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.discovery_queue
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "discoverer" processes started. Please check "StartDiscoverers" parameter in the server configuration file.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: af0386eb01f7465da3167558fed66b11
          name: 'LLD queue'
          type: DEPENDENT
          key: lld_queue
          description: 'The number of values enqueued in the low-level discovery processing queue.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.lld_queue
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: 2e0e211d720d496ab43b31c3330fa2d6
          name: 'Preprocessing queue'
          type: DEPENDENT
          key: preprocessing_queue
          description: 'The number of values enqueued in the preprocessing queue.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.preprocessing.queue
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: 2d956b642f834e0894fe223113d2c4c3
          name: 'Preprocessing throughput'
          type: DEPENDENT
          key: preprocessing_throughput
          value_type: FLOAT
          units: Bps
          description: 'Reflects the throughput of the preprocessing.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.preprocessing.queued.size
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: 26244cb39b2140a19331ee2813946d1f
          name: 'Utilization of agent poller data collector processes, in %'
          type: DEPENDENT
          key: process.agent_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the agent poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''agent poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "agent poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 6a89e07170e14a9c95154a64fb0248fc
              expression: 'avg(/Zabbix server health by Zabbix agent/process.agent_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"agent poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.agent_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"agent poller"}'
              name: 'Zabbix server: Utilization of agent poller processes is high'
              event_name: 'Zabbix server: Utilization of agent poller processes over {$ZABBIX.SERVER.UTIL.MAX:"agent poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the agent poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 5b48951a5868404a94fd644208554144
          name: 'Utilization of alerter internal processes, in %'
          type: DEPENDENT
          key: process.alerter.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the alerter processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''alerter''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "alerter" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: a1f644d8d3e34b658c57ef671422038d
              expression: 'avg(/Zabbix server health by Zabbix agent/process.alerter.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"alerter"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.alerter.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"alerter"}'
              name: 'Zabbix server: Utilization of alerter processes is high'
              event_name: 'Zabbix server: Utilization of alerter processes over {$ZABBIX.SERVER.UTIL.MAX:"alerter"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the alerter, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: e7bd566b2db444579b59abae5a2d6bfe
          name: 'Utilization of alert manager internal processes, in %'
          type: DEPENDENT
          key: process.alert_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the alert manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''alert manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "alert manager" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 0a9ebdc127bf42ccbbeeeffe02b57095
              expression: 'avg(/Zabbix server health by Zabbix agent/process.alert_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"alert manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.alert_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"alert manager"}'
              name: 'Zabbix server: Utilization of alert manager processes is high'
              event_name: 'Zabbix server: Utilization of alert manager processes over {$ZABBIX.SERVER.UTIL.MAX:"alert manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the alert manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 237aa592438e45e6b38943c14f5afa72
          name: 'Utilization of alert syncer internal processes, in %'
          type: DEPENDENT
          key: process.alert_syncer.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the alert syncer processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''alert syncer''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "alert syncer" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: bc7ed4d8ea2a455d813ff1146a010a6f
              expression: 'avg(/Zabbix server health by Zabbix agent/process.alert_syncer.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"alert syncer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.alert_syncer.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"alert syncer"}'
              name: 'Zabbix server: Utilization of alert syncer processes is high'
              event_name: 'Zabbix server: Utilization of alert syncer processes over {$ZABBIX.SERVER.UTIL.MAX:"alert syncer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the alert syncer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: aeb1631d9bcf401ab7e5f62d717b443c
          name: 'Utilization of availability manager internal processes, in %'
          type: DEPENDENT
          key: process.availability_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the availability manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''availability manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "availability manager" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 956b94177f544386bb4add58df433ca6
              expression: 'avg(/Zabbix server health by Zabbix agent/process.availability_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"availability manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.availability_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"availability manager"}'
              name: 'Zabbix server: Utilization of availability manager processes is high'
              event_name: 'Zabbix server: Utilization of availability manager processes over {$ZABBIX.SERVER.UTIL.MAX:"availability manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the availability manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 8015717df8a54d2680f6bc77be78277d
          name: 'Utilization of browser poller data collector processes, in %'
          type: DEPENDENT
          key: process.browser_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the browser poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''browser poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "browser poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 8df9cc8b0e1f462cae4898c6a54020fc
              expression: 'avg(/Zabbix server health by Zabbix agent/process.browser_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"browser poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.browser_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"browser poller"}'
              name: 'Zabbix server: Utilization of browser poller processes is high'
              event_name: 'Zabbix server: Utilization of browser poller processes over {$ZABBIX.SERVER.UTIL.MAX:"browser poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the browser poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 26bbe7da8a6544ae857f3828f7aad187
          name: 'Utilization of configuration syncer internal processes, in %'
          type: DEPENDENT
          key: process.configuration_syncer.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the configuration syncer processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''configuration syncer''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "configuration syncer" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: cb4f8f5ad7e24fbcbc64ab8006643124
              expression: 'avg(/Zabbix server health by Zabbix agent/process.configuration_syncer.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"configuration syncer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.configuration_syncer.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"configuration syncer"}'
              name: 'Zabbix server: Utilization of configuration syncer processes is high'
              event_name: 'Zabbix server: Utilization of configuration syncer processes over {$ZABBIX.SERVER.UTIL.MAX:"configuration syncer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the configuration syncer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 97ce279dac1843a299c1b1dfba4923cd
          name: 'Utilization of configuration syncer worker internal processes, in %'
          type: DEPENDENT
          key: process.configuration_syncer_worker.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the configuration syncer worker processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''configuration syncer worker''].busy.avg'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 5e4ee9a96013447ebe40b745c105fd03
              expression: 'avg(/Zabbix server health by Zabbix agent/process.configuration_syncer_worker.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"configuration syncer worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.configuration_syncer_worker.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"configuration syncer worker"}'
              name: 'Zabbix server: Utilization of configuration syncer worker processes is high'
              event_name: 'Zabbix server: Utilization of configuration syncer worker processes over {$ZABBIX.SERVER.UTIL.MAX:"configuration syncer worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the configuration syncer worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 4ad318d0b2824f348c8579fb41bf13bf
          name: 'Utilization of connector manager internal processes, in %'
          type: DEPENDENT
          key: process.connector_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the connector manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''connector manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "connector manager" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: eb8957d071b74a80bf3279444473cddb
              expression: 'avg(/Zabbix server health by Zabbix agent/process.connector_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"connector manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.connector_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"connector manager"}'
              name: 'Zabbix server: Utilization of connector manager processes is high'
              event_name: 'Zabbix server: Utilization of connector manager processes over {$ZABBIX.SERVER.UTIL.MAX:"connector manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the connector manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 1ccf61dc603341cca5dda60c03a5443a
          name: 'Utilization of connector worker internal processes, in %'
          type: DEPENDENT
          key: process.connector_worker.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the connector worker processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''connector worker''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "connector worker" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 79881c61531b4446a8f3107127ce36ed
              expression: 'avg(/Zabbix server health by Zabbix agent/process.connector_worker.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"connector worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.connector_worker.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"connector worker"}'
              name: 'Zabbix server: Utilization of connector worker processes is high'
              event_name: 'Zabbix server: Utilization of connector worker processes over {$ZABBIX.SERVER.UTIL.MAX:"connector worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the connector worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: a69a1684823a40789dbed2cfad68fddc
          name: 'Utilization of discovery manager internal processes, in %'
          type: DEPENDENT
          key: process.discovery_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the discovery manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''discovery manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "discovery manager" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 622a1cf7158c407789313819e74310cd
              expression: 'avg(/Zabbix server health by Zabbix agent/process.discovery_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"discovery manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.discovery_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"discovery manager"}'
              name: 'Zabbix server: Utilization of discovery manager processes is high'
              event_name: 'Zabbix server: Utilization of discovery manager processes over {$ZABBIX.SERVER.UTIL.MAX:"discovery manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the discovery manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 6ce4dc23c5a74d20ab00c51174fa0693
          name: 'Utilization of discovery worker internal processes, in %'
          type: DEPENDENT
          key: process.discovery_worker.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the discovery worker processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''discovery worker''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "discovery worker" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 38b49ca5610244b782c66e068727264f
              expression: 'avg(/Zabbix server health by Zabbix agent/process.discovery_worker.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"discovery worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.discovery_worker.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"discovery worker"}'
              name: 'Zabbix server: Utilization of discovery worker processes is high'
              event_name: 'Zabbix server: Utilization of discovery worker processes over {$ZABBIX.SERVER.UTIL.MAX:"discovery worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the discovery worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 5bd7ba1eb4aa46dba8f593008badc7ce
          name: 'Utilization of escalator internal processes, in %'
          type: DEPENDENT
          key: process.escalator.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the escalator processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''escalator''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "escalator" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 21eb9b4f3b204a348738b74752c9927d
              expression: 'avg(/Zabbix server health by Zabbix agent/process.escalator.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"escalator"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.escalator.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"escalator"}'
              name: 'Zabbix server: Utilization of escalator processes is high'
              event_name: 'Zabbix server: Utilization of escalator processes over {$ZABBIX.SERVER.UTIL.MAX:"escalator"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the escalator, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: b8502bfa3d89444caf68f0a61bfd80c0
          name: 'Utilization of history poller internal processes, in %'
          type: DEPENDENT
          key: process.history_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the history poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''history poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "history poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: a1886afb06824e1091220fbe5193461f
              expression: 'avg(/Zabbix server health by Zabbix agent/process.history_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"history poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.history_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"history poller"}'
              name: 'Zabbix server: Utilization of history poller processes is high'
              event_name: 'Zabbix server: Utilization of history poller processes over {$ZABBIX.SERVER.UTIL.MAX:"history poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the history poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: ac78caab34df45ea99a72578c742ef96
          name: 'Utilization of history syncer internal processes, in %'
          type: DEPENDENT
          key: process.history_syncer.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the history syncer processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''history syncer''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "history syncer" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: f738b0289c324e78989436bb92493720
              expression: 'avg(/Zabbix server health by Zabbix agent/process.history_syncer.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"history syncer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.history_syncer.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"history syncer"}'
              name: 'Zabbix server: Utilization of history syncer processes is high'
              event_name: 'Zabbix server: Utilization of history syncer processes over {$ZABBIX.SERVER.UTIL.MAX:"history syncer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the history syncer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 98a0a770a1484dcaa15a30bd4aa67667
          name: 'Utilization of housekeeper internal processes, in %'
          type: DEPENDENT
          key: process.housekeeper.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the housekeeper processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''housekeeper''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "housekeeper" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 96ceff1b787e41b0a02a2d2221f57f6e
              expression: 'avg(/Zabbix server health by Zabbix agent/process.housekeeper.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"housekeeper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.housekeeper.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"housekeeper"}'
              name: 'Zabbix server: Utilization of housekeeper processes is high'
              event_name: 'Zabbix server: Utilization of housekeeper processes over {$ZABBIX.SERVER.UTIL.MAX:"housekeeper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the housekeeper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: f7df477e29514cbcbef8ed98d3b3088d
          name: 'Utilization of http agent poller data collector processes, in %'
          type: DEPENDENT
          key: process.http_agent_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the http agent poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''http agent poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "http agent poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: e4d7add47be94419824f333fcc48880f
              expression: 'avg(/Zabbix server health by Zabbix agent/process.http_agent_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"http agent poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.http_agent_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"http agent poller"}'
              name: 'Zabbix server: Utilization of http agent poller processes is high'
              event_name: 'Zabbix server: Utilization of http agent poller processes over {$ZABBIX.SERVER.UTIL.MAX:"http agent poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the http agent poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 987678076aee4877abe79ca4fe13c0f5
          name: 'Utilization of http poller data collector processes, in %'
          type: DEPENDENT
          key: process.http_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the http poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''http poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "http poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: f254894eb0fb491989e803af02e707d2
              expression: 'avg(/Zabbix server health by Zabbix agent/process.http_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"http poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.http_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"http poller"}'
              name: 'Zabbix server: Utilization of http poller processes is high'
              event_name: 'Zabbix server: Utilization of http poller processes over {$ZABBIX.SERVER.UTIL.MAX:"http poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the http poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 72764d3afa1844d6984b7be20e6700cb
          name: 'Utilization of icmp pinger data collector processes, in %'
          type: DEPENDENT
          key: process.icmp_pinger.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the icmp pinger processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''icmp pinger''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "icmp pinger" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: b1ebb6969696476da6a90c6f0d8de5eb
              expression: 'avg(/Zabbix server health by Zabbix agent/process.icmp_pinger.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"icmp pinger"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.icmp_pinger.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"icmp pinger"}'
              name: 'Zabbix server: Utilization of icmp pinger processes is high'
              event_name: 'Zabbix server: Utilization of icmp pinger processes over {$ZABBIX.SERVER.UTIL.MAX:"icmp pinger"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the icmp pinger, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 686ee39bdc284684993e46ae250ceb82
          name: 'Utilization of internal poller data collector processes, in %'
          type: DEPENDENT
          key: process.internal_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the internal poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''internal poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "internal poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 99fad58c6c5244f58d71e4d45840f355
              expression: 'avg(/Zabbix server health by Zabbix agent/process.internal_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"internal poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.internal_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"internal poller"}'
              name: 'Zabbix server: Utilization of internal poller processes is high'
              event_name: 'Zabbix server: Utilization of internal poller processes over {$ZABBIX.SERVER.UTIL.MAX:"internal poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the internal poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 75882e08301a424aa282a65c300e45ec
          name: 'Utilization of ipmi manager internal processes, in %'
          type: DEPENDENT
          key: process.ipmi_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the ipmi manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''ipmi manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "ipmi manager" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 19f8d398245a4fa993467451571eb06a
              expression: 'avg(/Zabbix server health by Zabbix agent/process.ipmi_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"ipmi manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.ipmi_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"ipmi manager"}'
              name: 'Zabbix server: Utilization of ipmi manager processes is high'
              event_name: 'Zabbix server: Utilization of ipmi manager processes over {$ZABBIX.SERVER.UTIL.MAX:"ipmi manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the ipmi manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 4b3315753f2648fe839415d253274225
          name: 'Utilization of ipmi poller data collector processes, in %'
          type: DEPENDENT
          key: process.ipmi_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the ipmi poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''ipmi poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "ipmi poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: eb82596e6a25422fbbb2da9910616557
              expression: 'avg(/Zabbix server health by Zabbix agent/process.ipmi_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"ipmi poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.ipmi_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"ipmi poller"}'
              name: 'Zabbix server: Utilization of ipmi poller processes is high'
              event_name: 'Zabbix server: Utilization of ipmi poller processes over {$ZABBIX.SERVER.UTIL.MAX:"ipmi poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the ipmi poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 72964a592b434862855ae82ee4a51a47
          name: 'Utilization of java poller data collector processes, in %'
          type: DEPENDENT
          key: process.java_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the java poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''java poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "java poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 21114bc6d4be4ab393141ddc34eaec5f
              expression: 'avg(/Zabbix server health by Zabbix agent/process.java_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"java poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.java_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"java poller"}'
              name: 'Zabbix server: Utilization of java poller processes is high'
              event_name: 'Zabbix server: Utilization of java poller processes over {$ZABBIX.SERVER.UTIL.MAX:"java poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the java poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: bd339e2ee2b743e4bbf7c4614fc9142b
          name: 'Utilization of LLD manager internal processes, in %'
          type: DEPENDENT
          key: process.lld_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the LLD manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''lld manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "LLD manager" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 8b1e71a2be054aa9913b0d0ab980d7a3
              expression: 'avg(/Zabbix server health by Zabbix agent/process.lld_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"LLD manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.lld_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"LLD manager"}'
              name: 'Zabbix server: Utilization of LLD manager processes is high'
              event_name: 'Zabbix server: Utilization of LLD manager processes over {$ZABBIX.SERVER.UTIL.MAX:"LLD manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the LLD manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 76c3dd1ec25d4cb38d5a02681103fd01
          name: 'Utilization of LLD worker internal processes, in %'
          type: DEPENDENT
          key: process.lld_worker.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the LLD worker processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''lld worker''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "LLD worker" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 26ab68bbf6a54277aeaa51f41b413da6
              expression: 'avg(/Zabbix server health by Zabbix agent/process.lld_worker.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"LLD worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.lld_worker.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"LLD worker"}'
              name: 'Zabbix server: Utilization of LLD worker processes is high'
              event_name: 'Zabbix server: Utilization of LLD worker processes over {$ZABBIX.SERVER.UTIL.MAX:"LLD worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the LLD worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: a18f1241d78b463eae7dcb6442cb14de
          name: 'Utilization of ODBC poller data collector processes, in %'
          type: DEPENDENT
          key: process.odbc_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the ODBC poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''odbc poller''].busy.avg'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: f089d9f2c2f844f5acd69be08a8e048a
              expression: 'avg(/Zabbix server health by Zabbix agent/process.odbc_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"ODBC poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.odbc_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"ODBC poller"}'
              name: 'Zabbix server: Utilization of ODBC poller processes is high'
              event_name: 'Zabbix server: Utilization of ODBC poller processes over {$ZABBIX.SERVER.UTIL.MAX:"ODBC poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the ODBC poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 37a4b686f8bd42c49fdcde2d1d2aa0c5
          name: 'Utilization of poller data collector processes, in %'
          type: DEPENDENT
          key: process.poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 7d20639bec7a456685f7fce4bf70fb2e
              expression: 'avg(/Zabbix server health by Zabbix agent/process.poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"poller"}'
              name: 'Zabbix server: Utilization of poller processes is high'
              event_name: 'Zabbix server: Utilization of poller processes over {$ZABBIX.SERVER.UTIL.MAX:"poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: a8ce38ce9ade40d6accfeda76a2f67ce
          name: 'Utilization of preprocessing manager internal processes, in %'
          type: DEPENDENT
          key: process.preprocessing_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the preprocessing manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''preprocessing manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "preprocessing manager" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: b7e3dc93732f49d49d2a2f28251a9927
              expression: 'avg(/Zabbix server health by Zabbix agent/process.preprocessing_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"preprocessing manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.preprocessing_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"preprocessing manager"}'
              name: 'Zabbix server: Utilization of preprocessing manager processes is high'
              event_name: 'Zabbix server: Utilization of preprocessing manager processes over {$ZABBIX.SERVER.UTIL.MAX:"preprocessing manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the preprocessing manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 8350ba81df6641e388d9f7975aa35085
          name: 'Utilization of preprocessing worker internal processes, in %'
          type: DEPENDENT
          key: process.preprocessing_worker.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the preprocessing worker processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''preprocessing worker''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "preprocessing worker" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 87573b80d7124db284f1be3137ac3243
              expression: 'avg(/Zabbix server health by Zabbix agent/process.preprocessing_worker.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"preprocessing worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.preprocessing_worker.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"preprocessing worker"}'
              name: 'Zabbix server: Utilization of preprocessing worker processes is high'
              event_name: 'Zabbix server: Utilization of preprocessing worker processes over {$ZABBIX.SERVER.UTIL.MAX:"preprocessing worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the preprocessing worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 7b2e318316204619a6d0ec5fed697c76
          name: 'Utilization of proxy group manager internal processes, in %'
          type: DEPENDENT
          key: process.proxy_group_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the proxy group manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''proxy group manager''].busy.avg'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 528a1cc095c3485682af50d837b05912
              expression: 'avg(/Zabbix server health by Zabbix agent/process.proxy_group_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"proxy group manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.proxy_group_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"proxy group manager"}'
              name: 'Zabbix server: Utilization of proxy group manager processes is high'
              event_name: 'Zabbix server: Utilization of proxy group manager processes over {$ZABBIX.SERVER.UTIL.MAX:"proxy group manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the proxy group manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 36d5be78c569416cbf9fc7e304fdc841
          name: 'Utilization of proxy poller data collector processes, in %'
          type: DEPENDENT
          key: process.proxy_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the proxy poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''proxy poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "proxy poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 76b0b9bc6e38423681ab359159f9ca32
              expression: 'avg(/Zabbix server health by Zabbix agent/process.proxy_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"proxy poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.proxy_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"proxy poller"}'
              name: 'Zabbix server: Utilization of proxy poller processes is high'
              event_name: 'Zabbix server: Utilization of proxy poller processes over {$ZABBIX.SERVER.UTIL.MAX:"proxy poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the proxy poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 586a94a15daa4c5e92d08a7b9a513569
          name: 'Utilization of report manager internal processes, in %'
          type: DEPENDENT
          key: process.report_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the report manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''report manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "report manager" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: e4c4974ca3c540d9935bf2bf6a1a9f2f
              expression: 'avg(/Zabbix server health by Zabbix agent/process.report_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"report manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.report_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"report manager"}'
              name: 'Zabbix server: Utilization of report manager processes is high'
              event_name: 'Zabbix server: Utilization of report manager processes over {$ZABBIX.SERVER.UTIL.MAX:"report manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the report manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 54f4b6d1b41b4a229281d94e50040e67
          name: 'Utilization of report writer internal processes, in %'
          type: DEPENDENT
          key: process.report_writer.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the report writer processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''report writer''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "report writer" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 196346fa19dc43b6989c403da4bae618
              expression: 'avg(/Zabbix server health by Zabbix agent/process.report_writer.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"report writer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.report_writer.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"report writer"}'
              name: 'Zabbix server: Utilization of report writer processes is high'
              event_name: 'Zabbix server: Utilization of report writer processes over {$ZABBIX.SERVER.UTIL.MAX:"report writer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the report writer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 8bb2d6405fa344e89acca08eb2989347
          name: 'Utilization of self-monitoring internal processes, in %'
          type: DEPENDENT
          key: process.self-monitoring.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the self-monitoring processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''self-monitoring''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "self-monitoring" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: fe7628ada2c748d99d5e768f19d6925e
              expression: 'avg(/Zabbix server health by Zabbix agent/process.self-monitoring.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"self-monitoring"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.self-monitoring.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"self-monitoring"}'
              name: 'Zabbix server: Utilization of self-monitoring processes is high'
              event_name: 'Zabbix server: Utilization of self-monitoring processes over {$ZABBIX.SERVER.UTIL.MAX:"self-monitoring"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the self-monitoring, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 41a5e11bd0244b9b936f89337a70bf7b
          name: 'Utilization of service manager internal processes, in %'
          type: DEPENDENT
          key: process.service_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the service manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''service manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "service manager" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 273d3f4894754d92980827d67424626f
              expression: 'avg(/Zabbix server health by Zabbix agent/process.service_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"service manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.service_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"service manager"}'
              name: 'Zabbix server: Utilization of service manager processes is high'
              event_name: 'Zabbix server: Utilization of service manager processes over {$ZABBIX.SERVER.UTIL.MAX:"service manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the service manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: b3e03fd8df2a44c6b81b988aba962af0
          name: 'Utilization of snmp poller data collector processes, in %'
          type: DEPENDENT
          key: process.snmp_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the snmp poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''snmp poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "snmp poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 8d67b86d96214e63aa4150957d0f5448
              expression: 'avg(/Zabbix server health by Zabbix agent/process.snmp_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"snmp poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.snmp_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"snmp poller"}'
              name: 'Zabbix server: Utilization of snmp poller processes is high'
              event_name: 'Zabbix server: Utilization of snmp poller processes over {$ZABBIX.SERVER.UTIL.MAX:"snmp poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the snmp poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: cf3f6a2ab158418d9457dc5263bd00e6
          name: 'Utilization of snmp trapper data collector processes, in %'
          type: DEPENDENT
          key: process.snmp_trapper.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the snmp trapper processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''snmp trapper''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "snmp trapper" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 6b792b961a894028885cca471e58ea7d
              expression: 'avg(/Zabbix server health by Zabbix agent/process.snmp_trapper.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"snmp trapper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.snmp_trapper.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"snmp trapper"}'
              name: 'Zabbix server: Utilization of snmp trapper processes is high'
              event_name: 'Zabbix server: Utilization of snmp trapper processes over {$ZABBIX.SERVER.UTIL.MAX:"snmp trapper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the snmp trapper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: e73efbdec67a459e9cec663a527d8eb4
          name: 'Utilization of task manager internal processes, in %'
          type: DEPENDENT
          key: process.task_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the task manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''task manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "task manager" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 54324394c6da4fec99824d20620e5130
              expression: 'avg(/Zabbix server health by Zabbix agent/process.task_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"task manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.task_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"task manager"}'
              name: 'Zabbix server: Utilization of task manager processes is high'
              event_name: 'Zabbix server: Utilization of task manager processes over {$ZABBIX.SERVER.UTIL.MAX:"task manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the task manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 24a5de4abfa5464fb2c689ab45331013
          name: 'Utilization of timer internal processes, in %'
          type: DEPENDENT
          key: process.timer.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the timer processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''timer''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "timer" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: be3754033f584791aef90bf94cc03155
              expression: 'avg(/Zabbix server health by Zabbix agent/process.timer.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"timer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.timer.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"timer"}'
              name: 'Zabbix server: Utilization of timer processes is high'
              event_name: 'Zabbix server: Utilization of timer processes over {$ZABBIX.SERVER.UTIL.MAX:"timer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the timer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 87cd3e5ac5a443ce933902092afe2aef
          name: 'Utilization of trapper data collector processes, in %'
          type: DEPENDENT
          key: process.trapper.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the trapper processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''trapper''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "trapper" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 499ac8c8ac274b0a9c4e1e4e2604c393
              expression: 'avg(/Zabbix server health by Zabbix agent/process.trapper.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"trapper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.trapper.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"trapper"}'
              name: 'Zabbix server: Utilization of trapper processes is high'
              event_name: 'Zabbix server: Utilization of trapper processes over {$ZABBIX.SERVER.UTIL.MAX:"trapper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the trapper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: a4440e906d5e44459cdd89a8e65e49f1
          name: 'Utilization of trigger housekeeper internal processes, in %'
          type: DEPENDENT
          key: process.trigger_housekeeper.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the trigger housekeeper processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''trigger housekeeper''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "trigger housekeeper" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 2f024c50a951453abcd7a7998c270e9e
              expression: 'avg(/Zabbix server health by Zabbix agent/process.trigger_housekeeper.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"trigger housekeeper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.trigger_housekeeper.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"trigger housekeeper"}'
              name: 'Zabbix server: Utilization of trigger housekeeper processes is high'
              event_name: 'Zabbix server: Utilization of trigger housekeeper processes over {$ZABBIX.SERVER.UTIL.MAX:"trigger housekeeper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the trigger housekeeper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 4ea198b2d4544d35b713135f0e6abe1d
          name: 'Utilization of unreachable poller data collector processes, in %'
          type: DEPENDENT
          key: process.unreachable_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the unreachable poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''unreachable poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "unreachable poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: cd76cc2f895349319716aa3533181529
              expression: 'avg(/Zabbix server health by Zabbix agent/process.unreachable_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"unreachable poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.unreachable_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"unreachable poller"}'
              name: 'Zabbix server: Utilization of unreachable poller processes is high'
              event_name: 'Zabbix server: Utilization of unreachable poller processes over {$ZABBIX.SERVER.UTIL.MAX:"unreachable poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the unreachable poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: c06eefb4ce3742a6890e99b7340b8c1c
          name: 'Utilization of vmware collector data collector processes, in %'
          type: DEPENDENT
          key: process.vmware_collector.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the vmware collector processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''vmware collector''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "vmware collector" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 1aa12e51e357423ab198e6dcbba6e4f8
              expression: 'avg(/Zabbix server health by Zabbix agent/process.vmware_collector.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"vmware collector"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent/process.vmware_collector.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"vmware collector"}'
              name: 'Zabbix server: Utilization of vmware collector processes is high'
              event_name: 'Zabbix server: Utilization of vmware collector processes over {$ZABBIX.SERVER.UTIL.MAX:"vmware collector"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the vmware collector, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 449b05f7fefa4960bc4f50d300b60b30
          name: 'Configuration cache, % used'
          type: DEPENDENT
          key: rcache.buffer.pused
          value_type: FLOAT
          units: '%'
          description: 'The availability statistics of Zabbix configuration cache. The percentage of used data buffer.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.rcache.pused
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 363da6f7c0ad4d289939d1e3ffdd8cf6
              expression: 'max(/Zabbix server health by Zabbix agent/rcache.buffer.pused,10m)>{$ZABBIX.SERVER.UTIL.MAX:"configuration cache"}'
              name: 'Zabbix server: Excessive configuration cache usage'
              event_name: 'Zabbix server: More than {$ZABBIX.SERVER.UTIL.MAX:"configuration cache"}% used in the configuration cache'
              priority: AVERAGE
              description: 'Consider increasing `CacheSize` in the `zabbix_server.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
            - uuid: a9eb076bb3234e05a46a6884c04a53aa
              expression: 'nodata(/Zabbix server health by Zabbix agent/rcache.buffer.pused,{$ZABBIX.SERVER.NODATA_TIMEOUT})=1'
              name: 'Zabbix server: Failed to fetch stats data'
              event_name: 'Zabbix server: Failed to fetch stats data (or no data for {$ZABBIX.SERVER.NODATA_TIMEOUT})'
              priority: WARNING
              description: 'Zabbix has not received statistics data for `{$ZABBIX.SERVER.NODATA_TIMEOUT}`.'
              tags:
                - tag: scope
                  value: availability
        - uuid: d02caf97af874b929d78bccdcf80a1fd
          name: 'Zabbix server check'
          type: DEPENDENT
          key: server_check
          trends: '0'
          description: 'Flag indicating whether it is a server or not.'
          valuemap:
            name: 'Zabbix server check'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.triggers
              error_handler: CUSTOM_VALUE
              error_handler_params: '0'
            - type: IN_RANGE
              parameters:
                - ''
                - '0'
              error_handler: CUSTOM_VALUE
              error_handler_params: '1'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: a682723b57304a8a8fe824c97524c268
              expression: 'last(/Zabbix server health by Zabbix agent/server_check)=0'
              name: 'Zabbix server: Wrong template assigned'
              event_name: 'Zabbix server: Zabbix server template is assigned to Zabbix proxy'
              priority: DISASTER
              description: 'Check that the template has been selected correctly.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: af615158ecc546a5bde2dcc39c4477cd
          name: 'Trend function cache, % of unique requests'
          type: DEPENDENT
          key: tcache.pitems
          value_type: FLOAT
          units: '%'
          description: |
            The effectiveness statistics of the Zabbix trend function cache. The percentage of cached items calculated from the sum of the cached items plus requests.
            A low percentage most likely means that the cache size can be reduced.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.tcache.pitems
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Not supported in this version.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: d7a302b1eced46308c5d308eff7940f7
          name: 'Trend function cache, % of misses'
          type: DEPENDENT
          key: tcache.pmisses
          value_type: FLOAT
          units: '%'
          description: 'The effectiveness statistics of the Zabbix trend function cache. The percentage of cache misses.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.tcache.pmisses
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Not supported in this version.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: 667bde86aa124656a1470574203dabe8
          name: 'Value cache, % used'
          type: DEPENDENT
          key: vcache.buffer.pused
          value_type: FLOAT
          units: '%'
          description: 'The availability statistics of Zabbix value cache. The percentage of used data buffer.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.vcache.buffer.pused
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 3d2b9badc0ba4751b341127eca43b060
              expression: 'max(/Zabbix server health by Zabbix agent/vcache.buffer.pused,10m)>{$ZABBIX.SERVER.UTIL.MAX:"value cache"}'
              name: 'Zabbix server: Excessive value cache usage'
              event_name: 'Zabbix server: More than {$ZABBIX.SERVER.UTIL.MAX:"value cache"}% used in the value cache'
              priority: AVERAGE
              description: 'Consider increasing `ValueCacheSize` in the `zabbix_server.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 774a9545d7ec487eb7a3fa57075c4521
          name: 'Value cache hits'
          type: DEPENDENT
          key: vcache.cache.hits
          value_type: FLOAT
          units: '!vps'
          description: 'The effectiveness statistics of Zabbix value cache. The number of cache hits (history values taken from the cache).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.vcache.cache.hits
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: 350489880982410188ed0e09a1a29763
          name: 'Value cache misses'
          type: DEPENDENT
          key: vcache.cache.misses
          value_type: FLOAT
          units: '!vps'
          description: 'The effectiveness statistics of Zabbix value cache. The number of cache misses (history values taken from the database).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.vcache.cache.misses
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: 29f324a479dd4fcd8e7c25c11a979725
          name: 'Value cache operating mode'
          type: DEPENDENT
          key: vcache.cache.mode
          units: '!vps'
          description: 'The operating mode of the value cache.'
          valuemap:
            name: 'Value cache operating mode'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.vcache.cache.mode
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: da2f0e99f5fb45009ee61f9801db17ce
              expression: 'last(/Zabbix server health by Zabbix agent/vcache.cache.mode)=1'
              name: 'Zabbix server: Zabbix value cache working in low-memory mode'
              priority: HIGH
              description: 'Once low-memory mode has been switched on, the value cache will remain in this state for 24 hours, even if the problem that triggered this mode is resolved sooner.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 54c43b70ee6a43d1827ce5da810694ed
          name: Version
          type: DEPENDENT
          key: version
          value_type: CHAR
          description: 'The version of Zabbix server.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.version
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 067dbedff25c4536ace271693d5c404d
              expression: 'last(/Zabbix server health by Zabbix agent/version,#1)<>last(/Zabbix server health by Zabbix agent/version,#2) and length(last(/Zabbix server health by Zabbix agent/version))>0'
              name: 'Zabbix server: Version has changed'
              event_name: 'Zabbix server: Version has changed (new version: {ITEM.VALUE})'
              priority: INFO
              description: 'Zabbix server version has changed. Acknowledge to close the problem manually.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: 8ddbd31c13c447979d1fb57e942b1b34
          name: 'VMware cache, % used'
          type: DEPENDENT
          key: vmware.buffer.pused
          value_type: FLOAT
          units: '%'
          description: 'The availability statistics of Zabbix vmware cache. The percentage of used data buffer.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.vmware.pused
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "vmware collector" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 448b0d2931084946bdbe30994cc21a2a
              expression: 'max(/Zabbix server health by Zabbix agent/vmware.buffer.pused,10m)>{$ZABBIX.SERVER.UTIL.MAX:"vmware cache"}'
              name: 'Zabbix server: Excessive vmware cache usage'
              event_name: 'Zabbix server: More than {$ZABBIX.SERVER.UTIL.MAX:"vmware cache"}% used in the vmware cache'
              priority: AVERAGE
              description: 'Consider increasing `VMwareCacheSize` in the `zabbix_server.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: f5f751c4bd844086a5f7bf9d442dd761
          name: 'Number of values synchronized with the database per second'
          type: DEPENDENT
          key: vps.written
          value_type: FLOAT
          units: '!vps'
          description: 'Average quantity of values written to the database, recalculated once per minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.vps.written_total
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 07d74d4c2c1d4ce29dce164d68cbab73
          name: 'History write cache, % used'
          type: DEPENDENT
          key: wcache.history.pused
          value_type: FLOAT
          units: '%'
          description: |
            The statistics and availability of Zabbix write cache. The percentage of used history buffer.
            The history cache is used to store item values. A high number indicates database performance problems.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.history.pused
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 0b0c54160c6442c6ac4ab3807d3e3cbf
              expression: 'max(/Zabbix server health by Zabbix agent/wcache.history.pused,10m)>{$ZABBIX.SERVER.UTIL.MAX:"history cache"}'
              name: 'Zabbix server: Excessive history cache usage'
              event_name: 'Zabbix server: More than {$ZABBIX.SERVER.UTIL.MAX:"history cache"}% used in the history cache'
              priority: AVERAGE
              description: 'Consider increasing `HistoryCacheSize` in the `zabbix_server.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 8f8d3ca8c2f14b6d950946345e1c0659
          name: 'History index cache, % used'
          type: DEPENDENT
          key: wcache.index.pused
          value_type: FLOAT
          units: '%'
          description: |
            The statistics and availability of Zabbix write cache. The percentage of used history index buffer.
            The history index cache is used to index values stored in the history cache.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.index.pused
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 11838eec73024ff2abaa9473d3171bb4
              expression: 'max(/Zabbix server health by Zabbix agent/wcache.index.pused,10m)>{$ZABBIX.SERVER.UTIL.MAX:"index cache"}'
              name: 'Zabbix server: Excessive history index cache usage'
              event_name: 'Zabbix server: More than {$ZABBIX.SERVER.UTIL.MAX:"index cache"}% used in the history index cache'
              priority: AVERAGE
              description: 'Consider increasing `HistoryIndexCacheSize` in the `zabbix_server.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: e938f95f91414497a9a72166ee143dea
          name: 'Trend write cache, % used'
          type: DEPENDENT
          key: wcache.trend.pused
          value_type: FLOAT
          units: '%'
          description: |
            The statistics and availability of Zabbix write cache. The percentage of used trend buffer.
            The trend cache stores the aggregate of all items that have received data for the current hour.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.trend.pused
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 13b1ca9fa8f64deb9bd2bec2e919ee9a
              expression: 'max(/Zabbix server health by Zabbix agent/wcache.trend.pused,10m)>{$ZABBIX.SERVER.UTIL.MAX:"trend cache"}'
              name: 'Zabbix server: Excessive trends cache usage'
              event_name: 'Zabbix server: More than {$ZABBIX.SERVER.UTIL.MAX:"trend cache"}% used in the trends cache'
              priority: AVERAGE
              description: 'Consider increasing `TrendCacheSize` in the `zabbix_server.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 463b804470ef435995c09199b691904e
          name: 'Number of processed values per second'
          type: DEPENDENT
          key: wcache.values
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The total number of values processed by Zabbix server or Zabbix proxy, except unsupported items.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.all
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 529bbc2ab85f4e088b1c6f65a38b06d6
          name: 'Number of processed numeric (float) values per second'
          type: DEPENDENT
          key: wcache.values.float
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed numeric (float) values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.float
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 538e8a635b08414fbd0ce505cf2bd754
          name: 'Number of processed log values per second'
          type: DEPENDENT
          key: wcache.values.log
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed log values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.log
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: d2d3b7dd52194d898eb58e4ea731447c
          name: 'Number of processed not supported values per second'
          type: DEPENDENT
          key: wcache.values.not_supported
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of times the item processing resulted in an item becoming unsupported or remaining in that state.
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.wcache.values[''not supported'']'
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 060002e74f8d4e2c9aa24c167ddd8658
          name: 'Number of processed character values per second'
          type: DEPENDENT
          key: wcache.values.str
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed character values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.str
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 1a4bcfd5660b4e4a84848ccec5ff2a28
          name: 'Number of processed text values per second'
          type: DEPENDENT
          key: wcache.values.text
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed text values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.text
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 9ea10574cd3147c88d7e613cde988765
          name: 'Number of processed numeric (unsigned) values per second'
          type: DEPENDENT
          key: wcache.values.uint
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed numeric (unsigned) values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.uint
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 406e909296024280b7cdc76d288a398d
          name: 'Zabbix proxies stats'
          type: DEPENDENT
          key: zabbix.proxies.stats
          history: '0'
          value_type: TEXT
          description: 'The master item of Zabbix proxies'' statistics.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.proxy
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: raw
        - uuid: f3871d3395204212bffd236d80d208f7
          name: 'Queue over 10 minutes'
          key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT},queue,10m]'
          description: 'The number of monitored items in the queue that are delayed by at least 10 minutes.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.queue
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 3396dbfc687e4bbe80f9c38defbbb8e7
              expression: 'min(/Zabbix server health by Zabbix agent/zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT},queue,10m],10m)>100'
              name: 'Zabbix server: More than 100 items have been missing data for over 10 minutes'
              priority: WARNING
              description: 'Indicates potential issues with network connectivity, agent failures, or unresponsive monitored resources that require attention.'
              tags:
                - tag: scope
                  value: performance
        - uuid: e03e82b05bb140e7ae52be6d1d1ef869
          name: Queue
          key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT},queue]'
          description: 'The number of monitored items in the queue that are delayed by at least 6 seconds.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.queue
          tags:
            - tag: component
              value: system
        - uuid: 7084c5c4b6cd4bf6a0b2ab23f171e5de
          name: 'Zabbix stats'
          key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          history: '0'
          value_type: TEXT
          description: 'The master item of Zabbix server statistics.'
          tags:
            - tag: component
              value: raw
      discovery_rules:
        - uuid: 6615363e42424accbaf9a2e385240de6
          name: 'High availability cluster node discovery'
          type: DEPENDENT
          key: zabbix.nodes.discovery
          description: 'LLD rule with item and trigger prototypes for node discovery.'
          item_prototypes:
            - uuid: b05e4297dc57492cb09ef11eb4042906
              name: 'Cluster node [{#NODE.NAME}]: Address'
              type: DEPENDENT
              key: 'zabbix.node.address[{#NODE.ID}]'
              value_type: CHAR
              description: 'The IPv4 address of a node.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.address
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.node.stats[{#NODE.ID}]'
              tags:
                - tag: component
                  value: cluster
                - tag: node-id
                  value: '{#NODE.ID}'
                - tag: node-name
                  value: '{#NODE.NAME}'
            - uuid: 27bbff6ffee847f68a9f533af0b653e9
              name: 'Cluster node [{#NODE.NAME}]: Last access age'
              type: DEPENDENT
              key: 'zabbix.node.lastaccess.age[{#NODE.ID}]'
              units: uptime
              description: 'The time between the database''s `unix_timestamp()` and the last access time.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.lastaccess_age
              master_item:
                key: 'zabbix.node.stats[{#NODE.ID}]'
              tags:
                - tag: component
                  value: cluster
                - tag: node-id
                  value: '{#NODE.ID}'
                - tag: node-name
                  value: '{#NODE.NAME}'
            - uuid: 41547b3b694c49d79288dbf6f0b6d6cc
              name: 'Cluster node [{#NODE.NAME}]: Last access time'
              type: DEPENDENT
              key: 'zabbix.node.lastaccess.time[{#NODE.ID}]'
              units: unixtime
              description: 'Last access time.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.lastaccess
              master_item:
                key: 'zabbix.node.stats[{#NODE.ID}]'
              tags:
                - tag: component
                  value: cluster
                - tag: node-id
                  value: '{#NODE.ID}'
                - tag: node-name
                  value: '{#NODE.NAME}'
            - uuid: 72bec5b0e4314f78b272a0851c690d4b
              name: 'Cluster node [{#NODE.NAME}]: Stats'
              type: DEPENDENT
              key: 'zabbix.node.stats[{#NODE.ID}]'
              history: '0'
              value_type: TEXT
              description: 'Provides the statistics of a node.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.data.ha[?(@.id=="{#NODE.ID}")].first()'
              master_item:
                key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
              tags:
                - tag: component
                  value: cluster
                - tag: component
                  value: raw
                - tag: node-id
                  value: '{#NODE.ID}'
                - tag: node-name
                  value: '{#NODE.NAME}'
            - uuid: a2b9c365c340441c9505ab9fdfafc0fe
              name: 'Cluster node [{#NODE.NAME}]: Status'
              type: DEPENDENT
              key: 'zabbix.nodes.status[{#NODE.ID}]'
              description: 'The status of a node.'
              valuemap:
                name: 'Cluster node status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.node.stats[{#NODE.ID}]'
              tags:
                - tag: component
                  value: cluster
                - tag: node-id
                  value: '{#NODE.ID}'
                - tag: node-name
                  value: '{#NODE.NAME}'
              trigger_prototypes:
                - uuid: 6b9b6640b1dd4307b65840d465d40431
                  expression: 'last(/Zabbix server health by Zabbix agent/zabbix.nodes.status[{#NODE.ID}],#1)<>last(/Zabbix server health by Zabbix agent/zabbix.nodes.status[{#NODE.ID}],#2)'
                  name: 'Zabbix server: Cluster node [{#NODE.NAME}]: Status changed'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: INFO
                  description: 'The state of the node has changed. Acknowledge to close the problem manually.'
                  manual_close: 'YES'
                  tags:
                    - tag: scope
                      value: availability
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          lld_macro_paths:
            - lld_macro: '{#NODE.ID}'
              path: $.id
            - lld_macro: '{#NODE.NAME}'
              path: $.name
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.ha
            - type: JAVASCRIPT
              parameters:
                - |
                  var hacluster = JSON.parse(value);
                  
                  result = hacluster.map(function (hanode) {
                  	return {
                  		'id': hanode.id,
                  		'name': hanode.name
                  	};
                  });
                  
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
        - uuid: 53e742e9dfe8498f9075d507bd1fe957
          name: 'Zabbix proxy discovery'
          type: DEPENDENT
          key: zabbix.proxy.discovery
          description: 'LLD rule with item and trigger prototypes for proxy discovery.'
          item_prototypes:
            - uuid: 8381ffae3f204e788c160dd571faf2cb
              name: 'Proxy [{#PROXY.NAME}]: Certificate'
              type: DEPENDENT
              key: 'zabbix.proxy.cert[{#PROXY.NAME}]'
              description: 'The encryption status for connections from a proxy.'
              valuemap:
                name: 'Service state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.cert
                - type: JAVASCRIPT
                  parameters:
                    - 'return value === ''false'' ? 0 : 1'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: afc3fe7016b440ad8fb99ee80b585267
              name: 'Proxy [{#PROXY.NAME}]: Compatibility'
              type: DEPENDENT
              key: 'zabbix.proxy.compatibility[{#PROXY.NAME}]'
              description: |
                Version of proxy compared to Zabbix server version.
                
                Possible values:
                0 - Undefined;
                1 - Current version (proxy and server have the same major version);
                2 - Outdated version (proxy version is older than server version, but is partially supported);
                3 - Unsupported version (proxy version is older than server previous LTS release version or server major version is older than proxy major version).
              valuemap:
                name: Compatibility
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.compatibility
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
              trigger_prototypes:
                - uuid: d3f1ce16f1d343af955a2226d87efaa8
                  expression: 'last(/Zabbix server health by Zabbix agent/zabbix.proxy.compatibility[{#PROXY.NAME}],#1)=3'
                  name: 'Zabbix server: Proxy [{#PROXY.NAME}]: Zabbix proxy is not supported'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: HIGH
                  description: 'Zabbix proxy version is older than server previous LTS release version or server major version is older than proxy major version.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 9558abc739f44660a03b3d273a689647
                  expression: 'last(/Zabbix server health by Zabbix agent/zabbix.proxy.compatibility[{#PROXY.NAME}],#1)=2'
                  name: 'Zabbix server: Proxy [{#PROXY.NAME}]: Zabbix proxy is outdated'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: WARNING
                  description: 'Zabbix proxy version is older than server version, but is partially supported. Only data collection and remote execution is available.'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: c15ee99bd6fb42bea19e3fb121cfce0d
              name: 'Proxy [{#PROXY.NAME}]: Compression'
              type: DEPENDENT
              key: 'zabbix.proxy.compression[{#PROXY.NAME}]'
              description: 'The compression status of a proxy.'
              valuemap:
                name: 'Service state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.compression
                - type: JAVASCRIPT
                  parameters:
                    - 'return value === ''false'' ? 0 : 1'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 0d9b3aa276cd4629955663d79adffa50
              name: 'Proxy [{#PROXY.NAME}]: Host count'
              type: DEPENDENT
              key: 'zabbix.proxy.hosts[{#PROXY.NAME}]'
              description: 'The number of enabled hosts assigned to a proxy.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.hosts
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 05836b0ac4884c69ba8312286017b25d
              name: 'Proxy [{#PROXY.NAME}]: Item count'
              type: DEPENDENT
              key: 'zabbix.proxy.items[{#PROXY.NAME}]'
              description: 'The number of enabled items on enabled hosts assigned to a proxy.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.items
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: d2a358737c0d447c906b5156a539c5d5
              name: 'Proxy [{#PROXY.NAME}]: Last seen, in seconds'
              type: DEPENDENT
              key: 'zabbix.proxy.last_seen[{#PROXY.NAME}]'
              value_type: FLOAT
              description: 'The time when a proxy was last seen by a server.'
              valuemap:
                name: 'Last seen'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.last_seen
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
              trigger_prototypes:
                - uuid: 03c66875e25e450abc2cec1c44706de1
                  expression: 'last(/Zabbix server health by Zabbix agent/zabbix.proxy.last_seen[{#PROXY.NAME}],#1)>{$ZABBIX.PROXY.LAST_SEEN.MAX}'
                  name: 'Zabbix server: Proxy [{#PROXY.NAME}]: Zabbix proxy last seen'
                  event_name: 'Zabbix server: Proxy [{#PROXY.NAME}]: Zabbix proxy last seen more than {$ZABBIX.PROXY.LAST_SEEN.MAX} seconds ago'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: WARNING
                  description: 'Zabbix proxy is not updating the configuration data.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: df8e40481b814d00b3bbabc4f5bb80d7
                  expression: 'last(/Zabbix server health by Zabbix agent/zabbix.proxy.last_seen[{#PROXY.NAME}],#1)=-1'
                  name: 'Zabbix server: Proxy [{#PROXY.NAME}]: Zabbix proxy never seen'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: WARNING
                  description: 'Zabbix proxy is not updating the configuration data.'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: 51314d483e444e6c86b3585d1d37b152
              name: 'Proxy [{#PROXY.NAME}]: Mode'
              type: DEPENDENT
              key: 'zabbix.proxy.mode[{#PROXY.NAME}]'
              description: 'The mode of Zabbix proxy.'
              valuemap:
                name: 'Proxy mode'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.passive
                - type: JAVASCRIPT
                  parameters:
                    - 'return value === ''false'' ? 0 : 1'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 712b5cf03d574384abc9c57964157b12
              name: 'Proxy [{#PROXY.NAME}]: PSK'
              type: DEPENDENT
              key: 'zabbix.proxy.psk[{#PROXY.NAME}]'
              description: 'The encryption status for connections from a proxy.'
              valuemap:
                name: 'Service state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.psk
                - type: JAVASCRIPT
                  parameters:
                    - 'return value === ''false'' ? 0 : 1'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 5f4e9356c6e34d178b87cafdfc522e6e
              name: 'Proxy [{#PROXY.NAME}]: Required VPS'
              type: DEPENDENT
              key: 'zabbix.proxy.requiredperformance[{#PROXY.NAME}]'
              value_type: FLOAT
              units: '!vps'
              description: 'The required performance of a proxy (the number of values that need to be collected per second).'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.requiredperformance
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 578af553e8ef46ffaaae04fea8cfbf39
              name: 'Proxy [{#PROXY.NAME}]: Stats'
              type: DEPENDENT
              key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              history: '0'
              value_type: TEXT
              description: 'The statistics for the discovered proxy.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[?(@.name=="{#PROXY.NAME}")].first()'
              master_item:
                key: zabbix.proxies.stats
              tags:
                - tag: component
                  value: proxy
                - tag: component
                  value: raw
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: d83316ca1e8e49fdb02385642c749acb
              name: 'Proxy [{#PROXY.NAME}]: Unencrypted'
              type: DEPENDENT
              key: 'zabbix.proxy.unencrypted[{#PROXY.NAME}]'
              description: 'The encryption status for connections from a proxy.'
              valuemap:
                name: 'Service state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.unencrypted
                - type: JAVASCRIPT
                  parameters:
                    - 'return value === ''false'' ? 0 : 1'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 47df0dd4f9bf4c49a70ad26ad381c4a4
              name: 'Proxy [{#PROXY.NAME}]: Version'
              type: DEPENDENT
              key: 'zabbix.proxy.version[{#PROXY.NAME}]'
              value_type: CHAR
              description: 'A version of Zabbix proxy.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.version
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
          master_item:
            key: zabbix.proxies.stats
          lld_macro_paths:
            - lld_macro: '{#PROXY.GROUP}'
              path: $.proxy_group
            - lld_macro: '{#PROXY.NAME}'
              path: $.name
          preprocessing:
            - type: JAVASCRIPT
              parameters:
                - |
                  var proxies = JSON.parse(value);
                  
                  result = proxies.map(function (proxy) {
                  	return {
                  		'name': proxy.name,
                  		'proxy_group': proxy.proxy_group
                  	};
                  });
                  
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
          overrides:
            - name: 'Tag proxy-group if exists'
              step: '1'
              filter:
                conditions:
                  - macro: '{#PROXY.GROUP}'
                    operator: EXISTS
              operations:
                - operator: REGEXP
                  tags:
                    - tag: proxy-group
                      value: '{#PROXY.GROUP}'
      tags:
        - tag: class
          value: software
        - tag: subclass
          value: logging
        - tag: subclass
          value: monitoring
        - tag: target
          value: server
        - tag: target
          value: zabbix
      macros:
        - macro: '{$ZABBIX.PROXY.LAST_SEEN.MAX}'
          value: '600'
          description: 'The maximum number of seconds that Zabbix proxy has not been seen.'
          config:
            type: TEXT
            priority: '3'
            section_name: Thresholds
            label: 'Seconds since the last Zabbix proxy seen'
            description: 'Threshold value of time since the last Zabbix proxy seen for triggers. No less than 0.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$ZABBIX.SERVER.ADDRESS}'
          description: 'IP/DNS of the remote Zabbix server (default is 127.0.0.1).'
          config:
            type: TEXT
            priority: '1'
            label: 'Zabbix server Address'
            description: 'IP or DNS of the remote Zabbix server that should be monitored via the Zabbix agent.'
            required: 'YES'
        - macro: '{$ZABBIX.SERVER.NODATA_TIMEOUT}'
          value: 5m
          description: 'The time threshold after which statistics are considered unavailable. Used in trigger expressions.'
          config:
            type: TEXT
            priority: '4'
            section_name: Thresholds
            label: 'Time since the last statistic was received'
            description: 'Threshold value of time since the last statistic was received from the remote server.'
        - macro: '{$ZABBIX.SERVER.PORT}'
          description: 'Port of the remote Zabbix server (default is 10051).'
          config:
            type: TEXT
            priority: '2'
            label: 'Zabbix server Port'
            description: 'Port of the remote Zabbix server that should be monitored via the Zabbix agent. In the range from 1 to 65535 inclusive.'
            required: 'YES'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$ZABBIX.SERVER.UTIL.MAX}'
          value: '75'
          description: 'Default maximum threshold for percentage utilization triggers (use macro context for specification).'
          config:
            type: TEXT
            priority: '6'
            section_name: Thresholds
            label: 'Maximum process utilization percentage'
            description: 'Default maximum threshold for process utilization triggers. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$ZABBIX.SERVER.UTIL.MAX:"value cache"}'
          value: '95'
          description: 'Maximum threshold for value cache utilization triggers.'
          config:
            type: TEXT
            priority: '7'
            section_name: Thresholds
            label: 'Maximum value cache utilization percentage'
            description: 'Threshold for the value cache utilization trigger. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$ZABBIX.SERVER.UTIL.MIN}'
          value: '65'
          description: 'Default minimum threshold for percentage utilization triggers (use macro context for specification).'
          config:
            type: TEXT
            priority: '5'
            section_name: Thresholds
            label: 'Minimum process utilization percentage'
            description: 'Default minimum threshold for process utilization triggers. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
      dashboards:
        - uuid: dcb92016508d4aef8e48fbad302ad34b
          name: 'Zabbix server health'
          auto_start: 'NO'
          pages:
            - name: Performance
              widgets:
                - type: svggraph
                  name: 'Cache usage, in %'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.2
                      value: e31a1c
                    - type: STRING
                      name: ds.0.color.3
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.4
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.5
                      value: b15928
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: wcache.trend.pused
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: rcache.buffer.pused
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: wcache.index.pused
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: wcache.history.pused
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: vcache.buffer.pused
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: vmware.buffer.pused
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACA
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Server performance'
                  'y': '6'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.1
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.2
                      value: e31a1c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: wcache.values
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: vps.written
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT},queue]'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACC
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Values processed'
                  'y': '11'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.2
                      value: e31a1c
                    - type: STRING
                      name: ds.0.color.3
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.4
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.5
                      value: b15928
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: wcache.values.uint
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: wcache.values.float
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: wcache.values.not_supported
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: wcache.values.str
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: wcache.values.log
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: wcache.values.text
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACD
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Value cache effectiveness'
                  'y': '16'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.1
                      value: e31a1c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: vcache.cache.hits
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: vcache.cache.misses
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACE
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Internal queues'
                  x: '36'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: ffff99
                    - type: STRING
                      name: ds.0.color.1
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.2
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.3
                      value: d62728
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: preprocessing_queue
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: lld_queue
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: discovery_queue
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: connector_queue
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACB
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Trend cache effectiveness, in %'
                  x: '36'
                  'y': '16'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: ffff99
                    - type: STRING
                      name: ds.0.color.1
                      value: e31a1c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: tcache.pitems
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: tcache.pmisses
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACF
                    - type: INTEGER
                      name: show_problems
                      value: '1'
            - name: Processes
              widgets:
                - type: svggraph
                  name: 'Utilization: LLD processes'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: ffca58
                    - type: STRING
                      name: ds.0.color.1
                      value: 7e57c2
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.lld_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.lld_worker.avg.busy
                    - type: INTEGER
                      name: ds.1.axisy
                      value: '1'
                    - type: STRING
                      name: ds.1.color.0
                      value: ff465c
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.1.fill
                      value: '2'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: lld_queue
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABI
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Preprocessing processes'
                  'y': '6'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: ffca58
                    - type: STRING
                      name: ds.0.color.1
                      value: 7e57c2
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.preprocessing_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.preprocessing_worker.avg.busy
                    - type: INTEGER
                      name: ds.1.axisy
                      value: '1'
                    - type: STRING
                      name: ds.1.color.0
                      value: ff465c
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.1.fill
                      value: '2'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: preprocessing_queue
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABK
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Synchronous gathering processes'
                  'y': '12'
                  width: '72'
                  height: '7'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.2
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.3
                      value: b15928
                    - type: STRING
                      name: ds.0.color.4
                      value: 17becf
                    - type: STRING
                      name: ds.0.color.5
                      value: a6cee3
                    - type: STRING
                      name: ds.0.color.6
                      value: fb9a99
                    - type: STRING
                      name: ds.0.color.7
                      value: bcbd22
                    - type: STRING
                      name: ds.0.color.8
                      value: ffca58
                    - type: STRING
                      name: ds.0.color.9
                      value: e31a1c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.internal_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.ipmi_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.ipmi_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.http_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.java_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.6
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.vmware_collector.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.7
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.browser_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.8
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.odbc_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.9
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.icmp_pinger.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABM
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Asynchronous gathering processes'
                  'y': '19'
                  width: '72'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: bcbd22
                    - type: STRING
                      name: ds.0.color.2
                      value: 6a3d9a
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.agent_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.http_agent_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.snmp_poller.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABN
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Internal processes: Core'
                  'y': '25'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.2
                      value: e31a1c
                    - type: STRING
                      name: ds.0.color.3
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.4
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.5
                      value: b15928
                    - type: STRING
                      name: ds.0.color.6
                      value: a6cee3
                    - type: STRING
                      name: ds.0.color.7
                      value: ff465c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.configuration_syncer.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.configuration_syncer_worker.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.history_syncer.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.self-monitoring.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.service_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.task_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.6
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.timer.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.7
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.history_poller.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '8'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABO
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Gathering processes: Trappers'
                  'y': '31'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: cab2d6
                    - type: STRING
                      name: ds.0.color.1
                      value: ffca58
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.trapper.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.snmp_trapper.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABQ
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Alerting processes'
                  'y': '36'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 17becf
                    - type: STRING
                      name: ds.0.color.1
                      value: bcbd22
                    - type: STRING
                      name: ds.0.color.2
                      value: d62728
                    - type: STRING
                      name: ds.0.color.3
                      value: ff7f00
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.alert_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.alert_syncer.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.alerter.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.escalator.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '4'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABS
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Proxy management and data exchange'
                  'y': '41'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: cab2d6
                    - type: STRING
                      name: ds.0.color.1
                      value: '000080'
                    - type: STRING
                      name: ds.0.color.2
                      value: '808000'
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.trapper.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.proxy_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.proxy_group_manager.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABU
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Preprocessing throughput'
                  'y': '46'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: '808000'
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: preprocessing_throughput
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABV
                - type: svggraph
                  name: 'Utilization: Discovery processes'
                  x: '36'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 7e57c2
                    - type: STRING
                      name: ds.0.color.1
                      value: 1f78b4
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.discovery_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.discovery_worker.avg.busy
                    - type: INTEGER
                      name: ds.1.axisy
                      value: '1'
                    - type: STRING
                      name: ds.1.color.0
                      value: ff465c
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: discovery_queue
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABJ
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Connector processes'
                  x: '36'
                  'y': '6'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: b2df8a
                    - type: STRING
                      name: ds.0.color.1
                      value: ffca58
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.connector_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.connector_worker.avg.busy
                    - type: INTEGER
                      name: ds.1.axisy
                      value: '1'
                    - type: STRING
                      name: ds.1.color.0
                      value: ff465c
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: connector_queue
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABL
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Internal processes: Housekeeping'
                  x: '36'
                  'y': '25'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: ffca58
                    - type: STRING
                      name: ds.0.color.1
                      value: cab2d6
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.housekeeper.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.trigger_housekeeper.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABP
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Availability processes'
                  x: '36'
                  'y': '31'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.1
                      value: b15928
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.unreachable_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.availability_manager.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABR
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Reporting processes'
                  x: '36'
                  'y': '36'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: e377c2
                    - type: STRING
                      name: ds.0.color.1
                      value: ffdf00
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.report_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: process.report_writer.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABT
                    - type: INTEGER
                      name: show_problems
                      value: '1'
            - name: Statuses
              widgets:
                - type: item
                  name: 'Zabbix server version'
                  width: '16'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'Zabbix server health by Zabbix agent'
                        key: version
                    - type: INTEGER
                      name: show.0
                      value: '2'
                    - type: INTEGER
                      name: show.1
                      value: '3'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: time_h_pos
                      value: '2'
                    - type: INTEGER
                      name: time_size
                      value: '9'
                    - type: INTEGER
                      name: time_v_pos
                      value: '2'
                    - type: INTEGER
                      name: value_size
                      value: '25'
                - type: honeycomb
                  name: 'High availability: Node state'
                  x: '16'
                  width: '56'
                  height: '5'
                  fields:
                    - type: STRING
                      name: items.0
                      value: 'Cluster node [*]: Status'
                    - type: STRING
                      name: primary_label
                      value: '{{ITEM.NAME}.regsub("Cluster node \[(.*)]: Status","\1")}'
                    - type: STRING
                      name: reference
                      value: BAAAA
                    - type: INTEGER
                      name: secondary_label_decimal_places
                      value: '0'
                    - type: STRING
                      name: thresholds.0.color
                      value: b2df8a
                    - type: STRING
                      name: thresholds.0.threshold
                      value: '0'
                    - type: STRING
                      name: thresholds.1.color
                      value: '878787'
                    - type: STRING
                      name: thresholds.1.threshold
                      value: '1'
                    - type: STRING
                      name: thresholds.2.color
                      value: e31a1c
                    - type: STRING
                      name: thresholds.2.threshold
                      value: '2'
                    - type: STRING
                      name: thresholds.3.color
                      value: 33a02c
                    - type: STRING
                      name: thresholds.3.threshold
                      value: '3'
      valuemaps:
        - uuid: c9ec732079f64b5d9e8d4b7c628580e3
          name: 'Cluster node status'
          mappings:
            - value: '0'
              newvalue: Standby
            - value: '1'
              newvalue: Stopped
            - value: '2'
              newvalue: Unavailable
            - value: '3'
              newvalue: Active
        - uuid: ee5e7ff1e0e041eca7483ea45213d3a5
          name: Compatibility
          mappings:
            - value: '0'
              newvalue: Undefined
            - value: '1'
              newvalue: Current
            - value: '2'
              newvalue: Outdated
            - value: '3'
              newvalue: Unsupported
        - uuid: edc03d2774094cfcb20afbe8476c85fb
          name: 'Last seen'
          mappings:
            - value: '-1'
              newvalue: Never
        - uuid: 7247343b21ed4fd4823f9148a3245805
          name: 'Proxy mode'
          mappings:
            - value: '0'
              newvalue: Active
            - value: '1'
              newvalue: Passive
        - uuid: 253052f6133b498eb7248bc3d66fa18e
          name: 'Service state'
          mappings:
            - value: '0'
              newvalue: 'Off'
            - value: '1'
              newvalue: 'On'
        - uuid: cfe65eb3384047dfaf31a8d4b09c4de1
          name: 'Value cache operating mode'
          mappings:
            - value: '0'
              newvalue: Normal
            - value: '1'
              newvalue: 'Low memory'
        - uuid: bf89fa6047464f668db6b324abf0cc3e
          name: 'Zabbix server check'
          mappings:
            - value: '0'
              newvalue: 'False'
            - value: '1'
              newvalue: 'True'
    - uuid: 6d6c147c87de4af1b09cf0f55bac50a0
      template: 'Zabbix server health by Zabbix agent active'
      name: 'Zabbix server health by Zabbix agent active'
      description: |
        This template is designed to monitor Zabbix server metrics via the active Zabbix agent.
        
        Specify the address of the remote Zabbix server by changing the {$ZABBIX.SERVER.ADDRESS} and {$ZABBIX.SERVER.PORT} macros. Don't forget to adjust the "StatsAllowedIP" parameter in the remote server's configuration file to allow the collection of statistics.
        
        Generated by official Zabbix template tool "Templator"
      wizard_ready: 'YES'
      readme: |
        ## Overview
        
        This template is designed to monitor Zabbix server metrics via the active Zabbix agent.
        
        ## Setup
        
        Specify the address of the remote Zabbix server as the values for the `Zabbix server Address` and `Zabbix server Port` configuration fields. Don't forget to adjust the `StatsAllowedIP` parameter in the remote server's configuration file to allow the collection of statistics.
      vendor:
        name: Zabbix
        version: 7.4-5
      groups:
        - name: Templates/Applications
      items:
        - uuid: 9b49a702d9874dfab715523b87a98a1a
          name: 'Connector queue'
          type: DEPENDENT
          key: connector_queue
          description: 'The count of values enqueued in the connector queue.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.connector_queue
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "connector" processes started. Please check "StartConnectors" parameter in the server configuration file.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: 97af4a2fb95049ba836f7b2ea1b8ac29
          name: 'Discovery queue'
          type: DEPENDENT
          key: discovery_queue
          description: 'The count of values enqueued in the discovery queue.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.discovery_queue
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "discoverer" processes started. Please check "StartDiscoverers" parameter in the server configuration file.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: 6f925d7628d84fffa4837da1984db203
          name: 'LLD queue'
          type: DEPENDENT
          key: lld_queue
          description: 'The number of values enqueued in the low-level discovery processing queue.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.lld_queue
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: 0247833bf1ba4f7c87fa13c5dbc00308
          name: 'Preprocessing queue'
          type: DEPENDENT
          key: preprocessing_queue
          description: 'The number of values enqueued in the preprocessing queue.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.preprocessing.queue
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: 4ee40b08e9a44f448595fcbb0e8c9ece
          name: 'Preprocessing throughput'
          type: DEPENDENT
          key: preprocessing_throughput
          value_type: FLOAT
          units: Bps
          description: 'Reflects the throughput of the preprocessing.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.preprocessing.queued.size
              error_handler: DISCARD_VALUE
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: b74f03a8047b49af9a2dace775acf8ec
          name: 'Utilization of agent poller data collector processes, in %'
          type: DEPENDENT
          key: process.agent_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the agent poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''agent poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "agent poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 52051812fdb04a63acda8c59090db059
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.agent_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"agent poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.agent_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"agent poller"}'
              name: 'Zabbix server: Utilization of agent poller processes is high'
              event_name: 'Zabbix server: Utilization of agent poller processes over {$ZABBIX.SERVER.UTIL.MAX:"agent poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the agent poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 1f92d15a59a54aa485361deafbee15e8
          name: 'Utilization of alerter internal processes, in %'
          type: DEPENDENT
          key: process.alerter.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the alerter processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''alerter''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "alerter" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 55929cbec22d4bceb43c05615cc30aa4
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.alerter.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"alerter"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.alerter.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"alerter"}'
              name: 'Zabbix server: Utilization of alerter processes is high'
              event_name: 'Zabbix server: Utilization of alerter processes over {$ZABBIX.SERVER.UTIL.MAX:"alerter"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the alerter, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 101445ba757f4c1a9986df4b2302aae7
          name: 'Utilization of alert manager internal processes, in %'
          type: DEPENDENT
          key: process.alert_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the alert manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''alert manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "alert manager" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 161bc98198524413a00490196add9b2b
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.alert_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"alert manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.alert_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"alert manager"}'
              name: 'Zabbix server: Utilization of alert manager processes is high'
              event_name: 'Zabbix server: Utilization of alert manager processes over {$ZABBIX.SERVER.UTIL.MAX:"alert manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the alert manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: c8dec4c38b9c4ad3987bf6a9d200fa6e
          name: 'Utilization of alert syncer internal processes, in %'
          type: DEPENDENT
          key: process.alert_syncer.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the alert syncer processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''alert syncer''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "alert syncer" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: bed49050d02e4be5b64d6763101f81f4
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.alert_syncer.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"alert syncer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.alert_syncer.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"alert syncer"}'
              name: 'Zabbix server: Utilization of alert syncer processes is high'
              event_name: 'Zabbix server: Utilization of alert syncer processes over {$ZABBIX.SERVER.UTIL.MAX:"alert syncer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the alert syncer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: d54f576d30bd492d9379f250f506af7c
          name: 'Utilization of availability manager internal processes, in %'
          type: DEPENDENT
          key: process.availability_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the availability manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''availability manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "availability manager" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 7cda574ff0af44a88b3cde965dec3c1b
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.availability_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"availability manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.availability_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"availability manager"}'
              name: 'Zabbix server: Utilization of availability manager processes is high'
              event_name: 'Zabbix server: Utilization of availability manager processes over {$ZABBIX.SERVER.UTIL.MAX:"availability manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the availability manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: f976e0d8a109418c926882e02f520eaf
          name: 'Utilization of browser poller data collector processes, in %'
          type: DEPENDENT
          key: process.browser_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the browser poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''browser poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "browser poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 8090b7e65f0743938d34d031c04786c2
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.browser_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"browser poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.browser_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"browser poller"}'
              name: 'Zabbix server: Utilization of browser poller processes is high'
              event_name: 'Zabbix server: Utilization of browser poller processes over {$ZABBIX.SERVER.UTIL.MAX:"browser poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the browser poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 282ed37443d54b54ab033be9d8d70b23
          name: 'Utilization of configuration syncer internal processes, in %'
          type: DEPENDENT
          key: process.configuration_syncer.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the configuration syncer processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''configuration syncer''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "configuration syncer" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 0968f49341bf4d4c90fb2a9281f0e61b
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.configuration_syncer.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"configuration syncer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.configuration_syncer.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"configuration syncer"}'
              name: 'Zabbix server: Utilization of configuration syncer processes is high'
              event_name: 'Zabbix server: Utilization of configuration syncer processes over {$ZABBIX.SERVER.UTIL.MAX:"configuration syncer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the configuration syncer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: ba32bcaa13214c0fab6d98e0909d5c94
          name: 'Utilization of configuration syncer worker internal processes, in %'
          type: DEPENDENT
          key: process.configuration_syncer_worker.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the configuration syncer worker processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''configuration syncer worker''].busy.avg'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: b17ce9330f784c608e85c3d2d8e4665a
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.configuration_syncer_worker.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"configuration syncer worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.configuration_syncer_worker.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"configuration syncer worker"}'
              name: 'Zabbix server: Utilization of configuration syncer worker processes is high'
              event_name: 'Zabbix server: Utilization of configuration syncer worker processes over {$ZABBIX.SERVER.UTIL.MAX:"configuration syncer worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the configuration syncer worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 23c553180c134b8e813d721c80dcc76d
          name: 'Utilization of connector manager internal processes, in %'
          type: DEPENDENT
          key: process.connector_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the connector manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''connector manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "connector manager" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: aeea0a0f2394447483ba8274c072ee95
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.connector_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"connector manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.connector_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"connector manager"}'
              name: 'Zabbix server: Utilization of connector manager processes is high'
              event_name: 'Zabbix server: Utilization of connector manager processes over {$ZABBIX.SERVER.UTIL.MAX:"connector manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the connector manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 77ee49931238400d81c597b146d291cd
          name: 'Utilization of connector worker internal processes, in %'
          type: DEPENDENT
          key: process.connector_worker.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the connector worker processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''connector worker''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "connector worker" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 0a12645bdd92487486281070bd3b6ff9
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.connector_worker.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"connector worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.connector_worker.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"connector worker"}'
              name: 'Zabbix server: Utilization of connector worker processes is high'
              event_name: 'Zabbix server: Utilization of connector worker processes over {$ZABBIX.SERVER.UTIL.MAX:"connector worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the connector worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: d2ac8e1c42704bc9aea9fcfe50fbdbdd
          name: 'Utilization of discovery manager internal processes, in %'
          type: DEPENDENT
          key: process.discovery_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the discovery manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''discovery manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "discovery manager" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 96e3bce31fff4037a4586d0b815cf290
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.discovery_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"discovery manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.discovery_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"discovery manager"}'
              name: 'Zabbix server: Utilization of discovery manager processes is high'
              event_name: 'Zabbix server: Utilization of discovery manager processes over {$ZABBIX.SERVER.UTIL.MAX:"discovery manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the discovery manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 9e1200fc5d0a4ccfaff4fb1926b2ef31
          name: 'Utilization of discovery worker internal processes, in %'
          type: DEPENDENT
          key: process.discovery_worker.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the discovery worker processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''discovery worker''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "discovery worker" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 134b0d08ae6b43a1b136793b3084bfd3
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.discovery_worker.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"discovery worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.discovery_worker.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"discovery worker"}'
              name: 'Zabbix server: Utilization of discovery worker processes is high'
              event_name: 'Zabbix server: Utilization of discovery worker processes over {$ZABBIX.SERVER.UTIL.MAX:"discovery worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the discovery worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 27f7bcbcc7fa4c91a8f82bbc2f470cd5
          name: 'Utilization of escalator internal processes, in %'
          type: DEPENDENT
          key: process.escalator.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the escalator processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''escalator''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "escalator" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: bbb663f67af94a50bfc834487750385b
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.escalator.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"escalator"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.escalator.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"escalator"}'
              name: 'Zabbix server: Utilization of escalator processes is high'
              event_name: 'Zabbix server: Utilization of escalator processes over {$ZABBIX.SERVER.UTIL.MAX:"escalator"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the escalator, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 617a44fb20704e7c8ab1c7847df082d6
          name: 'Utilization of history poller internal processes, in %'
          type: DEPENDENT
          key: process.history_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the history poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''history poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "history poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: f307a979059d46e2b4a77a7756728996
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.history_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"history poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.history_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"history poller"}'
              name: 'Zabbix server: Utilization of history poller processes is high'
              event_name: 'Zabbix server: Utilization of history poller processes over {$ZABBIX.SERVER.UTIL.MAX:"history poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the history poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: ebdb96a5d7264126895181f1256de4a4
          name: 'Utilization of history syncer internal processes, in %'
          type: DEPENDENT
          key: process.history_syncer.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the history syncer processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''history syncer''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "history syncer" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: dfe7bf1d932d4451906ccdf1716c06e5
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.history_syncer.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"history syncer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.history_syncer.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"history syncer"}'
              name: 'Zabbix server: Utilization of history syncer processes is high'
              event_name: 'Zabbix server: Utilization of history syncer processes over {$ZABBIX.SERVER.UTIL.MAX:"history syncer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the history syncer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 9be1900382ee432f912882f61d457d55
          name: 'Utilization of housekeeper internal processes, in %'
          type: DEPENDENT
          key: process.housekeeper.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the housekeeper processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''housekeeper''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "housekeeper" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: b69548aebe7646b69848b66ea9c55cdc
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.housekeeper.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"housekeeper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.housekeeper.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"housekeeper"}'
              name: 'Zabbix server: Utilization of housekeeper processes is high'
              event_name: 'Zabbix server: Utilization of housekeeper processes over {$ZABBIX.SERVER.UTIL.MAX:"housekeeper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the housekeeper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: cc48cb65a5ad417a81bfc25b1c41aa3b
          name: 'Utilization of http agent poller data collector processes, in %'
          type: DEPENDENT
          key: process.http_agent_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the http agent poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''http agent poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "http agent poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: e64d4c1bd8334e65a40fdf1212931eba
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.http_agent_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"http agent poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.http_agent_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"http agent poller"}'
              name: 'Zabbix server: Utilization of http agent poller processes is high'
              event_name: 'Zabbix server: Utilization of http agent poller processes over {$ZABBIX.SERVER.UTIL.MAX:"http agent poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the http agent poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 91a0bab07ace4721aa91fdf4c943d1fc
          name: 'Utilization of http poller data collector processes, in %'
          type: DEPENDENT
          key: process.http_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the http poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''http poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "http poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 6e0171b059c14e0e901b9fe6ae1b87b7
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.http_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"http poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.http_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"http poller"}'
              name: 'Zabbix server: Utilization of http poller processes is high'
              event_name: 'Zabbix server: Utilization of http poller processes over {$ZABBIX.SERVER.UTIL.MAX:"http poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the http poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: f3604ea1b796405b97b0c0d1628e07ac
          name: 'Utilization of icmp pinger data collector processes, in %'
          type: DEPENDENT
          key: process.icmp_pinger.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the icmp pinger processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''icmp pinger''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "icmp pinger" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 1e25430b01b34700b0ff8133e18d5f87
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.icmp_pinger.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"icmp pinger"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.icmp_pinger.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"icmp pinger"}'
              name: 'Zabbix server: Utilization of icmp pinger processes is high'
              event_name: 'Zabbix server: Utilization of icmp pinger processes over {$ZABBIX.SERVER.UTIL.MAX:"icmp pinger"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the icmp pinger, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 0f53768b5c4a4958b081c70793aa3fdf
          name: 'Utilization of internal poller data collector processes, in %'
          type: DEPENDENT
          key: process.internal_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the internal poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''internal poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "internal poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: eb8a30975bef4bf4bafd4e69d7e94cd3
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.internal_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"internal poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.internal_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"internal poller"}'
              name: 'Zabbix server: Utilization of internal poller processes is high'
              event_name: 'Zabbix server: Utilization of internal poller processes over {$ZABBIX.SERVER.UTIL.MAX:"internal poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the internal poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 3c45bdcba13a4783984696ae2ff6eb46
          name: 'Utilization of ipmi manager internal processes, in %'
          type: DEPENDENT
          key: process.ipmi_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the ipmi manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''ipmi manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "ipmi manager" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 5c1b160b10d4463092051485a3489ddf
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.ipmi_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"ipmi manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.ipmi_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"ipmi manager"}'
              name: 'Zabbix server: Utilization of ipmi manager processes is high'
              event_name: 'Zabbix server: Utilization of ipmi manager processes over {$ZABBIX.SERVER.UTIL.MAX:"ipmi manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the ipmi manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 47a99733ef2b4e36a4ac58e29b63c810
          name: 'Utilization of ipmi poller data collector processes, in %'
          type: DEPENDENT
          key: process.ipmi_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the ipmi poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''ipmi poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "ipmi poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 3118da52346341d880b440c83d41e17a
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.ipmi_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"ipmi poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.ipmi_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"ipmi poller"}'
              name: 'Zabbix server: Utilization of ipmi poller processes is high'
              event_name: 'Zabbix server: Utilization of ipmi poller processes over {$ZABBIX.SERVER.UTIL.MAX:"ipmi poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the ipmi poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 933b92aecdbd4765867d679d3db4746e
          name: 'Utilization of java poller data collector processes, in %'
          type: DEPENDENT
          key: process.java_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the java poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''java poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "java poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 16a9e28d6c1f4bc6b933623aa6e6b067
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.java_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"java poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.java_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"java poller"}'
              name: 'Zabbix server: Utilization of java poller processes is high'
              event_name: 'Zabbix server: Utilization of java poller processes over {$ZABBIX.SERVER.UTIL.MAX:"java poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the java poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 30b7e2b8626c49d58b9b57490ad7ef3d
          name: 'Utilization of LLD manager internal processes, in %'
          type: DEPENDENT
          key: process.lld_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the LLD manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''lld manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "LLD manager" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 9128e4acba994c4898ac265e556eb709
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.lld_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"LLD manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.lld_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"LLD manager"}'
              name: 'Zabbix server: Utilization of LLD manager processes is high'
              event_name: 'Zabbix server: Utilization of LLD manager processes over {$ZABBIX.SERVER.UTIL.MAX:"LLD manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the LLD manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 8d38e7792a4649e49864271e9371abdc
          name: 'Utilization of LLD worker internal processes, in %'
          type: DEPENDENT
          key: process.lld_worker.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the LLD worker processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''lld worker''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "LLD worker" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 495c1295b5fe43a78f5a86c2844022e3
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.lld_worker.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"LLD worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.lld_worker.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"LLD worker"}'
              name: 'Zabbix server: Utilization of LLD worker processes is high'
              event_name: 'Zabbix server: Utilization of LLD worker processes over {$ZABBIX.SERVER.UTIL.MAX:"LLD worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the LLD worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 0fd4be9abb814541878730c77a118b4f
          name: 'Utilization of ODBC poller data collector processes, in %'
          type: DEPENDENT
          key: process.odbc_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the ODBC poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''odbc poller''].busy.avg'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: e790935b8a5d4e088dc2edff813ecbf9
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.odbc_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"ODBC poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.odbc_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"ODBC poller"}'
              name: 'Zabbix server: Utilization of ODBC poller processes is high'
              event_name: 'Zabbix server: Utilization of ODBC poller processes over {$ZABBIX.SERVER.UTIL.MAX:"ODBC poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the ODBC poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: c18525d18ae0460fbc1605ec2be08087
          name: 'Utilization of poller data collector processes, in %'
          type: DEPENDENT
          key: process.poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: a2aa7457b1444736aee85b246317ece0
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"poller"}'
              name: 'Zabbix server: Utilization of poller processes is high'
              event_name: 'Zabbix server: Utilization of poller processes over {$ZABBIX.SERVER.UTIL.MAX:"poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: ce96c2ee2cc74adb99d7fe4d3cac1507
          name: 'Utilization of preprocessing manager internal processes, in %'
          type: DEPENDENT
          key: process.preprocessing_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the preprocessing manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''preprocessing manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "preprocessing manager" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 27cf66b388224931b8b839a10f027b10
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.preprocessing_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"preprocessing manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.preprocessing_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"preprocessing manager"}'
              name: 'Zabbix server: Utilization of preprocessing manager processes is high'
              event_name: 'Zabbix server: Utilization of preprocessing manager processes over {$ZABBIX.SERVER.UTIL.MAX:"preprocessing manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the preprocessing manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 5d5d66cb32384b1294acdcfc99eb731f
          name: 'Utilization of preprocessing worker internal processes, in %'
          type: DEPENDENT
          key: process.preprocessing_worker.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the preprocessing worker processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''preprocessing worker''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "preprocessing worker" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: b6d5460fe0c640169574c9fdf3538773
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.preprocessing_worker.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"preprocessing worker"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.preprocessing_worker.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"preprocessing worker"}'
              name: 'Zabbix server: Utilization of preprocessing worker processes is high'
              event_name: 'Zabbix server: Utilization of preprocessing worker processes over {$ZABBIX.SERVER.UTIL.MAX:"preprocessing worker"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the preprocessing worker, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 9b799bcc2e0a46bca8811d5b5fb8ad9d
          name: 'Utilization of proxy group manager internal processes, in %'
          type: DEPENDENT
          key: process.proxy_group_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the proxy group manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''proxy group manager''].busy.avg'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: da4eb00198b54da8b621136df8299c80
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.proxy_group_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"proxy group manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.proxy_group_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"proxy group manager"}'
              name: 'Zabbix server: Utilization of proxy group manager processes is high'
              event_name: 'Zabbix server: Utilization of proxy group manager processes over {$ZABBIX.SERVER.UTIL.MAX:"proxy group manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the proxy group manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 3d9eaec2c0984ed48edd973f6b32614b
          name: 'Utilization of proxy poller data collector processes, in %'
          type: DEPENDENT
          key: process.proxy_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the proxy poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''proxy poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "proxy poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: df0010ebd7e848beadafba435765b1e0
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.proxy_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"proxy poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.proxy_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"proxy poller"}'
              name: 'Zabbix server: Utilization of proxy poller processes is high'
              event_name: 'Zabbix server: Utilization of proxy poller processes over {$ZABBIX.SERVER.UTIL.MAX:"proxy poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the proxy poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 47eba63d72b24dd3b57354b16cc8dd6a
          name: 'Utilization of report manager internal processes, in %'
          type: DEPENDENT
          key: process.report_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the report manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''report manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "report manager" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: a5836478648f4448a8e3ce85d08daa4e
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.report_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"report manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.report_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"report manager"}'
              name: 'Zabbix server: Utilization of report manager processes is high'
              event_name: 'Zabbix server: Utilization of report manager processes over {$ZABBIX.SERVER.UTIL.MAX:"report manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the report manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 69ede6567bb44228ae8cfa1258c1bed0
          name: 'Utilization of report writer internal processes, in %'
          type: DEPENDENT
          key: process.report_writer.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the report writer processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''report writer''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "report writer" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 545c0bf735524164b3d77e455d03e8af
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.report_writer.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"report writer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.report_writer.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"report writer"}'
              name: 'Zabbix server: Utilization of report writer processes is high'
              event_name: 'Zabbix server: Utilization of report writer processes over {$ZABBIX.SERVER.UTIL.MAX:"report writer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the report writer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 8968f305c67a4b929a18d2f8911d044c
          name: 'Utilization of self-monitoring internal processes, in %'
          type: DEPENDENT
          key: process.self-monitoring.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the self-monitoring processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''self-monitoring''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "self-monitoring" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 2a6c0c7ba1f4406695b938af44d6884d
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.self-monitoring.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"self-monitoring"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.self-monitoring.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"self-monitoring"}'
              name: 'Zabbix server: Utilization of self-monitoring processes is high'
              event_name: 'Zabbix server: Utilization of self-monitoring processes over {$ZABBIX.SERVER.UTIL.MAX:"self-monitoring"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the self-monitoring, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 39ecbb836a2647bb989807a31b30b791
          name: 'Utilization of service manager internal processes, in %'
          type: DEPENDENT
          key: process.service_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the service manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''service manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "service manager" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 3b9a86fd759641a78bcd43cfccc625b3
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.service_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"service manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.service_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"service manager"}'
              name: 'Zabbix server: Utilization of service manager processes is high'
              event_name: 'Zabbix server: Utilization of service manager processes over {$ZABBIX.SERVER.UTIL.MAX:"service manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the service manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 9a2fe1441aa84b35bbb076ed8429321f
          name: 'Utilization of snmp poller data collector processes, in %'
          type: DEPENDENT
          key: process.snmp_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the snmp poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''snmp poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "snmp poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 680e6203ce4849d0aa3b2ca16c9757f2
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.snmp_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"snmp poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.snmp_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"snmp poller"}'
              name: 'Zabbix server: Utilization of snmp poller processes is high'
              event_name: 'Zabbix server: Utilization of snmp poller processes over {$ZABBIX.SERVER.UTIL.MAX:"snmp poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the snmp poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 59857e15812347d0b231fa237acd3089
          name: 'Utilization of snmp trapper data collector processes, in %'
          type: DEPENDENT
          key: process.snmp_trapper.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the snmp trapper processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''snmp trapper''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "snmp trapper" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 60a0295d8b7b471db7e42ab32223cc57
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.snmp_trapper.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"snmp trapper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.snmp_trapper.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"snmp trapper"}'
              name: 'Zabbix server: Utilization of snmp trapper processes is high'
              event_name: 'Zabbix server: Utilization of snmp trapper processes over {$ZABBIX.SERVER.UTIL.MAX:"snmp trapper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the snmp trapper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 8a0c0e7b1c8c40d38e032f27e503c75e
          name: 'Utilization of task manager internal processes, in %'
          type: DEPENDENT
          key: process.task_manager.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the task manager processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''task manager''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "task manager" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 337a17c96f8f410790841f2f2807eba7
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.task_manager.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"task manager"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.task_manager.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"task manager"}'
              name: 'Zabbix server: Utilization of task manager processes is high'
              event_name: 'Zabbix server: Utilization of task manager processes over {$ZABBIX.SERVER.UTIL.MAX:"task manager"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the task manager, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: f1006194bd594541997308ce9d68a4a6
          name: 'Utilization of timer internal processes, in %'
          type: DEPENDENT
          key: process.timer.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the timer processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''timer''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "timer" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: 2498dbd86bc449b9afc80e4eeb6d19e9
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.timer.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"timer"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.timer.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"timer"}'
              name: 'Zabbix server: Utilization of timer processes is high'
              event_name: 'Zabbix server: Utilization of timer processes over {$ZABBIX.SERVER.UTIL.MAX:"timer"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the timer, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 63085203f3fe415da1e8d3be108b3688
          name: 'Utilization of trapper data collector processes, in %'
          type: DEPENDENT
          key: process.trapper.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the trapper processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''trapper''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "trapper" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 414276c3e1f749cfa210b5c8978d38df
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.trapper.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"trapper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.trapper.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"trapper"}'
              name: 'Zabbix server: Utilization of trapper processes is high'
              event_name: 'Zabbix server: Utilization of trapper processes over {$ZABBIX.SERVER.UTIL.MAX:"trapper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the trapper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: a17f1501fc924767adc3c6d98b630053
          name: 'Utilization of trigger housekeeper internal processes, in %'
          type: DEPENDENT
          key: process.trigger_housekeeper.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the trigger housekeeper processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''trigger housekeeper''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "trigger housekeeper" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: internal-process
          triggers:
            - uuid: b84fd09565a3470d81d9483551e74a4c
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.trigger_housekeeper.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"trigger housekeeper"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.trigger_housekeeper.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"trigger housekeeper"}'
              name: 'Zabbix server: Utilization of trigger housekeeper processes is high'
              event_name: 'Zabbix server: Utilization of trigger housekeeper processes over {$ZABBIX.SERVER.UTIL.MAX:"trigger housekeeper"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the trigger housekeeper, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: e08abc511b6b4f0c8decb626ca6f6780
          name: 'Utilization of unreachable poller data collector processes, in %'
          type: DEPENDENT
          key: process.unreachable_poller.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the unreachable poller processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''unreachable poller''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "unreachable poller" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 6d110c9dcb49446b9ff76e1f8e25d250
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.unreachable_poller.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"unreachable poller"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.unreachable_poller.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"unreachable poller"}'
              name: 'Zabbix server: Utilization of unreachable poller processes is high'
              event_name: 'Zabbix server: Utilization of unreachable poller processes over {$ZABBIX.SERVER.UTIL.MAX:"unreachable poller"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the unreachable poller, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 96d3c75e95e44d638125f9f67e62dd76
          name: 'Utilization of vmware collector data collector processes, in %'
          type: DEPENDENT
          key: process.vmware_collector.avg.busy
          value_type: FLOAT
          units: '%'
          description: 'The average percentage of the time during which the vmware collector processes have been busy for the last minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.process[''vmware collector''].busy.avg'
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "vmware collector" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: gathering-process
          triggers:
            - uuid: 5248479b4921499bbe3004d7de0d5bec
              expression: 'avg(/Zabbix server health by Zabbix agent active/process.vmware_collector.avg.busy,10m)>{$ZABBIX.SERVER.UTIL.MAX:"vmware collector"}'
              recovery_mode: RECOVERY_EXPRESSION
              recovery_expression: 'avg(/Zabbix server health by Zabbix agent active/process.vmware_collector.avg.busy,10m)<{$ZABBIX.SERVER.UTIL.MIN:"vmware collector"}'
              name: 'Zabbix server: Utilization of vmware collector processes is high'
              event_name: 'Zabbix server: Utilization of vmware collector processes over {$ZABBIX.SERVER.UTIL.MAX:"vmware collector"}%'
              priority: AVERAGE
              description: 'Indicates potential performance issues with the vmware collector, which may affect monitoring efficiency and response times.'
              tags:
                - tag: scope
                  value: performance
        - uuid: 9a91a17f14ac471094b7741c5eaeb84d
          name: 'Configuration cache, % used'
          type: DEPENDENT
          key: rcache.buffer.pused
          value_type: FLOAT
          units: '%'
          description: 'The availability statistics of Zabbix configuration cache. The percentage of used data buffer.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.rcache.pused
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 1d6d78c512d34286950c00b7a0ceb810
              expression: 'max(/Zabbix server health by Zabbix agent active/rcache.buffer.pused,10m)>{$ZABBIX.SERVER.UTIL.MAX:"configuration cache"}'
              name: 'Zabbix server: Excessive configuration cache usage'
              event_name: 'Zabbix server: More than {$ZABBIX.SERVER.UTIL.MAX:"configuration cache"}% used in the configuration cache'
              priority: AVERAGE
              description: 'Consider increasing `CacheSize` in the `zabbix_server.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
            - uuid: 407dc6ff910a46dd9cb72d9ccce66fce
              expression: 'nodata(/Zabbix server health by Zabbix agent active/rcache.buffer.pused,{$ZABBIX.SERVER.NODATA_TIMEOUT})=1'
              name: 'Zabbix server: Failed to fetch stats data'
              event_name: 'Zabbix server: Failed to fetch stats data (or no data for {$ZABBIX.SERVER.NODATA_TIMEOUT})'
              priority: WARNING
              description: 'Zabbix has not received statistics data for `{$ZABBIX.SERVER.NODATA_TIMEOUT}`.'
              tags:
                - tag: scope
                  value: availability
        - uuid: 244d6fafb5774ce09a02267369ebe627
          name: 'Zabbix server check'
          type: DEPENDENT
          key: server_check
          trends: '0'
          description: 'Flag indicating whether it is a server or not.'
          valuemap:
            name: 'Zabbix server check'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.triggers
              error_handler: CUSTOM_VALUE
              error_handler_params: '0'
            - type: IN_RANGE
              parameters:
                - ''
                - '0'
              error_handler: CUSTOM_VALUE
              error_handler_params: '1'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: b8f39d2f4b0a458eafde5d0442bf073f
              expression: 'last(/Zabbix server health by Zabbix agent active/server_check)=0'
              name: 'Zabbix server: Wrong template assigned'
              event_name: 'Zabbix server: Zabbix server template is assigned to Zabbix proxy'
              priority: DISASTER
              description: 'Check that the template has been selected correctly.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: 8ab73f9ddc8c4eabaef323693c350b0e
          name: 'Trend function cache, % of unique requests'
          type: DEPENDENT
          key: tcache.pitems
          value_type: FLOAT
          units: '%'
          description: |
            The effectiveness statistics of the Zabbix trend function cache. The percentage of cached items calculated from the sum of the cached items plus requests.
            A low percentage most likely means that the cache size can be reduced.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.tcache.pitems
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Not supported in this version.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: 2f23e8e930554c62aec0b11d3f1568b7
          name: 'Trend function cache, % of misses'
          type: DEPENDENT
          key: tcache.pmisses
          value_type: FLOAT
          units: '%'
          description: 'The effectiveness statistics of the Zabbix trend function cache. The percentage of cache misses.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.tcache.pmisses
              error_handler: CUSTOM_ERROR
              error_handler_params: 'Not supported in this version.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: ff55defb24074bf8b2346046f4fb3cda
          name: 'Value cache, % used'
          type: DEPENDENT
          key: vcache.buffer.pused
          value_type: FLOAT
          units: '%'
          description: 'The availability statistics of Zabbix value cache. The percentage of used data buffer.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.vcache.buffer.pused
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 0d970aa35f8a4086b1a5534bdbbc7480
              expression: 'max(/Zabbix server health by Zabbix agent active/vcache.buffer.pused,10m)>{$ZABBIX.SERVER.UTIL.MAX:"value cache"}'
              name: 'Zabbix server: Excessive value cache usage'
              event_name: 'Zabbix server: More than {$ZABBIX.SERVER.UTIL.MAX:"value cache"}% used in the value cache'
              priority: AVERAGE
              description: 'Consider increasing `ValueCacheSize` in the `zabbix_server.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 4bce063f5d374efcb1a2ffcd2658b153
          name: 'Value cache hits'
          type: DEPENDENT
          key: vcache.cache.hits
          value_type: FLOAT
          units: '!vps'
          description: 'The effectiveness statistics of Zabbix value cache. The number of cache hits (history values taken from the cache).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.vcache.cache.hits
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: e7510966d6ce41d3aa383e83d3fe7ec1
          name: 'Value cache misses'
          type: DEPENDENT
          key: vcache.cache.misses
          value_type: FLOAT
          units: '!vps'
          description: 'The effectiveness statistics of Zabbix value cache. The number of cache misses (history values taken from the database).'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.vcache.cache.misses
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
        - uuid: c7d7b0e80bf040aabc9f1350e24ba994
          name: 'Value cache operating mode'
          type: DEPENDENT
          key: vcache.cache.mode
          units: '!vps'
          description: 'The operating mode of the value cache.'
          valuemap:
            name: 'Value cache operating mode'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.vcache.cache.mode
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: afa69411eaf94f029b319c2b03c969c6
              expression: 'last(/Zabbix server health by Zabbix agent active/vcache.cache.mode)=1'
              name: 'Zabbix server: Zabbix value cache working in low-memory mode'
              priority: HIGH
              description: 'Once low-memory mode has been switched on, the value cache will remain in this state for 24 hours, even if the problem that triggered this mode is resolved sooner.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 92d7e426ec744ea196032825231df258
          name: Version
          type: DEPENDENT
          key: version
          value_type: CHAR
          description: 'The version of Zabbix server.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.version
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: a5c77cd2518844c9a27ced51d57b0a69
              expression: 'last(/Zabbix server health by Zabbix agent active/version,#1)<>last(/Zabbix server health by Zabbix agent active/version,#2) and length(last(/Zabbix server health by Zabbix agent active/version))>0'
              name: 'Zabbix server: Version has changed'
              event_name: 'Zabbix server: Version has changed (new version: {ITEM.VALUE})'
              priority: INFO
              description: 'Zabbix server version has changed. Acknowledge to close the problem manually.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: notice
        - uuid: e2244cdef6774aaf97b244ac6617316f
          name: 'VMware cache, % used'
          type: DEPENDENT
          key: vmware.buffer.pused
          value_type: FLOAT
          units: '%'
          description: 'The availability statistics of Zabbix vmware cache. The percentage of used data buffer.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.vmware.pused
              error_handler: CUSTOM_ERROR
              error_handler_params: 'No "vmware collector" processes started.'
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 8ef38ec3297344c48ee6a1c632481f2e
              expression: 'max(/Zabbix server health by Zabbix agent active/vmware.buffer.pused,10m)>{$ZABBIX.SERVER.UTIL.MAX:"vmware cache"}'
              name: 'Zabbix server: Excessive vmware cache usage'
              event_name: 'Zabbix server: More than {$ZABBIX.SERVER.UTIL.MAX:"vmware cache"}% used in the vmware cache'
              priority: AVERAGE
              description: 'Consider increasing `VMwareCacheSize` in the `zabbix_server.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 90ee7e364f7e4b64802482ea189a1d84
          name: 'Number of values synchronized with the database per second'
          type: DEPENDENT
          key: vps.written
          value_type: FLOAT
          units: '!vps'
          description: 'Average quantity of values written to the database, recalculated once per minute.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.vps.written_total
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: a7c9054d62324c61a6b7dba48683617e
          name: 'History write cache, % used'
          type: DEPENDENT
          key: wcache.history.pused
          value_type: FLOAT
          units: '%'
          description: |
            The statistics and availability of Zabbix write cache. The percentage of used history buffer.
            The history cache is used to store item values. A high number indicates database performance problems.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.history.pused
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 2cb075a78bf248aea1f18afe56a8406c
              expression: 'max(/Zabbix server health by Zabbix agent active/wcache.history.pused,10m)>{$ZABBIX.SERVER.UTIL.MAX:"history cache"}'
              name: 'Zabbix server: Excessive history cache usage'
              event_name: 'Zabbix server: More than {$ZABBIX.SERVER.UTIL.MAX:"history cache"}% used in the history cache'
              priority: AVERAGE
              description: 'Consider increasing `HistoryCacheSize` in the `zabbix_server.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 9a6c936674fb47daa2625604acb78f51
          name: 'History index cache, % used'
          type: DEPENDENT
          key: wcache.index.pused
          value_type: FLOAT
          units: '%'
          description: |
            The statistics and availability of Zabbix write cache. The percentage of used history index buffer.
            The history index cache is used to index values stored in the history cache.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.index.pused
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 4be3fd672e3c464b94a23fa3b51176df
              expression: 'max(/Zabbix server health by Zabbix agent active/wcache.index.pused,10m)>{$ZABBIX.SERVER.UTIL.MAX:"index cache"}'
              name: 'Zabbix server: Excessive history index cache usage'
              event_name: 'Zabbix server: More than {$ZABBIX.SERVER.UTIL.MAX:"index cache"}% used in the history index cache'
              priority: AVERAGE
              description: 'Consider increasing `HistoryIndexCacheSize` in the `zabbix_server.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: 55cb808101fe4fc8ace522c3f57e6c97
          name: 'Trend write cache, % used'
          type: DEPENDENT
          key: wcache.trend.pused
          value_type: FLOAT
          units: '%'
          description: |
            The statistics and availability of Zabbix write cache. The percentage of used trend buffer.
            The trend cache stores the aggregate of all items that have received data for the current hour.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.trend.pused
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: ae75c7ba703e42b7a443e14f3b47c38d
              expression: 'max(/Zabbix server health by Zabbix agent active/wcache.trend.pused,10m)>{$ZABBIX.SERVER.UTIL.MAX:"trend cache"}'
              name: 'Zabbix server: Excessive trends cache usage'
              event_name: 'Zabbix server: More than {$ZABBIX.SERVER.UTIL.MAX:"trend cache"}% used in the trends cache'
              priority: AVERAGE
              description: 'Consider increasing `TrendCacheSize` in the `zabbix_server.conf` configuration file.'
              tags:
                - tag: scope
                  value: capacity
                - tag: scope
                  value: performance
        - uuid: b031a389ab79493f8bf84df55673805f
          name: 'Number of processed values per second'
          type: DEPENDENT
          key: wcache.values
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The total number of values processed by Zabbix server or Zabbix proxy, except unsupported items.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.all
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 2b8411ca3fe048bbbe99631322cd2f88
          name: 'Number of processed numeric (float) values per second'
          type: DEPENDENT
          key: wcache.values.float
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed numeric (float) values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.float
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: ccefd74e15e14ead8914aab1874bcf9b
          name: 'Number of processed log values per second'
          type: DEPENDENT
          key: wcache.values.log
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed log values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.log
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: c6f051ebbcac4f1383cad1cac88b4710
          name: 'Number of processed not supported values per second'
          type: DEPENDENT
          key: wcache.values.not_supported
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of times the item processing resulted in an item becoming unsupported or remaining in that state.
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.data.wcache.values[''not supported'']'
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 8c2f87ab4b484d6ab206b19a50959088
          name: 'Number of processed character values per second'
          type: DEPENDENT
          key: wcache.values.str
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed character values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.str
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: f1c2ae5c89204efe81d67248587971c2
          name: 'Number of processed text values per second'
          type: DEPENDENT
          key: wcache.values.text
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed text values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.text
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: cb37f569c18247099e9b15951d76fdb4
          name: 'Number of processed numeric (unsigned) values per second'
          type: DEPENDENT
          key: wcache.values.uint
          value_type: FLOAT
          units: '!vps'
          description: |
            The statistics and availability of Zabbix write cache.
            The number of processed numeric (unsigned) values.
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.wcache.values.uint
            - type: CHANGE_PER_SECOND
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: nvps
            - tag: component
              value: system
        - uuid: 868fe1403673438d8d65d09609754a97
          name: 'Zabbix proxies stats'
          type: DEPENDENT
          key: zabbix.proxies.stats
          history: '0'
          value_type: TEXT
          description: 'The master item of Zabbix proxies'' statistics.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.proxy
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          tags:
            - tag: component
              value: raw
        - uuid: 99be4e08ef924b49a3237bc4970e61c2
          name: 'Queue over 10 minutes'
          type: ZABBIX_ACTIVE
          key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT},queue,10m]'
          description: 'The number of monitored items in the queue that are delayed by at least 10 minutes.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.queue
          tags:
            - tag: component
              value: system
          triggers:
            - uuid: 26f00ef4bbae4b94a8228232072722aa
              expression: 'min(/Zabbix server health by Zabbix agent active/zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT},queue,10m],10m)>100'
              name: 'Zabbix server: More than 100 items have been missing data for over 10 minutes'
              priority: WARNING
              description: 'Indicates potential issues with network connectivity, agent failures, or unresponsive monitored resources that require attention.'
              tags:
                - tag: scope
                  value: performance
        - uuid: ef3a71dd5daf4c8cbfa75ed66ef7dee7
          name: Queue
          type: ZABBIX_ACTIVE
          key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT},queue]'
          description: 'The number of monitored items in the queue that are delayed by at least 6 seconds.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.queue
          tags:
            - tag: component
              value: system
        - uuid: 6bc7fdba3ff846cb87f916b05e303572
          name: 'Zabbix stats'
          type: ZABBIX_ACTIVE
          key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          history: '0'
          value_type: TEXT
          description: 'The master item of Zabbix server statistics.'
          tags:
            - tag: component
              value: raw
      discovery_rules:
        - uuid: c0b766a1f6f640faa911b4ac4c5d7bb6
          name: 'High availability cluster node discovery'
          type: DEPENDENT
          key: zabbix.nodes.discovery
          description: 'LLD rule with item and trigger prototypes for node discovery.'
          item_prototypes:
            - uuid: 7c38495cd55044e29ced4ce5b095f86f
              name: 'Cluster node [{#NODE.NAME}]: Address'
              type: DEPENDENT
              key: 'zabbix.node.address[{#NODE.ID}]'
              value_type: CHAR
              description: 'The IPv4 address of a node.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.address
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.node.stats[{#NODE.ID}]'
              tags:
                - tag: component
                  value: cluster
                - tag: node-id
                  value: '{#NODE.ID}'
                - tag: node-name
                  value: '{#NODE.NAME}'
            - uuid: 89843094ec7944eea6a7cad2b4280e2d
              name: 'Cluster node [{#NODE.NAME}]: Last access age'
              type: DEPENDENT
              key: 'zabbix.node.lastaccess.age[{#NODE.ID}]'
              units: uptime
              description: 'The time between the database''s `unix_timestamp()` and the last access time.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.lastaccess_age
              master_item:
                key: 'zabbix.node.stats[{#NODE.ID}]'
              tags:
                - tag: component
                  value: cluster
                - tag: node-id
                  value: '{#NODE.ID}'
                - tag: node-name
                  value: '{#NODE.NAME}'
            - uuid: 81e699b0d3a349d0bb74071b0fb75f8f
              name: 'Cluster node [{#NODE.NAME}]: Last access time'
              type: DEPENDENT
              key: 'zabbix.node.lastaccess.time[{#NODE.ID}]'
              units: unixtime
              description: 'Last access time.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.lastaccess
              master_item:
                key: 'zabbix.node.stats[{#NODE.ID}]'
              tags:
                - tag: component
                  value: cluster
                - tag: node-id
                  value: '{#NODE.ID}'
                - tag: node-name
                  value: '{#NODE.NAME}'
            - uuid: 23101227cb3a4f4782bc9399c6a198ff
              name: 'Cluster node [{#NODE.NAME}]: Stats'
              type: DEPENDENT
              key: 'zabbix.node.stats[{#NODE.ID}]'
              history: '0'
              value_type: TEXT
              description: 'Provides the statistics of a node.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.data.ha[?(@.id=="{#NODE.ID}")].first()'
              master_item:
                key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
              tags:
                - tag: component
                  value: cluster
                - tag: component
                  value: raw
                - tag: node-id
                  value: '{#NODE.ID}'
                - tag: node-name
                  value: '{#NODE.NAME}'
            - uuid: 39751d281a5b40e8a1bb267f97982b6e
              name: 'Cluster node [{#NODE.NAME}]: Status'
              type: DEPENDENT
              key: 'zabbix.nodes.status[{#NODE.ID}]'
              description: 'The status of a node.'
              valuemap:
                name: 'Cluster node status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.status
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.node.stats[{#NODE.ID}]'
              tags:
                - tag: component
                  value: cluster
                - tag: node-id
                  value: '{#NODE.ID}'
                - tag: node-name
                  value: '{#NODE.NAME}'
              trigger_prototypes:
                - uuid: 3f5929a797014c4795ea812d14713da8
                  expression: 'last(/Zabbix server health by Zabbix agent active/zabbix.nodes.status[{#NODE.ID}],#1)<>last(/Zabbix server health by Zabbix agent active/zabbix.nodes.status[{#NODE.ID}],#2)'
                  name: 'Zabbix server: Cluster node [{#NODE.NAME}]: Status changed'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: INFO
                  description: 'The state of the node has changed. Acknowledge to close the problem manually.'
                  manual_close: 'YES'
                  tags:
                    - tag: scope
                      value: availability
          master_item:
            key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT}]'
          lld_macro_paths:
            - lld_macro: '{#NODE.ID}'
              path: $.id
            - lld_macro: '{#NODE.NAME}'
              path: $.name
          preprocessing:
            - type: JSONPATH
              parameters:
                - $.data.ha
            - type: JAVASCRIPT
              parameters:
                - |
                  var hacluster = JSON.parse(value);
                  
                  result = hacluster.map(function (hanode) {
                  	return {
                  		'id': hanode.id,
                  		'name': hanode.name
                  	};
                  });
                  
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
        - uuid: 9ae3dd3caef84e539d7a51495795f0b6
          name: 'Zabbix proxy discovery'
          type: DEPENDENT
          key: zabbix.proxy.discovery
          description: 'LLD rule with item and trigger prototypes for proxy discovery.'
          item_prototypes:
            - uuid: 2ba040518c6f47689ae14fcbae0be50f
              name: 'Proxy [{#PROXY.NAME}]: Certificate'
              type: DEPENDENT
              key: 'zabbix.proxy.cert[{#PROXY.NAME}]'
              description: 'The encryption status for connections from a proxy.'
              valuemap:
                name: 'Service state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.cert
                - type: JAVASCRIPT
                  parameters:
                    - 'return value === ''false'' ? 0 : 1'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 4364a9257de94337a8f3b646b5a0c64a
              name: 'Proxy [{#PROXY.NAME}]: Compatibility'
              type: DEPENDENT
              key: 'zabbix.proxy.compatibility[{#PROXY.NAME}]'
              description: |
                Version of proxy compared to Zabbix server version.
                
                Possible values:
                0 - Undefined;
                1 - Current version (proxy and server have the same major version);
                2 - Outdated version (proxy version is older than server version, but is partially supported);
                3 - Unsupported version (proxy version is older than server previous LTS release version or server major version is older than proxy major version).
              valuemap:
                name: Compatibility
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.compatibility
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
              trigger_prototypes:
                - uuid: ebb05d922d0b4115a7f543ec27884bb0
                  expression: 'last(/Zabbix server health by Zabbix agent active/zabbix.proxy.compatibility[{#PROXY.NAME}],#1)=3'
                  name: 'Zabbix server: Proxy [{#PROXY.NAME}]: Zabbix proxy is not supported'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: HIGH
                  description: 'Zabbix proxy version is older than server previous LTS release version or server major version is older than proxy major version.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: ecb8145b4d1742c5b63b70571d578841
                  expression: 'last(/Zabbix server health by Zabbix agent active/zabbix.proxy.compatibility[{#PROXY.NAME}],#1)=2'
                  name: 'Zabbix server: Proxy [{#PROXY.NAME}]: Zabbix proxy is outdated'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: WARNING
                  description: 'Zabbix proxy version is older than server version, but is partially supported. Only data collection and remote execution is available.'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: 20dcd000b9fc48b9a82558c51cc32664
              name: 'Proxy [{#PROXY.NAME}]: Compression'
              type: DEPENDENT
              key: 'zabbix.proxy.compression[{#PROXY.NAME}]'
              description: 'The compression status of a proxy.'
              valuemap:
                name: 'Service state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.compression
                - type: JAVASCRIPT
                  parameters:
                    - 'return value === ''false'' ? 0 : 1'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 081329ebe9854457ae4a437e54370063
              name: 'Proxy [{#PROXY.NAME}]: Host count'
              type: DEPENDENT
              key: 'zabbix.proxy.hosts[{#PROXY.NAME}]'
              description: 'The number of enabled hosts assigned to a proxy.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.hosts
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 23f760b8e7bb4a168c743f9392c78619
              name: 'Proxy [{#PROXY.NAME}]: Item count'
              type: DEPENDENT
              key: 'zabbix.proxy.items[{#PROXY.NAME}]'
              description: 'The number of enabled items on enabled hosts assigned to a proxy.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.items
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 75fd83f274174aa39866096801f58b35
              name: 'Proxy [{#PROXY.NAME}]: Last seen, in seconds'
              type: DEPENDENT
              key: 'zabbix.proxy.last_seen[{#PROXY.NAME}]'
              value_type: FLOAT
              description: 'The time when a proxy was last seen by a server.'
              valuemap:
                name: 'Last seen'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.last_seen
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
              trigger_prototypes:
                - uuid: 9e2c54be71674f98b10fc0b40c79d807
                  expression: 'last(/Zabbix server health by Zabbix agent active/zabbix.proxy.last_seen[{#PROXY.NAME}],#1)>{$ZABBIX.PROXY.LAST_SEEN.MAX}'
                  name: 'Zabbix server: Proxy [{#PROXY.NAME}]: Zabbix proxy last seen'
                  event_name: 'Zabbix server: Proxy [{#PROXY.NAME}]: Zabbix proxy last seen more than {$ZABBIX.PROXY.LAST_SEEN.MAX} seconds ago'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: WARNING
                  description: 'Zabbix proxy is not updating the configuration data.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 4fb72306aa814ac1a6f1376d012cab7b
                  expression: 'last(/Zabbix server health by Zabbix agent active/zabbix.proxy.last_seen[{#PROXY.NAME}],#1)=-1'
                  name: 'Zabbix server: Proxy [{#PROXY.NAME}]: Zabbix proxy never seen'
                  opdata: 'Current value: {ITEM.LASTVALUE1}'
                  priority: WARNING
                  description: 'Zabbix proxy is not updating the configuration data.'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: d11a0ed453644b719b181f7c7da9aed9
              name: 'Proxy [{#PROXY.NAME}]: Mode'
              type: DEPENDENT
              key: 'zabbix.proxy.mode[{#PROXY.NAME}]'
              description: 'The mode of Zabbix proxy.'
              valuemap:
                name: 'Proxy mode'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.passive
                - type: JAVASCRIPT
                  parameters:
                    - 'return value === ''false'' ? 0 : 1'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 7348feaca28843c293b58e8c8dcb4611
              name: 'Proxy [{#PROXY.NAME}]: PSK'
              type: DEPENDENT
              key: 'zabbix.proxy.psk[{#PROXY.NAME}]'
              description: 'The encryption status for connections from a proxy.'
              valuemap:
                name: 'Service state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.psk
                - type: JAVASCRIPT
                  parameters:
                    - 'return value === ''false'' ? 0 : 1'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 5ee3fb58653a4a228a0d02cd72937b19
              name: 'Proxy [{#PROXY.NAME}]: Required VPS'
              type: DEPENDENT
              key: 'zabbix.proxy.requiredperformance[{#PROXY.NAME}]'
              value_type: FLOAT
              units: '!vps'
              description: 'The required performance of a proxy (the number of values that need to be collected per second).'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.requiredperformance
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 49d2bf1f174a4bd69a6ca089cfefa448
              name: 'Proxy [{#PROXY.NAME}]: Stats'
              type: DEPENDENT
              key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              history: '0'
              value_type: TEXT
              description: 'The statistics for the discovered proxy.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[?(@.name=="{#PROXY.NAME}")].first()'
              master_item:
                key: zabbix.proxies.stats
              tags:
                - tag: component
                  value: proxy
                - tag: component
                  value: raw
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 04144956e5cd434b8558919e7035a1d8
              name: 'Proxy [{#PROXY.NAME}]: Unencrypted'
              type: DEPENDENT
              key: 'zabbix.proxy.unencrypted[{#PROXY.NAME}]'
              description: 'The encryption status for connections from a proxy.'
              valuemap:
                name: 'Service state'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.unencrypted
                - type: JAVASCRIPT
                  parameters:
                    - 'return value === ''false'' ? 0 : 1'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
            - uuid: 88c2717be026453a8d4a2c10108e5daa
              name: 'Proxy [{#PROXY.NAME}]: Version'
              type: DEPENDENT
              key: 'zabbix.proxy.version[{#PROXY.NAME}]'
              value_type: CHAR
              description: 'A version of Zabbix proxy.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - $.version
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 12h
              master_item:
                key: 'zabbix.proxy.stats[{#PROXY.NAME}]'
              tags:
                - tag: component
                  value: proxy
                - tag: proxy-name
                  value: '{#PROXY.NAME}'
          master_item:
            key: zabbix.proxies.stats
          lld_macro_paths:
            - lld_macro: '{#PROXY.GROUP}'
              path: $.proxy_group
            - lld_macro: '{#PROXY.NAME}'
              path: $.name
          preprocessing:
            - type: JAVASCRIPT
              parameters:
                - |
                  var proxies = JSON.parse(value);
                  
                  result = proxies.map(function (proxy) {
                  	return {
                  		'name': proxy.name,
                  		'proxy_group': proxy.proxy_group
                  	};
                  });
                  
                  return JSON.stringify(result);
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
          overrides:
            - name: 'Tag proxy-group if exists'
              step: '1'
              filter:
                conditions:
                  - macro: '{#PROXY.GROUP}'
                    operator: EXISTS
              operations:
                - operator: REGEXP
                  tags:
                    - tag: proxy-group
                      value: '{#PROXY.GROUP}'
      tags:
        - tag: class
          value: software
        - tag: subclass
          value: logging
        - tag: subclass
          value: monitoring
        - tag: target
          value: server
        - tag: target
          value: zabbix
      macros:
        - macro: '{$ZABBIX.PROXY.LAST_SEEN.MAX}'
          value: '600'
          description: 'The maximum number of seconds that Zabbix proxy has not been seen.'
          config:
            type: TEXT
            priority: '3'
            section_name: Thresholds
            label: 'Seconds since the last Zabbix proxy seen'
            description: 'Threshold value of time since the last Zabbix proxy seen for triggers. No less than 0.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$ZABBIX.SERVER.ADDRESS}'
          description: 'IP/DNS of the remote Zabbix server (default is 127.0.0.1).'
          config:
            type: TEXT
            priority: '1'
            label: 'Zabbix server Address'
            description: 'IP or DNS of the remote Zabbix server that should be monitored via the Zabbix agent.'
            required: 'YES'
        - macro: '{$ZABBIX.SERVER.NODATA_TIMEOUT}'
          value: 5m
          description: 'The time threshold after which statistics are considered unavailable. Used in trigger expression.'
          config:
            type: TEXT
            priority: '4'
            section_name: Thresholds
            label: 'Time since the last statistic was received'
            description: 'Threshold value of time since the last statistic was received from the remote server.'
        - macro: '{$ZABBIX.SERVER.PORT}'
          description: 'Port of the remote Zabbix server (default is 10051).'
          config:
            type: TEXT
            priority: '2'
            label: 'Zabbix server Port'
            description: 'Port of the remote Zabbix server that should be monitored via the Zabbix agent. In the range from 1 to 65535 inclusive.'
            required: 'YES'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$ZABBIX.SERVER.UTIL.MAX}'
          value: '75'
          description: 'Default maximum threshold for percentage utilization triggers (use macro context for specification).'
          config:
            type: TEXT
            priority: '6'
            section_name: Thresholds
            label: 'Maximum process utilization percentage'
            description: 'Default maximum threshold for process utilization triggers. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$ZABBIX.SERVER.UTIL.MAX:"value cache"}'
          value: '95'
          description: 'Maximum threshold for value cache utilization triggers.'
          config:
            type: TEXT
            priority: '7'
            section_name: Thresholds
            label: 'Maximum value cache utilization percentage'
            description: 'Threshold for the value cache utilization trigger. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
        - macro: '{$ZABBIX.SERVER.UTIL.MIN}'
          value: '65'
          description: 'Default minimum threshold for percentage utilization triggers (use macro context for specification).'
          config:
            type: TEXT
            priority: '5'
            section_name: Thresholds
            label: 'Minimum process utilization percentage'
            description: 'Default minimum threshold for process utilization triggers. In the range from 0 to 100 inclusive.'
            regex: '^-?([0-9]+|(([0-9]+)\.([0-9]+)))$'
      dashboards:
        - uuid: 4903e2c2ba9240e18ecb4153cee44e4f
          name: 'Zabbix server health'
          auto_start: 'NO'
          pages:
            - name: Performance
              widgets:
                - type: svggraph
                  name: 'Cache usage, in %'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.2
                      value: e31a1c
                    - type: STRING
                      name: ds.0.color.3
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.4
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.5
                      value: b15928
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: wcache.trend.pused
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: rcache.buffer.pused
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: wcache.index.pused
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: wcache.history.pused
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: vcache.buffer.pused
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: vmware.buffer.pused
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACA
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Server performance'
                  'y': '6'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.1
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.2
                      value: e31a1c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: wcache.values
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: vps.written
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: 'zabbix.stats[{$ZABBIX.SERVER.ADDRESS},{$ZABBIX.SERVER.PORT},queue]'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACC
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Values processed'
                  'y': '11'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.2
                      value: e31a1c
                    - type: STRING
                      name: ds.0.color.3
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.4
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.5
                      value: b15928
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: wcache.values.uint
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: wcache.values.float
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: wcache.values.not_supported
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: wcache.values.str
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: wcache.values.log
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: wcache.values.text
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACD
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Value cache effectiveness'
                  'y': '16'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.1
                      value: e31a1c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: vcache.cache.hits
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: vcache.cache.misses
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACE
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Internal queues'
                  x: '36'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: ffca58
                    - type: STRING
                      name: ds.0.color.1
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.2
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.3
                      value: d62728
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: preprocessing_queue
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: lld_queue
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: discovery_queue
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: connector_queue
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACB
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Trend cache effectiveness, in %'
                  x: '36'
                  'y': '16'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: ffca58
                    - type: STRING
                      name: ds.0.color.1
                      value: e31a1c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: tcache.pitems
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: tcache.pmisses
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_lines_mode
                      value: '1'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAACF
                    - type: INTEGER
                      name: show_problems
                      value: '1'
            - name: Processes
              widgets:
                - type: svggraph
                  name: 'Utilization: LLD processes'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: ffca58
                    - type: STRING
                      name: ds.0.color.1
                      value: 7e57c2
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.lld_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.lld_worker.avg.busy
                    - type: INTEGER
                      name: ds.1.axisy
                      value: '1'
                    - type: STRING
                      name: ds.1.color.0
                      value: ff465c
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.1.fill
                      value: '2'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: lld_queue
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABI
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Preprocessing processes'
                  'y': '6'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: ffca58
                    - type: STRING
                      name: ds.0.color.1
                      value: 7e57c2
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.preprocessing_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.preprocessing_worker.avg.busy
                    - type: INTEGER
                      name: ds.1.axisy
                      value: '1'
                    - type: STRING
                      name: ds.1.color.0
                      value: ff465c
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: INTEGER
                      name: ds.1.fill
                      value: '2'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: preprocessing_queue
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABK
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Synchronous gathering processes'
                  'y': '12'
                  width: '72'
                  height: '7'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.2
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.3
                      value: b15928
                    - type: STRING
                      name: ds.0.color.4
                      value: 17becf
                    - type: STRING
                      name: ds.0.color.5
                      value: a6cee3
                    - type: STRING
                      name: ds.0.color.6
                      value: fb9a99
                    - type: STRING
                      name: ds.0.color.7
                      value: bcbd22
                    - type: STRING
                      name: ds.0.color.8
                      value: ffca58
                    - type: STRING
                      name: ds.0.color.9
                      value: e31a1c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.internal_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.ipmi_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.ipmi_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.http_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.java_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.6
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.vmware_collector.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.7
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.browser_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.8
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.odbc_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.9
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.icmp_pinger.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '10'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABM
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Asynchronous gathering processes'
                  'y': '19'
                  width: '72'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: bcbd22
                    - type: STRING
                      name: ds.0.color.2
                      value: 6a3d9a
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.agent_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.http_agent_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.snmp_poller.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABN
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Internal processes: Core'
                  'y': '25'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 1f78b4
                    - type: STRING
                      name: ds.0.color.1
                      value: 33a02c
                    - type: STRING
                      name: ds.0.color.2
                      value: e31a1c
                    - type: STRING
                      name: ds.0.color.3
                      value: ff7f00
                    - type: STRING
                      name: ds.0.color.4
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.5
                      value: b15928
                    - type: STRING
                      name: ds.0.color.6
                      value: a6cee3
                    - type: STRING
                      name: ds.0.color.7
                      value: ff465c
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.configuration_syncer.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.configuration_syncer_worker.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.history_syncer.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.self-monitoring.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.4
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.service_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.5
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.task_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.6
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.timer.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.7
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.history_poller.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '8'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABO
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Gathering processes: Trappers'
                  'y': '31'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: cab2d6
                    - type: STRING
                      name: ds.0.color.1
                      value: ffca58
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.trapper.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.snmp_trapper.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABQ
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Alerting processes'
                  'y': '36'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 17becf
                    - type: STRING
                      name: ds.0.color.1
                      value: bcbd22
                    - type: STRING
                      name: ds.0.color.2
                      value: d62728
                    - type: STRING
                      name: ds.0.color.3
                      value: ff7f00
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.alert_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.alert_syncer.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.alerter.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.3
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.escalator.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '4'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABS
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Proxy management and data exchange'
                  'y': '41'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: cab2d6
                    - type: STRING
                      name: ds.0.color.1
                      value: '000080'
                    - type: STRING
                      name: ds.0.color.2
                      value: '808000'
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.trapper.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.proxy_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.proxy_group_manager.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABU
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Preprocessing throughput'
                  'y': '46'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: '808000'
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: preprocessing_throughput
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABV
                - type: svggraph
                  name: 'Utilization: Discovery processes'
                  x: '36'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 7e57c2
                    - type: STRING
                      name: ds.0.color.1
                      value: 1f78b4
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.discovery_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.discovery_worker.avg.busy
                    - type: INTEGER
                      name: ds.1.axisy
                      value: '1'
                    - type: STRING
                      name: ds.1.color.0
                      value: ff465c
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: discovery_queue
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABJ
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Connector processes'
                  x: '36'
                  'y': '6'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: b2df8a
                    - type: STRING
                      name: ds.0.color.1
                      value: ffca58
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.connector_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.connector_worker.avg.busy
                    - type: INTEGER
                      name: ds.1.axisy
                      value: '1'
                    - type: STRING
                      name: ds.1.color.0
                      value: ff465c
                    - type: INTEGER
                      name: ds.1.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.1.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: connector_queue
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABL
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Internal processes: Housekeeping'
                  x: '36'
                  'y': '25'
                  width: '36'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: ffca58
                    - type: STRING
                      name: ds.0.color.1
                      value: cab2d6
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.housekeeper.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.trigger_housekeeper.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABP
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Availability processes'
                  x: '36'
                  'y': '31'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 6a3d9a
                    - type: STRING
                      name: ds.0.color.1
                      value: b15928
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.unreachable_poller.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.availability_manager.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABR
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Utilization: Reporting processes'
                  x: '36'
                  'y': '36'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: e377c2
                    - type: STRING
                      name: ds.0.color.1
                      value: ffdf00
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.report_manager.avg.busy
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: process.report_writer.avg.busy
                    - type: STRING
                      name: lefty_max
                      value: '100'
                    - type: STRING
                      name: lefty_min
                      value: '0'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAABT
                    - type: INTEGER
                      name: show_problems
                      value: '1'
            - name: Statuses
              widgets:
                - type: item
                  name: 'Zabbix server version'
                  width: '16'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'Zabbix server health by Zabbix agent active'
                        key: version
                    - type: INTEGER
                      name: show.0
                      value: '2'
                    - type: INTEGER
                      name: show.1
                      value: '3'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: time_h_pos
                      value: '2'
                    - type: INTEGER
                      name: time_size
                      value: '9'
                    - type: INTEGER
                      name: time_v_pos
                      value: '2'
                    - type: INTEGER
                      name: value_size
                      value: '25'
                - type: honeycomb
                  name: 'High availability: Node state'
                  x: '16'
                  width: '56'
                  height: '5'
                  fields:
                    - type: STRING
                      name: items.0
                      value: 'Cluster node [*]: Status'
                    - type: STRING
                      name: primary_label
                      value: '{{ITEM.NAME}.regsub("Cluster node \[(.*)]: Status","\1")}'
                    - type: STRING
                      name: reference
                      value: BAAAA
                    - type: INTEGER
                      name: secondary_label_decimal_places
                      value: '0'
                    - type: STRING
                      name: thresholds.0.color
                      value: b2df8a
                    - type: STRING
                      name: thresholds.0.threshold
                      value: '0'
                    - type: STRING
                      name: thresholds.1.color
                      value: '878787'
                    - type: STRING
                      name: thresholds.1.threshold
                      value: '1'
                    - type: STRING
                      name: thresholds.2.color
                      value: e31a1c
                    - type: STRING
                      name: thresholds.2.threshold
                      value: '2'
                    - type: STRING
                      name: thresholds.3.color
                      value: 33a02c
                    - type: STRING
                      name: thresholds.3.threshold
                      value: '3'
      valuemaps:
        - uuid: f1f6de972fbc4675bee0426bcb15838c
          name: 'Cluster node status'
          mappings:
            - value: '0'
              newvalue: Standby
            - value: '1'
              newvalue: Stopped
            - value: '2'
              newvalue: Unavailable
            - value: '3'
              newvalue: Active
        - uuid: 2e74275424ff4939a9f1a02424fcb42e
          name: Compatibility
          mappings:
            - value: '0'
              newvalue: Undefined
            - value: '1'
              newvalue: Current
            - value: '2'
              newvalue: Outdated
            - value: '3'
              newvalue: Unsupported
        - uuid: 2e9f0571bae14b6485ae5cb79f2cb3b3
          name: 'Last seen'
          mappings:
            - value: '-1'
              newvalue: Never
        - uuid: ae285f32e1884d75bd485ad08106ee9c
          name: 'Proxy mode'
          mappings:
            - value: '0'
              newvalue: Active
            - value: '1'
              newvalue: Passive
        - uuid: 2fa179c8f5f2482ca216270b91896e50
          name: 'Service state'
          mappings:
            - value: '0'
              newvalue: 'Off'
            - value: '1'
              newvalue: 'On'
        - uuid: a73ec20cb9e9412296b6d604505376da
          name: 'Value cache operating mode'
          mappings:
            - value: '0'
              newvalue: Normal
            - value: '1'
              newvalue: 'Low memory'
        - uuid: c2fbdc79f9614caf99aa266087a7317d
          name: 'Zabbix server check'
          mappings:
            - value: '0'
              newvalue: 'False'
            - value: '1'
              newvalue: 'True'
  triggers:
    - uuid: da703e83e2e146569c173fd9bc6988dd
      expression: '(between(last(/VMware Guest/vmware.vm.guest.osuptime[{$VMWARE.URL},{$VMWARE.VM.UUID}]),1,10m)=1 or between(last(/VMware Guest/vmware.vm.uptime[{$VMWARE.URL},{$VMWARE.VM.UUID}]),1,10m)=1) and last(/VMware Guest/vmware.vm.powerstate[{$VMWARE.URL},{$VMWARE.VM.UUID}]) = 1'
      name: 'VMware Guest: VM has been restarted'
      event_name: 'VMware Guest: VM has been restarted (uptime < 10m)'
      priority: WARNING
      description: 'Uptime is less than 10 minutes.'
      manual_close: 'YES'
      dependencies:
        - name: 'VMware Guest: Hypervisor is in the maintenance mode'
          expression: 'last(/VMware Guest/vmware.vm.hv.maintenance[{$VMWARE.URL},{$VMWARE.VM.UUID}])=1 and {$VMWARE.HYPERVISOR.MAINTENANCE}=1'
      tags:
        - tag: scope
          value: notice
  graphs:
    - uuid: a3998992f7504a12826e3c4d592836b5
      name: 'Apache: Requests per second'
      graph_items:
        - drawtype: GRADIENT_LINE
          color: 199C0D
          item:
            host: 'Apache by HTTP'
            key: apache.requests.rate
    - uuid: dfc5334e77ce45d286145cc08d036f38
      name: 'Apache: Requests per second'
      graph_items:
        - drawtype: GRADIENT_LINE
          color: 199C0D
          item:
            host: 'Apache by Zabbix agent'
            key: apache.requests.rate
    - uuid: 3461ebdbfb024405a8e8da6c3e970d0d
      name: 'Apache: Requests per second'
      graph_items:
        - drawtype: GRADIENT_LINE
          color: 199C0D
          item:
            host: 'Apache by Zabbix agent active'
            key: apache.requests.rate
    - uuid: 1629062b5cd74b67af9a60226a79f8f1
      name: 'Apache: Worker states'
      graph_items:
        - color: 199C0D
          item:
            host: 'Apache by HTTP'
            key: apache.workers.dnslookup
        - sortorder: '1'
          color: F63100
          item:
            host: 'Apache by HTTP'
            key: apache.workers.cleanup
        - sortorder: '2'
          color: 00611C
          item:
            host: 'Apache by HTTP'
            key: apache.workers.logging
        - sortorder: '3'
          color: F7941D
          item:
            host: 'Apache by HTTP'
            key: apache.workers.reading
        - sortorder: '4'
          color: FC6EA3
          item:
            host: 'Apache by HTTP'
            key: apache.workers.sending
        - sortorder: '5'
          color: 6C59DC
          item:
            host: 'Apache by HTTP'
            key: apache.workers.starting
        - sortorder: '6'
          color: C7A72D
          item:
            host: 'Apache by HTTP'
            key: apache.workers.closing
        - sortorder: '7'
          color: BA2A5D
          item:
            host: 'Apache by HTTP'
            key: apache.workers.finishing
        - sortorder: '8'
          color: F230E0
          item:
            host: 'Apache by HTTP'
            key: apache.workers.keepalive
        - sortorder: '9'
          color: 5CCD18
          item:
            host: 'Apache by HTTP'
            key: apache.workers.slot
        - sortorder: '10'
          color: BB2A02
          item:
            host: 'Apache by HTTP'
            key: apache.workers.waiting
    - uuid: 6f646e8c11b04e8a835b81bc17824593
      name: 'Apache: Worker states'
      graph_items:
        - color: 199C0D
          item:
            host: 'Apache by Zabbix agent'
            key: apache.workers.dnslookup
        - sortorder: '1'
          color: F63100
          item:
            host: 'Apache by Zabbix agent'
            key: apache.workers.cleanup
        - sortorder: '2'
          color: 00611C
          item:
            host: 'Apache by Zabbix agent'
            key: apache.workers.logging
        - sortorder: '3'
          color: F7941D
          item:
            host: 'Apache by Zabbix agent'
            key: apache.workers.reading
        - sortorder: '4'
          color: FC6EA3
          item:
            host: 'Apache by Zabbix agent'
            key: apache.workers.sending
        - sortorder: '5'
          color: 6C59DC
          item:
            host: 'Apache by Zabbix agent'
            key: apache.workers.starting
        - sortorder: '6'
          color: C7A72D
          item:
            host: 'Apache by Zabbix agent'
            key: apache.workers.closing
        - sortorder: '7'
          color: BA2A5D
          item:
            host: 'Apache by Zabbix agent'
            key: apache.workers.finishing
        - sortorder: '8'
          color: F230E0
          item:
            host: 'Apache by Zabbix agent'
            key: apache.workers.keepalive
        - sortorder: '9'
          color: 5CCD18
          item:
            host: 'Apache by Zabbix agent'
            key: apache.workers.slot
        - sortorder: '10'
          color: BB2A02
          item:
            host: 'Apache by Zabbix agent'
            key: apache.workers.waiting
    - uuid: 0183d7d9c05843b19db5b4ba94f99350
      name: 'Apache: Worker states'
      graph_items:
        - color: 199C0D
          item:
            host: 'Apache by Zabbix agent active'
            key: apache.workers.dnslookup
        - sortorder: '1'
          color: F63100
          item:
            host: 'Apache by Zabbix agent active'
            key: apache.workers.cleanup
        - sortorder: '2'
          color: 00611C
          item:
            host: 'Apache by Zabbix agent active'
            key: apache.workers.logging
        - sortorder: '3'
          color: F7941D
          item:
            host: 'Apache by Zabbix agent active'
            key: apache.workers.reading
        - sortorder: '4'
          color: FC6EA3
          item:
            host: 'Apache by Zabbix agent active'
            key: apache.workers.sending
        - sortorder: '5'
          color: 6C59DC
          item:
            host: 'Apache by Zabbix agent active'
            key: apache.workers.starting
        - sortorder: '6'
          color: C7A72D
          item:
            host: 'Apache by Zabbix agent active'
            key: apache.workers.closing
        - sortorder: '7'
          color: BA2A5D
          item:
            host: 'Apache by Zabbix agent active'
            key: apache.workers.finishing
        - sortorder: '8'
          color: F230E0
          item:
            host: 'Apache by Zabbix agent active'
            key: apache.workers.keepalive
        - sortorder: '9'
          color: 5CCD18
          item:
            host: 'Apache by Zabbix agent active'
            key: apache.workers.slot
        - sortorder: '10'
          color: BB2A02
          item:
            host: 'Apache by Zabbix agent active'
            key: apache.workers.waiting
    - uuid: 78e59f1b5eb747019f92921ac5ef48b0
      name: 'Apache: Workers total'
      type: STACKED
      graph_items:
        - color: 199C0D
          item:
            host: 'Apache by HTTP'
            key: apache.workers_total.busy
        - sortorder: '1'
          color: F63100
          item:
            host: 'Apache by HTTP'
            key: apache.workers_total.idle
    - uuid: 121c2d4feb0b4b53b027f1566107ab29
      name: 'Apache: Workers total'
      type: STACKED
      graph_items:
        - color: 199C0D
          item:
            host: 'Apache by Zabbix agent'
            key: apache.workers_total.busy
        - sortorder: '1'
          color: F63100
          item:
            host: 'Apache by Zabbix agent'
            key: apache.workers_total.idle
    - uuid: c82c849b07564ca29e58df3b984c1da9
      name: 'Apache: Workers total'
      type: STACKED
      graph_items:
        - color: 199C0D
          item:
            host: 'Apache by Zabbix agent active'
            key: apache.workers_total.busy
        - sortorder: '1'
          color: F63100
          item:
            host: 'Apache by Zabbix agent active'
            key: apache.workers_total.idle
    - uuid: 749ed49ec625449db0a345d639f7d8fd
      name: 'Kubernetes API: HTTP requests rate'
      graph_items:
        - color: 199C0D
          item:
            host: 'Kubernetes API server by HTTP'
            key: kubernetes.api.apiserver_request_total_200.rate
        - sortorder: '1'
          color: F63100
          item:
            host: 'Kubernetes API server by HTTP'
            key: kubernetes.api.rest_client_requests_total_200.rate
        - sortorder: '2'
          color: 00611C
          item:
            host: 'Kubernetes API server by HTTP'
            key: kubernetes.api.apiserver_request_total_300.rate
        - sortorder: '3'
          color: F7941D
          item:
            host: 'Kubernetes API server by HTTP'
            key: kubernetes.api.rest_client_requests_total_300.rate
        - sortorder: '4'
          color: FC6EA3
          item:
            host: 'Kubernetes API server by HTTP'
            key: kubernetes.api.apiserver_request_total_400.rate
        - sortorder: '5'
          color: 6C59DC
          item:
            host: 'Kubernetes API server by HTTP'
            key: kubernetes.api.rest_client_requests_total_400.rate
        - sortorder: '6'
          color: C7A72D
          item:
            host: 'Kubernetes API server by HTTP'
            key: kubernetes.api.apiserver_request_total_500.rate
        - sortorder: '7'
          color: BA2A5D
          item:
            host: 'Kubernetes API server by HTTP'
            key: kubernetes.api.rest_client_requests_total_500.rate
        - sortorder: '8'
          color: F230E0
          item:
            host: 'Kubernetes API server by HTTP'
            key: kubernetes.api.apiserver_request_total_0.rate
    - uuid: 23af35d1d9af40e2ace1915ab8df7eec
      name: 'Kubernetes Controller Manager: Memory usage'
      graph_items:
        - color: 199C0D
          item:
            host: 'Kubernetes Controller manager by HTTP'
            key: kubernetes.controller.process_virtual_memory_bytes
        - sortorder: '1'
          color: F63100
          item:
            host: 'Kubernetes Controller manager by HTTP'
            key: kubernetes.controller.process_resident_memory_bytes
    - uuid: 908af34b10044af9b028e5e024eb89b3
      name: 'Kubernetes Controller Manager: REST Client query rate'
      graph_items:
        - color: 199C0D
          item:
            host: 'Kubernetes Controller manager by HTTP'
            key: kubernetes.controller.client_http_requests_500.rate
        - sortorder: '1'
          color: F63100
          item:
            host: 'Kubernetes Controller manager by HTTP'
            key: kubernetes.controller.client_http_requests_400.rate
        - sortorder: '2'
          color: 00611C
          item:
            host: 'Kubernetes Controller manager by HTTP'
            key: kubernetes.controller.client_http_requests_300.rate
        - sortorder: '3'
          color: F7941D
          item:
            host: 'Kubernetes Controller manager by HTTP'
            key: kubernetes.controller.client_http_requests_200.rate
    - uuid: dd98f209541449f4a476718c46a0e721
      name: 'Kubernetes Scheduler: Memory usage'
      graph_items:
        - color: 199C0D
          item:
            host: 'Kubernetes Scheduler by HTTP'
            key: kubernetes.scheduler.process_virtual_memory_bytes
        - sortorder: '1'
          color: F63100
          item:
            host: 'Kubernetes Scheduler by HTTP'
            key: kubernetes.scheduler.process_resident_memory_bytes
    - uuid: fd57f67690424eb6a2e5bee610c305ad
      name: 'Kubernetes Scheduler: REST Client query rate'
      graph_items:
        - color: 199C0D
          item:
            host: 'Kubernetes Scheduler by HTTP'
            key: kubernetes.scheduler.client_http_requests_500.rate
        - sortorder: '1'
          color: F63100
          item:
            host: 'Kubernetes Scheduler by HTTP'
            key: kubernetes.scheduler.client_http_requests_400.rate
        - sortorder: '2'
          color: 00611C
          item:
            host: 'Kubernetes Scheduler by HTTP'
            key: kubernetes.scheduler.client_http_requests_300.rate
        - sortorder: '3'
          color: F7941D
          item:
            host: 'Kubernetes Scheduler by HTTP'
            key: kubernetes.scheduler.client_http_requests_200.rate
    - uuid: 4ee3ca9852a2440ea100e21291ac9103
      name: 'Kubernetes Scheduler: Scheduling attempts rate'
      graph_items:
        - color: 199C0D
          item:
            host: 'Kubernetes Scheduler by HTTP'
            key: kubernetes.scheduler.scheduler_schedule_attempts.scheduled.rate
        - sortorder: '1'
          color: F63100
          item:
            host: 'Kubernetes Scheduler by HTTP'
            key: kubernetes.scheduler.scheduler_schedule_attempts.unschedulable.rate
        - sortorder: '2'
          color: 00611C
          item:
            host: 'Kubernetes Scheduler by HTTP'
            key: kubernetes.scheduler.scheduler_schedule_attempts.error.rate
    - uuid: aedcbacee74f4b0c861546c56e0fa9ab
      name: 'Nginx: Connections by state'
      graph_items:
        - drawtype: BOLD_LINE
          color: 199C0D
          item:
            host: 'Nginx by HTTP'
            key: nginx.connections.active
        - sortorder: '1'
          color: F63100
          item:
            host: 'Nginx by HTTP'
            key: nginx.connections.waiting
        - sortorder: '2'
          color: 00611C
          item:
            host: 'Nginx by HTTP'
            key: nginx.connections.writing
        - sortorder: '3'
          color: F7941D
          item:
            host: 'Nginx by HTTP'
            key: nginx.connections.reading
    - uuid: ba234158aeca468a8592d944f9aae691
      name: 'Nginx: Connections by state'
      graph_items:
        - drawtype: BOLD_LINE
          color: 199C0D
          item:
            host: 'Nginx by Zabbix agent'
            key: nginx.connections.active
        - sortorder: '1'
          color: F63100
          item:
            host: 'Nginx by Zabbix agent'
            key: nginx.connections.waiting
        - sortorder: '2'
          color: 00611C
          item:
            host: 'Nginx by Zabbix agent'
            key: nginx.connections.writing
        - sortorder: '3'
          color: F7941D
          item:
            host: 'Nginx by Zabbix agent'
            key: nginx.connections.reading
    - uuid: 5321b82a5beb4688b29f369acd0191c1
      name: 'Nginx: Connections by state'
      graph_items:
        - drawtype: BOLD_LINE
          color: 199C0D
          item:
            host: 'Nginx by Zabbix agent active'
            key: nginx.connections.active
        - sortorder: '1'
          color: F63100
          item:
            host: 'Nginx by Zabbix agent active'
            key: nginx.connections.waiting
        - sortorder: '2'
          color: 00611C
          item:
            host: 'Nginx by Zabbix agent active'
            key: nginx.connections.writing
        - sortorder: '3'
          color: F7941D
          item:
            host: 'Nginx by Zabbix agent active'
            key: nginx.connections.reading
    - uuid: 6feb26e5eb3246c0adb8d151b1443859
      name: 'Nginx: Connections per second'
      graph_items:
        - color: 199C0D
          item:
            host: 'Nginx by HTTP'
            key: nginx.connections.accepted.rate
        - sortorder: '1'
          color: F63100
          item:
            host: 'Nginx by HTTP'
            key: nginx.connections.handled.rate
        - sortorder: '2'
          color: 00611C
          item:
            host: 'Nginx by HTTP'
            key: nginx.connections.dropped.rate
    - uuid: b82a5b89864a47638421458f3e74563d
      name: 'Nginx: Connections per second'
      graph_items:
        - color: 199C0D
          item:
            host: 'Nginx by Zabbix agent'
            key: nginx.connections.accepted.rate
        - sortorder: '1'
          color: F63100
          item:
            host: 'Nginx by Zabbix agent'
            key: nginx.connections.handled.rate
        - sortorder: '2'
          color: 00611C
          item:
            host: 'Nginx by Zabbix agent'
            key: nginx.connections.dropped.rate
    - uuid: 993c7b78c337451992a048be7ed028e4
      name: 'Nginx: Connections per second'
      graph_items:
        - color: 199C0D
          item:
            host: 'Nginx by Zabbix agent active'
            key: nginx.connections.accepted.rate
        - sortorder: '1'
          color: F63100
          item:
            host: 'Nginx by Zabbix agent active'
            key: nginx.connections.handled.rate
        - sortorder: '2'
          color: 00611C
          item:
            host: 'Nginx by Zabbix agent active'
            key: nginx.connections.dropped.rate
    - uuid: 43a87936b35d4d28a658f810c2162a72
      name: 'Nginx: Requests per second'
      graph_items:
        - drawtype: GRADIENT_LINE
          color: 199C0D
          item:
            host: 'Nginx by HTTP'
            key: nginx.requests.total.rate
    - uuid: a2d2fec823514df09731381304c245e9
      name: 'Nginx: Requests per second'
      graph_items:
        - drawtype: GRADIENT_LINE
          color: 199C0D
          item:
            host: 'Nginx by Zabbix agent'
            key: nginx.requests.total.rate
    - uuid: d22b45b11f2746ae8a26b54417a67424
      name: 'Nginx: Requests per second'
      graph_items:
        - drawtype: GRADIENT_LINE
          color: 199C0D
          item:
            host: 'Nginx by Zabbix agent active'
            key: nginx.requests.total.rate
